@@ -23,7 +23,6 @@ package org.ojalgo.array;
 
 import java.math.BigDecimal;
 import java.util.AbstractList;
-import java.util.List;
 import java.util.RandomAccess;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ForkJoinPool;
@@ -55,10 +54,9 @@ import org.ojalgo.type.math.MathType;
  * @author apete
  */
 public final class Array1D<N extends Comparable<N>> extends AbstractList<N> implements Access1D.Visitable<N>, Access1D.Aggregatable<N>, Access1D.Sliceable<N>,
-        Access1D.Collectable<N, Mutate1D>, Mutate1D.ModifiableReceiver<N>, Mutate1D.Mixable<N>, Mutate1D.Sortable, RandomAccess {
+        Access1D.Collectable<N, Mutate1D>, Mutate1D.ModifiableReceiver<N>, Mutate1D.Mixable<N>, Mutate1D.Sortable, RandomAccess, Factory1D.Builder<Array1D<N>> {
 
-    public static final class Factory<N extends Comparable<N>>
-            implements Factory1D.Dense<Array1D<N>>, Factory1D.MayBeSparse<Array1D<N>, Array1D<N>, Array1D<N>> {
+    public static final class Factory<N extends Comparable<N>> implements Factory1D.MayBeSparse<Array1D<N>, Array1D<N>, Array1D<N>> {
 
         private final BasicArray.Factory<N> myDelegate;
 
@@ -69,22 +67,9 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
 
         @Override
         public Array1D<N> copy(final Access1D<?> source) {
-            return myDelegate.copy(source).wrapInArray1D();
-        }
-
-        @Override
-        public Array1D<N> copy(final Comparable<?>[] source) {
-            return myDelegate.copy(source).wrapInArray1D();
-        }
-
-        @Override
-        public Array1D<N> copy(final double... source) {
-            return myDelegate.copy(source).wrapInArray1D();
-        }
-
-        @Override
-        public Array1D<N> copy(final List<? extends Comparable<?>> source) {
-            return myDelegate.copy(source).wrapInArray1D();
+            BasicArray<N> basic = myDelegate.make(source.count());
+            basic.fillMatching(source);
+            return basic.wrapInArray1D();
         }
 
         @Override
@@ -98,22 +83,29 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
         }
 
         @Override
-        public Array1D<N> make(final long count) {
-            return this.makeDense(count);
+        public Array1D<N> make(final int size) {
+            return this.newDenseBuilder(size);
         }
 
         @Override
-        public Array1D<N> makeDense(final long count) {
-            return myDelegate.makeToBeFilled(count).wrapInArray1D();
+        public Array1D<N> make(final long count) {
+            return this.newDenseBuilder(count);
         }
 
         @Override
         public Array1D<N> makeFilled(final long count, final NullaryFunction<?> supplier) {
-            return myDelegate.makeFilled(count, supplier).wrapInArray1D();
+            BasicArray<N> basic = myDelegate.make(count);
+            basic.fillAll(supplier);
+            return basic.wrapInArray1D();
         }
 
         @Override
-        public Array1D<N> makeSparse(final long count) {
+        public Array1D<N> newDenseBuilder(final long count) {
+            return myDelegate.makeToBeFilled(count).wrapInArray1D();
+        }
+
+        @Override
+        public Array1D<N> newSparseBuilder(final long count) {
             return myDelegate.makeStructuredZero(count).wrapInArray1D();
         }
 
@@ -258,53 +250,13 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
 
     }
 
+    public static final Factory<ComplexNumber> C128 = Array1D.factory(ArrayC128.FACTORY);
+    public static final Factory<Quaternion> H256 = Array1D.factory(ArrayH256.FACTORY);
+    public static final Factory<RationalNumber> Q128 = Array1D.factory(ArrayQ128.FACTORY);
     public static final Factory<Double> R032 = Array1D.factory(ArrayR032.FACTORY);
     public static final Factory<Double> R064 = Array1D.factory(ArrayR064.FACTORY);
     public static final Factory<Quadruple> R128 = Array1D.factory(ArrayR128.FACTORY);
     public static final Factory<BigDecimal> R256 = Array1D.factory(ArrayR256.FACTORY);
-    /**
-     * @deprecated v52 Use {@link #R256} instead
-     */
-    @Deprecated
-    public static final Factory<BigDecimal> BIG = R256;
-    public static final Factory<ComplexNumber> C128 = Array1D.factory(ArrayC128.FACTORY);
-    /**
-     * @deprecated v52 Use {@link #C128} instead
-     */
-    @Deprecated
-    public static final Factory<ComplexNumber> COMPLEX = C128;
-    /**
-     * @deprecated v52 Use {@link #factory(DenseArray.Factory)} instead
-     */
-    @Deprecated
-    public static final Factory<Double> DIRECT32 = Array1D.factory(BufferArray.DIRECT32);
-    /**
-     * @deprecated v52 Use {@link #factory(DenseArray.Factory)} instead
-     */
-    @Deprecated
-    public static final Factory<Double> DIRECT64 = Array1D.factory(BufferArray.DIRECT64);
-    public static final Factory<Quaternion> H256 = Array1D.factory(ArrayH256.FACTORY);
-    /**
-     * @deprecated v52 Use {@link #R032} instead
-     */
-    @Deprecated
-    public static final Factory<Double> PRIMITIVE32 = R032;
-    /**
-     * @deprecated v52 Use {@link #R064} instead
-     */
-    @Deprecated
-    public static final Factory<Double> PRIMITIVE64 = R064;
-    public static final Factory<RationalNumber> Q128 = Array1D.factory(ArrayQ128.FACTORY);
-    /**
-     * @deprecated v52 Use {@link #H256} instead
-     */
-    @Deprecated
-    public static final Factory<Quaternion> QUATERNION = H256;
-    /**
-     * @deprecated v52 Use {@link #Q128} instead
-     */
-    @Deprecated
-    public static final Factory<RationalNumber> RATIONAL = Q128;
     public static final Factory<Double> Z008 = Array1D.factory(ArrayZ008.FACTORY);
     public static final Factory<Double> Z016 = Array1D.factory(ArrayZ016.FACTORY);
     public static final Factory<Double> Z032 = Array1D.factory(ArrayZ032.FACTORY);
@@ -380,6 +332,11 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
         return visitor.get();
     }
 
+    @Override
+    public Array1D<N> build() {
+        return this;
+    }
+
     @Override
     public byte byteValue(final int index) {
         return myDelegate.byteValue(this.convert(index));
@@ -447,21 +404,6 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
         myDelegate.fill(myFirst, myLimit, myStep, supplier);
     }
 
-    @Override
-    public void fillOne(final long index, final Access1D<?> values, final long valueIndex) {
-        myDelegate.fillOne(this.convert(index), values, valueIndex);
-    }
-
-    @Override
-    public void fillOne(final long index, final N value) {
-        myDelegate.fillOne(this.convert(index), value);
-    }
-
-    @Override
-    public void fillOne(final long index, final NullaryFunction<?> supplier) {
-        myDelegate.fillOne(this.convert(index), supplier);
-    }
-
     @Override
     public void fillRange(final long first, final long limit, final N value) {
         myDelegate.fill(this.convert(first), this.convert(limit), myStep, value);
@@ -823,6 +765,35 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
         }
     }
 
+    Factory1D<Array1D<N>> factory() {
+
+        return new Factory1D<>() {
+
+            ArrayFactory<N, ?> delegate = myDelegate.factory();
+
+            public FunctionSet<?> function() {
+                return delegate.function();
+            }
+
+            public MathType getMathType() {
+                return delegate.getMathType();
+            }
+
+            public Array1D<N> make(final int size) {
+                return this.make((long) size);
+            }
+
+            public Array1D<N> make(final long count) {
+                return delegate.make(count).wrapInArray1D();
+            }
+
+            public Scalar.Factory<?> scalar() {
+                return delegate.scalar();
+            }
+
+        };
+    }
+
     BasicArray<N> getDelegate() {
         return myDelegate;
     }
