@@ -22,7 +22,6 @@
 package org.ojalgo.array;
 
 import java.math.BigDecimal;
-import java.util.List;
 
 import org.ojalgo.ProgrammingError;
 import org.ojalgo.function.BinaryFunction;
@@ -51,11 +50,11 @@ import org.ojalgo.type.math.MathType;
  *
  * @author apete
  */
-public final class Array2D<N extends Comparable<N>> implements Access2D.Visitable<N>, Access2D.Aggregatable<N>, Access2D.Sliceable<N>,
-        Structure2D.ReducibleTo1D<Array1D<N>>, Access2D.Collectable<N, Mutate2D>, Mutate2D.ModifiableReceiver<N>, Mutate2D.Mixable<N>, Structure2D.Reshapable {
+public final class Array2D<N extends Comparable<N>>
+        implements Access2D.Visitable<N>, Access2D.Aggregatable<N>, Access2D.Sliceable<N>, Structure2D.ReducibleTo1D<Array1D<N>>,
+        Access2D.Collectable<N, Mutate2D>, Mutate2D.ModifiableReceiver<N>, Mutate2D.Mixable<N>, Structure2D.Reshapable, Factory2D.Builder<Array2D<N>> {
 
-    public static final class Factory<N extends Comparable<N>>
-            implements Factory2D.Dense<Array2D<N>>, Factory2D.MayBeSparse<Array2D<N>, Array2D<N>, Array2D<N>> {
+    public static final class Factory<N extends Comparable<N>> implements Factory2D.MayBeSparse<Array2D<N>, Array2D<N>, Array2D<N>> {
 
         private final BasicArray.Factory<N> myDelegate;
 
@@ -64,95 +63,11 @@ public final class Array2D<N extends Comparable<N>> implements Access2D.Visitabl
             myDelegate = new BasicArray.Factory<>(denseArray);
         }
 
-        @Override
-        public Array2D<N> columns(final Access1D<?>... source) {
-
-            int tmpColumns = source.length;
-            long tmpRows = source[0].count();
-
-            BasicArray<N> tmpDelegate = myDelegate.makeToBeFilled(tmpRows, tmpColumns);
-
-            if (tmpDelegate.isPrimitive()) {
-                long tmpIndex = 0L;
-                for (int j = 0; j < tmpColumns; j++) {
-                    Access1D<?> tmpColumn = source[j];
-                    for (long i = 0L; i < tmpRows; i++) {
-                        tmpDelegate.set(tmpIndex++, tmpColumn.doubleValue(i));
-                    }
-                }
-            } else {
-                long tmpIndex = 0L;
-                for (int j = 0; j < tmpColumns; j++) {
-                    Access1D<?> tmpColumn = source[j];
-                    for (long i = 0L; i < tmpRows; i++) {
-                        tmpDelegate.set(tmpIndex++, tmpColumn.get(i));
-                    }
-                }
-            }
-
-            return tmpDelegate.wrapInArray2D(tmpRows);
-        }
-
-        @Override
-        public Array2D<N> columns(final Comparable<?>[]... source) {
-
-            int tmpColumns = source.length;
-            int tmpRows = source[0].length;
-
-            BasicArray<N> tmpDelegate = myDelegate.makeToBeFilled(tmpRows, tmpColumns);
-
-            long tmpIndex = 0L;
-            for (int j = 0; j < tmpColumns; j++) {
-                Comparable<?>[] tmpColumn = source[j];
-                for (int i = 0; i < tmpRows; i++) {
-                    tmpDelegate.set(tmpIndex++, tmpColumn[i]);
-                }
-            }
-
-            return tmpDelegate.wrapInArray2D(tmpRows);
-        }
-
-        @Override
-        public Array2D<N> columns(final double[]... source) {
-
-            int tmpColumns = source.length;
-            int tmpRows = source[0].length;
-
-            BasicArray<N> tmpDelegate = myDelegate.makeToBeFilled(tmpRows, tmpColumns);
-
-            long tmpIndex = 0L;
-            for (int j = 0; j < tmpColumns; j++) {
-                double[] tmpColumn = source[j];
-                for (int i = 0; i < tmpRows; i++) {
-                    tmpDelegate.set(tmpIndex++, tmpColumn[i]);
-                }
-            }
-
-            return tmpDelegate.wrapInArray2D(tmpRows);
-        }
-
-        @Override
-        public Array2D<N> columns(final List<? extends Comparable<?>>... source) {
-
-            int tmpColumns = source.length;
-            int tmpRows = source[0].size();
-
-            BasicArray<N> tmpDelegate = myDelegate.makeToBeFilled(tmpRows, tmpColumns);
-
-            long tmpIndex = 0L;
-            for (int j = 0; j < tmpColumns; j++) {
-                List<? extends Comparable<?>> tmpColumn = source[j];
-                for (int i = 0; i < tmpRows; i++) {
-                    tmpDelegate.set(tmpIndex++, tmpColumn.get(i));
-                }
-            }
-
-            return tmpDelegate.wrapInArray2D(tmpRows);
-        }
-
         @Override
         public Array2D<N> copy(final Access2D<?> source) {
-            return myDelegate.copy(source).wrapInArray2D(source.countRows());
+            BasicArray<N> basic = myDelegate.make(source.count());
+            basic.fillMatching(source);
+            return basic.wrapInArray2D(source.countRows());
         }
 
         @Override
@@ -166,114 +81,30 @@ public final class Array2D<N extends Comparable<N>> implements Access2D.Visitabl
         }
 
         @Override
-        public Array2D<N> make(final long rows, final long columns) {
-            return this.makeDense(rows, columns);
+        public Array2D<N> make(final int nbRows, final int nbCols) {
+            return this.newDenseBuilder(nbRows, nbCols);
         }
 
         @Override
-        public Array2D<N> makeDense(final long rows, final long columns) {
-            return myDelegate.makeToBeFilled(rows, columns).wrapInArray2D(rows);
+        public Array2D<N> make(final long nbRows, final long nbCols) {
+            return this.newDenseBuilder(nbRows, nbCols);
         }
 
         @Override
         public Array2D<N> makeFilled(final long rows, final long columns, final NullaryFunction<?> supplier) {
-
-            BasicArray<N> tmpDelegate = myDelegate.makeToBeFilled(rows, columns);
-
-            long tmpIndex = 0L;
-            for (long j = 0L; j < columns; j++) {
-                for (long i = 0L; i < rows; i++) {
-                    tmpDelegate.set(tmpIndex++, supplier.get());
-                }
-            }
-
-            return tmpDelegate.wrapInArray2D(rows);
+            BasicArray<N> basic = myDelegate.makeToBeFilled(rows, columns);
+            basic.fillAll(supplier);
+            return basic.wrapInArray2D(rows);
         }
 
         @Override
-        public Array2D<N> makeSparse(final long rows, final long columns) {
-            return myDelegate.makeStructuredZero(rows, columns).wrapInArray2D(rows);
+        public Array2D<N> newDenseBuilder(final long nbRows, final long nbCols) {
+            return myDelegate.makeToBeFilled(nbRows, nbCols).wrapInArray2D(nbRows);
         }
 
         @Override
-        public Array2D<N> rows(final Access1D<?>... source) {
-
-            int tmpRows = source.length;
-            long tmpColumns = source[0].count();
-
-            BasicArray<N> tmpDelegate = myDelegate.makeToBeFilled(tmpRows, tmpColumns);
-
-            if (tmpDelegate.isPrimitive()) {
-                for (int i = 0; i < tmpRows; i++) {
-                    Access1D<?> tmpRow = source[i];
-                    for (long j = 0L; j < tmpColumns; j++) {
-                        tmpDelegate.set(Structure2D.index(tmpRows, i, j), tmpRow.doubleValue(j));
-                    }
-                }
-            } else {
-                for (int i = 0; i < tmpRows; i++) {
-                    Access1D<?> tmpRow = source[i];
-                    for (long j = 0L; j < tmpColumns; j++) {
-                        tmpDelegate.set(Structure2D.index(tmpRows, i, j), tmpRow.get(j));
-                    }
-                }
-            }
-
-            return tmpDelegate.wrapInArray2D(tmpRows);
-        }
-
-        @Override
-        public Array2D<N> rows(final Comparable<?>[]... source) {
-
-            int tmpRows = source.length;
-            int tmpColumns = source[0].length;
-
-            BasicArray<N> tmpDelegate = myDelegate.makeToBeFilled(tmpRows, tmpColumns);
-
-            for (int i = 0; i < tmpRows; i++) {
-                Comparable<?>[] tmpRow = source[i];
-                for (int j = 0; j < tmpColumns; j++) {
-                    tmpDelegate.set(Structure2D.index(tmpRows, i, j), tmpRow[j]);
-                }
-            }
-
-            return tmpDelegate.wrapInArray2D(tmpRows);
-        }
-
-        @Override
-        public Array2D<N> rows(final double[]... source) {
-
-            int tmpRows = source.length;
-            int tmpColumns = source[0].length;
-
-            BasicArray<N> tmpDelegate = myDelegate.makeToBeFilled(tmpRows, tmpColumns);
-
-            for (int i = 0; i < tmpRows; i++) {
-                double[] tmpRow = source[i];
-                for (int j = 0; j < tmpColumns; j++) {
-                    tmpDelegate.set(Structure2D.index(tmpRows, i, j), tmpRow[j]);
-                }
-            }
-
-            return tmpDelegate.wrapInArray2D(tmpRows);
-        }
-
-        @Override
-        public Array2D<N> rows(final List<? extends Comparable<?>>... source) {
-
-            int tmpRows = source.length;
-            int tmpColumns = source[0].size();
-
-            BasicArray<N> tmpDelegate = myDelegate.makeToBeFilled(tmpRows, tmpColumns);
-
-            for (int i = 0; i < tmpRows; i++) {
-                List<? extends Comparable<?>> tmpRow = source[i];
-                for (int j = 0; j < tmpColumns; j++) {
-                    tmpDelegate.set(Structure2D.index(tmpRows, i, j), tmpRow.get(j));
-                }
-            }
-
-            return tmpDelegate.wrapInArray2D(tmpRows);
+        public Array2D<N> newSparseBuilder(final long nbRows, final long nbCols) {
+            return myDelegate.makeStructuredZero(nbRows, nbCols).wrapInArray2D(nbRows);
         }
 
         @Override
@@ -287,53 +118,13 @@ public final class Array2D<N extends Comparable<N>> implements Access2D.Visitabl
 
     }
 
+    public static final Factory<ComplexNumber> C128 = Array2D.factory(ArrayC128.FACTORY);
+    public static final Factory<Quaternion> H256 = Array2D.factory(ArrayH256.FACTORY);
+    public static final Factory<RationalNumber> Q128 = Array2D.factory(ArrayQ128.FACTORY);
     public static final Factory<Double> R032 = Array2D.factory(ArrayR032.FACTORY);
     public static final Factory<Double> R064 = Array2D.factory(ArrayR064.FACTORY);
     public static final Factory<Quadruple> R128 = Array2D.factory(ArrayR128.FACTORY);
     public static final Factory<BigDecimal> R256 = Array2D.factory(ArrayR256.FACTORY);
-    /**
-     * @deprecated v52 Use {@link #R256} instead
-     */
-    @Deprecated
-    public static final Factory<BigDecimal> BIG = R256;
-    public static final Factory<ComplexNumber> C128 = Array2D.factory(ArrayC128.FACTORY);
-    /**
-     * @deprecated v52 Use {@link #C128} instead
-     */
-    @Deprecated
-    public static final Factory<ComplexNumber> COMPLEX = C128;
-    /**
-     * @deprecated v52 Use {@link #factory(DenseArray.Factory)} instead
-     */
-    @Deprecated
-    public static final Factory<Double> DIRECT32 = Array2D.factory(BufferArray.DIRECT32);
-    /**
-     * @deprecated v52 Use {@link #factory(DenseArray.Factory)} instead
-     */
-    @Deprecated
-    public static final Factory<Double> DIRECT64 = Array2D.factory(BufferArray.DIRECT64);
-    public static final Factory<Quaternion> H256 = Array2D.factory(ArrayH256.FACTORY);
-    /**
-     * @deprecated v52 Use {@link #R032} instead
-     */
-    @Deprecated
-    public static final Factory<Double> PRIMITIVE32 = R032;
-    /**
-     * @deprecated v52 Use {@link #R064} instead
-     */
-    @Deprecated
-    public static final Factory<Double> PRIMITIVE64 = R064;
-    public static final Factory<RationalNumber> Q128 = Array2D.factory(ArrayQ128.FACTORY);
-    /**
-     * @deprecated v52 Use {@link #H256} instead
-     */
-    @Deprecated
-    public static final Factory<Quaternion> QUATERNION = H256;
-    /**
-     * @deprecated v52 Use {@link #Q128} instead
-     */
-    @Deprecated
-    public static final Factory<RationalNumber> RATIONAL = Q128;
     public static final Factory<Double> Z008 = Array2D.factory(ArrayZ008.FACTORY);
     public static final Factory<Double> Z016 = Array2D.factory(ArrayZ016.FACTORY);
     public static final Factory<Double> Z032 = Array2D.factory(ArrayZ032.FACTORY);
@@ -455,6 +246,11 @@ public final class Array2D<N extends Comparable<N>> implements Access2D.Visitabl
         return visitor.get();
     }
 
+    @Override
+    public Array2D<N> build() {
+        return this;
+    }
+
     @Override
     public byte byteValue(final int index) {
         return myDelegate.byteValue(index);
@@ -564,7 +360,7 @@ public final class Array2D<N extends Comparable<N>> implements Access2D.Visitabl
             }
         } else {
             for (long i = 0L; i < limit; i++) {
-                this.fillOne(offset + i, values.get(i));
+                this.set(offset + i, values.get(i));
             }
         }
     }
@@ -591,36 +387,6 @@ public final class Array2D<N extends Comparable<N>> implements Access2D.Visitabl
         myDelegate.fill(Structure2D.index(myRowsCount, row, col), Structure2D.index(myRowsCount, row + tmpCount, col + tmpCount), 1L + myRowsCount, supplier);
     }
 
-    @Override
-    public void fillOne(final long index, final Access1D<?> values, final long valueIndex) {
-        myDelegate.fillOne(index, values, valueIndex);
-    }
-
-    @Override
-    public void fillOne(final long row, final long col, final Access1D<?> values, final long valueIndex) {
-        myDelegate.fillOne(Structure2D.index(myRowsCount, row, col), values, valueIndex);
-    }
-
-    @Override
-    public void fillOne(final long row, final long col, final N value) {
-        myDelegate.fillOne(Structure2D.index(myRowsCount, row, col), value);
-    }
-
-    @Override
-    public void fillOne(final long row, final long col, final NullaryFunction<?> supplier) {
-        myDelegate.fillOne(Structure2D.index(myRowsCount, row, col), supplier);
-    }
-
-    @Override
-    public void fillOne(final long index, final N value) {
-        myDelegate.fillOne(index, value);
-    }
-
-    @Override
-    public void fillOne(final long index, final NullaryFunction<?> supplier) {
-        myDelegate.fillOne(index, supplier);
-    }
-
     @Override
     public void fillRange(final long first, final long limit, final N value) {
         myDelegate.fill(first, limit, 1L, value);
@@ -643,7 +409,7 @@ public final class Array2D<N extends Comparable<N>> implements Access2D.Visitabl
             }
         } else {
             for (long i = 0L; i < limit; i++) {
-                this.fillOne(offset + i * myRowsCount, values.get(i));
+                this.set(offset + i * myRowsCount, values.get(i));
             }
         }
     }
@@ -699,6 +465,16 @@ public final class Array2D<N extends Comparable<N>> implements Access2D.Visitabl
         return myDelegate.get(Structure2D.index(myRowsCount, row, col));
     }
 
+    @Override
+    public int getColDim() {
+        return Math.toIntExact(myColumnsCount);
+    }
+
+    @Override
+    public int getRowDim() {
+        return Math.toIntExact(myRowsCount);
+    }
+
     @Override
     public int hashCode() {
         int prime = 31;
@@ -1081,6 +857,35 @@ public final class Array2D<N extends Comparable<N>> implements Access2D.Visitabl
         myDelegate.visit(Structure2D.index(myRowsCount, row, col), Structure2D.index(myRowsCount, row, myColumnsCount), myRowsCount, visitor);
     }
 
+    Factory2D<Array2D<N>> factory() {
+
+        return new Factory2D<>() {
+
+            ArrayFactory<N, ?> delegate = myDelegate.factory();
+
+            public FunctionSet<?> function() {
+                return delegate.function();
+            }
+
+            public MathType getMathType() {
+                return delegate.getMathType();
+            }
+
+            public Array2D<N> make(final int nbRows, final int nbCols) {
+                return this.make((long) nbRows, (long) nbCols);
+            }
+
+            public Array2D<N> make(final long nbRows, final long nbCols) {
+                return delegate.make(Structure2D.count(nbRows, nbCols)).wrapInArray2D(nbRows);
+            }
+
+            public Scalar.Factory<?> scalar() {
+                return delegate.scalar();
+            }
+
+        };
+    }
+
     BasicArray<N> getDelegate() {
         return myDelegate;
     }
