@@ -42,6 +42,7 @@ import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.AccessAnyD;
 import org.ojalgo.structure.FactoryAnyD;
 import org.ojalgo.structure.MutateAnyD;
+import org.ojalgo.structure.Structure1D;
 import org.ojalgo.structure.StructureAnyD;
 import org.ojalgo.structure.TransformationAnyD;
 import org.ojalgo.tensor.TensorFactoryAnyD;
@@ -54,10 +55,9 @@ import org.ojalgo.type.math.MathType;
  */
 public final class ArrayAnyD<N extends Comparable<N>> implements AccessAnyD.Visitable<N>, AccessAnyD.Aggregatable<N>, AccessAnyD.Sliceable<N>,
         StructureAnyD.ReducibleTo1D<Array1D<N>>, StructureAnyD.ReducibleTo2D<Array2D<N>>, AccessAnyD.Collectable<N, MutateAnyD>,
-        MutateAnyD.ModifiableReceiver<N>, MutateAnyD.Mixable<N>, StructureAnyD.Reshapable {
+        MutateAnyD.ModifiableReceiver<N>, MutateAnyD.Mixable<N>, StructureAnyD.Reshapable, FactoryAnyD.Builder<ArrayAnyD<N>> {
 
-    public static final class Factory<N extends Comparable<N>>
-            implements FactoryAnyD.Dense<ArrayAnyD<N>>, FactoryAnyD.MayBeSparse<ArrayAnyD<N>, ArrayAnyD<N>, ArrayAnyD<N>> {
+    public static final class Factory<N extends Comparable<N>> implements FactoryAnyD.MayBeSparse<ArrayAnyD<N>, ArrayAnyD<N>, ArrayAnyD<N>> {
 
         private final BasicArray.Factory<N> myDelegate;
 
@@ -68,7 +68,9 @@ public final class ArrayAnyD<N extends Comparable<N>> implements AccessAnyD.Visi
 
         @Override
         public ArrayAnyD<N> copy(final AccessAnyD<?> source) {
-            return myDelegate.copy(source).wrapInArrayAnyD(source.shape());
+            BasicArray<N> basic = myDelegate.make(source.count());
+            basic.fillMatching(source);
+            return basic.wrapInArrayAnyD(source.shape());
         }
 
         @Override
@@ -82,28 +84,31 @@ public final class ArrayAnyD<N extends Comparable<N>> implements AccessAnyD.Visi
         }
 
         @Override
-        public ArrayAnyD<N> make(final long... structure) {
-            return this.makeDense(structure);
+        public ArrayAnyD<N> make(final int... shape) {
+            long[] longIndexes = Structure1D.toLongIndexes(shape);
+            return myDelegate.makeToBeFilled(longIndexes).wrapInArrayAnyD(longIndexes);
         }
 
         @Override
-        public ArrayAnyD<N> makeDense(final long... structure) {
-            return myDelegate.makeToBeFilled(structure).wrapInArrayAnyD(structure);
+        public ArrayAnyD<N> make(final long... shape) {
+            return this.newDenseBuilder(shape);
         }
 
         @Override
-        public ArrayAnyD<N> makeFilled(final long[] structure, final NullaryFunction<?> supplier) {
-
-            BasicArray<N> toBeFilled = myDelegate.makeToBeFilled(structure);
-
-            toBeFilled.fillAll(supplier);
-
-            return toBeFilled.wrapInArrayAnyD(structure);
+        public ArrayAnyD<N> makeFilled(final long[] shape, final NullaryFunction<?> supplier) {
+            BasicArray<N> basic = myDelegate.makeToBeFilled(shape);
+            basic.fillAll(supplier);
+            return basic.wrapInArrayAnyD(shape);
         }
 
         @Override
-        public ArrayAnyD<N> makeSparse(final long... structure) {
-            return myDelegate.makeStructuredZero(structure).wrapInArrayAnyD(structure);
+        public ArrayAnyD<N> newDenseBuilder(final long... shape) {
+            return myDelegate.makeToBeFilled(shape).wrapInArrayAnyD(shape);
+        }
+
+        @Override
+        public ArrayAnyD<N> newSparseBuilder(final long... shape) {
+            return myDelegate.makeStructuredZero(shape).wrapInArrayAnyD(shape);
         }
 
         @Override
@@ -117,53 +122,13 @@ public final class ArrayAnyD<N extends Comparable<N>> implements AccessAnyD.Visi
 
     }
 
+    public static final Factory<ComplexNumber> C128 = ArrayAnyD.factory(ArrayC128.FACTORY);
+    public static final Factory<Quaternion> H256 = ArrayAnyD.factory(ArrayH256.FACTORY);
+    public static final Factory<RationalNumber> Q128 = ArrayAnyD.factory(ArrayQ128.FACTORY);
     public static final Factory<Double> R032 = ArrayAnyD.factory(ArrayR032.FACTORY);
     public static final Factory<Double> R064 = ArrayAnyD.factory(ArrayR064.FACTORY);
     public static final Factory<Quadruple> R128 = ArrayAnyD.factory(ArrayR128.FACTORY);
     public static final Factory<BigDecimal> R256 = ArrayAnyD.factory(ArrayR256.FACTORY);
-    /**
-     * @deprecated v52 Use {@link #R256} instead
-     */
-    @Deprecated
-    public static final Factory<BigDecimal> BIG = R256;
-    public static final Factory<ComplexNumber> C128 = ArrayAnyD.factory(ArrayC128.FACTORY);
-    /**
-     * @deprecated v52 Use {@link #C128} instead
-     */
-    @Deprecated
-    public static final Factory<ComplexNumber> COMPLEX = C128;
-    /**
-     * @deprecated v52 Use {@link #factory(DenseArray.Factory)} instead
-     */
-    @Deprecated
-    public static final Factory<Double> DIRECT32 = ArrayAnyD.factory(BufferArray.DIRECT32);
-    /**
-     * @deprecated v52 Use {@link #factory(DenseArray.Factory)} instead
-     */
-    @Deprecated
-    public static final Factory<Double> DIRECT64 = ArrayAnyD.factory(BufferArray.DIRECT64);
-    public static final Factory<Quaternion> H256 = ArrayAnyD.factory(ArrayH256.FACTORY);
-    /**
-     * @deprecated v52 Use {@link #R032} instead
-     */
-    @Deprecated
-    public static final Factory<Double> PRIMITIVE32 = R032;
-    /**
-     * @deprecated v52 Use {@link #R064} instead
-     */
-    @Deprecated
-    public static final Factory<Double> PRIMITIVE64 = R064;
-    public static final Factory<RationalNumber> Q128 = ArrayAnyD.factory(ArrayQ128.FACTORY);
-    /**
-     * @deprecated v52 Use {@link #H256} instead
-     */
-    @Deprecated
-    public static final Factory<Quaternion> QUATERNION = H256;
-    /**
-     * @deprecated v52 Use {@link #Q128} instead
-     */
-    @Deprecated
-    public static final Factory<RationalNumber> RATIONAL = Q128;
     public static final Factory<Double> Z008 = ArrayAnyD.factory(ArrayZ008.FACTORY);
     public static final Factory<Double> Z016 = ArrayAnyD.factory(ArrayZ016.FACTORY);
     public static final Factory<Double> Z032 = ArrayAnyD.factory(ArrayZ032.FACTORY);
@@ -280,6 +245,11 @@ public final class ArrayAnyD<N extends Comparable<N>> implements AccessAnyD.Visi
         return visitor.get();
     }
 
+    @Override
+    public ArrayAnyD<N> build() {
+        return this;
+    }
+
     @Override
     public byte byteValue(final int index) {
         return myDelegate.byteValue(index);
@@ -365,31 +335,6 @@ public final class ArrayAnyD<N extends Comparable<N>> implements AccessAnyD.Visi
         myDelegate.fill(0L, this.count(), 1L, supplier);
     }
 
-    @Override
-    public void fillOne(final long index, final Access1D<?> values, final long valueIndex) {
-        myDelegate.fillOne(index, values, valueIndex);
-    }
-
-    @Override
-    public void fillOne(final long index, final N value) {
-        myDelegate.fillOne(index, value);
-    }
-
-    @Override
-    public void fillOne(final long index, final NullaryFunction<?> supplier) {
-        myDelegate.fillOne(index, supplier);
-    }
-
-    @Override
-    public void fillOne(final long[] reference, final N value) {
-        myDelegate.fillOne(StructureAnyD.index(myStructure, reference), value);
-    }
-
-    @Override
-    public void fillOne(final long[] reference, final NullaryFunction<?> supplier) {
-        myDelegate.fillOne(StructureAnyD.index(myStructure, reference), supplier);
-    }
-
     @Override
     public void fillRange(final long first, final long limit, final N value) {
         myDelegate.fill(first, limit, 1L, value);
@@ -727,7 +672,7 @@ public final class ArrayAnyD<N extends Comparable<N>> implements AccessAnyD.Visi
 
     @Override
     public long[] shape() {
-        return myStructure;
+        return myStructure.clone();
     }
 
     @Override
@@ -745,6 +690,16 @@ public final class ArrayAnyD<N extends Comparable<N>> implements AccessAnyD.Visi
         return myDelegate.shortValue(StructureAnyD.index(myStructure, ref));
     }
 
+    @Override
+    public int size() {
+        return myDelegate.size();
+    }
+
+    @Override
+    public int size(final int dimension) {
+        return Math.toIntExact(this.count(dimension));
+    }
+
     @Override
     public Array1D<N> sliceRange(final long first, final long limit) {
         return myDelegate.wrapInArray1D().sliceRange(first, limit);
@@ -850,6 +805,35 @@ public final class ArrayAnyD<N extends Comparable<N>> implements AccessAnyD.Visi
         this.loop(initial, dimension, (f, l, s) -> myDelegate.visit(f, l, s, visitor));
     }
 
+    FactoryAnyD<ArrayAnyD<N>> factory() {
+
+        return new FactoryAnyD<>() {
+
+            ArrayFactory<N, ?> delegate = myDelegate.factory();
+
+            public FunctionSet<?> function() {
+                return delegate.function();
+            }
+
+            public MathType getMathType() {
+                return delegate.getMathType();
+            }
+
+            @Override
+            public ArrayAnyD<N> make(final int... shape) {
+                return this.make(Structure1D.toLongIndexes(shape));
+            }
+
+            public ArrayAnyD<N> make(final long... shape) {
+                return delegate.make(StructureAnyD.count(shape)).wrapInArrayAnyD(shape);
+            }
+
+            public Scalar.Factory<?> scalar() {
+                return delegate.scalar();
+            }
+        };
+    }
+
     BasicArray<N> getDelegate() {
         return myDelegate;
     }
