@@ -25,7 +25,6 @@ import java.util.function.LongFunction;
 
 import org.ojalgo.function.BinaryFunction;
 import org.ojalgo.function.FunctionSet;
-import org.ojalgo.function.NullaryFunction;
 import org.ojalgo.function.PrimitiveFunction;
 import org.ojalgo.function.UnaryFunction;
 import org.ojalgo.function.VoidFunction;
@@ -69,6 +68,11 @@ public abstract class OffHeapArray extends DenseArray<Double> {
             return PrimitiveFunction.getSet();
         }
 
+        @Override
+        public MathType getMathType() {
+            return myMathType;
+        }
+
         @Override
         public DenseArray<Double> makeDenseArray(final long size) {
             return myConstructor.apply(size);
@@ -84,11 +88,6 @@ public abstract class OffHeapArray extends DenseArray<Double> {
             return Long.MAX_VALUE;
         }
 
-        @Override
-        public MathType getMathType() {
-            return myMathType;
-        }
-
     }
 
     public static final DenseArray.Factory<Double> R032 = new Factory(MathType.R032, OffHeapR032::new);
@@ -98,33 +97,6 @@ public abstract class OffHeapArray extends DenseArray<Double> {
     public static final DenseArray.Factory<Double> Z032 = new Factory(MathType.Z032, OffHeapZ032::new);
     public static final DenseArray.Factory<Double> Z064 = new Factory(MathType.Z064, OffHeapZ064::new);
 
-    /**
-     * @deprecated Use {@link #R032} instead
-     */
-    @Deprecated
-    public static final DenseArray.Factory<Double> NATIVE32 = R032;
-    /**
-     * @deprecated Use {@link #R064} instead
-     */
-    @Deprecated
-    public static final DenseArray.Factory<Double> NATIVE64 = R064;
-
-    /**
-     * @deprecated Use {@link #R032} instead
-     */
-    @Deprecated
-    public static OffHeapArray makeNative32(final long count) {
-        return new OffHeapR032(count);
-    }
-
-    /**
-     * @deprecated Use {@link #R064} instead
-     */
-    @Deprecated
-    public static OffHeapArray makeNative64(final long count) {
-        return new OffHeapR064(count);
-    }
-
     private final long myCount;
 
     OffHeapArray(final DenseArray.Factory<Double> factory, final long count) {
@@ -134,6 +106,11 @@ public abstract class OffHeapArray extends DenseArray<Double> {
         myCount = count;
     }
 
+    @Override
+    public final void add(final long index, final byte addend) {
+        this.set(index, this.byteValue(index) + addend);
+    }
+
     @Override
     public final void add(final long index, final double addend) {
         this.set(index, this.doubleValue(index) + addend);
@@ -144,24 +121,19 @@ public abstract class OffHeapArray extends DenseArray<Double> {
         this.set(index, this.floatValue(index) + addend);
     }
 
-    @Override
-    public final void add(final long index, final long addend) {
-        this.set(index, this.longValue(index) + addend);
-    }
-
     @Override
     public final void add(final long index, final int addend) {
         this.set(index, this.intValue(index) + addend);
     }
 
     @Override
-    public final void add(final long index, final short addend) {
-        this.set(index, this.shortValue(index) + addend);
+    public final void add(final long index, final long addend) {
+        this.set(index, this.longValue(index) + addend);
     }
 
     @Override
-    public final void add(final long index, final byte addend) {
-        this.set(index, this.byteValue(index) + addend);
+    public final void add(final long index, final short addend) {
+        this.set(index, this.shortValue(index) + addend);
     }
 
     @Override
@@ -174,21 +146,6 @@ public abstract class OffHeapArray extends DenseArray<Double> {
         this.fill(0L, this.count(), 1L, value);
     }
 
-    @Override
-    public void fillOne(final long index, final Access1D<?> values, final long valueIndex) {
-        this.set(index, values.doubleValue(valueIndex));
-    }
-
-    @Override
-    public void fillOne(final long index, final Double value) {
-        this.set(index, value.doubleValue());
-    }
-
-    @Override
-    public void fillOne(final long index, final NullaryFunction<?> supplier) {
-        this.set(index, supplier.doubleValue());
-    }
-
     @Override
     public Double get(final long index) {
         return Double.valueOf(this.doubleValue(index));
@@ -199,6 +156,11 @@ public abstract class OffHeapArray extends DenseArray<Double> {
         this.set(index, modifier.invoke(this.doubleValue(index)));
     }
 
+    @Override
+    public final int size() {
+        return Math.toIntExact(myCount);
+    }
+
     @Override
     public void visitOne(final long index, final VoidFunction<Double> visitor) {
         visitor.accept(this.doubleValue(index));
