@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2022 Optimatika
+ * Copyright 1997-2024 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -98,6 +98,9 @@ public abstract class PlainArray<N extends Comparable<N>> extends DenseArray<N>
         this.add((int) index, addend);
     }
 
+    @Override
+    public abstract byte byteValue(int index);
+
     @Override
     public final byte byteValue(final long index) {
         // No Math.toIntExact() here, be as direct as possible
@@ -109,6 +112,11 @@ public abstract class PlainArray<N extends Comparable<N>> extends DenseArray<N>
         return this.size();
     }
 
+    @Override
+    public double doubleValue(final int index) {
+        return this.floatValue(index);
+    }
+
     @Override
     public final double doubleValue(final long index) {
         // No Math.toIntExact() here, be as direct as possible
@@ -125,21 +133,6 @@ public abstract class PlainArray<N extends Comparable<N>> extends DenseArray<N>
         this.fill(0, this.size(), 1, supplier);
     }
 
-    @Override
-    public final void fillOne(final long index, final Access1D<?> values, final long valueIndex) {
-        this.fillOne(Math.toIntExact(index), values, valueIndex);
-    }
-
-    @Override
-    public final void fillOne(final long index, final N value) {
-        this.fillOne(Math.toIntExact(index), value);
-    }
-
-    @Override
-    public final void fillOne(final long index, final NullaryFunction<?> supplier) {
-        this.fillOne(Math.toIntExact(index), supplier);
-    }
-
     @Override
     public final void fillRange(final long first, final long limit, final N number) {
         this.fill(first, limit, 1L, number);
@@ -150,6 +143,9 @@ public abstract class PlainArray<N extends Comparable<N>> extends DenseArray<N>
         this.fill(first, limit, 1L, supplier);
     }
 
+    @Override
+    public abstract float floatValue(final int index);
+
     @Override
     public final float floatValue(final long index) {
         // No Math.toIntExact() here, be as direct as possible
@@ -162,12 +158,22 @@ public abstract class PlainArray<N extends Comparable<N>> extends DenseArray<N>
         return this.get((int) index);
     }
 
+    @Override
+    public int intValue(final int index) {
+        return this.shortValue(index);
+    }
+
     @Override
     public final int intValue(final long index) {
         // No Math.toIntExact() here, be as direct as possible
         return this.intValue((int) index);
     }
 
+    @Override
+    public long longValue(final int index) {
+        return this.intValue(index);
+    }
+
     @Override
     public final long longValue(final long index) {
         // No Math.toIntExact() here, be as direct as possible
@@ -179,6 +185,32 @@ public abstract class PlainArray<N extends Comparable<N>> extends DenseArray<N>
         this.modifyOne(Math.toIntExact(index), modifier);
     }
 
+    @Override
+    public void set(final int index, final byte value) {
+        this.set(index, (short) value);
+    }
+
+    @Override
+    public abstract void set(final int index, final double value);
+
+    @Override
+    public void set(final int index, final float value) {
+        this.set(index, (double) value);
+    }
+
+    @Override
+    public void set(final int index, final int value) {
+        this.set(index, (long) value);
+    }
+
+    @Override
+    public abstract void set(final int index, final long value);
+
+    @Override
+    public void set(final int index, final short value) {
+        this.set(index, (int) value);
+    }
+
     @Override
     public final void set(final long index, final byte value) {
         // No Math.toIntExact() here, be as direct as possible
@@ -221,12 +253,18 @@ public abstract class PlainArray<N extends Comparable<N>> extends DenseArray<N>
         this.set((int) index, value);
     }
 
+    @Override
+    public short shortValue(final int index) {
+        return this.byteValue(index);
+    }
+
     @Override
     public final short shortValue(final long index) {
         // No Math.toIntExact() here, be as direct as possible
         return this.shortValue((int) index);
     }
 
+    @Override
     public final int size() {
         return mySize;
     }
@@ -271,12 +309,6 @@ public abstract class PlainArray<N extends Comparable<N>> extends DenseArray<N>
         this.add(index, (int) addend);
     }
 
-    protected abstract byte byteValue(int index);
-
-    protected double doubleValue(final int index) {
-        return this.floatValue(index);
-    }
-
     protected abstract void exchange(int firstA, int firstB, int step, int count);
 
     @Override
@@ -304,8 +336,6 @@ public abstract class PlainArray<N extends Comparable<N>> extends DenseArray<N>
 
     protected abstract void fillOne(int index, NullaryFunction<?> supplier);
 
-    protected abstract float floatValue(final int index);
-
     protected abstract N get(final int index);
 
     protected abstract int indexOfLargest(int first, int limit, int step);
@@ -315,10 +345,6 @@ public abstract class PlainArray<N extends Comparable<N>> extends DenseArray<N>
         return this.indexOfLargest(Math.toIntExact(first), Math.toIntExact(limit), Math.toIntExact(step));
     }
 
-    protected int intValue(final int index) {
-        return this.shortValue(index);
-    }
-
     /**
      * @see Scalar#isAbsolute()
      */
@@ -329,10 +355,6 @@ public abstract class PlainArray<N extends Comparable<N>> extends DenseArray<N>
      */
     protected abstract boolean isSmall(int index, double comparedTo);
 
-    protected long longValue(final int index) {
-        return this.intValue(index);
-    }
-
     protected abstract void modify(int first, int limit, int step, Access1D<N> left, BinaryFunction<N> function);
 
     protected abstract void modify(int first, int limit, int step, BinaryFunction<N> function, Access1D<N> right);
@@ -358,32 +380,8 @@ public abstract class PlainArray<N extends Comparable<N>> extends DenseArray<N>
 
     protected abstract int searchAscending(final N number);
 
-    protected void set(final int index, final byte value) {
-        this.set(index, (short) value);
-    }
-
     protected abstract void set(final int index, final Comparable<?> number);
 
-    protected abstract void set(final int index, final double value);
-
-    protected void set(final int index, final float value) {
-        this.set(index, (double) value);
-    }
-
-    protected void set(final int index, final int value) {
-        this.set(index, (long) value);
-    }
-
-    protected abstract void set(final int index, final long value);
-
-    protected void set(final int index, final short value) {
-        this.set(index, (int) value);
-    }
-
-    protected short shortValue(final int index) {
-        return this.byteValue(index);
-    }
-
     protected abstract void sortAscending();
 
     protected abstract void sortDescending();
