@@ -211,13 +211,9 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
             super(denseFactory);
         }
 
-        /**
-         * @deprecated v53 This will create an array of maximum/infinite length. That's probably not what you
-         *             want. Use {@link #make(long)} instead.
-         */
-        @Deprecated
-        public SparseArray<N> make() {
-            return this.make(Long.MAX_VALUE);
+        @Override
+        public SparseArray<N> make(final int size) {
+            return new SparseArray<>(this.getDenseFactory(), this.getGrowthStrategy(), size);
         }
 
         @Override
@@ -238,9 +234,9 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
      */
     private int myActualLength = 0;
     private final long myCount;
-    private long[] myIndices;
     private final DenseArray.Factory<N> myDenseFactory;
     private final GrowthStrategy myGrowthStrategy;
+    private long[] myIndices;
     private DenseArray<N> myValues;
     private final N myZeroNumber;
     private final Scalar<N> myZeroScalar;
@@ -305,7 +301,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
         return myCount;
     }
 
-    public long countNonzeros() {
+    public int countNonzeros() {
         return myActualLength;
     }
 
@@ -326,7 +322,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     }
 
     @Override
-    public double doubleValue(final long index) {
+    public double doubleValue(final int index) {
 
         final int tmpIndex = this.index(index);
         if (tmpIndex >= 0) {
@@ -336,7 +332,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     }
 
     @Override
-    public double doubleValue(final int index) {
+    public double doubleValue(final long index) {
 
         final int tmpIndex = this.index(index);
         if (tmpIndex >= 0) {
@@ -384,25 +380,6 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
         myValues.fillAll(supplier);
     }
 
-    @Override
-    public void fillOne(final long index, final Access1D<?> values, final long valueIndex) {
-        if (this.isPrimitive()) {
-            this.set(index, values.doubleValue(valueIndex));
-        } else {
-            this.set(index, values.get(valueIndex));
-        }
-    }
-
-    @Override
-    public void fillOne(final long index, final N value) {
-        this.set(index, value);
-    }
-
-    @Override
-    public void fillOne(final long index, final NullaryFunction<?> supplier) {
-        this.set(index, supplier.get());
-    }
-
     @Override
     public void fillRange(final long first, final long limit, final N value) {
         this.fill(first, limit, 1L, value);
@@ -478,6 +455,14 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
         myValues.reset();
     }
 
+    @Override
+    public void set(final int index, final double value) {
+
+        int internalIndex = this.index(index);
+
+        this.update(index, internalIndex, value, false);
+    }
+
     @Override
     public void set(final long index, final Comparable<?> value) {
 
@@ -502,6 +487,11 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
         this.update(index, internalIndex, value, false);
     }
 
+    @Override
+    public int size() {
+        return Math.toIntExact(myCount);
+    }
+
     public void supplyNonZerosTo(final Mutate1D consumer) {
         if (this.isPrimitive()) {
             for (int n = 0; n < myActualLength; n++) {
@@ -722,14 +712,14 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     @Override
     protected void fill(final long first, final long limit, final long step, final N value) {
         for (long i = first; i < limit; i += step) {
-            this.fillOne(i, value);
+            this.set(i, value);
         }
     }
 
     @Override
     protected void fill(final long first, final long limit, final long step, final NullaryFunction<?> supplier) {
         for (long i = first; i < limit; i += step) {
-            this.fillOne(i, supplier);
+            this.set(i, supplier.get());
         }
     }
 
@@ -876,11 +866,6 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
 
         return new Access1D<>() {
 
-            @Override
-            public long count() {
-                return limit - first;
-            }
-
             @Override
             public double doubleValue(final int index) {
                 return myValues.doubleValue(first + index);
@@ -896,6 +881,11 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
                 return myValues.get(first + index);
             }
 
+            @Override
+            public int size() {
+                return limit - first;
+            }
+
         };
     }
 
@@ -941,12 +931,4 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
         }
     }
 
-    @Override
-    public void set(final int index, final double value) {
-
-        int internalIndex = this.index(index);
-
-        this.update(index, internalIndex, value, false);
-    }
-
 }
