@@ -21,7 +21,8 @@
  */
 package org.ojalgo.data;
 
-import static org.ojalgo.function.constant.PrimitiveMath.*;
+import static org.ojalgo.function.constant.PrimitiveMath.ONE;
+import static org.ojalgo.function.constant.PrimitiveMath.ZERO;
 
 import java.util.Collection;
 
@@ -97,6 +98,16 @@ public final class DataBatch implements Access2D<Double>, Access2D.Collectable<D
         return Double.valueOf(this.doubleValue(row, col));
     }
 
+    @Override
+    public int getColDim() {
+        return myData.getColDim();
+    }
+
+    @Override
+    public int getRowDim() {
+        return myData.getRowDim();
+    }
+
     public boolean isFull() {
         return this.remaining() == 0;
     }
