@@ -39,7 +39,7 @@ import org.ojalgo.matrix.MatrixR064;
 import org.ojalgo.matrix.decomposition.Eigenvalue;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.random.Deterministic;
 import org.ojalgo.random.RandomNumber;
 import org.ojalgo.random.SampleSet;
@@ -141,7 +141,7 @@ public abstract class FinanceUtils {
 
         int tmpSize = timeSeriesCollection.size();
 
-        MatrixR064.DenseReceiver retValStore = MatrixR064.FACTORY.makeDense(tmpSize, tmpSize);
+        MatrixR064.DenseReceiver retValStore = MatrixR064.FACTORY.newDenseBuilder(tmpSize, tmpSize);
 
         double tmpToYearFactor = (double) CalendarDateUnit.YEAR.toDurationInMillis() / (double) tmpCoordinator.getResolution().toDurationInMillis();
 
@@ -181,7 +181,7 @@ public abstract class FinanceUtils {
 
         CoordinationSet<N> tmpCoordinated = tmpUncoordinated.prune(tmpDataResolution);
 
-        MatrixR064.DenseReceiver tmpMatrixBuilder = MatrixR064.FACTORY.makeDense(tmpSize, tmpSize);
+        MatrixR064.DenseReceiver tmpMatrixBuilder = MatrixR064.FACTORY.newDenseBuilder(tmpSize, tmpSize);
 
         double tmpToYearFactor = (double) CalendarDateUnit.YEAR.toDurationInMillis() / (double) tmpDataResolution.toDurationInMillis();
 
@@ -358,11 +358,11 @@ public abstract class FinanceUtils {
 
         int size = Math.toIntExact(Math.min(covariances.countRows(), covariances.countColumns()));
 
-        MatrixStore<Double> covarianceMtrx = Primitive64Store.FACTORY.makeWrapper(covariances);
+        MatrixStore<Double> covarianceMtrx = R064Store.FACTORY.makeWrapper(covariances);
 
         if (clean) {
 
-            Eigenvalue<Double> evd = Eigenvalue.PRIMITIVE.make(covarianceMtrx, true);
+            Eigenvalue<Double> evd = Eigenvalue.R064.make(covarianceMtrx, true);
             evd.decompose(covarianceMtrx);
 
             MatrixStore<Double> mtrxV = evd.getV();
@@ -380,7 +380,7 @@ public abstract class FinanceUtils {
             covarianceMtrx = mtrxV.multiply(mtrxD).multiply(mtrxV.transpose());
         }
 
-        MatrixR064.DenseReceiver retVal = MatrixR064.FACTORY.makeDense(size, size);
+        MatrixR064.DenseReceiver retVal = MatrixR064.FACTORY.newDenseBuilder(size, size);
 
         double[] volatilities = new double[size];
         for (int ij = 0; ij < size; ij++) {
@@ -422,7 +422,7 @@ public abstract class FinanceUtils {
 
         int tmpSize = (int) volatilities.count();
 
-        MatrixR064.DenseReceiver retVal = MatrixR064.FACTORY.makeDense(tmpSize, tmpSize);
+        MatrixR064.DenseReceiver retVal = MatrixR064.FACTORY.newDenseBuilder(tmpSize, tmpSize);
 
         for (int j = 0; j < tmpSize; j++) {
             double tmpColumnVolatility = volatilities.doubleValue(j);
@@ -479,7 +479,7 @@ public abstract class FinanceUtils {
 
         if (clean) {
 
-            MatrixStore<Double> covarianceMtrx = Primitive64Store.FACTORY.makeWrapper(covariances);
+            MatrixStore<Double> covarianceMtrx = R064Store.FACTORY.makeWrapper(covariances);
 
             double largest = covarianceMtrx.aggregateDiagonal(Aggregator.LARGEST).doubleValue();
             double limit = largest * size * PrimitiveMath.RELATIVELY_SMALL;
