@@ -83,7 +83,7 @@ public final class BlackLittermanModel extends EquilibriumModel {
                 return myReturnVariance.doubleValue();
 
             }
-            final MatrixR064 tmpWeights = MATRIX_FACTORY.columns(myWeights);
+            final MatrixR064 tmpWeights = MATRIX_FACTORY.column(myWeights);
 
             BigDecimal retVal = myModel.calculateVariance(tmpWeights);
 
@@ -129,7 +129,7 @@ public final class BlackLittermanModel extends EquilibriumModel {
 
         super(context);
 
-        myOriginalWeights = MATRIX_FACTORY.columns(originalWeights.getWeights());
+        myOriginalWeights = MATRIX_FACTORY.column(originalWeights.getWeights());
         myViews = new ArrayList<>();
     }
 
@@ -161,39 +161,35 @@ public final class BlackLittermanModel extends EquilibriumModel {
 
     public void addViewWithBalancedConfidence(final List<BigDecimal> someWeights, final Comparable<?> aReturn) {
 
-        final View tmpView = new View(this, someWeights);
+        View view = new View(this, someWeights);
 
-        tmpView.setMeanReturn(TypeUtils.toBigDecimal(aReturn));
-        tmpView.setReturnVariance(null);
-        tmpView.setScale(null);
+        view.setMeanReturn(TypeUtils.toBigDecimal(aReturn));
+        view.setReturnVariance(null);
+        view.setScale(null);
 
-        myViews.add(tmpView);
+        myViews.add(view);
     }
 
     public void addViewWithScaledConfidence(final List<BigDecimal> someWeights, final Comparable<?> aReturn, final Comparable<?> aScale) {
 
-        final View tmpView = new View(this, someWeights);
+        View view = new View(this, someWeights);
 
-        tmpView.setMeanReturn(TypeUtils.toBigDecimal(aReturn));
-        tmpView.setReturnVariance(null);
-        tmpView.setScale(TypeUtils.toBigDecimal(aScale));
+        view.setMeanReturn(TypeUtils.toBigDecimal(aReturn));
+        view.setReturnVariance(null);
+        view.setScale(TypeUtils.toBigDecimal(aScale));
 
-        myViews.add(tmpView);
+        myViews.add(view);
     }
 
-    /**
-     * @deprecated v30
-     */
-    @Deprecated
-    public void addViewWithStandardDeviation(final List<BigDecimal> someWeights, final BigDecimal aReturn, final BigDecimal aStdDev) {
+    public void addViewWithStandardDeviation(final List<BigDecimal> weights, final BigDecimal expected, final BigDecimal stdDev) {
 
-        final View tmpView = new View(this, someWeights);
+        View view = new View(this, weights);
 
-        tmpView.setMeanReturn(aReturn);
-        tmpView.setReturnVariance(aStdDev.multiply(aStdDev));
-        tmpView.setScale(null);
+        view.setMeanReturn(expected);
+        view.setReturnVariance(stdDev.multiply(stdDev));
+        view.setScale(null);
 
-        myViews.add(tmpView);
+        myViews.add(view);
     }
 
     /**
@@ -252,7 +248,7 @@ public final class BlackLittermanModel extends EquilibriumModel {
         final int tmpRowDim = myViews.size();
         final int tmpColDim = (int) myOriginalWeights.count();
 
-        final MatrixR064.DenseReceiver retVal = MATRIX_FACTORY.makeDense(tmpRowDim, tmpColDim);
+        final MatrixR064.DenseReceiver retVal = MATRIX_FACTORY.newDenseBuilder(tmpRowDim, tmpColDim);
 
         FinancePortfolio tmpView;
         List<BigDecimal> tmpWeights;
@@ -278,7 +274,7 @@ public final class BlackLittermanModel extends EquilibriumModel {
         final int tmpRowDim = myViews.size();
         final int tmpColDim = 1;
 
-        final MatrixR064.DenseReceiver retVal = MATRIX_FACTORY.makeDense(tmpRowDim, tmpColDim);
+        final MatrixR064.DenseReceiver retVal = MATRIX_FACTORY.newDenseBuilder(tmpRowDim, tmpColDim);
 
         double tmpRet;
         final double tmpRAF = this.getRiskAversion().doubleValue();
@@ -304,7 +300,7 @@ public final class BlackLittermanModel extends EquilibriumModel {
 
         final int tmpDim = myViews.size();
 
-        final MatrixR064.DenseReceiver retVal = MATRIX_FACTORY.makeDense(tmpDim, tmpDim);
+        final MatrixR064.DenseReceiver retVal = MATRIX_FACTORY.newDenseBuilder(tmpDim, tmpDim);
 
         if (myConfidence.compareTo(BigMath.ONE) == 0) {
 
