@@ -37,9 +37,9 @@ public class PortfolioContext implements FinancePortfolio.Context {
 
         super();
 
-        myAssetReturns = FinancePortfolio.MATRIX_FACTORY.columns(assetReturns);
+        myAssetReturns = FinancePortfolio.MATRIX_FACTORY.column(assetReturns);
 
-        myAssetVolatilities = FinancePortfolio.MATRIX_FACTORY.columns(assetVolatilities);
+        myAssetVolatilities = FinancePortfolio.MATRIX_FACTORY.column(assetVolatilities);
         myCorrelations = FinancePortfolio.MATRIX_FACTORY.copy(correlations);
     }
 
@@ -47,7 +47,7 @@ public class PortfolioContext implements FinancePortfolio.Context {
 
         super();
 
-        myAssetReturns = FinancePortfolio.MATRIX_FACTORY.columns(assetReturns);
+        myAssetReturns = FinancePortfolio.MATRIX_FACTORY.column(assetReturns);
 
         myCovariances = FinancePortfolio.MATRIX_FACTORY.copy(covariances);
     }
@@ -60,21 +60,23 @@ public class PortfolioContext implements FinancePortfolio.Context {
         myAssetReturns = null;
     }
 
-    @SuppressWarnings("unchecked")
+    @Override
     public double calculatePortfolioReturn(final FinancePortfolio weightsPortfolio) {
-        return FinancePortfolio.MATRIX_FACTORY.rows(weightsPortfolio.getWeights()).multiply(this.getAssetReturns()).doubleValue(0);
+        return FinancePortfolio.MATRIX_FACTORY.row(weightsPortfolio.getWeights()).multiply(this.getAssetReturns()).doubleValue(0);
     }
 
-    @SuppressWarnings("unchecked")
+    @Override
     public double calculatePortfolioVariance(final FinancePortfolio weightsPortfolio) {
-        final MatrixR064 tmpWeights = FinancePortfolio.MATRIX_FACTORY.columns(weightsPortfolio.getWeights());
+        final MatrixR064 tmpWeights = FinancePortfolio.MATRIX_FACTORY.column(weightsPortfolio.getWeights());
         return tmpWeights.transpose().multiply(this.getCovariances().multiply(tmpWeights)).doubleValue(0);
     }
 
+    @Override
     public MatrixR064 getAssetReturns() {
         return myAssetReturns;
     }
 
+    @Override
     public MatrixR064 getAssetVolatilities() {
         if (myAssetVolatilities == null) {
             myAssetVolatilities = FinanceUtils.toVolatilities(myCovariances);
@@ -82,6 +84,7 @@ public class PortfolioContext implements FinancePortfolio.Context {
         return myAssetVolatilities;
     }
 
+    @Override
     public MatrixR064 getCorrelations() {
         if (myCorrelations == null) {
             myCorrelations = FinanceUtils.toCorrelations(myCovariances, false);
@@ -89,6 +92,7 @@ public class PortfolioContext implements FinancePortfolio.Context {
         return myCorrelations;
     }
 
+    @Override
     public MatrixR064 getCovariances() {
         if (myCovariances == null) {
             myCovariances = FinanceUtils.toCovariances(myAssetVolatilities, myCorrelations);
@@ -96,6 +100,7 @@ public class PortfolioContext implements FinancePortfolio.Context {
         return myCovariances;
     }
 
+    @Override
     public int size() {
         return (int) myAssetReturns.count();
     }
