@@ -8,11 +8,16 @@ import org.ojalgo.netio.ServiceClient.Response;
 import org.ojalgo.type.CalendarDateUnit;
 
 /**
+ * All data downloaders/fetchers are deprecated. They will be removed in a future release, and most likely
+ * they're already broken.
+ * <P>
  * Fetch historical financial time series data from Alpha Vantage: https://www.alphavantage.co
  *
  * @see https://www.alphavantage.co
  * @author stefanvanegmond
+ * @deprecated
  */
+@Deprecated
 public final class AlphaVantageFetcher implements DataFetcher {
 
     private final ServiceClient.Request myRequest;
@@ -42,11 +47,12 @@ public final class AlphaVantageFetcher implements DataFetcher {
         myRequest.query("symbol", symbol);
         myRequest.query("apikey", apiKey);
         myRequest.query("datatype", "csv");
-        if (fullOutputSize && (resolution == CalendarDateUnit.DAY) && !"demo".equals(apiKey)) {
+        if (fullOutputSize && resolution == CalendarDateUnit.DAY && !"demo".equals(apiKey)) {
             myRequest.query("outputsize", "full");
         }
     }
 
+    @Override
     public InputStream getInputStream() {
         Response<InputStream> response = myRequest.send(BodyHandlers.ofInputStream());
         if (response.isResponseOK()) {
@@ -56,10 +62,12 @@ public final class AlphaVantageFetcher implements DataFetcher {
         }
     }
 
+    @Override
     public CalendarDateUnit getResolution() {
         return myResolution;
     }
 
+    @Override
     public String getSymbol() {
         return mySymbol;
     }
