@@ -42,14 +42,14 @@ public final class BigFunction extends FunctionSet<BigDecimal> {
     @FunctionalInterface
     public interface Binary extends BinaryFunction<BigDecimal> {
 
-        default double invoke(final double arg1, final double arg2) {
-            return this.invoke(BigDecimal.valueOf(arg1), BigDecimal.valueOf(arg2)).doubleValue();
-        }
-
         default BigDecimal invoke(final BigDecimal arg1, final double arg2) {
             return this.invoke(arg1, BigDecimal.valueOf(arg2));
         }
 
+        default double invoke(final double arg1, final double arg2) {
+            return this.invoke(BigDecimal.valueOf(arg1), BigDecimal.valueOf(arg2)).doubleValue();
+        }
+
         default float invoke(final float arg1, final float arg2) {
             return this.invoke(BigDecimal.valueOf(arg1), BigDecimal.valueOf(arg2)).floatValue();
         }
@@ -69,6 +69,15 @@ public final class BigFunction extends FunctionSet<BigDecimal> {
 
     }
 
+    @FunctionalInterface
+    public interface Nullary extends NullaryFunction<BigDecimal> {
+
+        default double doubleValue() {
+            return this.invoke().doubleValue();
+        }
+
+    }
+
     @FunctionalInterface
     public interface Parameter extends ParameterFunction<BigDecimal> {
 
@@ -114,6 +123,10 @@ public final class BigFunction extends FunctionSet<BigDecimal> {
         return SET;
     }
 
+    public static Nullary nullary(final BigDecimal value) {
+        return () -> value;
+    }
+
     private BigFunction() {
         super();
     }
