@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2022 Optimatika
+ * Copyright 1997-2024 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -169,6 +169,10 @@ public interface BinaryFunction<N extends Comparable<N>> extends BasicFunction,
                 return after.invoke(BinaryFunction.this.invoke(arg1, arg2));
             }
 
+            public N invoke(final N arg1, final double arg2) {
+                return after.invoke(BinaryFunction.this.invoke(arg1, arg2));
+            }
+
             public N invoke(final N arg1, final N arg2) {
                 return after.invoke(BinaryFunction.this.invoke(arg1, arg2));
             }
@@ -244,6 +248,8 @@ public interface BinaryFunction<N extends Comparable<N>> extends BasicFunction,
         return NumberDefinition.toLong(this.invoke((double) arg1, (double) arg2));
     }
 
+    N invoke(N arg1, double arg2);
+
     N invoke(N arg1, N arg2);
 
     default short invoke(final short arg1, final short arg2) {
