@@ -32,14 +32,14 @@ public final class ComplexFunction extends FunctionSet<ComplexNumber> {
     @FunctionalInterface
     public interface Binary extends BinaryFunction<ComplexNumber> {
 
-        default double invoke(final double arg1, final double arg2) {
-            return this.invoke(ComplexNumber.valueOf(arg1), ComplexNumber.valueOf(arg2)).doubleValue();
-        }
-
         default ComplexNumber invoke(final ComplexNumber arg1, final double arg2) {
             return this.invoke(arg1, ComplexNumber.valueOf(arg2));
         }
 
+        default double invoke(final double arg1, final double arg2) {
+            return this.invoke(ComplexNumber.valueOf(arg1), ComplexNumber.valueOf(arg2)).doubleValue();
+        }
+
         default float invoke(final float arg1, final float arg2) {
             return this.invoke(ComplexNumber.valueOf(arg1), ComplexNumber.valueOf(arg2)).floatValue();
         }
@@ -59,6 +59,15 @@ public final class ComplexFunction extends FunctionSet<ComplexNumber> {
 
     }
 
+    @FunctionalInterface
+    public interface Nullary extends NullaryFunction<ComplexNumber> {
+
+        default double doubleValue() {
+            return this.invoke().doubleValue();
+        }
+
+    }
+
     @FunctionalInterface
     public interface Parameter extends ParameterFunction<ComplexNumber> {
 
@@ -104,6 +113,10 @@ public final class ComplexFunction extends FunctionSet<ComplexNumber> {
         return SET;
     }
 
+    public static Nullary nullary(final ComplexNumber value) {
+        return () -> value;
+    }
+
     private ComplexFunction() {
         super();
     }
