@@ -36,14 +36,14 @@ public final class QuaternionFunction extends FunctionSet<Quaternion> {
             return this.invoke(Quaternion.valueOf(arg1), Quaternion.valueOf(arg2)).doubleValue();
         }
 
-        default Quaternion invoke(final Quaternion arg1, final double arg2) {
-            return this.invoke(arg1, Quaternion.valueOf(arg2));
-        }
-
         default float invoke(final float arg1, final float arg2) {
             return this.invoke(Quaternion.valueOf(arg1), Quaternion.valueOf(arg2)).floatValue();
         }
 
+        default Quaternion invoke(final Quaternion arg1, final double arg2) {
+            return this.invoke(arg1, Quaternion.valueOf(arg2));
+        }
+
     }
 
     @FunctionalInterface
@@ -59,6 +59,15 @@ public final class QuaternionFunction extends FunctionSet<Quaternion> {
 
     }
 
+    @FunctionalInterface
+    public interface Nullary extends NullaryFunction<Quaternion> {
+
+        default double doubleValue() {
+            return this.invoke().doubleValue();
+        }
+
+    }
+
     @FunctionalInterface
     public interface Parameter extends ParameterFunction<Quaternion> {
 
@@ -104,6 +113,10 @@ public final class QuaternionFunction extends FunctionSet<Quaternion> {
         return SET;
     }
 
+    public static Nullary nullary(final Quaternion value) {
+        return () -> value;
+    }
+
     private QuaternionFunction() {
         super();
     }
