@@ -41,14 +41,14 @@ public final class RationalFunction extends FunctionSet<RationalNumber> {
             return this.invoke(RationalNumber.valueOf(arg1), RationalNumber.valueOf(arg2)).doubleValue();
         }
 
-        default RationalNumber invoke(final RationalNumber arg1, final double arg2) {
-            return this.invoke(arg1, RationalNumber.valueOf(arg2));
-        }
-
         default float invoke(final float arg1, final float arg2) {
             return this.invoke(RationalNumber.valueOf(arg1), RationalNumber.valueOf(arg2)).floatValue();
         }
 
+        default RationalNumber invoke(final RationalNumber arg1, final double arg2) {
+            return this.invoke(arg1, RationalNumber.valueOf(arg2));
+        }
+
     }
 
     @FunctionalInterface
@@ -64,6 +64,15 @@ public final class RationalFunction extends FunctionSet<RationalNumber> {
 
     }
 
+    @FunctionalInterface
+    public interface Nullary extends NullaryFunction<RationalNumber> {
+
+        default double doubleValue() {
+            return this.invoke().doubleValue();
+        }
+
+    }
+
     @FunctionalInterface
     public interface Parameter extends ParameterFunction<RationalNumber> {
 
@@ -109,6 +118,10 @@ public final class RationalFunction extends FunctionSet<RationalNumber> {
         return SET;
     }
 
+    public static Nullary nullary(final RationalNumber value) {
+        return () -> value;
+    }
+
     private RationalFunction() {
         super();
     }
