@@ -108,12 +108,6 @@ public abstract class PrimitiveMath {
     public static final double MACHINE_SMALLEST = Double.MIN_NORMAL;
     public static final double MACHINE_EPSILON = Math.pow(2.0, -52.0);
     public static final double RELATIVELY_SMALL = Math.pow(2.0, -26.0);
-    /**
-     * ≈ 1.6E-291
-     */
-    @Deprecated
-    public static final double TINY = Math.pow(2.0, -966.0);
-
     private static final int[] PRIME = new int[] { 2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47, 53, 59, 61, 67, 71, 73, 79, 83, 89, 97, 101, 103,
             107, 109, 113, 127, 131, 137, 139, 149, 151, 157, 163, 167, 173, 179, 181, 191, 193, 197, 199, 211, 223, 227, 229, 233, 239, 241, 251, 257, 263,
             269, 271 };
