@@ -21,12 +21,8 @@
  */
 package org.ojalgo.function.multiary;
 
-import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
-import org.ojalgo.scalar.ComplexNumber;
-import org.ojalgo.scalar.RationalNumber;
 import org.ojalgo.scalar.Scalar;
 import org.ojalgo.structure.Access1D;
 
@@ -54,7 +50,7 @@ public final class AffineFunction<N extends Comparable<N>> implements MultiaryFu
 
         public AffineFunction<N> make(final int arity) {
             if (myCoefficients != null) {
-                return new AffineFunction<>(myFactory.rows(myCoefficients));
+                return new AffineFunction<>(myFactory.row(myCoefficients));
             } else {
                 return new AffineFunction<>(myFactory.make(1, arity));
             }
@@ -66,60 +62,6 @@ public final class AffineFunction<N extends Comparable<N>> implements MultiaryFu
         return new Factory<>(factory);
     }
 
-    /**
-     * @deprecated v53 Use {@link #factory(PhysicalStore.Factory)} instead.
-     */
-    @Deprecated
-    public static AffineFunction<ComplexNumber> makeComplex(final Access1D<?> coefficients) {
-        // return new AffineFunction<>(GenericStore.C128.rows(coefficients));
-        return AffineFunction.factory(GenericStore.C128).coefficients(coefficients).make(coefficients.size());
-    }
-
-    /**
-     * @deprecated v53 Use {@link #factory(PhysicalStore.Factory)} instead.
-     */
-    @Deprecated
-    public static AffineFunction<ComplexNumber> makeComplex(final int arity) {
-        // return new AffineFunction<>(GenericStore.C128.make(1, arity));
-        return AffineFunction.factory(GenericStore.C128).make(arity);
-    }
-
-    /**
-     * @deprecated v53 Use {@link #factory(PhysicalStore.Factory)} instead.
-     */
-    @Deprecated
-    public static AffineFunction<Double> makePrimitive(final Access1D<?> coefficients) {
-        // return new AffineFunction<>(Primitive64Store.FACTORY.rows(coefficients));
-        return AffineFunction.factory(Primitive64Store.FACTORY).coefficients(coefficients).make(coefficients.size());
-    }
-
-    /**
-     * @deprecated v53 Use {@link #factory(PhysicalStore.Factory)} instead.
-     */
-    @Deprecated
-    public static AffineFunction<Double> makePrimitive(final int arity) {
-        // return new AffineFunction<>(Primitive64Store.FACTORY.make(1, arity));
-        return AffineFunction.factory(Primitive64Store.FACTORY).make(arity);
-    }
-
-    /**
-     * @deprecated v53 Use {@link #factory(PhysicalStore.Factory)} instead.
-     */
-    @Deprecated
-    public static AffineFunction<RationalNumber> makeRational(final Access1D<?> coefficients) {
-        // return new AffineFunction<>(GenericStore.Q128.rows(coefficients));
-        return AffineFunction.factory(GenericStore.Q128).coefficients(coefficients).make(coefficients.size());
-    }
-
-    /**
-     * @deprecated v53 Use {@link #factory(PhysicalStore.Factory)} instead.
-     */
-    @Deprecated
-    public static AffineFunction<RationalNumber> makeRational(final int arity) {
-        // return new AffineFunction<>(GenericStore.Q128.make(1, arity));
-        return AffineFunction.factory(GenericStore.Q128).make(arity);
-    }
-
     public static <N extends Comparable<N>> AffineFunction<N> wrap(final PhysicalStore<N> coefficients) {
         return new AffineFunction<>(coefficients);
     }
@@ -139,10 +81,12 @@ public final class AffineFunction<N extends Comparable<N>> implements MultiaryFu
         myConstant = new ConstantFunction<>(coefficients.count(), coefficients.physical());
     }
 
+    @Override
     public int arity() {
         return Math.toIntExact(myCoefficients.count());
     }
 
+    @Override
     public N getConstant() {
         return myConstant.getConstant();
     }
@@ -157,6 +101,7 @@ public final class AffineFunction<N extends Comparable<N>> implements MultiaryFu
         return myCoefficients.physical().makeZero(this.arity(), this.arity());
     }
 
+    @Override
     public MatrixStore<N> getLinearFactors(final boolean negated) {
 
         MatrixStore<N> retVal = myCoefficients;
@@ -177,10 +122,12 @@ public final class AffineFunction<N extends Comparable<N>> implements MultiaryFu
         return this.getScalarValue(arg).get();
     }
 
+    @Override
     public PhysicalStore<N> linear() {
         return (PhysicalStore<N>) myCoefficients;
     }
 
+    @Override
     public void setConstant(final Comparable<?> constant) {
         myConstant.setConstant(constant);
     }
