@@ -101,15 +101,6 @@ public interface MultiaryFunction<N extends Comparable<N>> extends BasicFunction
          */
         MatrixStore<N> getHessian(Access1D<N> point);
 
-        /**
-         * @return The gradient at origin (0-vector), negated or not
-         * @deprecated v53 Use {@link #getLinearFactors(boolean)} instead.
-         */
-        @Deprecated
-        default MatrixStore<N> getLinearFactors() {
-            return this.getLinearFactors(false);
-        }
-
         /**
          * @return The gradient at origin (0-vector), negated or not
          */
