@@ -27,6 +27,7 @@ import java.util.Optional;
 import org.ojalgo.ProgrammingError;
 import org.ojalgo.algebra.NormedVectorSpace;
 import org.ojalgo.function.BinaryFunction;
+import org.ojalgo.function.ParameterFunction;
 import org.ojalgo.function.UnaryFunction;
 import org.ojalgo.function.aggregator.Aggregator;
 import org.ojalgo.function.constant.PrimitiveMath;
@@ -156,7 +157,6 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
 
     @Override
     public M add(final M addend) {
-        ProgrammingError.throwIfNotEqualDimensions(this.store(), addend);
         return this.newInstance(this.store().add(addend.store()));
     }
 
@@ -237,7 +237,7 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
      *         always creates a full dense copy.
      * @see #logical()
      */
-    public abstract Mutator2D<N, M, PhysicalStore<N>> copy();
+    public abstract DenseMutator2D<N, M> copy();
 
     @Override
     public long count() {
@@ -275,13 +275,13 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
     }
 
     @Override
-    public double doubleValue(final long index) {
-        return this.store().doubleValue(index);
+    public double doubleValue(final int row, final int col) {
+        return this.store().doubleValue(row, col);
     }
 
     @Override
-    public double doubleValue(final int row, final int col) {
-        return this.store().doubleValue(row, col);
+    public double doubleValue(final long index) {
+        return this.store().doubleValue(index);
     }
 
     @Override
@@ -306,28 +306,6 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
         return super.equals(other);
     }
 
-    /**
-     * BasicMatrix instances are intended to be immutable. If they are it is possible to cache (partial)
-     * calculation results. Calling this method should flush any cached calculation results.
-     *
-     * @deprecated v50 Caching, if necessary, is handled for you. If you want control of this then use the
-     *             lower level stuff in org.ojagl.matrix.store and org.ojagl.matrix.decomposition instead.
-     */
-    @Deprecated
-    public void flushCache() {
-
-        myHashCode = 0;
-
-        if (myDecomposition != null) {
-            myDecomposition.reset();
-            myDecomposition = null;
-        }
-
-        myHermitian = null;
-        mySymmetric = null;
-        mySPD = null;
-    }
-
     /**
      * @deprecated v50 No need for this!
      */
@@ -346,6 +324,11 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
         return this.store().get(row, col);
     }
 
+    @Override
+    public int getColDim() {
+        return mySupplier.getColDim();
+    }
+
     /**
      * Matrix condition (2-norm)
      *
@@ -386,6 +369,11 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
         return this.getRankProvider().getRank();
     }
 
+    @Override
+    public int getRowDim() {
+        return mySupplier.getRowDim();
+    }
+
     /**
      * The sum of the diagonal elements.
      *
@@ -496,11 +484,6 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
     }
 
     /**
-     * Compared to {@link #copy()} this does not create a copy – not initially anyway. The returned instance
-     * is a starting point for logically composing a new matrix.
-     *
-     * @return A logical builder that tries to avoid unnecessary copying.
-     * @see #copy()
      * @deprecated v50 No need for this!
      */
     @Deprecated
@@ -548,6 +531,31 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
         return this.newInstance(this.store().offsets(rowOffset, columnOffset));
     }
 
+    @Override
+    public M onAll(final BinaryFunction<N> operator, final double right) {
+        return this.newInstance(this.supplier().onAll(operator, right));
+    }
+
+    @Override
+    public M onAll(final BinaryFunction<N> operator, final N right) {
+        return this.newInstance(this.supplier().onAll(operator, right));
+    }
+
+    @Override
+    public M onAll(final double left, final BinaryFunction<N> operator) {
+        return this.newInstance(this.supplier().onAll(left, operator));
+    }
+
+    @Override
+    public M onAll(final N left, final BinaryFunction<N> operator) {
+        return this.newInstance(this.supplier().onAll(left, operator));
+    }
+
+    @Override
+    public M onAll(final ParameterFunction<N> operator, final int parameter) {
+        return this.newInstance(this.supplier().onAll(operator, parameter));
+    }
+
     @Override
     public M onAll(final UnaryFunction<N> operator) {
         return this.newInstance(this.supplier().onAll(operator));
@@ -558,11 +566,26 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
         return this.newInstance(this.supplier().onAny(operator));
     }
 
+    @Override
+    public M onColumns(final Access1D<N> left, final BinaryFunction<N> operator) {
+        return this.newInstance(this.supplier().onColumns(left, operator));
+    }
+
     @Override
     public M onColumns(final BinaryFunction<N> operator, final Access1D<N> right) {
         return this.newInstance(this.supplier().onColumns(operator, right));
     }
 
+    @Override
+    public M onCompatible(final Access2D<N> left, final BinaryFunction<N> operator) {
+        return this.newInstance(this.supplier().onCompatible(left, operator));
+    }
+
+    @Override
+    public M onCompatible(final BinaryFunction<N> operator, final Access2D<N> right) {
+        return this.newInstance(this.supplier().onCompatible(operator, right));
+    }
+
     @Override
     public M onMatching(final Access2D<N> left, final BinaryFunction<N> operator) {
         return this.newInstance(this.supplier().onMatching(left, operator));
@@ -573,6 +596,11 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
         return this.newInstance(this.supplier().onMatching(operator, right));
     }
 
+    @Override
+    public M onRows(final Access1D<N> left, final BinaryFunction<N> operator) {
+        return this.newInstance(this.supplier().onRows(left, operator));
+    }
+
     @Override
     public M onRows(final BinaryFunction<N> operator, final Access1D<N> right) {
         return this.newInstance(this.supplier().onRows(operator, right));
@@ -648,6 +676,11 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
         return this.newInstance(this.store().signum());
     }
 
+    @Override
+    public int size() {
+        return mySupplier.size();
+    }
+
     /**
      * <p>
      * This method solves a system of linear equations: [this][X]=[rhs]. A combination of columns in [this]
@@ -676,7 +709,6 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
 
     @Override
     public M subtract(final M subtrahend) {
-        ProgrammingError.throwIfNotEqualDimensions(this.store(), subtrahend);
         return this.newInstance(this.store().subtract(subtrahend.store()));
     }
 
@@ -700,16 +732,8 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
         return this.newInstance(this.store().symmetric(upper));
     }
 
-    /**
-     * Extracts one element of this matrix as a Scalar.
-     *
-     * @param row A row index.
-     * @param col A column index.
-     * @return One matrix element
-     * @deprecated v50 Use {@link #get(long, long)} instead
-     */
-    @Deprecated
-    public Scalar<N> toScalar(final long row, final long col) {
+    @Override
+    public Scalar<N> toScalar(final int row, final int col) {
         return this.store().toScalar(row, col);
     }
 
@@ -874,9 +898,9 @@ public abstract class BasicMatrix<N extends Comparable<N>, M extends BasicMatrix
 
         if (myStore != null) {
             return myStore;
+        } else {
+            return mySupplier;
         }
-
-        return mySupplier;
     }
 
 }
