@@ -34,7 +34,7 @@ import org.ojalgo.matrix.Provider2D;
 import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.scalar.ComplexNumber;
 import org.ojalgo.scalar.Quadruple;
 import org.ojalgo.scalar.Quaternion;
@@ -80,6 +80,7 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
             vector = aVector;
         }
 
+        @Override
         public int compareTo(final Eigenpair other) {
             return DESCENDING_NORM.compare(value, other.value);
         }
@@ -129,17 +130,20 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
         default Eigenvalue<N> make(final int dimension, final boolean hermitian) {
             return this.make(new Structure2D() {
 
-                public long countColumns() {
+                @Override
+                public int getColDim() {
                     return dimension;
                 }
 
-                public long countRows() {
+                @Override
+                public int getRowDim() {
                     return dimension;
                 }
 
             }, hermitian);
         }
 
+        @Override
         default Eigenvalue<N> make(final Structure2D typical) {
             if (typical instanceof MatrixStore) {
                 return this.make(typical, ((MatrixStore<?>) typical).isHermitian());
@@ -230,7 +234,7 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
         public Eigenvalue.Generalised<ComplexNumber> makeGeneralised(final Structure2D typical, final Eigenvalue.Generalisation type) {
 
             PhysicalStore.Factory<ComplexNumber, GenericStore<ComplexNumber>> factory = GenericStore.C128;
-            Cholesky<ComplexNumber> cholesky = Cholesky.COMPLEX.make(typical);
+            Cholesky<ComplexNumber> cholesky = Cholesky.C128.make(typical);
             Eigenvalue<ComplexNumber> eigenvalue = this.make(typical, true);
 
             return new GeneralisedEvD<>(factory, cholesky, eigenvalue, type);
@@ -238,6 +242,56 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
 
     };
 
+    /**
+     * Sorts on the norm in descending order. If the 2 eigenvalues have equal norm then the usual
+     * {@link ComplexNumber} sort order is used (reversed).
+     */
+    Comparator<ComplexNumber> DESCENDING_NORM = (arg1, arg2) -> {
+        int retVal = Double.compare(arg2.norm(), arg1.norm());
+        if (retVal == 0) {
+            return arg2.compareTo(arg1);
+        }
+        return retVal;
+    };
+
+    Factory<Quaternion> H256 = new Factory<>() {
+
+        @Override
+        public Eigenvalue<Quaternion> make(final Structure2D typical, final boolean hermitian) {
+            return hermitian ? new HermitianEvD.H256() : null;
+        }
+
+        @Override
+        public Eigenvalue.Generalised<Quaternion> makeGeneralised(final Structure2D typical, final Eigenvalue.Generalisation type) {
+
+            PhysicalStore.Factory<Quaternion, GenericStore<Quaternion>> factory = GenericStore.H256;
+            Cholesky<Quaternion> cholesky = Cholesky.H256.make(typical);
+            Eigenvalue<Quaternion> eigenvalue = this.make(typical, true);
+
+            return new GeneralisedEvD<>(factory, cholesky, eigenvalue, type);
+        }
+
+    };
+
+    Factory<RationalNumber> Q128 = new Factory<>() {
+
+        @Override
+        public Eigenvalue<RationalNumber> make(final Structure2D typical, final boolean hermitian) {
+            return hermitian ? new HermitianEvD.Q128() : null;
+        }
+
+        @Override
+        public Eigenvalue.Generalised<RationalNumber> makeGeneralised(final Structure2D typical, final Eigenvalue.Generalisation type) {
+
+            PhysicalStore.Factory<RationalNumber, GenericStore<RationalNumber>> factory = GenericStore.Q128;
+            Cholesky<RationalNumber> cholesky = Cholesky.Q128.make(typical);
+            Eigenvalue<RationalNumber> eigenvalue = this.make(typical, true);
+
+            return new GeneralisedEvD<>(factory, cholesky, eigenvalue, type);
+        }
+
+    };
+
     Factory<Double> R064 = new Factory<>() {
 
         @Override
@@ -265,8 +319,8 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
         @Override
         public Eigenvalue.Generalised<Double> makeGeneralised(final Structure2D typical, final Eigenvalue.Generalisation type) {
 
-            PhysicalStore.Factory<Double, Primitive64Store> factory = Primitive64Store.FACTORY;
-            Cholesky<Double> cholesky = Cholesky.PRIMITIVE.make(typical);
+            PhysicalStore.Factory<Double, R064Store> factory = R064Store.FACTORY;
+            Cholesky<Double> cholesky = Cholesky.R064.make(typical);
             Eigenvalue<Double> eigenvalue = this.make(typical, true);
 
             return new GeneralisedEvD<>(factory, cholesky, eigenvalue, type);
@@ -274,44 +328,6 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
 
     };
 
-    Factory<Quaternion> H256 = new Factory<>() {
-
-        @Override
-        public Eigenvalue<Quaternion> make(final Structure2D typical, final boolean hermitian) {
-            return hermitian ? new HermitianEvD.H256() : null;
-        }
-
-        @Override
-        public Eigenvalue.Generalised<Quaternion> makeGeneralised(final Structure2D typical, final Eigenvalue.Generalisation type) {
-
-            PhysicalStore.Factory<Quaternion, GenericStore<Quaternion>> factory = GenericStore.H256;
-            Cholesky<Quaternion> cholesky = Cholesky.QUATERNION.make(typical);
-            Eigenvalue<Quaternion> eigenvalue = this.make(typical, true);
-
-            return new GeneralisedEvD<>(factory, cholesky, eigenvalue, type);
-        }
-
-    };
-
-    Factory<RationalNumber> Q128 = new Factory<>() {
-
-        @Override
-        public Eigenvalue<RationalNumber> make(final Structure2D typical, final boolean hermitian) {
-            return hermitian ? new HermitianEvD.Q128() : null;
-        }
-
-        @Override
-        public Eigenvalue.Generalised<RationalNumber> makeGeneralised(final Structure2D typical, final Eigenvalue.Generalisation type) {
-
-            PhysicalStore.Factory<RationalNumber, GenericStore<RationalNumber>> factory = GenericStore.Q128;
-            Cholesky<RationalNumber> cholesky = Cholesky.RATIONAL.make(typical);
-            Eigenvalue<RationalNumber> eigenvalue = this.make(typical, true);
-
-            return new GeneralisedEvD<>(factory, cholesky, eigenvalue, type);
-        }
-
-    };
-
     Factory<Quadruple> R128 = new Factory<>() {
 
         @Override
@@ -323,7 +339,7 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
         public Eigenvalue.Generalised<Quadruple> makeGeneralised(final Structure2D typical, final Eigenvalue.Generalisation type) {
 
             PhysicalStore.Factory<Quadruple, GenericStore<Quadruple>> factory = GenericStore.R128;
-            Cholesky<Quadruple> cholesky = Cholesky.QUADRUPLE.make(typical);
+            Cholesky<Quadruple> cholesky = Cholesky.R128.make(typical);
             Eigenvalue<Quadruple> eigenvalue = this.make(typical, true);
 
             return new GeneralisedEvD<>(factory, cholesky, eigenvalue, type);
@@ -331,48 +347,6 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
 
     };
 
-    /**
-     * Sorts on the norm in descending order. If the 2 eigenvalues have equal norm then the usual
-     * {@link ComplexNumber} sort order is used (reversed).
-     */
-    Comparator<ComplexNumber> DESCENDING_NORM = (arg1, arg2) -> {
-        int retVal = Double.compare(arg2.norm(), arg1.norm());
-        if (retVal == 0) {
-            return arg2.compareTo(arg1);
-        }
-        return retVal;
-    };
-
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<ComplexNumber> COMPLEX = C128;
-
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<Double> PRIMITIVE = R064;
-
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<Quaternion> QUATERNION = H256;
-
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<RationalNumber> RATIONAL = Q128;
-
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<Quadruple> QUADRUPLE = R128;
-
     static <N extends Comparable<N>> boolean equals(final MatrixStore<N> matrix, final Eigenvalue<N> decomposition, final NumberContext context) {
 
         final MatrixStore<N> tmpD = decomposition.getD();
@@ -442,6 +416,7 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
      *
      * @see org.ojalgo.matrix.Provider2D.Eigenpairs#getEigenpairs()
      */
+    @Override
     default List<Eigenpair> getEigenpairs() {
 
         List<Eigenpair> retVal = new ArrayList<>();
@@ -569,8 +544,10 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
      *
      * @return true if they are ordered
      */
+    @Override
     boolean isOrdered();
 
+    @Override
     default MatrixStore<N> reconstruct() {
         final MatrixStore<N> mtrxV = this.getV();
         MatrixStore<N> mtrxD = this.getD();
