@@ -48,37 +48,13 @@ public interface Hessenberg<N extends Comparable<N>> extends MatrixDecomposition
 
     Factory<ComplexNumber> C128 = typical -> new HessenbergDecomposition.C128();
 
-    Factory<Quadruple> R128 = typical -> new HessenbergDecomposition.R128();
-
-    Factory<Double> R064 = typical -> new HessenbergDecomposition.R064();
-
     Factory<Quaternion> H256 = typical -> new HessenbergDecomposition.H256();
 
     Factory<RationalNumber> Q128 = typical -> new HessenbergDecomposition.Q128();
 
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<ComplexNumber> COMPLEX = C128;
+    Factory<Double> R064 = typical -> new HessenbergDecomposition.R064();
 
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<Double> PRIMITIVE = R064;
-
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<Quaternion> QUATERNION = H256;
-
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<RationalNumber> RATIONAL = Q128;
+    Factory<Quadruple> R128 = typical -> new HessenbergDecomposition.R128();
 
     static <N extends Comparable<N>> boolean equals(final MatrixStore<N> matrix, final Hessenberg<N> decomposition, final NumberContext context) {
 
