@@ -86,44 +86,14 @@ public interface LDL<N extends Comparable<N>> extends LDU<N>, MatrixDecompositio
 
     Factory<ComplexNumber> C128 = typical -> new LDLDecomposition.C128();
 
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<ComplexNumber> COMPLEX = C128;
-
     Factory<Quaternion> H256 = typical -> new LDLDecomposition.H256();
 
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<Quaternion> QUATERNION = H256;
-
     Factory<Double> R064 = typical -> new LDLDecomposition.R064();
 
     Factory<Quadruple> R128 = typical -> new LDLDecomposition.R128();
 
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<Double> PRIMITIVE = R064;
-
     Factory<RationalNumber> Q128 = typical -> new LDLDecomposition.Q128();
 
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<Quadruple> QUADRUPLE = R128;
-
-    /**
-     * @deprecated
-     */
-    @Deprecated
-    Factory<RationalNumber> RATIONAL = Q128;
-
     static <N extends Comparable<N>> boolean equals(final MatrixStore<N> matrix, final LDL<N> decomposition, final NumberContext context) {
         return Access2D.equals(matrix, decomposition.reconstruct(), context);
     }
