@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2022 Optimatika
+ * Copyright 1997-2024 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -24,6 +24,7 @@ package org.ojalgo.matrix.decomposition;
 import org.ojalgo.array.PlainArray;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.scalar.ComplexNumber;
+import org.ojalgo.scalar.Quadruple;
 import org.ojalgo.scalar.Quaternion;
 import org.ojalgo.scalar.RationalNumber;
 import org.ojalgo.structure.Access2D;
@@ -57,19 +58,22 @@ public interface LU<N extends Comparable<N>> extends LDU<N>, MatrixDecomposition
 
     }
 
-    Factory<ComplexNumber> COMPLEX = typical -> new LUDecomposition.Complex();
+    Factory<ComplexNumber> C128 = typical -> new LUDecomposition.C128();
 
-    Factory<Double> PRIMITIVE = typical -> {
+    Factory<Quaternion> H256 = typical -> new LUDecomposition.H256();
+
+    Factory<RationalNumber> Q128 = typical -> new LUDecomposition.Q128();
+
+    Factory<Double> R064 = typical -> {
 
         if (512L < typical.countColumns() && typical.count() <= PlainArray.MAX_SIZE) {
-            return new LUDecomposition.Primitive();
+            return new LUDecomposition.R064();
+        } else {
+            return new RawLU();
         }
-        return new RawLU();
     };
 
-    Factory<Quaternion> QUATERNION = typical -> new LUDecomposition.Quat();
-
-    Factory<RationalNumber> RATIONAL = typical -> new LUDecomposition.Rational();
+    Factory<Quadruple> R128 = typical -> new LUDecomposition.R128();
 
     static <N extends Comparable<N>> boolean equals(final MatrixStore<N> matrix, final LU<N> decomposition, final NumberContext context) {
 
@@ -93,11 +97,12 @@ public interface LU<N extends Comparable<N>> extends LDU<N>, MatrixDecomposition
      */
     MatrixStore<N> getU();
 
+    @Override
     default MatrixStore<N> reconstruct() {
         MatrixStore<N> mtrxL = this.getL();
         MatrixStore<N> mtrxU = this.getU();
-        int[] pivotOrder = this.getPivotOrder();
-        return mtrxL.multiply(mtrxU).rows(pivotOrder);
+        int[] reversePivotOrder = this.getReversePivotOrder();
+        return mtrxL.multiply(mtrxU).rows(reversePivotOrder);
     }
 
 }
