@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2022 Optimatika
+ * Copyright 1997-2024 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -32,6 +32,7 @@ import org.ojalgo.matrix.store.PhysicalStore;
 import org.ojalgo.matrix.task.DeterminantTask;
 import org.ojalgo.matrix.task.InverterTask;
 import org.ojalgo.matrix.task.SolverTask;
+import org.ojalgo.matrix.transformation.InvertibleFactor;
 import org.ojalgo.structure.Access2D;
 import org.ojalgo.structure.Access2D.Collectable;
 import org.ojalgo.structure.Structure2D;
@@ -72,8 +73,10 @@ public interface MatrixDecomposition<N extends Comparable<N>> extends Structure2
          *
          * @return The matrix' determinant
          */
+        @Override
         N getDeterminant();
 
+        @Override
         default Provider2D.Determinant<N> toDeterminantProvider(final ElementsSupplier<N> original,
                 final Supplier<MatrixStore<N>> alternativeOriginalSupplier) {
             this.decompose(original);
@@ -101,23 +104,62 @@ public interface MatrixDecomposition<N extends Comparable<N>> extends Structure2
 
     interface Factory<D extends MatrixDecomposition<?>> {
 
+        /**
+         * Will create a new decomposition instance and directly perform the decomposition.
+         */
+        default <N extends Comparable<N>, DN extends MatrixDecomposition<N>> DN decompose(final Access2D.Collectable<N, ? super PhysicalStore<N>> matrix) {
+            DN retVal = (DN) this.make(matrix);
+            retVal.decompose(matrix);
+            return retVal;
+        }
+
+        /**
+         * Will create a new decomposition instance suitable for typical/most cases.
+         * <p>
+         * To calculate the decomposition you then need to call the {@link #decompose(Access2D.Collectable)}
+         * method.
+         * 
+         * @return A "decomposer" ready to decompose matrices.
+         */
         default D make() {
             return this.make(TYPICAL);
         }
 
-        default D make(final int numberOfRows, final int numberOfColumns) {
+        /**
+         * Will create a new decomposition instance suitable for matrices of the specified size.
+         * <p>
+         * To calculate the decomposition you then need to call the {@link #decompose(Access2D.Collectable)}
+         * method.
+         * 
+         * @param nbRows The expected number of rows in the matrices to decompose
+         * @param nbCols The expected number of columns in the matrices to decompose
+         * @return A "decomposer" ready to decompose matrices.
+         */
+        default D make(final int nbRows, final int nbCols) {
             return this.make(new Structure2D() {
 
-                public long countColumns() {
-                    return numberOfColumns;
+                @Override
+                public int getColDim() {
+                    return nbCols;
                 }
 
-                public long countRows() {
-                    return numberOfRows;
+                @Override
+                public int getRowDim() {
+                    return nbRows;
                 }
             });
         }
 
+        /**
+         * Will create a new decomposition instance suitable for matrices of the specified size.
+         * <p>
+         * To calculate the decomposition you then need to call the {@link #decompose(Access2D.Collectable)}
+         * method.
+         * 
+         * @param typical A 2D structure of roughly the expected size with which this decomposition will be
+         *        used.
+         * @return A "decomposer" ready to decompose matrices.
+         */
         D make(Structure2D typical);
 
     }
@@ -131,11 +173,11 @@ public interface MatrixDecomposition<N extends Comparable<N>> extends Structure2
     public interface Hermitian<N extends Comparable<N>> extends MatrixDecomposition<N> {
 
         /**
-         * Absolutely must check if the matrix is hermitian or not. Then, depending on the result differents
+         * Absolutely must check if the matrix is hermitian or not. Then, depending on the result different
          * paths can be chosen - compute or not / choose different algorithms...
          *
          * @param matrix A matrix to check and then (maybe) decompose
-         * @return true if the hermitian check passed and decomposition suceeded; false if not
+         * @return true if the hermitian check passed and decomposition succeeded; false if not
          */
         default boolean checkAndDecompose(final MatrixStore<N> matrix) {
 
@@ -143,8 +185,9 @@ public interface MatrixDecomposition<N extends Comparable<N>> extends Structure2
 
             if (matrix.isHermitian()) {
                 return this.decompose(matrix);
+            } else {
+                return false;
             }
-            return false;
         }
     }
 
@@ -201,6 +244,8 @@ public interface MatrixDecomposition<N extends Comparable<N>> extends Structure2
          */
         int[] getPivotOrder();
 
+        int[] getReversePivotOrder();
+
         /**
          * @return true if any pivoting was actually done
          */
@@ -241,6 +286,7 @@ public interface MatrixDecomposition<N extends Comparable<N>> extends Structure2
          *
          * @return The effective numerical rank (best estimate)
          */
+        @Override
         default int getRank() {
             return this.countSignificant(this.getRankThreshold());
         }
@@ -257,7 +303,7 @@ public interface MatrixDecomposition<N extends Comparable<N>> extends Structure2
     }
 
     interface Solver<N extends Comparable<N>> extends MatrixDecomposition<N>, SolverTask<N>, InverterTask<N>, Provider2D.Inverse<Optional<MatrixStore<N>>>,
-            Provider2D.Solution<Optional<MatrixStore<N>>> {
+            Provider2D.Solution<Optional<MatrixStore<N>>>, InvertibleFactor<N> {
 
         /**
          * @param matrix A matrix to decompose
@@ -267,6 +313,16 @@ public interface MatrixDecomposition<N extends Comparable<N>> extends Structure2
             return this.decompose(matrix) && this.isSolvable();
         }
 
+        @Override
+        default void ftran(final Collectable<N, ? super PhysicalStore<N>> rhs, final PhysicalStore<N> solution) {
+            this.getSolution(rhs, solution);
+        }
+
+        @Override
+        default void ftran(final PhysicalStore<N> arg) {
+            this.ftran(arg, arg);
+        }
+
         /**
          * The output must be a "right inverse" and a "generalised inverse".
          */
@@ -274,7 +330,7 @@ public interface MatrixDecomposition<N extends Comparable<N>> extends Structure2
 
         /**
          * <p>
-         * Implementiong this method is optional.
+         * Implementing this method is optional.
          * </p>
          * <p>
          * Exactly how a specific implementation makes use of <code>preallocated</code> is not specified by
@@ -300,7 +356,7 @@ public interface MatrixDecomposition<N extends Comparable<N>> extends Structure2
 
         /**
          * <p>
-         * Implementiong this method is optional.
+         * Implementing this method is optional.
          * </p>
          * <p>
          * Exactly how a specific implementation makes use of <code>preallocated</code> is not specified by
@@ -320,11 +376,13 @@ public interface MatrixDecomposition<N extends Comparable<N>> extends Structure2
          */
         MatrixStore<N> getSolution(Collectable<N, ? super PhysicalStore<N>> rhs, PhysicalStore<N> preallocated);
 
+        @Override
         default Optional<MatrixStore<N>> invert() {
             if (this.isSolvable()) {
                 return Optional.of(this.getInverse());
+            } else {
+                return Optional.empty();
             }
-            return Optional.empty();
         }
 
         /**
@@ -338,29 +396,35 @@ public interface MatrixDecomposition<N extends Comparable<N>> extends Structure2
          */
         boolean isSolvable();
 
+        @Override
         default Optional<MatrixStore<N>> solve(final Access2D<?> rhs) {
             if (this.isSolvable()) {
                 return Optional.of(this.getSolution(rhs.asCollectable2D()));
+            } else {
+                return Optional.empty();
             }
-            return Optional.empty();
         }
 
+        @Override
         default Provider2D.Inverse<Optional<MatrixStore<N>>> toInverseProvider(final ElementsSupplier<N> original,
                 final Supplier<MatrixStore<N>> alternativeOriginalSupplier) {
             boolean ok = this.decompose(original);
             if (ok && this.isSolvable()) {
                 return this;
+            } else {
+                return Optional::empty;
             }
-            return Optional::empty;
         }
 
+        @Override
         default Provider2D.Solution<Optional<MatrixStore<N>>> toSolutionProvider(final ElementsSupplier<N> body,
                 final Supplier<MatrixStore<N>> alternativeBodySupplier, final Access2D<?> rhs) {
             boolean ok = this.decompose(body);
             if (ok && this.isSolvable()) {
                 return this;
+            } else {
+                return r -> Optional.empty();
             }
-            return r -> Optional.empty();
         }
 
     }
@@ -383,12 +447,14 @@ public interface MatrixDecomposition<N extends Comparable<N>> extends Structure2
 
     Structure2D TYPICAL = new Structure2D() {
 
-        public long countColumns() {
-            return 50L;
+        @Override
+        public int getColDim() {
+            return 50;
         }
 
-        public long countRows() {
-            return 50L;
+        @Override
+        public int getRowDim() {
+            return 50;
         }
 
     };
