@@ -29,7 +29,7 @@ import org.ojalgo.function.aggregator.AggregatorFunction;
 import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.matrix.transformation.Householder;
 import org.ojalgo.matrix.transformation.HouseholderReference;
 import org.ojalgo.scalar.ComplexNumber;
@@ -86,7 +86,7 @@ abstract class QRDecomposition<N extends Comparable<N>> extends InPlaceDecomposi
         }
 
         R064(final boolean fullSize) {
-            super(Primitive64Store.FACTORY, fullSize);
+            super(R064Store.FACTORY, fullSize);
         }
 
     }
