@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2022 Optimatika
+ * Copyright 1997-2024 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -125,6 +125,10 @@ abstract class RawEigenvalue extends RawDecomposition implements Eigenvalue<Doub
             super();
         }
 
+        public void btran(final PhysicalStore<Double> arg) {
+            arg.fillByMultiplying(this.getInverse(), arg.copy());
+        }
+
         public MatrixStore<Double> getSolution(final Collectable<Double, ? super PhysicalStore<Double>> rhs) {
             long numberOfEquations = rhs.countRows();
             DecompositionStore<Double> tmpPreallocated = this.allocate(numberOfEquations, numberOfEquations);
