@@ -34,7 +34,7 @@ import org.ojalgo.matrix.store.DiagonalStore;
 import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.scalar.ComplexNumber;
 import org.ojalgo.scalar.Quadruple;
@@ -92,7 +92,7 @@ abstract class SingularValueDecomposition<N extends Comparable<N>> extends Gener
         }
 
         R064(final boolean fullSize) {
-            super(Primitive64Store.FACTORY, new BidiagonalDecomposition.R064(fullSize), fullSize);
+            super(R064Store.FACTORY, new BidiagonalDecomposition.R064(fullSize), fullSize);
         }
 
     }
@@ -109,6 +109,11 @@ abstract class SingularValueDecomposition<N extends Comparable<N>> extends Gener
 
     }
 
+    /**
+     * ≈ 1.6E-291
+     */
+    private static final double TINY = Math.pow(2.0, -966.0);
+
     private static void doCase1(final double[] s, final double[] e, final int p, final int k, final RotateRight q2RotR) {
 
         double f = e[p - 2];
@@ -334,12 +339,12 @@ abstract class SingularValueDecomposition<N extends Comparable<N>> extends Gener
     private final Structure2D myInputStructure = new Structure2D() {
 
         @Override
-        public long countColumns() {
+        public int getColDim() {
             return myTransposed ? myBidiagonal.getRowDim() : myBidiagonal.getColDim();
         }
 
         @Override
-        public long countRows() {
+        public int getRowDim() {
             return myTransposed ? myBidiagonal.getColDim() : myBidiagonal.getRowDim();
         }
     };
