@@ -22,7 +22,6 @@
 package org.ojalgo.matrix.store;
 
 import java.util.Arrays;
-import java.util.List;
 
 import org.ojalgo.ProgrammingError;
 import org.ojalgo.array.*;
@@ -52,6 +51,7 @@ import org.ojalgo.scalar.RationalNumber;
 import org.ojalgo.scalar.Scalar;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.Access2D;
+import org.ojalgo.structure.Factory2D;
 import org.ojalgo.type.math.MathType;
 
 /**
@@ -59,7 +59,8 @@ import org.ojalgo.type.math.MathType;
  *
  * @author apete
  */
-public final class GenericStore<N extends Scalar<N>> extends ScalarArray<N> implements PhysicalStore<N>, DecompositionStore<N> {
+public final class GenericStore<N extends Scalar<N>> extends ScalarArray<N>
+        implements PhysicalStore<N>, DecompositionStore<N>, Factory2D.Builder<GenericStore<N>> {
 
     static final class Factory<N extends Scalar<N>> implements PhysicalStore.Factory<N, GenericStore<N>> {
 
@@ -80,82 +81,6 @@ public final class GenericStore<N extends Scalar<N>> extends ScalarArray<N> impl
             return myDenseArrayFactory;
         }
 
-        @Override
-        public GenericStore<N> columns(final Access1D<?>... source) {
-
-            int tmpRowDim = source[0].size();
-            int tmpColDim = source.length;
-
-            N[] tmpData = myDenseArrayFactory.scalar().newArrayInstance(tmpRowDim * tmpColDim);
-
-            Access1D<?> tmpColumn;
-            for (int j = 0; j < tmpColDim; j++) {
-                tmpColumn = source[j];
-                for (int i = 0; i < tmpRowDim; i++) {
-                    tmpData[i + tmpRowDim * j] = myDenseArrayFactory.scalar().cast(tmpColumn.get(i));
-                }
-            }
-
-            return new GenericStore<>(this, tmpRowDim, tmpColDim, tmpData);
-        }
-
-        @Override
-        public GenericStore<N> columns(final Comparable<?>[]... source) {
-
-            int tmpRowDim = source[0].length;
-            int tmpColDim = source.length;
-
-            N[] tmpData = myDenseArrayFactory.scalar().newArrayInstance(tmpRowDim * tmpColDim);
-
-            Comparable<?>[] tmpColumn;
-            for (int j = 0; j < tmpColDim; j++) {
-                tmpColumn = source[j];
-                for (int i = 0; i < tmpRowDim; i++) {
-                    tmpData[i + tmpRowDim * j] = myDenseArrayFactory.scalar().cast(tmpColumn[i]);
-                }
-            }
-
-            return new GenericStore<>(this, tmpRowDim, tmpColDim, tmpData);
-        }
-
-        @Override
-        public GenericStore<N> columns(final double[]... source) {
-
-            int tmpRowDim = source[0].length;
-            int tmpColDim = source.length;
-
-            N[] tmpData = myDenseArrayFactory.scalar().newArrayInstance(tmpRowDim * tmpColDim);
-
-            double[] tmpColumn;
-            for (int j = 0; j < tmpColDim; j++) {
-                tmpColumn = source[j];
-                for (int i = 0; i < tmpRowDim; i++) {
-                    tmpData[i + tmpRowDim * j] = myDenseArrayFactory.scalar().cast(tmpColumn[i]);
-                }
-            }
-
-            return new GenericStore<>(this, tmpRowDim, tmpColDim, tmpData);
-        }
-
-        @Override
-        public GenericStore<N> columns(final List<? extends Comparable<?>>... source) {
-
-            int tmpRowDim = source[0].size();
-            int tmpColDim = source.length;
-
-            N[] tmpData = myDenseArrayFactory.scalar().newArrayInstance(tmpRowDim * tmpColDim);
-
-            List<? extends Comparable<?>> tmpColumn;
-            for (int j = 0; j < tmpColDim; j++) {
-                tmpColumn = source[j];
-                for (int i = 0; i < tmpRowDim; i++) {
-                    tmpData[i + tmpRowDim * j] = myDenseArrayFactory.scalar().cast(tmpColumn.get(i));
-                }
-            }
-
-            return new GenericStore<>(this, tmpRowDim, tmpColDim, tmpData);
-        }
-
         @Override
         public GenericStore<N> conjugate(final Access2D<?> source) {
 
@@ -225,8 +150,13 @@ public final class GenericStore<N extends Scalar<N>> extends ScalarArray<N> impl
         }
 
         @Override
-        public GenericStore<N> make(final long rows, final long columns) {
-            return new GenericStore<>(this, (int) rows, (int) columns);
+        public GenericStore<N> make(final int nbRows, final int nbCols) {
+            return new GenericStore<>(this, nbRows, nbCols);
+        }
+
+        @Override
+        public GenericStore<N> make(final long nbRows, final long nbCols) {
+            return new GenericStore<>(this, (int) nbRows, (int) nbCols);
         }
 
         @Override
@@ -244,82 +174,6 @@ public final class GenericStore<N extends Scalar<N>> extends ScalarArray<N> impl
             return new Rotation.Generic<>(low, high, cos, sin);
         }
 
-        @Override
-        public GenericStore<N> rows(final Access1D<?>... source) {
-
-            final int tmpRowDim = source.length;
-            final int tmpColDim = (int) source[0].count();
-
-            final N[] tmpData = myDenseArrayFactory.scalar().newArrayInstance(tmpRowDim * tmpColDim);
-
-            Access1D<?> tmpRow;
-            for (int i = 0; i < tmpRowDim; i++) {
-                tmpRow = source[i];
-                for (int j = 0; j < tmpColDim; j++) {
-                    tmpData[i + tmpRowDim * j] = myDenseArrayFactory.scalar().cast(tmpRow.get(j));
-                }
-            }
-
-            return new GenericStore<>(this, tmpRowDim, tmpColDim, tmpData);
-        }
-
-        @Override
-        public GenericStore<N> rows(final Comparable<?>[]... source) {
-
-            final int tmpRowDim = source.length;
-            final int tmpColDim = source[0].length;
-
-            final N[] tmpData = myDenseArrayFactory.scalar().newArrayInstance(tmpRowDim * tmpColDim);
-
-            Comparable<?>[] tmpRow;
-            for (int i = 0; i < tmpRowDim; i++) {
-                tmpRow = source[i];
-                for (int j = 0; j < tmpColDim; j++) {
-                    tmpData[i + tmpRowDim * j] = myDenseArrayFactory.scalar().cast(tmpRow[j]);
-                }
-            }
-
-            return new GenericStore<>(this, tmpRowDim, tmpColDim, tmpData);
-        }
-
-        @Override
-        public GenericStore<N> rows(final double[]... source) {
-
-            final int tmpRowDim = source.length;
-            final int tmpColDim = source[0].length;
-
-            final N[] tmpData = myDenseArrayFactory.scalar().newArrayInstance(tmpRowDim * tmpColDim);
-
-            double[] tmpRow;
-            for (int i = 0; i < tmpRowDim; i++) {
-                tmpRow = source[i];
-                for (int j = 0; j < tmpColDim; j++) {
-                    tmpData[i + tmpRowDim * j] = myDenseArrayFactory.scalar().cast(tmpRow[j]);
-                }
-            }
-
-            return new GenericStore<>(this, tmpRowDim, tmpColDim, tmpData);
-        }
-
-        @Override
-        public GenericStore<N> rows(final List<? extends Comparable<?>>... source) {
-
-            final int tmpRowDim = source.length;
-            final int tmpColDim = source[0].size();
-
-            final N[] tmpData = myDenseArrayFactory.scalar().newArrayInstance(tmpRowDim * tmpColDim);
-
-            List<? extends Comparable<?>> tmpRow;
-            for (int i = 0; i < tmpRowDim; i++) {
-                tmpRow = source[i];
-                for (int j = 0; j < tmpColDim; j++) {
-                    tmpData[i + tmpRowDim * j] = myDenseArrayFactory.scalar().cast(tmpRow.get(j));
-                }
-            }
-
-            return new GenericStore<>(this, tmpRowDim, tmpColDim, tmpData);
-        }
-
         @Override
         public Scalar.Factory<N> scalar() {
             return myDenseArrayFactory.scalar();
@@ -357,29 +211,9 @@ public final class GenericStore<N extends Scalar<N>> extends ScalarArray<N> impl
     }
 
     public static final PhysicalStore.Factory<ComplexNumber, GenericStore<ComplexNumber>> C128 = new GenericStore.Factory<>(ArrayC128.FACTORY);
-    /**
-     * @deprecated Use {@link #C128} instead
-     */
-    @Deprecated
-    public static final PhysicalStore.Factory<ComplexNumber, GenericStore<ComplexNumber>> COMPLEX = C128;
     public static final PhysicalStore.Factory<Quaternion, GenericStore<Quaternion>> H256 = new GenericStore.Factory<>(ArrayH256.FACTORY);
     public static final PhysicalStore.Factory<RationalNumber, GenericStore<RationalNumber>> Q128 = new GenericStore.Factory<>(ArrayQ128.FACTORY);
     public static final PhysicalStore.Factory<Quadruple, GenericStore<Quadruple>> R128 = new GenericStore.Factory<>(ArrayR128.FACTORY);
-    /**
-     * @deprecated Use {@link #R128} instead
-     */
-    @Deprecated
-    public static final PhysicalStore.Factory<Quadruple, GenericStore<Quadruple>> QUADRUPLE = R128;
-    /**
-     * @deprecated Use {@link #H256} instead
-     */
-    @Deprecated
-    public static final PhysicalStore.Factory<Quaternion, GenericStore<Quaternion>> QUATERNION = H256;
-    /**
-     * @deprecated Use {@link #Q128} instead
-     */
-    @Deprecated
-    public static final PhysicalStore.Factory<RationalNumber, GenericStore<RationalNumber>> RATIONAL = Q128;
 
     public static <N extends Scalar<N>> GenericStore<N> wrap(final GenericStore.Factory<N> factory, final N... data) {
         return new GenericStore<>(factory, data.length, 1, data);
@@ -539,6 +373,11 @@ public final class GenericStore<N extends Scalar<N>> extends ScalarArray<N> impl
         return myUtility.flatten();
     }
 
+    @Override
+    public GenericStore<N> build() {
+        return this;
+    }
+
     @Override
     public Array1D<ComplexNumber> computeInPlaceSchur(final PhysicalStore<N> transformationCollector, final boolean eigenvalue) {
         ProgrammingError.throwForUnsupportedOptionalOperation();
@@ -794,21 +633,6 @@ public final class GenericStore<N extends Scalar<N>> extends ScalarArray<N> impl
         }
     }
 
-    @Override
-    public void fillOne(final long row, final long col, final Access1D<?> values, final long valueIndex) {
-        this.set(row, col, values.get(valueIndex));
-    }
-
-    @Override
-    public void fillOne(final long row, final long col, final N value) {
-        myUtility.fillOne(row, col, value);
-    }
-
-    @Override
-    public void fillOne(final long row, final long col, final NullaryFunction<?> supplier) {
-        myUtility.fillOne(row, col, supplier);
-    }
-
     @Override
     public void fillRow(final long row, final long col, final Access1D<N> values) {
         myUtility.fillRow(row, col, values);
@@ -943,7 +767,7 @@ public final class GenericStore<N extends Scalar<N>> extends ScalarArray<N> impl
         final PhysicalStore<N> tmpStep1 = myFactory.make(1L, leftAndRight.count());
         final PhysicalStore<N> tmpStep2 = myFactory.make(1L, 1L);
 
-        final PhysicalStore<N> tmpLeft = myFactory.rows(leftAndRight);
+        final PhysicalStore<N> tmpLeft = myFactory.row(leftAndRight);
         tmpLeft.modifyAll(myFactory.function().conjugate());
         tmpStep1.fillByMultiplying(tmpLeft, this);
 
@@ -1080,8 +904,8 @@ public final class GenericStore<N extends Scalar<N>> extends ScalarArray<N> impl
     }
 
     @Override
-    public Scalar<N> toScalar(final long row, final long column) {
-        return myUtility.get(row, column);
+    public Scalar<N> toScalar(final int row, final int col) {
+        return myUtility.get(row, col);
     }
 
     @Override
@@ -1181,7 +1005,7 @@ public final class GenericStore<N extends Scalar<N>> extends ScalarArray<N> impl
         } else if (matrix instanceof Access2D<?>) {
             return myFactory.copy((Access2D<?>) matrix);
         } else {
-            return myFactory.columns(matrix);
+            return myFactory.column(matrix);
         }
     }
 
