@@ -95,7 +95,7 @@ final class IdentityStore<N extends Comparable<N>> extends FactoryStore<N> {
     @Override
     public MatrixStore<N> multiply(final double scalar) {
 
-        final SparseStore<N> retVal = SparseStore.makeSparse(this.physical(), this);
+        SparseStore<N> retVal = new SparseStore<>(this.physical(), this.getRowDim(), this.getColDim(), Math::min);
 
         retVal.fillDiagonal(this.physical().scalar().cast(scalar));
 
@@ -110,7 +110,7 @@ final class IdentityStore<N extends Comparable<N>> extends FactoryStore<N> {
     @Override
     public MatrixStore<N> multiply(final N scalar) {
 
-        final SparseStore<N> retVal = SparseStore.makeSparse(this.physical(), this);
+        SparseStore<N> retVal = new SparseStore<>(this.physical(), this.getRowDim(), this.getColDim(), Math::min);
 
         retVal.fillDiagonal(scalar);
 
@@ -138,11 +138,12 @@ final class IdentityStore<N extends Comparable<N>> extends FactoryStore<N> {
     }
 
     @Override
-    public Scalar<N> toScalar(final long row, final long column) {
-        if (row == column) {
+    public Scalar<N> toScalar(final int row, final int col) {
+        if (row == col) {
             return this.one();
+        } else {
+            return this.zero();
         }
-        return this.zero();
     }
 
     @Override
