@@ -42,6 +42,16 @@ public final class RowsSupplier<N extends Comparable<N>> implements MatrixStore<
             return this.getCurrent().elements();
         }
 
+        @Override
+        public int getColDim() {
+            return myBase.getColDim();
+        }
+
+        @Override
+        public int getRowDim() {
+            return 1;
+        }
+
         @Override
         public ElementView1D<N, ?> nonzeros() {
             return this.getCurrent().nonzeros();
@@ -110,10 +120,20 @@ public final class RowsSupplier<N extends Comparable<N>> implements MatrixStore<
         return myRows.get(row).get(col);
     }
 
+    @Override
+    public int getColDim() {
+        return myColumnsCount;
+    }
+
     public SparseArray<N> getRow(final int index) {
         return myRows.get(index);
     }
 
+    @Override
+    public int getRowDim() {
+        return myRows.size();
+    }
+
     @Override
     public Factory<N, ?> physical() {
         return myPhysicalStoreFactory;
@@ -148,6 +168,14 @@ public final class RowsSupplier<N extends Comparable<N>> implements MatrixStore<
                 return RowsSupplier.this.get(rows[row], col);
             }
 
+            public int getColDim() {
+                return RowsSupplier.this.getColDim();
+            }
+
+            public int getRowDim() {
+                return rows.length;
+            }
+
             public Factory<N, ?> physical() {
                 return RowsSupplier.this.physical();
             }
