@@ -21,16 +21,19 @@
  */
 package org.ojalgo.matrix.store;
 
-import static org.ojalgo.function.constant.PrimitiveMath.*;
+import static org.ojalgo.function.constant.PrimitiveMath.E;
+import static org.ojalgo.function.constant.PrimitiveMath.ZERO;
 
 import java.util.Arrays;
+import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.function.IntBinaryOperator;
 
 import org.ojalgo.ProgrammingError;
 import org.ojalgo.array.SparseArray;
 import org.ojalgo.array.SparseArray.NonzeroView;
 import org.ojalgo.function.BinaryFunction;
 import org.ojalgo.function.FunctionSet;
-import org.ojalgo.function.NullaryFunction;
 import org.ojalgo.function.UnaryFunction;
 import org.ojalgo.function.VoidFunction;
 import org.ojalgo.function.aggregator.Aggregator;
@@ -48,17 +51,119 @@ import org.ojalgo.structure.Mutate2D;
 import org.ojalgo.structure.Structure2D;
 import org.ojalgo.type.NumberDefinition;
 import org.ojalgo.type.context.NumberContext;
+import org.ojalgo.type.keyvalue.EntryPair;
+import org.ojalgo.type.keyvalue.EntryPair.KeyedPrimitive;
 import org.ojalgo.type.math.MathType;
 
+/**
+ * A sparse matrix (this implementation) is not thread safe. Mutating the matrix (in particular creating
+ * new/more non-zero elements) from multiple threads will result in unpredictable behaviour (even if the
+ * threads update different elements). To mutate the matrix in a concurrent/multi-threaded environment you
+ * need to do one of the following:
+ * <ul>
+ * <li>Use the {@link #synchronised()} method to create a synchronised wrapper of the matrix.
+ * <li>Use the {@link Builder} to build the matrix.
+ * </ul>
+ */
 public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N> implements TransformableRegion<N> {
 
-    public static final class Factory<N extends Comparable<N>> implements Factory2D<SparseStore<N>> {
+    /**
+     * May be a preferable way to build a sparse matrix if:
+     * <ul>
+     * <li>You don't know the number of nonzero elements in advance.
+     * <li>Setting elements in strictly increasing column major order is not possible.
+     * <li>Multiple threads are used to set elements.
+     * </ul>
+     * This builder uses separate/additional memory to store the elements before they are copied to the actual
+     * sparse matrix. The actual sparse matrix is built when the {@link #build()} method is called.
+     */
+    public static final class Builder<N extends Comparable<N>> implements Factory2D.Builder<SparseStore<N>> {
 
+        private final int myColDim;
+        private final Set<KeyedPrimitive<Comparable<?>>> myElements = ConcurrentHashMap.newKeySet();
         private final PhysicalStore.Factory<N, ?> myPhysicalFactory;
+        private final int myRowDim;
 
-        Factory(final org.ojalgo.matrix.store.PhysicalStore.Factory<N, ?> physicalFactory) {
+        Builder(final PhysicalStore.Factory<N, ?> physicalFactory, final int rowDim, final int colDim) {
             super();
             myPhysicalFactory = physicalFactory;
+            myRowDim = rowDim;
+            myColDim = colDim;
+        }
+
+        @Override
+        public SparseStore<N> build() {
+
+            SparseStore<N> retVal = new SparseStore<>(myPhysicalFactory, myRowDim, myColDim, (r, c) -> myElements.size());
+            SparseArray<N> destination = retVal.getElements();
+
+            myElements.stream().sorted().forEach(element -> destination.set(element.longValue(), element.getKey()));
+
+            myElements.clear();
+
+            return retVal;
+        }
+
+        @Override
+        public int getColDim() {
+            return myColDim;
+        }
+
+        @Override
+        public int getRowDim() {
+            return myRowDim;
+        }
+
+        @Override
+        public void set(final int row, final int col, final double value) {
+            myElements.add(EntryPair.of(Double.valueOf(value), Structure2D.index(myRowDim, row, col)));
+        }
+
+        @Override
+        public void set(final long row, final long col, final Comparable<?> value) {
+            myElements.add(EntryPair.of(value, Structure2D.index(myRowDim, row, col)));
+        }
+
+    }
+
+    public static final class Factory<N extends Comparable<N>> implements Factory2D<SparseStore<N>>, Factory2D.TwoStep<SparseStore<N>, SparseStore.Builder<N>> {
+
+        private final IntBinaryOperator myInitial;
+        private final PhysicalStore.Factory<N, ?> myPhysicalFactory;
+
+        Factory(final PhysicalStore.Factory<N, ?> physicalFactory) {
+            this(physicalFactory, Math::max);
+        }
+
+        Factory(final PhysicalStore.Factory<N, ?> physicalFactory, final IntBinaryOperator initial) {
+            super();
+            myPhysicalFactory = physicalFactory;
+            myInitial = initial;
+        }
+
+        @Override
+        public SparseStore<N> copy(final Access2D<?> source) {
+
+            if (source instanceof SparseStore) {
+
+                SparseArray<N> elements = ((SparseStore<N>) source).getElements();
+
+                SparseStore<N> retVal = new SparseStore<>(myPhysicalFactory, source.getRowDim(), source.getColDim(), (r, c) -> elements.countNonzeros());
+
+                SparseArray<N> destination = retVal.getElements();
+
+                if (myPhysicalFactory.getMathType().isPrimitive()) {
+                    elements.nonzeros().stream().forEach(element -> destination.set(element.index(), element.doubleValue()));
+                } else {
+                    elements.nonzeros().stream().forEach(element -> destination.set(element.index(), element.get()));
+                }
+
+                return retVal;
+
+            } else {
+
+                return TwoStep.super.copy(source);
+            }
         }
 
         @Override
@@ -67,8 +172,26 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
         }
 
         @Override
-        public SparseStore<N> make(final long rows, final long columns) {
-            return SparseStore.makeSparse(myPhysicalFactory, rows, columns);
+        public MathType getMathType() {
+            return myPhysicalFactory.getMathType();
+        }
+
+        /**
+         * Specify how to calculate the initial capacity of the sparse store, based on the number of rows and
+         * columns.
+         */
+        public Factory<N> initial(final IntBinaryOperator initial) {
+            return new Factory<>(myPhysicalFactory, initial);
+        }
+
+        @Override
+        public SparseStore<N> make(final int nbRows, final int nbCols) {
+            return new SparseStore<>(myPhysicalFactory, nbRows, nbCols, myInitial);
+        }
+
+        @Override
+        public SparseStore.Builder<N> newBuilder(final long nbRows, final long nbCols) {
+            return new SparseStore.Builder<>(myPhysicalFactory, Math.toIntExact(nbRows), Math.toIntExact(nbCols));
         }
 
         @Override
@@ -76,90 +199,19 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
             return myPhysicalFactory.scalar();
         }
 
-        @Override
-        public MathType getMathType() {
-            return myPhysicalFactory.getMathType();
-        }
-
     }
 
     public static final SparseStore.Factory<ComplexNumber> C128 = SparseStore.factory(GenericStore.C128);
     public static final SparseStore.Factory<Quaternion> H256 = SparseStore.factory(GenericStore.H256);
-    public static final SparseStore.Factory<Double> R032 = SparseStore.factory(Primitive32Store.FACTORY);
-    public static final SparseStore.Factory<Double> R064 = SparseStore.factory(Primitive64Store.FACTORY);
-    public static final SparseStore.Factory<Quadruple> R128 = SparseStore.factory(GenericStore.R128);
     public static final SparseStore.Factory<RationalNumber> Q128 = SparseStore.factory(GenericStore.Q128);
-
-    /**
-     * @deprecated v53 Use {@link #C128} instead
-     */
-    @Deprecated
-    public static final SparseStore.Factory<ComplexNumber> COMPLEX = C128;
-    /**
-     * @deprecated v53 Use {@link #R032} instead
-     */
-    @Deprecated
-    public static final SparseStore.Factory<Double> PRIMITIVE32 = R032;
-    /**
-     * @deprecated v53 Use {@link #R064} instead
-     */
-    @Deprecated
-    public static final SparseStore.Factory<Double> PRIMITIVE64 = R064;
-    /**
-     * @deprecated v53 Use {@link #H256} instead
-     */
-    @Deprecated
-    public static final SparseStore.Factory<Quaternion> QUATERNION = H256;
-    /**
-     * @deprecated v53 Use {@link #Q128} instead
-     */
-    @Deprecated
-    public static final SparseStore.Factory<RationalNumber> RATIONAL = Q128;
+    public static final SparseStore.Factory<Double> R032 = SparseStore.factory(R032Store.FACTORY);
+    public static final SparseStore.Factory<Double> R064 = SparseStore.factory(R064Store.FACTORY);
+    public static final SparseStore.Factory<Quadruple> R128 = SparseStore.factory(GenericStore.R128);
 
     public static <N extends Comparable<N>> SparseStore.Factory<N> factory(final PhysicalStore.Factory<N, ?> physicalFactory) {
         return new SparseStore.Factory<>(physicalFactory);
     }
 
-    /**
-     * @deprecated v53 Use {@link #C128} instead
-     */
-    @Deprecated
-    public static SparseStore<ComplexNumber> makeComplex(final long rowsCount, final long columnsCount) {
-        return SparseStore.makeSparse(GenericStore.C128, rowsCount, columnsCount);
-    }
-
-    /**
-     * @deprecated v53 Use {@link #R064} instead
-     */
-    @Deprecated
-    public static SparseStore<Double> makePrimitive(final long rowsCount, final long columnsCount) {
-        return SparseStore.makeSparse(Primitive64Store.FACTORY, rowsCount, columnsCount);
-    }
-
-    /**
-     * @deprecated v53 Use {@link #R032} instead
-     */
-    @Deprecated
-    public static SparseStore<Double> makePrimitive32(final long rowsCount, final long columnsCount) {
-        return SparseStore.makeSparse(Primitive32Store.FACTORY, rowsCount, columnsCount);
-    }
-
-    /**
-     * @deprecated v53 Use {@link #H256} instead
-     */
-    @Deprecated
-    public static SparseStore<Quaternion> makeQuaternion(final long rowsCount, final long columnsCount) {
-        return SparseStore.makeSparse(GenericStore.H256, rowsCount, columnsCount);
-    }
-
-    /**
-     * @deprecated v53 Use {@link #Q128} instead
-     */
-    @Deprecated
-    public static SparseStore<RationalNumber> makeRational(final long rowsCount, final long columnsCount) {
-        return SparseStore.makeSparse(GenericStore.Q128, rowsCount, columnsCount);
-    }
-
     private static <N extends Scalar<N>> void doGenericColumnAXPY(final SparseArray<N> elements, final long colX, final long colY, final N a,
             final TransformableRegion<N> y) {
 
@@ -182,15 +234,6 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
         elements.visitPrimitiveNonzerosInRange(first, limit, (index, value) -> y.add(Structure2D.row(index, structure), colY, a * value));
     }
 
-    static <N extends Comparable<N>> SparseStore<N> makeSparse(final PhysicalStore.Factory<N, ?> physical, final long numberOfRows,
-            final long numberOfColumns) {
-        return new SparseStore<>(physical, Math.toIntExact(numberOfRows), Math.toIntExact(numberOfColumns));
-    }
-
-    static <N extends Comparable<N>> SparseStore<N> makeSparse(final PhysicalStore.Factory<N, ?> physical, final Structure2D shape) {
-        return SparseStore.makeSparse(physical, shape.countRows(), shape.countColumns());
-    }
-
     static <N extends Comparable<N>> void multiply(final SparseStore<N> left, final SparseStore<N> right, final TransformableRegion<N> target) {
 
         target.reset();
@@ -245,33 +288,29 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
     private final int[] myLimits;
     private final TransformableRegion.FillByMultiplying<N> myMultiplier;
 
-    SparseStore(final PhysicalStore.Factory<N, ?> factory, final int rowsCount, final int columnsCount) {
+    SparseStore(final PhysicalStore.Factory<N, ?> factory, final int nbRows, final int nbCols, final IntBinaryOperator initial) {
 
-        super(factory, rowsCount, columnsCount);
+        super(factory, nbRows, nbCols);
 
-        myElements = SparseArray.factory(factory.array()).limit(this.count()).initial(Math.max(rowsCount, columnsCount)).make();
-        myFirsts = new int[rowsCount];
-        myLimits = new int[rowsCount];
-        Arrays.fill(myFirsts, columnsCount);
+        myElements = SparseArray.factory(factory.array()).initial(initial.applyAsInt(nbRows, nbCols)).make(this.count());
+        myFirsts = new int[nbRows];
+        myLimits = new int[nbRows];
+        Arrays.fill(myFirsts, nbCols);
         // Arrays.fill(myLimits, 0); // Behövs inte, redan 0
 
         Class<? extends Comparable> tmpType = factory.scalar().zero().get().getClass();
-        myMultiplier = Subregion2D.findMultiplier(tmpType, rowsCount, columnsCount);
+        myMultiplier = Subregion2D.findMultiplier(tmpType, nbRows, nbCols);
     }
 
     @Override
     public void add(final long row, final long col, final Comparable<?> addend) {
-        synchronized (myElements) {
-            myElements.add(Structure2D.index(myFirsts.length, row, col), addend);
-        }
+        myElements.add(Structure2D.index(myFirsts.length, row, col), addend);
         this.updateNonZeros(row, col);
     }
 
     @Override
     public void add(final long row, final long col, final double addend) {
-        synchronized (myElements) {
-            myElements.add(Structure2D.index(myFirsts.length, row, col), addend);
-        }
+        myElements.add(Structure2D.index(myFirsts.length, row, col), addend);
         this.updateNonZeros(row, col);
     }
 
@@ -310,28 +349,7 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
             ProgrammingError.throwForMultiplicationNotPossible();
         }
 
-        myMultiplier.invoke(this, left, complexity, right);
-    }
-
-    @Override
-    public void fillOne(final long row, final long col, final Access1D<?> values, final long valueIndex) {
-        this.set(row, col, values.get(valueIndex));
-    }
-
-    @Override
-    public void fillOne(final long row, final long col, final N value) {
-        synchronized (myElements) {
-            myElements.fillOne(Structure2D.index(myFirsts.length, row, col), value);
-        }
-        this.updateNonZeros(row, col);
-    }
-
-    @Override
-    public void fillOne(final long row, final long col, final NullaryFunction<?> supplier) {
-        synchronized (myElements) {
-            myElements.fillOne(Structure2D.index(myFirsts.length, row, col), supplier);
-        }
-        this.updateNonZeros(row, col);
+        myMultiplier.invoke(this.synchronised(), left, complexity, right);
     }
 
     @Override
@@ -512,7 +530,7 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
     @Override
     public MatrixStore<N> multiply(final double scalar) {
 
-        SparseStore<N> retVal = SparseStore.makeSparse(this.physical(), this);
+        SparseStore<N> retVal = new SparseStore<>(this.physical(), this.getRowDim(), this.getColDim(), (r, c) -> myElements.countNonzeros());
 
         if (this.isPrimitive()) {
 
@@ -535,12 +553,12 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
     @Override
     public MatrixStore<N> multiply(final MatrixStore<N> right) {
 
-        long numberOfRows = this.countRows();
-        long numberOfColumns = right.countColumns();
+        int numberOfRows = this.getRowDim();
+        int numberOfColumns = right.getColDim();
 
         if (right instanceof SparseStore) {
 
-            SparseStore<N> retVal = SparseStore.makeSparse(this.physical(), numberOfRows, numberOfColumns);
+            SparseStore<N> retVal = new SparseStore<>(this.physical(), numberOfRows, numberOfColumns, (r, c) -> myElements.countNonzeros());
 
             SparseStore.multiply(this, (SparseStore<N>) right, retVal);
 
@@ -557,7 +575,7 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
     @Override
     public MatrixStore<N> multiply(final N scalar) {
 
-        SparseStore<N> retVal = SparseStore.makeSparse(this.physical(), this);
+        SparseStore<N> retVal = new SparseStore<>(this.physical(), this.getRowDim(), this.getColDim(), (r, c) -> myElements.countNonzeros());
 
         if (this.isPrimitive()) {
 
@@ -593,43 +611,45 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
     @Override
     public ElementsSupplier<N> premultiply(final Access1D<N> left) {
 
-        long complexity = this.countRows();
-        long numberOfColumns = this.countColumns();
-        long numberOfRows = left.count() / complexity;
+        int complexity = this.getRowDim();
+        int nbCols = this.getColDim();
+        int nbRows = Math.toIntExact(left.count() / complexity);
 
         if (left instanceof SparseStore<?>) {
 
-            SparseStore<N> retVal = SparseStore.makeSparse(this.physical(), numberOfRows, numberOfColumns);
+            SparseStore<N> retVal = new SparseStore<>(this.physical(), nbRows, nbCols, (r, c) -> myElements.countNonzeros());
 
             SparseStore.multiply((SparseStore<N>) left, this, retVal);
 
             return retVal;
 
-        }
-        if (!this.isPrimitive()) {
+        } else if (!this.isPrimitive()) {
 
             return super.premultiply(left);
-        }
-        SparseStore<N> retVal = SparseStore.makeSparse(this.physical(), numberOfRows, numberOfColumns);
 
-        this.nonzeros().stream().forEach(element -> {
+        } else {
 
-            long row = element.row();
-            long col = element.column();
-            double value = element.doubleValue();
+            SparseStore<N> retVal = new SparseStore<>(this.physical(), nbRows, nbCols, (r, c) -> myElements.countNonzeros());
 
-            long first = Structure2D.firstInColumn(left, row, 0L);
-            long limit = Structure2D.limitOfColumn(left, row, numberOfRows);
-            for (long i = first; i < limit; i++) {
-                long index = Structure2D.index(numberOfRows, i, row);
-                double addition = value * left.doubleValue(index);
-                if (NumberContext.compare(addition, ZERO) != 0) {
-                    retVal.add(i, col, addition);
+            this.nonzeros().stream().forEach(element -> {
+
+                long row = element.row();
+                long col = element.column();
+                double value = element.doubleValue();
+
+                long first = Structure2D.firstInColumn(left, row, 0L);
+                long limit = Structure2D.limitOfColumn(left, row, nbRows);
+                for (long i = first; i < limit; i++) {
+                    long index = Structure2D.index(nbRows, i, row);
+                    double addition = value * left.doubleValue(index);
+                    if (NumberContext.compare(addition, ZERO) != 0) {
+                        retVal.add(i, col, addition);
+                    }
                 }
-            }
-        });
+            });
 
-        return retVal;
+            return retVal;
+        }
     }
 
     @Override
@@ -662,27 +682,27 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
 
     @Override
     public TransformableRegion<N> regionByColumns(final int... columns) {
-        return new Subregion2D.ColumnsRegion<>(this, myMultiplier, columns);
+        return new Subregion2D.ColumnsRegion<>(this.synchronised(), myMultiplier, columns);
     }
 
     @Override
     public TransformableRegion<N> regionByLimits(final int rowLimit, final int columnLimit) {
-        return new Subregion2D.LimitRegion<>(this, myMultiplier, rowLimit, columnLimit);
+        return new Subregion2D.LimitRegion<>(this.synchronised(), myMultiplier, rowLimit, columnLimit);
     }
 
     @Override
     public TransformableRegion<N> regionByOffsets(final int rowOffset, final int columnOffset) {
-        return new Subregion2D.OffsetRegion<>(this, myMultiplier, rowOffset, columnOffset);
+        return new Subregion2D.OffsetRegion<>(this.synchronised(), myMultiplier, rowOffset, columnOffset);
     }
 
     @Override
     public TransformableRegion<N> regionByRows(final int... rows) {
-        return new Subregion2D.RowsRegion<>(this, myMultiplier, rows);
+        return new Subregion2D.RowsRegion<>(this.synchronised(), myMultiplier, rows);
     }
 
     @Override
     public TransformableRegion<N> regionByTransposing() {
-        return new Subregion2D.TransposedRegion<>(this, myMultiplier);
+        return new Subregion2D.TransposedRegion<>(this.synchronised(), myMultiplier);
     }
 
     @Override
@@ -693,18 +713,14 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
     }
 
     @Override
-    public void set(final long row, final long col, final Comparable<?> value) {
-        synchronized (myElements) {
-            myElements.set(Structure2D.index(myFirsts.length, row, col), value);
-        }
+    public void set(final int row, final int col, final double value) {
+        myElements.set(Structure2D.index(myFirsts.length, row, col), value);
         this.updateNonZeros(row, col);
     }
 
     @Override
-    public void set(final int row, final int col, final double value) {
-        synchronized (myElements) {
-            myElements.set(Structure2D.index(myFirsts.length, row, col), value);
-        }
+    public void set(final long row, final long col, final Comparable<?> value) {
+        myElements.set(Structure2D.index(myFirsts.length, row, col), value);
         this.updateNonZeros(row, col);
     }
 
