@@ -47,16 +47,6 @@ final class TransposedStore<N extends Comparable<N>> extends TransjugatedStore<N
         return this.base().get(aCol, aRow);
     }
 
-    @Override
-    public void loopColumn(final long col, final RowColumnCallback callback) {
-        this.base().loopRow(col, callback);
-    }
-
-    @Override
-    public void loopRow(final long row, final RowColumnCallback callback) {
-        this.base().loopColumn(row, callback);
-    }
-
     @Override
     public MatrixStore<N> multiply(final MatrixStore<N> right) {
 
@@ -92,8 +82,8 @@ final class TransposedStore<N extends Comparable<N>> extends TransjugatedStore<N
     }
 
     @Override
-    public Scalar<N> toScalar(final long row, final long column) {
-        return this.base().toScalar(column, row);
+    public Scalar<N> toScalar(final int row, final int col) {
+        return this.base().toScalar(col, row);
     }
 
     @Override
