@@ -51,12 +51,12 @@ final class ZeroStore<N extends Comparable<N>> extends FactoryStore<N> {
     }
 
     @Override
-    public double doubleValue(final long anInd) {
+    public double doubleValue(final int aRow, final int aCol) {
         return PrimitiveMath.ZERO;
     }
 
     @Override
-    public double doubleValue(final int aRow, final int aCol) {
+    public double doubleValue(final long anInd) {
         return PrimitiveMath.ZERO;
     }
 
@@ -121,7 +121,7 @@ final class ZeroStore<N extends Comparable<N>> extends FactoryStore<N> {
     }
 
     @Override
-    public Scalar<N> toScalar(final long row, final long column) {
+    public Scalar<N> toScalar(final int row, final int col) {
         return this.zero();
     }
 
