@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2022 Optimatika
+ * Copyright 1997-2024 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -29,7 +29,7 @@ import java.math.BigDecimal;
 import java.util.Arrays;
 import java.util.Optional;
 
-import org.ojalgo.matrix.ComplexMatrix;
+import org.ojalgo.matrix.MatrixC128;
 import org.ojalgo.scalar.ComplexNumber;
 import org.ojalgo.scalar.Scalar;
 import org.ojalgo.structure.Access2D;
@@ -73,6 +73,7 @@ public interface BasicLogger {
             myPrintWriter = new PrintWriter(out, true);
         }
 
+        @Override
         public Optional<Writer> asWriter() {
             return Optional.of(this);
         }
@@ -87,55 +88,68 @@ public interface BasicLogger {
             myPrintWriter.flush();
         }
 
+        @Override
         public void print(final boolean value) {
             myPrintWriter.print(value);
         }
 
+        @Override
         public void print(final byte value) {
             myPrintWriter.print(value);
         }
 
+        @Override
         public void print(final char value) {
             myPrintWriter.print(value);
         }
 
+        @Override
         public void print(final double value) {
             myPrintWriter.print(value);
         }
 
+        @Override
         public void print(final float value) {
             myPrintWriter.print(value);
         }
 
+        @Override
         public void print(final int value) {
             myPrintWriter.print(value);
         }
 
+        @Override
         public void print(final long value) {
             myPrintWriter.print(value);
         }
 
+        @Override
         public void print(final Object object) {
             myPrintWriter.append(object.toString());
         }
 
+        @Override
         public void print(final short value) {
             myPrintWriter.print(value);
         }
 
+        @Override
         public void print(final Throwable throwable) {
             throwable.printStackTrace(myPrintWriter);
         }
 
+        @Override
         public void printf(final String format, final Object... args) {
             myPrintWriter.printf(format, args);
             myPrintWriter.println();
         }
 
+        @Override
         public void println() {
             myPrintWriter.println();
         }
 
+        @Override
         public void println(final Object object) {
             myPrintWriter.println(object);
         }
@@ -170,6 +184,12 @@ public interface BasicLogger {
             }
         }
 
+        static void printf(final BasicLogger appender, final String format, final Object... arguments) {
+            if (appender != null) {
+                appender.printf(format, arguments);
+            }
+        }
+
         static void println(final BasicLogger appender) {
             if (appender != null) {
                 appender.println();
@@ -220,56 +240,68 @@ public interface BasicLogger {
 
         private static void printmtrx(final BasicLogger appender, final Access2D<?> matrix, final NumberContext context, final boolean plain) {
 
-            final int tmpRowDim = (int) matrix.countRows();
-            final int tmpColDim = (int) matrix.countColumns();
+            int nbRows = matrix.getRowDim();
+            int nbCols = matrix.getColDim();
 
-            final String[][] tmpElements = new String[tmpRowDim][tmpColDim];
+            String[][] elements = new String[nbRows][nbCols];
 
-            int tmpWidth = 0;
-            Comparable<?> tmpElementNumber;
-            String tmpElementString;
-            for (int j = 0; j < tmpColDim; j++) {
-                for (int i = 0; i < tmpRowDim; i++) {
-                    tmpElementNumber = matrix.get(i, j);
-                    tmpElementString = PrivateDetails.toString(tmpElementNumber, context, plain);
-                    tmpWidth = Math.max(tmpWidth, tmpElementString.length());
-                    tmpElements[i][j] = tmpElementString;
+            int width = 0;
+            Comparable<?> elementNumber;
+            String elementString;
+            for (int j = 0; j < nbCols; j++) {
+                for (int i = 0; i < nbRows; i++) {
+                    elementNumber = matrix.get(i, j);
+                    elementString = PrivateDetails.toString(elementNumber, context, plain);
+                    width = Math.max(width, elementString.length());
+                    elements[i][j] = elementString;
                 }
             }
-            tmpWidth++;
+            width++;
 
-            int tmpPadding;
-            for (int i = 0; i < tmpRowDim; i++) {
-                for (int j = 0; j < tmpColDim; j++) {
-                    tmpElementString = tmpElements[i][j];
-                    tmpPadding = tmpWidth - tmpElementString.length();
-                    for (int p = 0; p < tmpPadding; p++) {
+            int padding;
+            for (int i = 0; i < nbRows; i++) {
+                for (int j = 0; j < nbCols; j++) {
+                    elementString = elements[i][j];
+                    padding = width - elementString.length();
+                    for (int p = 0; p < padding; p++) {
                         appender.print(ASCII.SP);
                     }
-                    appender.print(tmpElementString);
+                    appender.print(elementString);
                 }
                 appender.println();
             }
-
         }
 
         private static String toString(final Comparable<?> number, final NumberContext context, final boolean plain) {
             if (plain) {
                 if (number instanceof Scalar<?>) {
                     return ((Scalar<?>) number).toPlainString(context);
+                } else {
+                    double doubleValue = NumberDefinition.doubleValue(number);
+                    if (Double.isFinite(doubleValue)) {
+                        return context.enforce(BigDecimal.valueOf(doubleValue)).toPlainString();
+                    } else {
+                        return Double.toString(doubleValue);
+                    }
+                }
+            } else {
+                if (number instanceof Scalar<?>) {
+                    return ((Scalar<?>) number).toString(context);
+                } else {
+                    double doubleValue = NumberDefinition.doubleValue(number);
+                    if (Double.isFinite(doubleValue)) {
+                        return context.enforce(BigDecimal.valueOf(doubleValue)).toString();
+                    } else {
+                        return Double.toString(doubleValue);
+                    }
                 }
-                return context.enforce(BigDecimal.valueOf(NumberDefinition.doubleValue(number))).toPlainString();
             }
-            if (number instanceof Scalar<?>) {
-                return ((Scalar<?>) number).toString(context);
-            }
-            return context.enforce(BigDecimal.valueOf(NumberDefinition.doubleValue(number))).toString();
         }
 
         static void printmtrx(final BasicLogger appender, final String message, final Access2D<?> matrix, final NumberContext context) {
             appender.println(message);
             if (matrix.count() > 0L) {
-                if (matrix instanceof ComplexMatrix || matrix.get(0, 0) instanceof ComplexNumber) {
+                if (matrix instanceof MatrixC128 || matrix.get(0, 0) instanceof ComplexNumber) {
                     PrivateDetails.printmtrx(appender, matrix, context, false);
                 } else {
                     PrivateDetails.printmtrx(appender, matrix, context, true);
@@ -285,45 +317,46 @@ public interface BasicLogger {
 
     BasicLogger NULL = new BasicLogger() {
 
+        @Override
         public Optional<Writer> asWriter() {
             return Optional.empty();
         }
 
-        public void print(final boolean value) {
-        }
+        @Override
+        public void print(final boolean value) {}
 
-        public void print(final byte value) {
-        }
+        @Override
+        public void print(final byte value) {}
 
-        public void print(final char value) {
-        }
+        @Override
+        public void print(final char value) {}
 
-        public void print(final double value) {
-        }
+        @Override
+        public void print(final double value) {}
 
-        public void print(final float value) {
-        }
+        @Override
+        public void print(final float value) {}
 
-        public void print(final int value) {
-        }
+        @Override
+        public void print(final int value) {}
 
-        public void print(final long value) {
-        }
+        @Override
+        public void print(final long value) {}
 
-        public void print(final Object object) {
-        }
+        @Override
+        public void print(final Object object) {}
 
-        public void print(final short value) {
-        }
+        @Override
+        public void print(final short value) {}
 
-        public void print(final Throwable throwable) {
-        }
+        @Override
+        public void print(final Throwable throwable) {}
 
-        public void printf(final String format, final Object... args) {
-        }
+        @Override
+        public void printf(final String format, final Object... args) {}
 
-        public void println() {
-        }
+        @Override
+        public void println() {}
 
     };
 
@@ -331,14 +364,6 @@ public interface BasicLogger {
         NotNull.println(DEBUG);
     }
 
-    /**
-     * @deprecated Use {@link #debugColumns(int,Object...)} instead
-     */
-    @Deprecated
-    static void debug(final int width, final Object... columns) {
-        BasicLogger.debugColumns(width, columns);
-    }
-
     static void debug(final int tabs, final String message, final Object... arguments) {
         NotNull.println(DEBUG, tabs, message, arguments);
     }
@@ -347,22 +372,6 @@ public interface BasicLogger {
         NotNull.println(DEBUG, message);
     }
 
-    /**
-     * @deprecated Use {@link #debugMatrix(String,Access2D<?>)} instead
-     */
-    @Deprecated
-    static void debug(final String message, final Access2D<?> matrix) {
-        BasicLogger.debugMatrix(message, matrix);
-    }
-
-    /**
-     * @deprecated Use {@link #debugMatrix(String,Access2D<?>,NumberContext)} instead
-     */
-    @Deprecated
-    static void debug(final String message, final Access2D<?> matrix, final NumberContext context) {
-        BasicLogger.debugMatrix(message, matrix, context);
-    }
-
     static void debug(final String message, final Object... arguments) {
         NotNull.println(DEBUG, message, arguments);
     }
@@ -375,6 +384,10 @@ public interface BasicLogger {
         NotNull.columns(DEBUG, width, columns);
     }
 
+    static void debugFormatted(final String format, final Object... args) {
+        NotNull.printf(DEBUG, format, args);
+    }
+
     static void debugMatrix(final String message, final Access2D<?> matrix) {
         NotNull.printmtrx(DEBUG, message, matrix, PrivateDetails.MATRIX_ELEMENT_CONTEXT);
     }
@@ -387,14 +400,6 @@ public interface BasicLogger {
         NotNull.println(ERROR);
     }
 
-    /**
-     * @deprecated Use {@link #errorColumns(int,Object...)} instead
-     */
-    @Deprecated
-    static void error(final int width, final Object... columns) {
-        BasicLogger.errorColumns(width, columns);
-    }
-
     static void error(final int tabs, final String message, final Object... arguments) {
         NotNull.println(ERROR, tabs, message, arguments);
     }
@@ -403,22 +408,6 @@ public interface BasicLogger {
         NotNull.println(ERROR, message);
     }
 
-    /**
-     * @deprecated Use {@link #errorMatrix(String,Access2D<?>)} instead
-     */
-    @Deprecated
-    static void error(final String message, final Access2D<?> matrix) {
-        BasicLogger.errorMatrix(message, matrix);
-    }
-
-    /**
-     * @deprecated Use {@link #errorMatrix(String,Access2D<?>,NumberContext)} instead
-     */
-    @Deprecated
-    static void error(final String message, final Access2D<?> matrix, final NumberContext context) {
-        BasicLogger.errorMatrix(message, matrix, context);
-    }
-
     static void error(final String message, final Object... arguments) {
         NotNull.println(ERROR, message, arguments);
     }
@@ -431,6 +420,10 @@ public interface BasicLogger {
         NotNull.columns(ERROR, width, columns);
     }
 
+    static void errorFormatted(final String format, final Object... args) {
+        NotNull.printf(ERROR, format, args);
+    }
+
     static void errorMatrix(final String message, final Access2D<?> matrix) {
         NotNull.printmtrx(ERROR, message, matrix, PrivateDetails.MATRIX_ELEMENT_CONTEXT);
     }
