@@ -191,26 +191,30 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
 
         /**
          * The number of variables, in the solver, that directly correspond to a model variable. (Not slack or
-         * artificial variables.) This defines the range of the indices that can be used with the indexOf
-         * method.
+         * artificial variables.)
+         * <p>
+         * This defines the range of the indices that can be used with the {@link #indexOf(int)} and
+         * {@link #isNegated(int)} methods.
          */
         int countModelVariables();
 
         /**
-         * The number of slack variables
+         * The number of slack variables.
+         * <p>
+         * This defines the range of the indices that can be used with the {@link #getSlack(int)} method.
          */
         int countSlackVariables();
 
-        EntryPair<ModelEntity<?>, ConstraintType> getConstraintMap(int i);
+        EntryPair<ModelEntity<?>, ConstraintType> getConstraint(int idc);
 
         /**
          * Returns which model entity, and constraint type, that corresponds to the slack variable at the
          * supplied index.
          *
-         * @param idx Index of solver slack variable (If there are 3 slack variables this input argument
+         * @param ids Index of solver slack variable (If there are 3 slack variables this input argument
          *        should be in the range [0.2].)
          */
-        EntryPair<ModelEntity<?>, ConstraintType> getSlack(int idx);
+        EntryPair<ModelEntity<?>, ConstraintType> getSlack(int ids);
 
         /**
          * Converts from a solver specific variable index to the corresponding index of the variable in the
@@ -218,18 +222,18 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
          * variable may result in multiple solver variables. Further, slack variables, artificial variables
          * and such are typically not represented in the model.
          *
-         * @param idx Index of solver variable
+         * @param idm Index of solver variable
          * @return Index of model variable (negative if no map)
          */
-        int indexOf(int idx);
+        int indexOf(int idm);
 
         /**
          * Is this solver variable negated relative to the corresponding model variable?
          *
-         * @param idx Index of solver variable
+         * @param idm Index of solver variable
          * @return true if this solver variable represents a negated model variable
          */
-        boolean isNegated(int idx);
+        boolean isNegated(int idm);
 
     }
 
@@ -739,19 +743,6 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         this(new Optimisation.Options());
     }
 
-    /**
-     * @deprecated v53 Use {@link #ExpressionsBasedModel()} and {@link #newVariable(String)} instead.
-     */
-    @Deprecated
-    public ExpressionsBasedModel(final Collection<? extends Variable> variables) {
-
-        this();
-
-        for (Variable variable : variables) {
-            this.addVariable(variable);
-        }
-    }
-
     public ExpressionsBasedModel(final Optimisation.Options optimisationOptions) {
 
         super();
@@ -764,19 +755,6 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         myRelaxed = false;
     }
 
-    /**
-     * @deprecated v53 Use {@link #ExpressionsBasedModel()} and {@link #newVariable(String)} instead.
-     */
-    @Deprecated
-    public ExpressionsBasedModel(final Variable... variables) {
-
-        this();
-
-        for (Variable variable : variables) {
-            this.addVariable(variable);
-        }
-    }
-
     ExpressionsBasedModel(final ExpressionsBasedModel modelToCopy, final boolean shallow, final boolean prune) {
 
         super();
@@ -787,7 +765,7 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         this.addObjectiveConstant(modelToCopy.getObjectiveConstant());
 
         for (Variable tmpVar : modelToCopy.getVariables()) {
-            myVariables.add(tmpVar.clone());
+            myVariables.add(tmpVar.copy());
         }
 
         Set<IntIndex> fixedVariables = modelToCopy.getFixedVariables();
@@ -814,6 +792,8 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
 
         myShallowCopy = shallow || modelToCopy.isShallowCopy();
         myRelaxed = modelToCopy.isRelaxed();
+        myKnownSolution = modelToCopy.getKnownSolution(); // TODO Should this be copied?
+        myValidationFailureHandler = modelToCopy.getValidationFailureHandler();
     }
 
     public Expression addExpression() {
@@ -881,7 +861,7 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
             if (variable == null || variable.getIndex() == null || !variable.isBinary()) {
                 throw new ProgrammingError("Variables must be binary and already inserted in the model!");
             }
-            expression.set(variable.getIndex(), ONE);
+            expression.doSet(variable.getIndex(), ONE);
         }
 
         expression.upper(BigDecimal.valueOf(max));
@@ -900,38 +880,6 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         return this.newVariable(name);
     }
 
-    /**
-     * @deprecated v53 Use {@link #newVariable(String)} instead.
-     */
-    @Deprecated
-    public void addVariable(final Variable variable) {
-        if (myShallowCopy) {
-            throw new IllegalStateException("This model is a work copy - its set of variables cannot be modified!");
-        }
-        myVariables.add(variable);
-        variable.setIndex(new IntIndex(myVariables.size() - 1));
-    }
-
-    /**
-     * @deprecated v53 Use {@link #newVariable(String)} instead.
-     */
-    @Deprecated
-    public void addVariables(final Collection<? extends Variable> variables) {
-        for (final Variable tmpVariable : variables) {
-            this.addVariable(tmpVariable);
-        }
-    }
-
-    /**
-     * @deprecated v53 Use {@link #newVariable(String)} instead.
-     */
-    @Deprecated
-    public void addVariables(final Variable[] variables) {
-        for (final Variable tmpVariable : variables) {
-            this.addVariable(tmpVariable);
-        }
-    }
-
     /**
      * @return A prefiltered stream of variables that are constraints and not fixed
      */
@@ -1337,8 +1285,13 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
     }
 
     public Variable newVariable(final String name) {
-        final Variable retVal = new Variable(name);
-        this.addVariable(retVal);
+
+        if (myShallowCopy) {
+            throw new IllegalStateException("This model is a work copy - its set of variables cannot be modified!");
+        }
+
+        Variable retVal = new Variable(name, myVariables.size());
+        myVariables.add(retVal);
         return retVal;
     }
 
@@ -1381,7 +1334,7 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
                         tmpOldVal = retVal.get(tmpKey);
                         tmpDiff = tmpExpression.get(tmpKey);
                         tmpNewVal = tmpOldVal.add(tmpNotOne ? tmpContributionWeight.multiply(tmpDiff) : tmpDiff);
-                        retVal.set(tmpKey, tmpNewVal);
+                        retVal.doSet(tmpKey, tmpNewVal);
                     }
                 }
 
@@ -1390,7 +1343,7 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
                         tmpOldVal = retVal.get(tmpKey);
                         tmpDiff = tmpExpression.get(tmpKey);
                         tmpNewVal = tmpOldVal.add(tmpNotOne ? tmpContributionWeight.multiply(tmpDiff) : tmpDiff);
-                        retVal.set(tmpKey, tmpNewVal);
+                        retVal.doSet(tmpKey, tmpNewVal);
                     }
                 }
             }
@@ -1902,4 +1855,12 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         myOptimisationSense = optimisationSense;
     }
 
+    IntIndex toIntIndex(final int index) {
+        return myVariables.get(index).getIndex();
+    }
+
+    IntRowColumn toIntRowColumn(final int row, final int column) {
+        return new IntRowColumn(myVariables.get(row).getIndex(), myVariables.get(column).getIndex());
+    }
+
 }
