@@ -23,19 +23,19 @@ package org.ojalgo.optimisation.convex;
 
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
-import org.ojalgo.optimisation.ConstraintsMap;
+import org.ojalgo.matrix.store.R064Store;
+import org.ojalgo.optimisation.ConstraintsMetaData;
 import org.ojalgo.optimisation.Optimisation;
 import org.ojalgo.structure.Access2D.Collectable;
 
 abstract class ConstrainedSolver extends BasePrimitiveSolver {
 
-    private final Primitive64Store mySlackE;
-    private final Primitive64Store mySolutionL;
+    private final R064Store mySlackE;
+    private final R064Store mySolutionL;
 
-    protected ConstrainedSolver(final ConvexData<Double> convexSolverBuilder, final Optimisation.Options optimisationOptions) {
+    protected ConstrainedSolver(final ConvexData<Double> convexData, final Optimisation.Options optimisationOptions) {
 
-        super(convexSolverBuilder, optimisationOptions);
+        super(convexData, optimisationOptions);
 
         int numberOfEqualityConstraints = this.countEqualityConstraints();
         int numberOfInequalityConstraints = this.countInequalityConstraints();
@@ -49,7 +49,7 @@ abstract class ConstrainedSolver extends BasePrimitiveSolver {
 
         Result result = super.buildResult();
 
-        ConstraintsMap constraints = this.getEntityMap().getConstraintsMap();
+        ConstraintsMetaData constraints = this.getEntityMap().getConstraintsMetaData();
         if (constraints.isEntityMap()) {
             return result.multipliers(constraints, mySolutionL);
         } else {
@@ -136,7 +136,7 @@ abstract class ConstrainedSolver extends BasePrimitiveSolver {
         return mySlackE;
     }
 
-    Primitive64Store getSolutionL() {
+    R064Store getSolutionL() {
         return mySolutionL;
     }
 
