@@ -33,7 +33,7 @@ import org.ojalgo.equation.Equation;
 import org.ojalgo.matrix.store.ElementsSupplier;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.matrix.task.iterative.ConjugateGradientSolver;
 import org.ojalgo.matrix.task.iterative.MutableSolver;
 import org.ojalgo.optimisation.Optimisation;
@@ -85,16 +85,6 @@ final class IterativeASS extends ActiveSetSolver {
             myIterationRows = new Equation[myFullDim];
         }
 
-        @Override
-        public long countColumns() {
-            return IterativeASS.this.countEqualityConstraints() + IterativeASS.this.countIncluded();
-        }
-
-        @Override
-        public long countRows() {
-            return IterativeASS.this.countEqualityConstraints() + IterativeASS.this.countIncluded();
-        }
-
         @Override
         public double doubleValue(final int row, final int col) {
 
@@ -113,6 +103,16 @@ final class IterativeASS extends ActiveSetSolver {
             return Double.valueOf(this.doubleValue(row, col));
         }
 
+        @Override
+        public int getColDim() {
+            return IterativeASS.this.countEqualityConstraints() + IterativeASS.this.countIncluded();
+        }
+
+        @Override
+        public int getRowDim() {
+            return IterativeASS.this.countEqualityConstraints() + IterativeASS.this.countIncluded();
+        }
+
         @Override
         public PhysicalStore.Factory<Double, ?> physical() {
             return MATRIX_FACTORY;
@@ -201,9 +201,9 @@ final class IterativeASS extends ActiveSetSolver {
      */
     private final SchurComplementSolver myS;
 
-    IterativeASS(final ConvexData<Double> convexSolverBuilder, final Optimisation.Options optimisationOptions) {
+    IterativeASS(final ConvexData<Double> convexData, final Optimisation.Options optimisationOptions) {
 
-        super(convexSolverBuilder, optimisationOptions);
+        super(convexData, optimisationOptions);
 
         myS = new SchurComplementSolver();
         myColumnInvQAt = MATRIX_FACTORY.make(this.countVariables(), 1);
@@ -240,7 +240,7 @@ final class IterativeASS extends ActiveSetSolver {
             this.addConstraint(constrIndex, constrBody, constrRHS);
         }
 
-        Primitive64Store iterX = this.getIterationX();
+        R064Store iterX = this.getIterationX();
 
         if (this.countIterationConstraints() <= this.countVariables() && (solved = this.isSolvableQ())) {
             // Q is SPD
@@ -274,7 +274,7 @@ final class IterativeASS extends ActiveSetSolver {
         if (!solved) {
             // The above failed, try solving the full KKT system instaed
 
-            Primitive64Store tmpXL = MATRIX_FACTORY.make(this.countVariables() + this.countIterationConstraints(), 1L);
+            R064Store tmpXL = MATRIX_FACTORY.make(this.countVariables() + this.countIterationConstraints(), 1L);
 
             if (solved = this.solveFullKKT(tmpXL)) {
 
