@@ -35,7 +35,7 @@ import org.ojalgo.concurrent.MultiviewSet;
 import org.ojalgo.concurrent.ProcessingService;
 import org.ojalgo.function.multiary.MultiaryFunction;
 import org.ojalgo.matrix.store.MatrixStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.netio.CharacterRing;
 import org.ojalgo.netio.CharacterRing.RingLogger;
@@ -162,6 +162,10 @@ public final class IntegerSolver extends GenericSolver {
         return new IntegerSolver(model);
     }
 
+    public static IntegerSolver newSolver(final ExpressionsBasedModel model) {
+        return INTEGRATION.build(model);
+    }
+
     static void flush(final RingLogger buffer, final BasicLogger receiver) {
         if (buffer != null && receiver != null) {
             buffer.flush(receiver);
@@ -200,10 +204,12 @@ public final class IntegerSolver extends GenericSolver {
 
         this.resetIterationsCount();
 
-        ExpressionsBasedModel cutModel = myIntegerModel.snapshot();
-        NodeSolver cutSolver = cutModel.prepare(NodeSolver::new);
-        Result cutResult = cutSolver.solve();
-        cutSolver.generateCuts(strategy, myIntegerModel);
+        if (strategy.cutting) {
+            ExpressionsBasedModel cutModel = myIntegerModel.snapshot();
+            NodeSolver cutSolver = cutModel.prepare(NodeSolver::new);
+            Result cutResult = cutSolver.solve();
+            cutSolver.generateCuts(strategy, myIntegerModel);
+        }
 
         NodeKey rootNode = new NodeKey(myIntegerModel);
         ExpressionsBasedModel rootModel = myIntegerModel.snapshot();
@@ -297,7 +303,7 @@ public final class IntegerSolver extends GenericSolver {
     }
 
     protected MatrixStore<Double> extractSolution() {
-        return Primitive64Store.FACTORY.columns(this.getBestResultSoFar());
+        return R064Store.FACTORY.column(this.getBestResultSoFar());
     }
 
     protected Optimisation.Result getBestEstimate() {
@@ -314,7 +320,7 @@ public final class IntegerSolver extends GenericSolver {
 
         State tmpSate = State.INVALID;
         double tmpValue = myMinimisation ? Double.POSITIVE_INFINITY : Double.NEGATIVE_INFINITY;
-        MatrixStore<Double> tmpSolution = Primitive64Store.FACTORY.makeZero(myIntegerModel.countVariables(), 1);
+        MatrixStore<Double> tmpSolution = R064Store.FACTORY.makeZero(myIntegerModel.countVariables(), 1);
 
         return new Optimisation.Result(tmpSate, tmpValue, tmpSolution);
     }
@@ -516,10 +522,10 @@ public final class IntegerSolver extends GenericSolver {
             IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
         }
 
-        if (strategy.cutting && nodeKey.sequence % 10L == 0L) {
+        if (strategy.cutting && nodeKey.sequence % 100L == 0L) {
             double displacement = nodeKey.getMinimumDisplacement(branchIntegerIndex, variableValue);
             if (strategy.isCutRatherThanBranch(displacement, myBestResultSoFar != null)) {
-                if (nodeSolver.generateCuts(strategy)) {
+                if (nodeSolver.generateCuts(strategy, nodeKey)) {
                     return this.compute(nodeKey, nodeSolver, nodePrinter, strategy);
                 }
                 strategy.cutting = false;
