@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2022 Optimatika
+ * Copyright 1997-2024 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -219,6 +219,10 @@ public abstract class ModelStrategy implements IntegerStrategy {
         return myStrategy.getGMICutConfiguration();
     }
 
+    public NumberContext getIntegralityTolerance() {
+        return myStrategy.getIntegralityTolerance();
+    }
+
     public List<Comparator<NodeKey>> getWorkerPriorities() {
         return myWorkerPriorities;
     }
