@@ -24,20 +24,27 @@ package org.ojalgo.optimisation.linear;
 import static org.ojalgo.function.constant.PrimitiveMath.*;
 
 import java.math.RoundingMode;
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.List;
+import java.util.Set;
+import java.util.function.Function;
 
+import org.ojalgo.array.operation.IndexOf;
 import org.ojalgo.equation.Equation;
-import org.ojalgo.netio.BasicLogger;
-import org.ojalgo.optimisation.ConstraintsMap;
+import org.ojalgo.optimisation.ConstraintsMetaData;
+import org.ojalgo.optimisation.Expression;
+import org.ojalgo.optimisation.ExpressionsBasedModel;
 import org.ojalgo.optimisation.Optimisation;
+import org.ojalgo.optimisation.Variable;
 import org.ojalgo.optimisation.linear.SimplexStore.ColumnState;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.Access2D;
-import org.ojalgo.type.PrimitiveNumber;
+import org.ojalgo.structure.Mutate1D;
+import org.ojalgo.structure.Mutate2D;
+import org.ojalgo.structure.Structure1D.IntIndex;
 import org.ojalgo.type.context.NumberContext;
-import org.ojalgo.type.keyvalue.EntryPair;
-import org.ojalgo.type.keyvalue.EntryPair.KeyedPrimitive;
 
 /**
  * Meant to replace {@link SimplexTableauSolver}. It is already better in many aspects, but still can't do
@@ -110,12 +117,22 @@ abstract class SimplexSolver extends LinearSolver {
             return index >= 0 ? myExcluded[index] : index;
         }
 
+        void column(final int column) {
+            index = this.indexOf(column);
+        }
+
+        int indexOf(final int column) {
+            return IndexOf.indexOf(myExcluded, column);
+        }
+
         void reset() {
             index = -1;
             from = ColumnState.BASIS;
             direction = Direction.STAY;
         }
+
     }
+
     /**
      * Exit from {@link ColumnState#BASIS} to either {@link ColumnState#LOWER} or {@link ColumnState#UPPER}.
      * <p>
@@ -173,6 +190,10 @@ abstract class SimplexSolver extends LinearSolver {
             return index >= 0 ? myIncluded[index] : index;
         }
 
+        int indexOf(final int column) {
+            return IndexOf.indexOf(myIncluded, column);
+        }
+
         void reset() {
             index = -1;
             to = ColumnState.BASIS;
@@ -243,6 +264,10 @@ abstract class SimplexSolver extends LinearSolver {
             }
         }
 
+        int column() {
+            return enter.column();
+        }
+
         /**
          * Normal basis update – one variable leaves the basis and another enters.
          */
@@ -280,9 +305,114 @@ abstract class SimplexSolver extends LinearSolver {
             ratioDual = MACHINE_LARGEST;
         }
 
+        int row() {
+            return exit.row();
+        }
+
     }
 
-    private static final NumberContext ALGORITHM = NumberContext.of(8).withMode(RoundingMode.HALF_DOWN);
+    private static final NumberContext PIVOT = NumberContext.of(6).withMode(RoundingMode.HALF_DOWN);
+    private static final NumberContext RATIO = NumberContext.of(8).withMode(RoundingMode.HALF_DOWN);
+
+    static <S extends SimplexStore> S build(final ExpressionsBasedModel model, final Function<LinearStructure, S> factory) {
+
+        Set<IntIndex> fixedVariables = model.getFixedVariables();
+        List<Variable> freeVariables = model.getFreeVariables();
+
+        List<Expression> equalityConstraints = new ArrayList<>();
+        List<Expression> lowerConstraints = new ArrayList<>();
+        List<Expression> upperConstraints = new ArrayList<>();
+
+        model.constraints().map(c -> c.compensate(fixedVariables)).forEach(constraint -> {
+            if (constraint.isEqualityConstraint()) {
+                equalityConstraints.add(constraint);
+            } else {
+                if (constraint.isLowerConstraint()) {
+                    lowerConstraints.add(constraint);
+                }
+                if (constraint.isUpperConstraint()) {
+                    upperConstraints.add(constraint);
+                }
+            }
+        });
+
+        Expression objective = model.objective().compensate(fixedVariables);
+
+        int nbUpConstr = upperConstraints.size();
+        int nbLoConstr = lowerConstraints.size();
+        int nbEqConstr = equalityConstraints.size();
+
+        int nbProbVars = freeVariables.size();
+        int nbSlckVars = nbUpConstr + nbLoConstr;
+
+        LinearStructure structure = new LinearStructure(true, nbUpConstr + nbLoConstr, nbEqConstr, nbProbVars, 0, 0, nbSlckVars);
+
+        S simplex = factory.apply(structure);
+        double[] lowerBounds = simplex.getLowerBounds();
+        double[] upperBounds = simplex.getUpperBounds();
+
+        Mutate2D mtrxA = simplex.constraintsBody();
+        Mutate1D mtrxB = simplex.constraintsRHS();
+        Mutate1D mtrxC = simplex.objective();
+
+        for (int i = 0; i < nbUpConstr; i++) {
+            Expression expression = upperConstraints.get(i);
+            for (IntIndex key : expression.getLinearKeySet()) {
+                int column = model.indexOfFreeVariable(key);
+                double factor = expression.doubleValue(key, true);
+                mtrxA.set(i, column, factor);
+            }
+            mtrxA.set(i, nbProbVars + i, ONE);
+            mtrxB.set(i, expression.getUpperLimit(true, POSITIVE_INFINITY));
+            lowerBounds[nbProbVars + i] = ZERO;
+            upperBounds[nbProbVars + i] = POSITIVE_INFINITY;
+            structure.setConstraintMap(i, expression, ConstraintType.UPPER, false);
+        }
+
+        for (int i = 0; i < nbLoConstr; i++) {
+            Expression expression = lowerConstraints.get(i);
+            for (IntIndex key : expression.getLinearKeySet()) {
+                int column = model.indexOfFreeVariable(key);
+                double factor = expression.doubleValue(key, true);
+                mtrxA.set(nbUpConstr + i, column, factor);
+            }
+            mtrxA.set(nbUpConstr + i, nbProbVars + nbUpConstr + i, ONE);
+            mtrxB.set(nbUpConstr + i, expression.getLowerLimit(true, NEGATIVE_INFINITY));
+            lowerBounds[nbProbVars + nbUpConstr + i] = NEGATIVE_INFINITY;
+            upperBounds[nbProbVars + nbUpConstr + i] = ZERO;
+            structure.setConstraintMap(nbUpConstr + i, expression, ConstraintType.LOWER, true);
+        }
+
+        for (int i = 0; i < nbEqConstr; i++) {
+            Expression expression = equalityConstraints.get(i);
+            for (IntIndex key : expression.getLinearKeySet()) {
+                int column = model.indexOfFreeVariable(key);
+                double factor = expression.doubleValue(key, true);
+                mtrxA.set(nbUpConstr + nbLoConstr + i, column, factor);
+            }
+            mtrxA.set(nbUpConstr + nbLoConstr + i, nbProbVars + nbSlckVars + i, ONE);
+            mtrxB.set(nbUpConstr + nbLoConstr + i, expression.getUpperLimit(true, ZERO));
+            lowerBounds[nbProbVars + nbSlckVars + i] = ZERO;
+            upperBounds[nbProbVars + nbSlckVars + i] = ZERO;
+            structure.setConstraintMap(nbUpConstr + nbLoConstr + i, expression, ConstraintType.EQUALITY, false);
+        }
+
+        for (int i = 0; i < nbProbVars; i++) {
+            Variable variable = freeVariables.get(i);
+            lowerBounds[i] = variable.getLowerLimit(false, NEGATIVE_INFINITY);
+            upperBounds[i] = variable.getUpperLimit(false, POSITIVE_INFINITY);
+            structure.positivePartVariables[i] = model.indexOf(variable);
+        }
+
+        structure.setObjectiveAdjustmentFactor(objective.getAdjustmentFactor());
+        boolean negate = model.getOptimisationSense() == Optimisation.Sense.MAX;
+        for (IntIndex key : objective.getLinearKeySet()) {
+            double weight = objective.doubleValue(key, true);
+            mtrxC.set(model.indexOfFreeVariable(key), negate ? -weight : weight);
+        }
+
+        return simplex;
+    }
 
     private final SimplexStore mySimplex;
     private final double[] mySolutionShift;
@@ -294,25 +424,17 @@ abstract class SimplexSolver extends LinearSolver {
         mySolutionShift = new double[simplexStore.n];
     }
 
+    @Override
+    public boolean fixVariable(final int index, final double value) {
+        return this.updateRange(index, value, value);
+    }
+
     @Override
     public final Collection<Equation> generateCutCandidates(final double fractionality, final boolean... integer) {
 
-        double[] solution = this.extractSolution();
+        NumberContext integralityTolerance = options.integer().getIntegralityTolerance();
 
-        if (this.isLogDebug()) {
-            BasicLogger.debug("Sol: {}", Arrays.toString(solution));
-            BasicLogger.debug("+++: {}", Arrays.toString(mySolutionShift));
-        }
-
-        boolean[] negated = new boolean[integer.length];
-        for (int j = 0; j < negated.length; j++) {
-            //if (this.getEntityMap().isNegated(j)) {
-            if (this.isNegated(j)) {
-                negated[j] = true;
-            }
-        }
-
-        return mySimplex.generateCutCandidates(solution, integer, negated, options.integer().getIntegralityTolerance(), fractionality);
+        return mySimplex.generateCutCandidates(integer, integralityTolerance, fractionality, mySolutionShift);
     }
 
     @Override
@@ -321,26 +443,10 @@ abstract class SimplexSolver extends LinearSolver {
     }
 
     @Override
-    public KeyedPrimitive<EntryPair<ConstraintType, PrimitiveNumber>> getImpliedBoundSlack(final int col) {
-
-        double shift = mySolutionShift[col];
-
-        if (shift != ZERO) {
-
-            ColumnState columnState = mySimplex.getColumnState(col);
-            ConstraintType constraintType = ConstraintType.EQUALITY;
-            if (columnState == ColumnState.LOWER) {
-                constraintType = ConstraintType.LOWER;
-            } else if (columnState == ColumnState.UPPER) {
-                constraintType = ConstraintType.UPPER;
-            }
-
-            return EntryPair.of(constraintType, col).asKeyTo(shift);
-
-        } else {
-
-            return null;
-        }
+    public boolean updateRange(final int index, final double lower, final double upper) {
+        double shift = mySolutionShift[index];
+        this.setState(State.UNEXPLORED);
+        return mySimplex.updateRange(index, lower - shift, upper - shift);
     }
 
     private Access1D<?> extractMultipliers() {
@@ -351,11 +457,6 @@ abstract class SimplexSolver extends LinearSolver {
 
         return new Access1D<Double>() {
 
-            @Override
-            public long count() {
-                return structure.countConstraints();
-            }
-
             @Override
             public double doubleValue(final int index) {
                 int i = Math.toIntExact(index);
@@ -367,6 +468,11 @@ abstract class SimplexSolver extends LinearSolver {
                 return Double.valueOf(this.doubleValue(index));
             }
 
+            @Override
+            public int size() {
+                return structure.countConstraints();
+            }
+
             @Override
             public String toString() {
                 return Access1D.toString(this);
@@ -407,7 +513,7 @@ abstract class SimplexSolver extends LinearSolver {
 
         double largest = 1E-10;
         int[] included = mySimplex.included;
-        for (int ji = 0, limit = included.length; ji < limit; ji++) {
+        for (int ji = included.length - 1; ji >= 0; ji--) {
             int j = included[ji];
 
             double candidate = mySimplex.getInfeasibility(ji);
@@ -554,14 +660,6 @@ abstract class SimplexSolver extends LinearSolver {
         return retVal;
     }
 
-    private boolean isNegated(final int j) {
-        if (this.getUpperBound(j) <= ZERO && this.getLowerBound(j) < ZERO) {
-            return true;
-        } else {
-            return false;
-        }
-    }
-
     private void logCurrentState() {
 
         this.log();
@@ -603,70 +701,6 @@ abstract class SimplexSolver extends LinearSolver {
         }
     }
 
-    /**
-     * <ul>
-     * <li>Determine if non-basic variables are at their lower or upper bound (or if they are unbounded)
-     * <li>Shift ranges/bounds so that (one of) the bound(s) is at zero
-     * <li>Assumes that the ranges/bounds of basic variables are already defined this way.
-     * </ul>
-     *
-     * @param prioritiseFeasibility TODO
-     * @param modifyObjective TODO
-     */
-    private void shiftBounds(final boolean prioritiseFeasibility, final boolean modifyObjective) {
-
-        int[] excluded = mySimplex.excluded;
-        for (int je = 0, limit = excluded.length; je < limit; je++) {
-            int j = excluded[je];
-
-            double rc = prioritiseFeasibility ? ZERO : mySimplex.getCost(j);
-            double lb = mySimplex.getLowerBound(j);
-            double ub = mySimplex.getUpperBound(j);
-
-            if (lb > ub) {
-                throw new IllegalStateException();
-            }
-
-            if (rc > ZERO && Double.isFinite(lb)) {
-                mySimplex.lower(j);
-                mySimplex.shiftColumn(j, lb);
-                mySolutionShift[j] = lb;
-                myValueShift += rc * lb;
-            } else if (rc < ZERO && Double.isFinite(ub)) {
-                mySimplex.upper(j);
-                mySimplex.shiftColumn(j, ub);
-                mySolutionShift[j] = ub;
-                myValueShift += rc * ub;
-            } else if (!Double.isFinite(lb) && !Double.isFinite(ub)) {
-                mySimplex.unbounded(j);
-                if (modifyObjective) {
-                    mySimplex.objective().set(j, ZERO);
-                }
-            } else if (Math.abs(lb) <= Math.abs(ub)) {
-                mySimplex.lower(j);
-                mySimplex.shiftColumn(j, lb);
-                mySolutionShift[j] = lb;
-                myValueShift += rc * lb;
-                if (modifyObjective) {
-                    mySimplex.objective().set(j, ONE);
-                }
-            } else if (Math.abs(lb) >= Math.abs(ub)) {
-                mySimplex.upper(j);
-                mySimplex.shiftColumn(j, ub);
-                mySolutionShift[j] = ub;
-                myValueShift += rc * ub;
-                if (modifyObjective) {
-                    mySimplex.objective().set(j, NEG);
-                }
-            } else {
-                mySimplex.lower(j);
-                if (modifyObjective) {
-                    mySimplex.objective().set(j, ONE);
-                }
-            }
-        }
-    }
-
     private Optimisation.Result solveUnconstrained() {
 
         int nbVars = mySimplex.n;
@@ -723,8 +757,10 @@ abstract class SimplexSolver extends LinearSolver {
         double numer = ZERO;
         double denom = ONE;
         double ratio = ZERO;
+        double scale = ONE;
 
         iteration.ratioDual = Double.MAX_VALUE;
+        double iterationScale = MACHINE_LARGEST;
 
         int n = mySimplex.structure.countVariables();
         int[] excluded = mySimplex.excluded;
@@ -732,9 +768,10 @@ abstract class SimplexSolver extends LinearSolver {
             int j = excluded[je];
             if (j < n) {
 
-                denom = mySimplex.getTableauElement(exit, je);
+                denom = mySimplex.getCurrentElement(exit, je);
+                scale = Math.abs(denom);
 
-                if (!ALGORITHM.isZero(denom)) {
+                if (!PIVOT.isZero(denom)) {
 
                     ColumnState columnState = mySimplex.getColumnState(j);
 
@@ -767,7 +804,8 @@ abstract class SimplexSolver extends LinearSolver {
                         this.log(1, "{}({}) {} / {} = {}", j, je, numer, denom, ratio);
                     }
 
-                    if (ratio < iteration.ratioDual) {
+                    if (ratio < iteration.ratioDual
+                            || scale > iterationScale && PIVOT.isDifferent(iterationScale, scale) && !RATIO.isDifferent(iteration.ratioDual, ratio)) {
 
                         enter.index = je;
                         enter.from = columnState;
@@ -778,6 +816,7 @@ abstract class SimplexSolver extends LinearSolver {
                         }
 
                         iteration.ratioDual = ratio;
+                        iterationScale = scale;
                     }
                 }
             }
@@ -808,16 +847,19 @@ abstract class SimplexSolver extends LinearSolver {
         double numer = ZERO;
         double denom = ONE;
         double ratio = ZERO;
+        double scale = ONE;
 
         iteration.ratioPrimal = range;
+        double iterationScale = MACHINE_LARGEST;
 
         int[] included = mySimplex.included;
-        for (int ji = 0; ji < included.length; ji++) {
+        for (int ji = included.length - 1; ji >= 0; ji--) {
             int j = included[ji];
 
-            denom = mySimplex.getTableauElement(ji, enter);
+            denom = mySimplex.getCurrentElement(ji, enter);
+            scale = Math.abs(denom);
 
-            if (!ALGORITHM.isZero(denom)) {
+            if (!PIVOT.isZero(denom)) {
 
                 if (enterDirection == Direction.INCREASE) {
                     // Entering variable will increase
@@ -836,7 +878,8 @@ abstract class SimplexSolver extends LinearSolver {
                         this.log(1, "{}({}) {} / {} = {}", j, ji, numer, denom, ratio);
                     }
 
-                    if (ratio < iteration.ratioPrimal) {
+                    if (ratio < iteration.ratioPrimal
+                            || scale > iterationScale && PIVOT.isDifferent(iterationScale, scale) && !RATIO.isDifferent(iteration.ratioPrimal, ratio)) {
 
                         exit.index = ji;
                         if (denom < ZERO) {
@@ -852,6 +895,7 @@ abstract class SimplexSolver extends LinearSolver {
                         }
 
                         iteration.ratioPrimal = ratio;
+                        iterationScale = scale;
                     }
 
                 } else if (enterDirection == Direction.DECREASE) {
@@ -871,7 +915,8 @@ abstract class SimplexSolver extends LinearSolver {
                         this.log(1, "{}({}) {} / {} = {}", j, ji, numer, denom, ratio);
                     }
 
-                    if (ratio < iteration.ratioPrimal) {
+                    if (ratio < iteration.ratioPrimal
+                            || scale > iterationScale && PIVOT.isDifferent(iterationScale, scale) && !RATIO.isDifferent(iteration.ratioPrimal, ratio)) {
 
                         exit.index = ji;
                         if (denom > ZERO) {
@@ -887,6 +932,7 @@ abstract class SimplexSolver extends LinearSolver {
                         }
 
                         iteration.ratioPrimal = ratio;
+                        iterationScale = scale;
                     }
 
                 } else {
@@ -920,6 +966,9 @@ abstract class SimplexSolver extends LinearSolver {
                 this.log();
                 this.log("Pivoting: {}", iteration);
                 this.log("==>> Row: {}, Exit: {}, Column/Enter: {}.", iteration.exit.index, iteration.exit.column(), iteration.enter.column());
+                this.log("Cost={}, Pivot1={}, Pivot2={}, RHS={}, Inf={}", mySimplex.getReducedCost(iteration.enter.index),
+                        mySimplex.getCurrentElement(iteration.exit, iteration.enter.index), mySimplex.getCurrentElement(iteration.exit.index, iteration.enter),
+                        mySimplex.getCurrentRHS(iteration.exit.row()), mySimplex.getInfeasibility(iteration.exit.index));
                 this.log("Shift Exit: {}, Enter: {}", mySolutionShift[iteration.exit.column()], mySolutionShift[iteration.enter.column()]);
             }
 
@@ -927,7 +976,7 @@ abstract class SimplexSolver extends LinearSolver {
 
             this.shift(iteration.enter.column(), iteration.exit.to);
 
-            mySimplex.calculateIteration(iteration);
+            mySimplex.calculateIteration();
 
         } else if (iteration.isBoundSwitch()) {
 
@@ -999,7 +1048,7 @@ abstract class SimplexSolver extends LinearSolver {
                 done = true;
             }
 
-            if (this.isLogDebug()) {
+            if (this.isLogDebug() && mySimplex.isPrintable()) {
                 this.logCurrentState();
             }
         }
@@ -1007,9 +1056,10 @@ abstract class SimplexSolver extends LinearSolver {
 
     final void doPrimalIterations(final IterDescr iteration) {
 
-        if (options.validate) {
-            this.validate(this.extractResult());
-        }
+        // TODO Re-enable validation here
+        //        if (options.validate) {
+        //            this.validate(this.extractResult());
+        //        }
 
         boolean done = false;
         while (this.isIterationAllowed() && !done) {
@@ -1041,13 +1091,14 @@ abstract class SimplexSolver extends LinearSolver {
                 done = true;
             }
 
-            if (this.isLogDebug()) {
+            if (this.isLogDebug() && mySimplex.isPrintable()) {
                 this.logCurrentState();
             }
 
-            if (options.validate) {
-                this.validate(this.extractResult());
-            }
+            // TODO Re-enable validation here
+            //            if (options.validate) {
+            //                this.validate(this.extractResult());
+            //            }
         }
     }
 
@@ -1069,7 +1120,7 @@ abstract class SimplexSolver extends LinearSolver {
             this.log("UB: {}", this.getUpperBounds());
         }
 
-        ConstraintsMap constraints = this.getEntityMap().constraints;
+        ConstraintsMetaData constraints = this.getEntityMap().constraints;
         if (constraints.isEntityMap()) {
             return result.multipliers(constraints, this.extractMultipliers());
         } else {
@@ -1077,7 +1128,7 @@ abstract class SimplexSolver extends LinearSolver {
         }
     }
 
-    void initiatePhase1() {
+    final void initiatePhase1() {
         mySimplex.copyObjective();
     }
 
@@ -1089,9 +1140,9 @@ abstract class SimplexSolver extends LinearSolver {
         return !this.getDualExitCandidate(null);
     }
 
-    final IterDescr prepareToIterate(final boolean prioritiseFeasibility, final boolean modifyObjective) {
+    final IterDescr prepareToIterate() {
 
-        this.shiftBounds(prioritiseFeasibility, modifyObjective);
+        this.setup(mySimplex);
 
         if (mySimplex.m == 0) {
             this.solveUnconstrained(); // TODO return?
@@ -1108,6 +1159,21 @@ abstract class SimplexSolver extends LinearSolver {
         return new IterDescr(mySimplex);
     }
 
+    /**
+     * <ul>
+     * <li>Determine if non-basic variables are at their lower or upper bound (or if they are unbounded)
+     * <li>Shift ranges/bounds so that (one of) the bound(s) is at zero
+     * <li>Assumes that the ranges/bounds of basic variables are already defined this way.
+     * </ul>
+     */
+    abstract void setup(SimplexStore simplex);
+
+    final void shift(final int index, final double shift, final double weight) {
+        mySimplex.shiftColumn(index, shift);
+        mySolutionShift[index] += shift;
+        myValueShift += weight * shift;
+    }
+
     void switchToPhase2() {
         mySimplex.restoreObjective();
         mySimplex.calculateIteration();
