@@ -29,6 +29,7 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.List;
 import java.util.Set;
+import java.util.function.Function;
 import java.util.stream.Collectors;
 
 import org.ojalgo.array.Array1D;
@@ -37,9 +38,9 @@ import org.ojalgo.array.LongToNumberMap;
 import org.ojalgo.array.SparseArray.NonzeroView;
 import org.ojalgo.equation.Equation;
 import org.ojalgo.matrix.store.MatrixStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.netio.BasicLogger;
-import org.ojalgo.optimisation.ConstraintsMap;
+import org.ojalgo.optimisation.ConstraintsMetaData;
 import org.ojalgo.optimisation.Expression;
 import org.ojalgo.optimisation.ExpressionsBasedModel;
 import org.ojalgo.optimisation.Optimisation;
@@ -48,11 +49,13 @@ import org.ojalgo.optimisation.convex.ConvexData;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.Access2D.RowView;
 import org.ojalgo.structure.ElementView1D;
+import org.ojalgo.structure.Primitive1D;
+import org.ojalgo.structure.Primitive2D;
 import org.ojalgo.structure.Structure1D.IntIndex;
 import org.ojalgo.type.context.NumberContext;
 
 /**
- * Classic simplex solver:
+ * Classic simplex tableau solver:
  * <ul>
  * <li>Primal algorithm
  * <li>2-phase
@@ -76,6 +79,12 @@ final class SimplexTableauSolver extends LinearSolver {
             this.reset();
         }
 
+        @Override
+        public String toString() {
+            int phase = myPhase1 ? 1 : 2;
+            return phase + "-[row=" + row + ", col=" + col + "]";
+        }
+
         boolean isPhase1() {
             return myPhase1;
         }
@@ -106,34 +115,6 @@ final class SimplexTableauSolver extends LinearSolver {
     private static final NumberContext RATIO = NumberContext.of(12, 8).withMode(RoundingMode.HALF_DOWN);
     private static final NumberContext WEIGHT = NumberContext.of(8, 10).withMode(RoundingMode.HALF_DOWN);
 
-    private static void set(final ExpressionsBasedModel model, final Primitive2D constraintsBdy, final int indCnstr, final int basePosVars,
-            final int baseNegVars, final IntIndex key, final double factor) {
-
-        int tmpPosInd = model.indexOfPositiveVariable(key);
-        if (tmpPosInd >= 0) {
-            constraintsBdy.set(indCnstr, basePosVars + tmpPosInd, factor);
-        }
-
-        int tmpNegInd = model.indexOfNegativeVariable(key);
-        if (tmpNegInd >= 0) {
-            constraintsBdy.set(indCnstr, baseNegVars + tmpNegInd, -factor);
-        }
-    }
-
-    private static void set(final ExpressionsBasedModel model, final Primitive2D constraintsBdy, final int indCnstr, final int basePosVars,
-            final int baseNegVars, final Variable variable, final double factor) {
-
-        int tmpPosInd = model.indexOfPositiveVariable(variable);
-        if (tmpPosInd >= 0) {
-            constraintsBdy.set(indCnstr, basePosVars + tmpPosInd, factor);
-        }
-
-        int tmpNegInd = model.indexOfNegativeVariable(variable);
-        if (tmpNegInd >= 0) {
-            constraintsBdy.set(indCnstr, baseNegVars + tmpNegInd, -factor);
-        }
-    }
-
     private static Optimisation.Result toConvexStateFromDual(final Optimisation.Result result, final ConvexData<Double> convex) {
 
         int nbEqus = convex.countEqualityConstraints();
@@ -225,7 +206,7 @@ final class SimplexTableauSolver extends LinearSolver {
         return result.withSolution(solution);
     }
 
-    static SimplexTableau build(final ExpressionsBasedModel model) {
+    static <T extends SimplexTableau> T build(final ExpressionsBasedModel model, final Function<LinearStructure, T> factory) {
 
         List<Variable> posVariables = model.getPositiveVariables();
         List<Variable> negVariables = model.getNegativeVariables();
@@ -320,7 +301,10 @@ final class SimplexTableauSolver extends LinearSolver {
 
         LinearStructure structure = new LinearStructure(true, constrIn, constrEq, nbPosProbVars, nbNegProbVars, nbOtherSlackVars, nbIdentitySlackVars);
 
-        SimplexTableau retVal = SimplexTableau.make(structure, model.options);
+        T retVal = factory.apply(structure);
+        double[] lowerBounds = retVal.getLowerBounds();
+        double[] upperBounds = retVal.getUpperBounds();
+        Arrays.fill(upperBounds, POSITIVE_INFINITY);
 
         Primitive2D retConstraintsBdy = retVal.constraintsBody();
         Primitive1D retConstraintsRHS = retVal.constraintsRHS();
@@ -341,17 +325,16 @@ final class SimplexTableauSolver extends LinearSolver {
 
         structure.setObjectiveAdjustmentFactor(objective.getAdjustmentFactor());
 
-        for (IntIndex tmpKey : objective.getLinearKeySet()) {
+        for (IntIndex key : objective.getLinearKeySet()) {
 
-            double tmpFactor = model.getOptimisationSense() == Optimisation.Sense.MAX ? -objective.getAdjustedLinearFactor(tmpKey)
-                    : objective.getAdjustedLinearFactor(tmpKey);
+            double tmpFactor = model.getOptimisationSense() == Optimisation.Sense.MAX ? -objective.doubleValue(key, true) : objective.doubleValue(key, true);
 
-            int tmpPosInd = model.indexOfPositiveVariable(tmpKey);
+            int tmpPosInd = model.indexOfPositiveVariable(key);
             if (tmpPosInd >= 0) {
                 retObjective.set(basePosVars + tmpPosInd, tmpFactor);
             }
 
-            int tmpNegInd = model.indexOfNegativeVariable(tmpKey);
+            int tmpNegInd = model.indexOfNegativeVariable(key);
             if (tmpNegInd >= 0) {
                 retObjective.set(baseNegVars + tmpNegInd, -tmpFactor);
             }
@@ -365,13 +348,13 @@ final class SimplexTableauSolver extends LinearSolver {
         for (Expression expression : exprUpPos) {
 
             for (IntIndex key : expression.getLinearKeySet()) {
-                double factor = expression.getAdjustedLinearFactor(key);
+                double factor = expression.doubleValue(key, true);
                 SimplexTableauSolver.set(model, retConstraintsBdy, indCnstr, basePosVars, baseNegVars, key, factor);
             }
 
             retConstraintsBdy.set(indCnstr, indSlack, ONE);
 
-            double rhs = expression.getAdjustedUpperLimit();
+            double rhs = expression.getUpperLimit(true, Double.POSITIVE_INFINITY);
             retConstraintsRHS.set(indCnstr, rhs);
 
             structure.setConstraintMap(indCnstr, expression, ConstraintType.UPPER, false);
@@ -384,13 +367,13 @@ final class SimplexTableauSolver extends LinearSolver {
         for (Expression expression : exprLoNeg) {
 
             for (IntIndex key : expression.getLinearKeySet()) {
-                double factor = -expression.getAdjustedLinearFactor(key);
+                double factor = -expression.doubleValue(key, true);
                 SimplexTableauSolver.set(model, retConstraintsBdy, indCnstr, basePosVars, baseNegVars, key, factor);
             }
 
             retConstraintsBdy.set(indCnstr, indSlack, ONE);
 
-            double rhs = -expression.getAdjustedLowerLimit();
+            double rhs = -expression.getLowerLimit(true, Double.NEGATIVE_INFINITY);
             retConstraintsRHS.set(indCnstr, rhs);
 
             structure.setConstraintMap(indCnstr, expression, ConstraintType.LOWER, false);
@@ -407,7 +390,7 @@ final class SimplexTableauSolver extends LinearSolver {
 
             retConstraintsBdy.set(indCnstr, indSlack, ONE);
 
-            double rhs = variable.getAdjustedUpperLimit();
+            double rhs = variable.getUpperLimit(true, Double.POSITIVE_INFINITY);
             retConstraintsRHS.set(indCnstr, rhs);
 
             structure.setConstraintMap(indCnstr, variable, ConstraintType.UPPER, false);
@@ -424,7 +407,7 @@ final class SimplexTableauSolver extends LinearSolver {
 
             retConstraintsBdy.set(indCnstr, indSlack, ONE);
 
-            double rhs = -variable.getAdjustedLowerLimit();
+            double rhs = -variable.getLowerLimit(true, Double.NEGATIVE_INFINITY);
             retConstraintsRHS.set(indCnstr, rhs);
 
             structure.setConstraintMap(indCnstr, variable, ConstraintType.LOWER, false);
@@ -439,13 +422,13 @@ final class SimplexTableauSolver extends LinearSolver {
         for (Expression expression : exprLoPos) {
 
             for (IntIndex key : expression.getLinearKeySet()) {
-                double factor = expression.getAdjustedLinearFactor(key);
+                double factor = expression.doubleValue(key, true);
                 SimplexTableauSolver.set(model, retConstraintsBdy, indCnstr, basePosVars, baseNegVars, key, factor);
             }
 
             retConstraintsBdy.set(indCnstr, indSlack, NEG);
 
-            double rhs = expression.getAdjustedLowerLimit();
+            double rhs = expression.getLowerLimit(true, Double.NEGATIVE_INFINITY);
             retConstraintsRHS.set(indCnstr, rhs);
 
             structure.setConstraintMap(indCnstr, expression, ConstraintType.LOWER, true);
@@ -458,13 +441,13 @@ final class SimplexTableauSolver extends LinearSolver {
         for (Expression expression : exprUpNeg) {
 
             for (IntIndex key : expression.getLinearKeySet()) {
-                double factor = -expression.getAdjustedLinearFactor(key);
+                double factor = -expression.doubleValue(key, true);
                 SimplexTableauSolver.set(model, retConstraintsBdy, indCnstr, basePosVars, baseNegVars, key, factor);
             }
 
             retConstraintsBdy.set(indCnstr, indSlack, NEG);
 
-            double rhs = -expression.getAdjustedUpperLimit();
+            double rhs = -expression.getUpperLimit(true, Double.POSITIVE_INFINITY);
             retConstraintsRHS.set(indCnstr, rhs);
 
             structure.setConstraintMap(indCnstr, expression, ConstraintType.UPPER, true);
@@ -481,7 +464,7 @@ final class SimplexTableauSolver extends LinearSolver {
 
             retConstraintsBdy.set(indCnstr, indSlack, NEG);
 
-            double rhs = variable.getAdjustedLowerLimit();
+            double rhs = variable.getLowerLimit(true, Double.NEGATIVE_INFINITY);
             retConstraintsRHS.set(indCnstr, rhs);
 
             structure.setConstraintMap(indCnstr, variable, ConstraintType.LOWER, true);
@@ -498,7 +481,7 @@ final class SimplexTableauSolver extends LinearSolver {
 
             retConstraintsBdy.set(indCnstr, indSlack, NEG);
 
-            double rhs = -variable.getAdjustedUpperLimit();
+            double rhs = -variable.getUpperLimit(true, Double.POSITIVE_INFINITY);
             retConstraintsRHS.set(indCnstr, rhs);
 
             structure.setConstraintMap(indCnstr, variable, ConstraintType.UPPER, true);
@@ -513,11 +496,11 @@ final class SimplexTableauSolver extends LinearSolver {
         for (Expression expression : exprEqPos) {
 
             for (IntIndex key : expression.getLinearKeySet()) {
-                double factor = expression.getAdjustedLinearFactor(key);
+                double factor = expression.doubleValue(key, true);
                 SimplexTableauSolver.set(model, retConstraintsBdy, indCnstr, basePosVars, baseNegVars, key, factor);
             }
 
-            double rhs = expression.getAdjustedUpperLimit();
+            double rhs = expression.getUpperLimit(true, Double.POSITIVE_INFINITY);
             retConstraintsRHS.set(indCnstr, rhs);
 
             structure.setConstraintMap(indCnstr, expression, ConstraintType.EQUALITY, false);
@@ -530,11 +513,11 @@ final class SimplexTableauSolver extends LinearSolver {
         for (Expression expression : exprEqNeg) {
 
             for (IntIndex key : expression.getLinearKeySet()) {
-                double factor = -expression.getAdjustedLinearFactor(key);
+                double factor = -expression.doubleValue(key, true);
                 SimplexTableauSolver.set(model, retConstraintsBdy, indCnstr, basePosVars, baseNegVars, key, factor);
             }
 
-            double rhs = -expression.getAdjustedLowerLimit();
+            double rhs = -expression.getLowerLimit(true, Double.NEGATIVE_INFINITY);
             retConstraintsRHS.set(indCnstr, rhs);
 
             structure.setConstraintMap(indCnstr, expression, ConstraintType.EQUALITY, true);
@@ -555,7 +538,7 @@ final class SimplexTableauSolver extends LinearSolver {
 
         LinearStructure structure = new LinearStructure(false, 0, nbCvxVars, nbCvxEqus + nbCvxEqus + nbCvxInes, 0, 0, 0);
 
-        SimplexTableau retVal = SimplexTableau.make(structure, options);
+        SimplexTableau retVal = SimplexTableau.newTableauFactory(options).apply(structure);
 
         Primitive2D constraintsBody = retVal.constraintsBody();
         Primitive1D constraintsRHS = retVal.constraintsRHS();
@@ -620,14 +603,13 @@ final class SimplexTableauSolver extends LinearSolver {
 
         LinearStructure structure = new LinearStructure(false, nbInes, nbEqus, nbVars + nbVars, 0, nbInes, 0);
 
-        SimplexTableau retVal = SimplexTableau.make(structure, options);
+        SimplexTableau retVal = SimplexTableau.newTableauFactory(options).apply(structure);
 
         Primitive2D constraintsBody = retVal.constraintsBody();
         Primitive1D constraintsRHS = retVal.constraintsRHS();
         Primitive1D objective = retVal.objective();
 
-        MatrixStore<Double> convexC = checkFeasibility ? Primitive64Store.FACTORY.makeZero(convex.countVariables(), 1)
-                : convex.getObjective().getLinearFactors(true);
+        MatrixStore<Double> convexC = checkFeasibility ? R064Store.FACTORY.makeZero(convex.countVariables(), 1) : convex.getObjective().getLinearFactors(true);
 
         for (int v = 0; v < nbVars; v++) {
             double valC = convexC.doubleValue(v);
@@ -690,6 +672,34 @@ final class SimplexTableauSolver extends LinearSolver {
         return SimplexTableauSolver.toConvexStateFromPrimal(result, convex);
     }
 
+    static void set(final ExpressionsBasedModel model, final Primitive2D constraintsBdy, final int indCnstr, final int basePosVars, final int baseNegVars,
+            final IntIndex key, final double factor) {
+
+        int tmpPosInd = model.indexOfPositiveVariable(key);
+        if (tmpPosInd >= 0) {
+            constraintsBdy.set(indCnstr, basePosVars + tmpPosInd, factor);
+        }
+
+        int tmpNegInd = model.indexOfNegativeVariable(key);
+        if (tmpNegInd >= 0) {
+            constraintsBdy.set(indCnstr, baseNegVars + tmpNegInd, -factor);
+        }
+    }
+
+    static void set(final ExpressionsBasedModel model, final Primitive2D constraintsBdy, final int indCnstr, final int basePosVars, final int baseNegVars,
+            final Variable variable, final double factor) {
+
+        int tmpPosInd = model.indexOfPositiveVariable(variable);
+        if (tmpPosInd >= 0) {
+            constraintsBdy.set(indCnstr, basePosVars + tmpPosInd, factor);
+        }
+
+        int tmpNegInd = model.indexOfNegativeVariable(variable);
+        if (tmpNegInd >= 0) {
+            constraintsBdy.set(indCnstr, baseNegVars + tmpNegInd, -factor);
+        }
+    }
+
     static int sizeOfDual(final ConvexData<?> convex) {
 
         int nbCvxVars = convex.countVariables();
@@ -767,12 +777,9 @@ final class SimplexTableauSolver extends LinearSolver {
     @Override
     public final Collection<Equation> generateCutCandidates(final double fractionality, final boolean... integer) {
 
-        if (this.isLogDebug()) {
-            BasicLogger.debug("Sol: {}", Arrays.toString(this.extractSolution().toRawCopy1D()));
-            BasicLogger.debug("+++: {}", Arrays.toString(new double[integer.length]));
-        }
+        NumberContext integralityTolerance = options.integer().getIntegralityTolerance();
 
-        return myTableau.generateCutCandidates(integer, options.integer().getIntegralityTolerance(), fractionality);
+        return myTableau.generateCutCandidates(integer, integralityTolerance, fractionality);
     }
 
     @Override
@@ -809,19 +816,29 @@ final class SimplexTableauSolver extends LinearSolver {
         return this.buildResult();
     }
 
+    @Override
+    public boolean updateRange(final int index, final double lower, final double upper) {
+
+        if (lower == upper) {
+            return this.fixVariable(index, lower);
+        } else {
+            return false;
+        }
+    }
+
     /**
      * https://math.stackexchange.com/questions/3254444/artificial-variables-in-two-phase-simplex-method
      */
     private void cleanUpPhase1Artificials() {
 
-        int[] basis = myTableau.included;
-        int[] excluded = myTableau.excluded();
+        int[] included = myTableau.included;
+        int[] excluded = myTableau.excluded;
 
         int colRHS = myTableau.n;
 
-        for (int i = 0; i < basis.length; i++) {
+        for (int i = 0; i < included.length; i++) {
 
-            if (myTableau.isArtificial(basis[i])) {
+            if (myTableau.isArtificial(included[i])) {
 
                 double rhs = myTableau.doubleValue(i, colRHS);
 
@@ -882,18 +899,13 @@ final class SimplexTableauSolver extends LinearSolver {
 
         Result result = new Optimisation.Result(state, value, solution);
 
-        if (myTableau.isAbleToExtractDual()) {
+        ConstraintsMetaData constraints = this.getEntityMap().constraints;
 
-            ConstraintsMap constraints = this.getEntityMap().constraints;
-
-            if (constraints.isEntityMap()) {
-                return result.multipliers(constraints, this.extractMultipliers());
-            } else {
-                return result.multipliers(this.extractMultipliers());
-            }
+        if (constraints.isEntityMap()) {
+            return result.multipliers(constraints, this.extractMultipliers());
+        } else {
+            return result.multipliers(this.extractMultipliers());
         }
-
-        return result;
     }
 
     protected double evaluateFunction(final Access1D<?> solution) {
@@ -908,16 +920,10 @@ final class SimplexTableauSolver extends LinearSolver {
 
         return new Access1D<Double>() {
 
-            @Override
-            public long count() {
-                return structure.countConstraints();
-            }
-
             @Override
             public double doubleValue(final int index) {
-                int i = Math.toIntExact(index);
                 double dualValue = duals.doubleValue(index);
-                return structure.isConstraintNegated(i) ? -dualValue : dualValue;
+                return structure.isConstraintNegated(index) ? -dualValue : dualValue;
             }
 
             @Override
@@ -925,6 +931,11 @@ final class SimplexTableauSolver extends LinearSolver {
                 return Double.valueOf(this.doubleValue(index));
             }
 
+            @Override
+            public int size() {
+                return structure.countConstraints();
+            }
+
             @Override
             public String toString() {
                 return Access1D.toString(this);
@@ -940,7 +951,7 @@ final class SimplexTableauSolver extends LinearSolver {
 
         int colRHS = myTableau.n;
 
-        Primitive64Store solution = Primitive64Store.FACTORY.make(myTableau.structure.countVariables(), 1);
+        R064Store solution = R064Store.FACTORY.make(myTableau.structure.countVariables(), 1);
 
         int numberOfConstraints = myTableau.m;
         for (int row = 0; row < numberOfConstraints; row++) {
@@ -1052,7 +1063,7 @@ final class SimplexTableauSolver extends LinearSolver {
 
         if (this.isLogDebug()) {
             if (options.validate) {
-                int[] excluded = myTableau.excluded();
+                int[] excluded = myTableau.excluded;
                 Access1D<Double> sliceTableauRow = myTableau.sliceTableauRow(row);
                 double[] exclVals = new double[excluded.length];
                 for (int i = 0; i < exclVals.length; i++) {
