@@ -27,7 +27,7 @@ import java.math.MathContext;
 import org.ojalgo.ProgrammingError;
 import org.ojalgo.function.constant.PrimitiveMath;
 import org.ojalgo.matrix.store.MatrixStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.structure.Access2D;
 import org.ojalgo.structure.Mutate2D;
 import org.ojalgo.structure.Mutate2D.ModifiableReceiver;
@@ -489,6 +489,11 @@ public final class ComplexNumber
         return this.phase();
     }
 
+    @Override
+    public int getColDim() {
+        return 2;
+    }
+
     public double getImaginary() {
         return i;
     }
@@ -501,6 +506,11 @@ public final class ComplexNumber
         return this.doubleValue();
     }
 
+    @Override
+    public int getRowDim() {
+        return 2;
+    }
+
     @Override
     public int hashCode() {
         final int prime = 31;
@@ -675,14 +685,14 @@ public final class ComplexNumber
     }
 
     public MatrixStore<Double> toMultiplicationMatrix() {
-        final Primitive64Store retVal = Primitive64Store.FACTORY.make(this);
+        final R064Store retVal = R064Store.FACTORY.make(this);
         this.supplyTo(retVal);
         return retVal;
     }
 
     public MatrixStore<Double> toMultiplicationVector() {
 
-        final Primitive64Store retVal = Primitive64Store.FACTORY.make(2L, 1L);
+        final R064Store retVal = R064Store.FACTORY.make(2L, 1L);
 
         retVal.set(0L, myRealValue);
         retVal.set(1L, i);
@@ -692,7 +702,7 @@ public final class ComplexNumber
 
     public MatrixStore<Double> toRotationMatrix() {
 
-        final Primitive64Store retVal = Primitive64Store.FACTORY.make(2L, 2L);
+        final R064Store retVal = R064Store.FACTORY.make(2L, 2L);
 
         final double s = myRealValue;
 
