@@ -22,6 +22,7 @@
 package org.ojalgo.series.primitive;
 
 import org.ojalgo.data.DataProcessors;
+import org.ojalgo.structure.Access2D;
 import org.ojalgo.structure.Factory2D;
 import org.ojalgo.structure.Mutate2D;
 import org.ojalgo.structure.Structure2D;
@@ -57,8 +58,18 @@ public class SeriesSet {
     /**
      * Return a {@link Structure2D} with variables in columns and matching samples in rows.
      */
-    public <M extends Structure2D> M getData(final Factory2D.Dense<M> factory) {
-        return factory.columns(mySet);
+    public <M extends Access2D<?>> M getData(final Factory2D.TwoStep<M, ?> factory) {
+
+        int nbCols = mySet.length;
+        int nbRows = mySet[0].size();
+        Factory2D.Builder<M> builder = factory.newBuilder(nbRows, nbCols);
+        for (int j = 0; j < nbCols; j++) {
+            PrimitiveSeries tmpSet = mySet[j];
+            for (int i = 0; i < nbRows; i++) {
+                builder.set(i, j, tmpSet.doubleValue(i));
+            }
+        }
+        return builder.build();
     }
 
     public SeriesSet log() {
