@@ -29,6 +29,7 @@ import java.util.List;
  *
  * @author apete
  */
+@FunctionalInterface
 public interface Structure1D {
 
     class BasicMapper<T> implements IndexMapper<T> {
@@ -39,6 +40,7 @@ public interface Structure1D {
             super();
         }
 
+        @Override
         public synchronized long toIndex(final T key) {
             long retVal = myKeys.indexOf(key);
             if (retVal < 0L) {
@@ -47,6 +49,7 @@ public interface Structure1D {
             return retVal;
         }
 
+        @Override
         public final T toKey(final long index) {
             return myKeys.get(Math.toIntExact(index));
         }
@@ -59,20 +62,6 @@ public interface Structure1D {
 
     }
 
-    /**
-     * @deprecated v53 Will be removed!
-     */
-    @Deprecated
-    @FunctionalInterface
-    public interface IndexCallback {
-
-        /**
-         * @param index Index
-         */
-        void call(final long index);
-
-    }
-
     public interface IndexMapper<T> {
 
         /**
@@ -131,6 +120,7 @@ public interface Structure1D {
             this(-1);
         }
 
+        @Override
         public int compareTo(final IntIndex ref) {
             return Integer.compare(index, ref.index);
         }
@@ -140,7 +130,7 @@ public interface Structure1D {
             if (this == obj) {
                 return true;
             }
-            if ((obj == null) || !(obj instanceof IntIndex)) {
+            if (obj == null || !(obj instanceof IntIndex)) {
                 return false;
             }
             final IntIndex other = (IntIndex) obj;
@@ -190,6 +180,7 @@ public interface Structure1D {
             this(-1L);
         }
 
+        @Override
         public int compareTo(final LongIndex ref) {
             return Long.compare(index, ref.index);
         }
@@ -199,7 +190,7 @@ public interface Structure1D {
             if (this == obj) {
                 return true;
             }
-            if ((obj == null) || !(obj instanceof LongIndex)) {
+            if (obj == null || !(obj instanceof LongIndex)) {
                 return false;
             }
             final LongIndex other = (LongIndex) obj;
@@ -239,27 +230,6 @@ public interface Structure1D {
         return Math.toIntExact(index);
     }
 
-    /**
-     * @deprecated v53 Will be removed!
-     */
-    @Deprecated
-    static void loopMatching(final Structure1D structureA, final Structure1D structureB, final IndexCallback callback) {
-        long limit = Math.min(structureA.count(), structureB.count());
-        for (long i = 0L; i < limit; i++) {
-            callback.call(i);
-        }
-    }
-
-    /**
-     * @deprecated v53 Will be removed!
-     */
-    @Deprecated
-    static void loopRange(final long first, final long limit, final IndexCallback callback) {
-        for (long i = first; i < limit; i++) {
-            callback.call(i);
-        }
-    }
-
     /**
      * @return A very simple implementation - you better come up with something else.
      */
@@ -324,22 +294,18 @@ public interface Structure1D {
     }
 
     /**
-     * @return The total number of elements in this structure.
+     * The total number of elements in this structure.
+     * <p>
+     * You only need to implement this method if the structure can contain more than Integer.MAX_VALUE
+     * elements.
      */
-    long count();
+    default long count() {
+        return this.size();
+    }
 
     /**
-     * @deprecated v53 Will be removed!
+     * The total number of elements in this structure.
      */
-    @Deprecated
-    default void loopAll(final IndexCallback callback) {
-        for (long i = 0L; i < this.count(); i++) {
-            callback.call(i);
-        }
-    }
-
-    default int size() {
-        return Math.toIntExact(this.count());
-    }
+    int size();
 
 }
