@@ -21,7 +21,8 @@
  */
 package org.ojalgo.type;
 
-import static java.time.temporal.ChronoField.*;
+import static java.time.temporal.ChronoField.INSTANT_SECONDS;
+import static java.time.temporal.ChronoField.NANO_OF_SECOND;
 
 import java.time.*;
 import java.time.temporal.*;
@@ -72,6 +73,10 @@ public final class CalendarDate implements Temporal, Comparable<CalendarDate> {
             return epochMilli + this.toDurationInMillis();
         }
 
+        default CalendarDate adjustInto(final CalendarDate temporal) {
+            return new CalendarDate(this.adjustInto(temporal.millis));
+        }
+
         /**
          * Maps a range of instances in time to a single instance.
          */
@@ -98,10 +103,6 @@ public final class CalendarDate implements Temporal, Comparable<CalendarDate> {
             return new CalendarDate(index);
         }
 
-        default CalendarDate adjustInto(final CalendarDate temporal) {
-            return new CalendarDate(this.adjustInto(temporal.millis));
-        }
-
     }
 
     static final long MILLIS_PER_SECOND = 1_000L;
