@@ -24,11 +24,13 @@ package org.ojalgo;
 import java.io.File;
 import java.io.InputStream;
 import java.math.BigDecimal;
+import java.math.MathContext;
 import java.util.Arrays;
 import java.util.function.IntSupplier;
 
 import org.junit.jupiter.api.Assertions;
 import org.ojalgo.array.Array1D;
+import org.ojalgo.array.ArrayR064;
 import org.ojalgo.function.constant.PrimitiveMath;
 import org.ojalgo.function.special.MissingMath;
 import org.ojalgo.matrix.decomposition.Bidiagonal;
@@ -108,6 +110,13 @@ public abstract class TestUtils /* extends Assertions */ {
         TestUtils.assertEquals("Access1D<?> != Access1D<?>", expected, actual, context);
     }
 
+    public static void assertEquals(final BigDecimal expected, final BigDecimal actual, final MathContext context) {
+        boolean equal = expected.round(context).compareTo(actual.round(context)) == 0;
+        if (!equal) {
+            TestUtils.fail(expected + " != " + actual);
+        }
+    }
+
     public static void assertEquals(final boolean expected, final boolean actual) {
         Assertions.assertEquals(expected, actual);
     }
@@ -155,6 +164,10 @@ public abstract class TestUtils /* extends Assertions */ {
         }
     }
 
+    public static void assertEquals(final double[] expected, final double[] actual) {
+        TestUtils.assertEquals(ArrayR064.wrap(expected), ArrayR064.wrap(actual));
+    }
+
     public static void assertEquals(final int expected, final int actual) {
         Assertions.assertEquals(expected, actual);
     }
@@ -234,10 +247,6 @@ public abstract class TestUtils /* extends Assertions */ {
         }
     }
 
-    public static void assertNull(final Object actual) {
-        Assertions.assertNull(actual);
-    }
-
     public static void assertEquals(final Object expected, final Object actual) {
         Assertions.assertEquals(expected, actual);
     }
@@ -385,10 +394,6 @@ public abstract class TestUtils /* extends Assertions */ {
         TestUtils.assertEquals(message, (Access1D<?>) expected, (Access1D<?>) actual, context);
     }
 
-    public static void assertEquivalent(final Optimisation.Result expected, final Optimisation.Result actual) {
-        TestUtils.assertOptimisationResult("Optimisation.Result != Optimisation.Result", expected, actual, EQUALS, true, true, true, true);
-    }
-
     public static void assertFalse(final boolean condition) {
         Assertions.assertFalse(condition);
     }
@@ -452,6 +457,10 @@ public abstract class TestUtils /* extends Assertions */ {
         }
     }
 
+    public static void assertNull(final Object actual) {
+        Assertions.assertNull(actual);
+    }
+
     /**
      * Will compare state, value, solution and multiplier if available.
      */
@@ -588,6 +597,10 @@ public abstract class TestUtils /* extends Assertions */ {
         MatrixOperation.setAllOperationThresholds(2);
     }
 
+    public static void success() {
+        Assertions.assertTrue(true);
+    }
+
     private static String buildAbsoluteResourcePath(final String... pathElements) {
 
         File builder = new File(pathElements[0]);
