@@ -23,7 +23,7 @@ package org.ojalgo.ann;
 
 import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.type.context.NumberContext;
 
 public class DesignTestANN extends ANNTest {
@@ -37,8 +37,8 @@ public class DesignTestANN extends ANNTest {
 
         NumberContext precision = NumberContext.of(7, 8);
 
-        Primitive64Store arguments = Primitive64Store.FACTORY.row(1.0, 2.0, 3.0, 4.0, 1.0, 2.0, 3.0);
-        Primitive64Store results = Primitive64Store.FACTORY.row(0.02364054, 0.06426166, 0.1746813, 0.474833, 0.02364054, 0.06426166, 0.1746813);
+        R064Store arguments = R064Store.FACTORY.row(1.0, 2.0, 3.0, 4.0, 1.0, 2.0, 3.0);
+        R064Store results = R064Store.FACTORY.row(0.02364054, 0.06426166, 0.1746813, 0.474833, 0.02364054, 0.06426166, 0.1746813);
 
         ArtificialNeuralNetwork.Activator.SOFTMAX.activate(arguments);
 
