@@ -31,7 +31,7 @@ import java.util.List;
 import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
 import org.ojalgo.matrix.store.PhysicalStore.Factory;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.type.context.NumberContext;
 
@@ -53,19 +53,19 @@ public class StepByStepBackpropagationExample extends BackPropagationExample {
     public void testStepByStepBackpropagationExample() {
 
         NumberContext precision = this.precision();
-        Factory<Double, Primitive64Store> factory = Primitive64Store.FACTORY;
+        Factory<Double, R064Store> factory = R064Store.FACTORY;
 
         ArtificialNeuralNetwork.Error errorMeassure = HALF_SQUARED_DIFFERENCE;
 
-        ArtificialNeuralNetwork network = this.getInitialNetwork(Primitive64Store.FACTORY);
+        ArtificialNeuralNetwork network = this.getInitialNetwork(R064Store.FACTORY);
 
         NetworkTrainer trainer = network.newTrainer();
         NetworkInvoker invoker = network.newInvoker();
 
         Data testCase = this.getTestCases().get(0);
 
-        Primitive64Store givenInput = testCase.input;
-        Primitive64Store targetOutput = testCase.target;
+        R064Store givenInput = testCase.input;
+        R064Store targetOutput = testCase.target;
         Access1D<Double> expectedOutput = testCase.expected;
         Access1D<Double> actualOutput = invoker.invoke(givenInput);
 
@@ -110,9 +110,9 @@ public class StepByStepBackpropagationExample extends BackPropagationExample {
         NetworkTrainer largerTrainer = largerNetwork.newTrainer();
         NetworkInvoker largerInvoker = largerNetwork.newInvoker();
 
-        Access1D<Double> preTrainingOutput = factory.rows(largerInvoker.invoke(givenInput));
+        Access1D<Double> preTrainingOutput = factory.row(largerInvoker.invoke(givenInput));
         largerTrainer.rate(HALF).train(givenInput, targetOutput);
-        Access1D<Double> postTrainingOutput = factory.rows(largerInvoker.invoke(givenInput));
+        Access1D<Double> postTrainingOutput = factory.row(largerInvoker.invoke(givenInput));
 
         // Even in this case training should reduce the error
         TestUtils.assertTrue(errorMeassure.invoke(targetOutput, preTrainingOutput) > errorMeassure.invoke(targetOutput, postTrainingOutput));
