@@ -26,7 +26,7 @@ import org.ojalgo.TestUtils;
 import org.ojalgo.matrix.decomposition.Cholesky;
 import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.matrix.store.RawStore;
 import org.ojalgo.random.Uniform;
 import org.ojalgo.scalar.RationalNumber;
@@ -39,14 +39,14 @@ public class SubstitutionTest extends ArrayOperationTests {
         int numbEquations = 4;
         int numbSolutions = 3;
 
-        MatrixStore<Double> primitiveBody = Primitive64Store.FACTORY.makeIdentity(numbEquations);
+        MatrixStore<Double> primitiveBody = R064Store.FACTORY.makeIdentity(numbEquations);
         MatrixStore<RationalNumber> rationalBody = GenericStore.Q128.makeIdentity(numbEquations);
 
-        Primitive64Store denseRHS = Primitive64Store.FACTORY.makeFilled(numbEquations, numbSolutions, new Uniform());
+        R064Store denseRHS = R064Store.FACTORY.makeFilled(numbEquations, numbSolutions, new Uniform());
         RawStore rawRHS = RawStore.FACTORY.copy(denseRHS);
         GenericStore<RationalNumber> rationalRHS = GenericStore.Q128.copy(denseRHS);
 
-        Primitive64Store expected = Primitive64Store.FACTORY.copy(denseRHS);
+        R064Store expected = R064Store.FACTORY.copy(denseRHS);
 
         SubstituteBackwards.invoke(denseRHS.data, numbEquations, 0, numbSolutions, primitiveBody, false, false, false);
         SubstituteBackwards.invoke(rawRHS.data, primitiveBody, false, false, false);
@@ -56,8 +56,8 @@ public class SubstitutionTest extends ArrayOperationTests {
         TestUtils.assertEquals(expected, rawRHS);
         TestUtils.assertEquals(expected, rationalRHS);
 
-        Cholesky<Double> cholesky = Cholesky.PRIMITIVE.make(numbEquations, numbEquations);
-        cholesky.decompose(Primitive64Store.FACTORY.makeSPD(numbEquations));
+        Cholesky<Double> cholesky = Cholesky.R064.make(numbEquations, numbEquations);
+        cholesky.decompose(R064Store.FACTORY.makeSPD(numbEquations));
 
         primitiveBody = cholesky.getR();
         rationalBody = GenericStore.Q128.copy(primitiveBody);
@@ -84,14 +84,14 @@ public class SubstitutionTest extends ArrayOperationTests {
         int numbEquations = 4;
         int numbSolutions = 3;
 
-        MatrixStore<Double> primitiveBody = Primitive64Store.FACTORY.makeIdentity(numbEquations);
+        MatrixStore<Double> primitiveBody = R064Store.FACTORY.makeIdentity(numbEquations);
         MatrixStore<RationalNumber> rationalBody = GenericStore.Q128.makeIdentity(numbEquations);
 
-        Primitive64Store denseRHS = Primitive64Store.FACTORY.makeFilled(numbEquations, numbSolutions, new Uniform());
+        R064Store denseRHS = R064Store.FACTORY.makeFilled(numbEquations, numbSolutions, new Uniform());
         RawStore rawRHS = RawStore.FACTORY.copy(denseRHS);
         GenericStore<RationalNumber> rationalRHS = GenericStore.Q128.copy(denseRHS);
 
-        Primitive64Store expected = Primitive64Store.FACTORY.copy(denseRHS);
+        R064Store expected = R064Store.FACTORY.copy(denseRHS);
 
         SubstituteForwards.invoke(denseRHS.data, numbEquations, 0, numbSolutions, primitiveBody, false, false, false);
         SubstituteForwards.invoke(rawRHS.data, primitiveBody, false, false, false);
@@ -101,8 +101,8 @@ public class SubstitutionTest extends ArrayOperationTests {
         TestUtils.assertEquals(expected, rawRHS);
         TestUtils.assertEquals(expected, rationalRHS);
 
-        Cholesky<Double> cholesky = Cholesky.PRIMITIVE.make(numbEquations, numbEquations);
-        cholesky.decompose(Primitive64Store.FACTORY.makeSPD(numbEquations));
+        Cholesky<Double> cholesky = Cholesky.R064.make(numbEquations, numbEquations);
+        cholesky.decompose(R064Store.FACTORY.makeSPD(numbEquations));
 
         primitiveBody = cholesky.getL();
         rationalBody = GenericStore.Q128.copy(primitiveBody);
