@@ -31,7 +31,7 @@ import org.ojalgo.function.constant.BigMath;
 import org.ojalgo.matrix.MatrixR064;
 import org.ojalgo.matrix.MatrixR064.DenseReceiver;
 import org.ojalgo.matrix.store.MatrixStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.RawStore;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.optimisation.Optimisation;
 import org.ojalgo.optimisation.Optimisation.State;
@@ -98,7 +98,7 @@ public class PortfolioProblems extends FinancePortfolioTests {
     @Test
     public void testP20110614() {
 
-        MatrixR064.DenseReceiver tmpCovarsBuilder = MatrixR064.FACTORY.makeDense(3, 3);
+        MatrixR064.DenseReceiver tmpCovarsBuilder = MatrixR064.FACTORY.newDenseBuilder(3, 3);
         tmpCovarsBuilder.set(0, 0, 0.04);
         tmpCovarsBuilder.set(0, 1, 0.01);
         tmpCovarsBuilder.set(0, 2, 0.02);
@@ -109,7 +109,7 @@ public class PortfolioProblems extends FinancePortfolioTests {
         tmpCovarsBuilder.set(2, 1, 0.01);
         tmpCovarsBuilder.set(2, 2, 0.16);
         MatrixR064 tmpCovars = tmpCovarsBuilder.get();
-        MatrixR064.DenseReceiver tmpReturnsBuilder = MatrixR064.FACTORY.makeDense(3, 1);
+        MatrixR064.DenseReceiver tmpReturnsBuilder = MatrixR064.FACTORY.newDenseBuilder(3, 1);
         tmpReturnsBuilder.set(0, 0, 0.10);
         tmpReturnsBuilder.set(1, 0, 0.15);
         tmpReturnsBuilder.set(2, 0, 0.18);
@@ -134,18 +134,18 @@ public class PortfolioProblems extends FinancePortfolioTests {
 
         // As the Markowitz model built it the problem
 
-        MatrixStore<Double> tmpQ = Primitive64Store.FACTORY.rows(new double[][] { { 4.0, 1.0, 2.0 }, { 1.0, 9.0, 1.0 }, { 2.0, 1.0, 16.0 } });
-        MatrixStore<Double> tmpC = Primitive64Store.FACTORY.rows(new double[][] { { 10.0 }, { 15.0 }, { 18.0 } });
+        MatrixStore<Double> tmpQ = RawStore.wrap(new double[][] { { 4.0, 1.0, 2.0 }, { 1.0, 9.0, 1.0 }, { 2.0, 1.0, 16.0 } });
+        MatrixStore<Double> tmpC = RawStore.wrap(new double[][] { { 10.0 }, { 15.0 }, { 18.0 } });
 
-        MatrixStore<Double> tmpAE = Primitive64Store.FACTORY.rows(new double[][] { { 1.0, 1.0, 1.0 } });
-        MatrixStore<Double> tmpBE = Primitive64Store.FACTORY.rows(new double[][] { { 1.0 } });
+        MatrixStore<Double> tmpAE = RawStore.wrap(new double[][] { { 1.0, 1.0, 1.0 } });
+        MatrixStore<Double> tmpBE = RawStore.wrap(new double[][] { { 1.0 } });
 
-        MatrixStore<Double> tmpAI = Primitive64Store.FACTORY.rows(new double[][] { { -1.0, 0.0, 0.0 }, { 0.0, -1.0, 0.0 }, { 0.0, 0.0, -1.0 } });
-        MatrixStore<Double> tmpBI = Primitive64Store.FACTORY.rows(new double[][] { { 0.0 }, { 0.0 }, { 0.0 } });
+        MatrixStore<Double> tmpAI = RawStore.wrap(new double[][] { { -1.0, 0.0, 0.0 }, { 0.0, -1.0, 0.0 }, { 0.0, 0.0, -1.0 } });
+        MatrixStore<Double> tmpBI = RawStore.wrap(new double[][] { { 0.0 }, { 0.0 }, { 0.0 } });
 
-        MatrixStore<Double> tmpX = Primitive64Store.FACTORY.rows(new double[][] { { 0.0 }, { 0.5217391304347826 }, { 0.4782608695652173 } });
+        MatrixStore<Double> tmpX = RawStore.wrap(new double[][] { { 0.0 }, { 0.5217391304347826 }, { 0.4782608695652173 } });
 
-        ConvexSolver.Builder tmpBuilder = new ConvexSolver.Builder(tmpQ, tmpC).equalities(tmpAE, tmpBE).inequalities(tmpAI, tmpBI);
+        ConvexSolver.Builder tmpBuilder = ConvexSolver.newBuilder().objective(tmpQ, tmpC).equalities(tmpAE, tmpBE).inequalities(tmpAI, tmpBI);
 
         ConvexSolver tmpSolver = tmpBuilder.build();
         // tmpSolver.options.debug(ConvexSolver.class);
@@ -160,10 +160,10 @@ public class PortfolioProblems extends FinancePortfolioTests {
         // on the portfolio weights, which you have to do. No problem with
         // ojAlgo.
 
-        tmpAI = Primitive64Store.FACTORY.rows(new double[][] { { 1.0, 0.0, 0.0 }, { 0.0, 1.0, 0.0 }, { 0.0, 0.0, 1.0 } });
-        tmpBI = Primitive64Store.FACTORY.rows(new double[][] { { 1.0 }, { 1.0 }, { 1.0 } });
+        tmpAI = RawStore.wrap(new double[][] { { 1.0, 0.0, 0.0 }, { 0.0, 1.0, 0.0 }, { 0.0, 0.0, 1.0 } });
+        tmpBI = RawStore.wrap(new double[][] { { 1.0 }, { 1.0 }, { 1.0 } });
 
-        tmpBuilder = new ConvexSolver.Builder(tmpQ, tmpC).equalities(tmpAE, tmpBE).inequalities(tmpAI, tmpBI);
+        tmpBuilder = ConvexSolver.newBuilder().objective(tmpQ, tmpC).equalities(tmpAE, tmpBE).inequalities(tmpAI, tmpBI);
         tmpSolver = tmpBuilder.build();
         tmpResult = tmpSolver.solve();
 
@@ -172,11 +172,11 @@ public class PortfolioProblems extends FinancePortfolioTests {
 
         // No problem with both the lower and upper limits set.
 
-        tmpAI = Primitive64Store.FACTORY
-                .rows(new double[][] { { -1.0, 0.0, 0.0 }, { 0.0, -1.0, 0.0 }, { 0.0, 0.0, -1.0 }, { 1.0, 0.0, 0.0 }, { 0.0, 1.0, 0.0 }, { 0.0, 0.0, 1.0 } });
-        tmpBI = Primitive64Store.FACTORY.rows(new double[][] { { 0.0 }, { 0.0 }, { 0.0 }, { 1.0 }, { 1.0 }, { 1.0 } });
+        tmpAI = RawStore
+                .wrap(new double[][] { { -1.0, 0.0, 0.0 }, { 0.0, -1.0, 0.0 }, { 0.0, 0.0, -1.0 }, { 1.0, 0.0, 0.0 }, { 0.0, 1.0, 0.0 }, { 0.0, 0.0, 1.0 } });
+        tmpBI = RawStore.wrap(new double[][] { { 0.0 }, { 0.0 }, { 0.0 }, { 1.0 }, { 1.0 }, { 1.0 } });
 
-        tmpBuilder = new ConvexSolver.Builder(tmpQ, tmpC).equalities(tmpAE, tmpBE).inequalities(tmpAI, tmpBI);
+        tmpBuilder = ConvexSolver.newBuilder().objective(tmpQ, tmpC).equalities(tmpAE, tmpBE).inequalities(tmpAI, tmpBI);
         tmpSolver = tmpBuilder.build();
         tmpResult = tmpSolver.solve();
 
@@ -194,7 +194,7 @@ public class PortfolioProblems extends FinancePortfolioTests {
     @Test
     public void testP20130329() {
 
-        MatrixR064 tmpCovariances = MatrixR064.FACTORY.rows(new double[][] { { 0.00360000, 0.001800000000 }, { 0.001800000000, 0.00090000 } });
+        MatrixR064 tmpCovariances = MatrixR064.FACTORY.copy(RawStore.wrap(new double[][] { { 0.00360000, 0.001800000000 }, { 0.001800000000, 0.00090000 } }));
 
         //         Eigenvalue<Double> tmpEvD = Eigenvalue.makePrimitive(true);
         //        tmpEvD.compute(tmpCovariances, true);
@@ -202,7 +202,7 @@ public class PortfolioProblems extends FinancePortfolioTests {
 
         MarketEquilibrium tmpMarketEquilibrium = new MarketEquilibrium(tmpCovariances, BigMath.THOUSAND);
 
-        MatrixR064.DenseReceiver tmpExcessReturnsBuilder = MatrixR064.FACTORY.makeDense(2, 1);
+        MatrixR064.DenseReceiver tmpExcessReturnsBuilder = MatrixR064.FACTORY.newDenseBuilder(2, 1);
         tmpExcessReturnsBuilder.set(0, 0, 0.1400);
         tmpExcessReturnsBuilder.set(1, 0, 0.0800);
         MatrixR064 tmpExcessReturns = tmpExcessReturnsBuilder.get();
@@ -326,8 +326,8 @@ public class PortfolioProblems extends FinancePortfolioTests {
     public void testP20160608() {
 
         MatrixR064.Factory matrixFactory = MatrixR064.FACTORY;
-        MatrixR064 cov = matrixFactory.rows(new double[][] { { 0.01, 0.0018, 0.0011 }, { 0.0018, 0.0109, 0.0026 }, { 0.0011, 0.0026, 0.0199 } });
-        MatrixR064 ret = matrixFactory.columns(new double[] { 0.0427, 0.0015, 0.0285 });
+        MatrixR064 cov = matrixFactory.copy(RawStore.wrap(new double[][] { { 0.01, 0.0018, 0.0011 }, { 0.0018, 0.0109, 0.0026 }, { 0.0011, 0.0026, 0.0199 } }));
+        MatrixR064 ret = matrixFactory.column(0.0427, 0.0015, 0.0285);
 
         MarketEquilibrium marketEquilibrium = new MarketEquilibrium(cov);
         MarkowitzModel markowitz = new MarkowitzModel(marketEquilibrium, ret);
@@ -365,7 +365,7 @@ public class PortfolioProblems extends FinancePortfolioTests {
     @Test
     public void testP20170508() {
 
-        MatrixR064.DenseReceiver tmpBuilder = MatrixR064.FACTORY.makeDense(2, 2);
+        MatrixR064.DenseReceiver tmpBuilder = MatrixR064.FACTORY.newDenseBuilder(2, 2);
         tmpBuilder.add(0, 0, 0.040000);
         tmpBuilder.add(0, 1, 0.1000);
         tmpBuilder.add(1, 0, 0.1000);
@@ -417,7 +417,7 @@ public class PortfolioProblems extends FinancePortfolioTests {
         double[] assetsReturns = { 1.43676262431851, 0.9538185507216703, 1.069364872519786, 1.1612520648051148, 0.8803365994805741 };
         double targetReturn = 0.08;
 
-        DenseReceiver assetsCovariancesMatrix = MatrixR064.FACTORY.makeDense(assetsCovariances.length, assetsCovariances.length);
+        DenseReceiver assetsCovariancesMatrix = MatrixR064.FACTORY.newDenseBuilder(assetsCovariances.length, assetsCovariances.length);
         for (int i = 0; i < assetsCovariances.length; i++) {
             for (int j = 0; j < assetsCovariances[i].length; j++) {
                 assetsCovariancesMatrix.set(i, j, assetsCovariances[i][j]);
@@ -475,12 +475,13 @@ public class PortfolioProblems extends FinancePortfolioTests {
     public void testP20200821() {
 
         MatrixR064.Factory matrixFactory = MatrixR064.FACTORY;
-        MatrixR064 cov = matrixFactory.rows(new double[][] { { 0.19828575384387814, 0.19939590712485014, 0.04848819110209297, 0.001060547131952715 },
-                { 0.19939590712485014, 0.17420946085220315, 0.05503998250848539, 0.09756310857237219 },
-                { 0.04848819110209297, 0.05503998250848539, 0.03544331442632964, 0.08244505440089961 },
-                { 0.001060547131952715, 0.09756310857237219, 0.08244505440089961, 0.18516185344938874 } });
+        MatrixR064 cov = matrixFactory
+                .copy(RawStore.wrap(new double[][] { { 0.19828575384387814, 0.19939590712485014, 0.04848819110209297, 0.001060547131952715 },
+                        { 0.19939590712485014, 0.17420946085220315, 0.05503998250848539, 0.09756310857237219 },
+                        { 0.04848819110209297, 0.05503998250848539, 0.03544331442632964, 0.08244505440089961 },
+                        { 0.001060547131952715, 0.09756310857237219, 0.08244505440089961, 0.18516185344938874 } }));
         MatrixR064 ret = matrixFactory
-                .rows(new double[][] { { 0.16373354541629026 }, { 0.007304578002244022 }, { 0.05247478842401128 }, { 0.12286070470561875 } });
+                .copy(RawStore.wrap(new double[][] { { 0.16373354541629026 }, { 0.007304578002244022 }, { 0.05247478842401128 }, { 0.12286070470561875 } }));
 
         MarketEquilibrium marketEquilibrium = new MarketEquilibrium(cov);
 
