@@ -25,6 +25,7 @@ import java.math.BigDecimal;
 import java.util.ArrayList;
 import java.util.List;
 
+import org.junit.jupiter.api.Tag;
 import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
 import org.ojalgo.function.UnaryFunction;
@@ -32,7 +33,7 @@ import org.ojalgo.function.constant.BigMath;
 import org.ojalgo.function.constant.PrimitiveMath;
 import org.ojalgo.matrix.MatrixR064;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.random.Uniform;
 import org.ojalgo.type.StandardType;
 import org.ojalgo.type.TypeUtils;
@@ -40,7 +41,7 @@ import org.ojalgo.type.context.NumberContext;
 
 public class TestEquilibrium extends FinancePortfolioTests {
 
-    public static void main(String[] args) {
+    public static void main(final String[] args) {
         int assetNum = 16;
 
         double[][] om = { { 0.003330616, 0.003524811, 0.00386567, 0.003656347, 0.004494241, 0.004623772, 0.00458625, 0.004365933, 0, 0, 0, 0, 0, 0, 0, 0 },
@@ -70,7 +71,7 @@ public class TestEquilibrium extends FinancePortfolioTests {
 
         MarketEquilibrium marketEquilibrium = new MarketEquilibrium(covariances, riskAversion);
 
-        MatrixR064.DenseReceiver expectedExcessReturns1 = MatrixR064.FACTORY.makeDense(assetNum, 1);
+        MatrixR064.DenseReceiver expectedExcessReturns1 = MatrixR064.FACTORY.newDenseBuilder(assetNum, 1);
         expectedExcessReturns1.set(0, 0, 0.03360872);
         expectedExcessReturns1.set(1, 0, 0.027322319);
         expectedExcessReturns1.set(2, 0, 0.027668137);
@@ -117,12 +118,12 @@ public class TestEquilibrium extends FinancePortfolioTests {
         super();
     }
 
-    public MatrixR064 getCovariances(double[][] returns) {
+    public MatrixR064 getCovariances(final double[][] returns) {
 
         int row = returns.length;
         int col = returns[0].length;
 
-        MatrixR064.DenseReceiver covariances = MatrixR064.FACTORY.makeDense(row, col);
+        MatrixR064.DenseReceiver covariances = MatrixR064.FACTORY.newDenseBuilder(row, col);
 
         for (int i = 1; i <= row; i++) {
             for (int j = i; j <= col; j++) {
@@ -135,6 +136,7 @@ public class TestEquilibrium extends FinancePortfolioTests {
     }
 
     @Test
+    @Tag("unstable")
     public void testRandomProblemsComparedToEquilibrium() {
 
         NumberContext weightsContext = StandardType.PERCENT.withPrecision(5);
@@ -146,7 +148,7 @@ public class TestEquilibrium extends FinancePortfolioTests {
         Uniform uniformRiskAversionExponent = new Uniform(-1.0, 3.0);
         Uniform uniformWeight = new Uniform(0.0, 1.0);
 
-        PhysicalStore<Double> covarianceMatrix = Primitive64Store.FACTORY.makeFilled(dim, dim, uniformCorrelation);
+        PhysicalStore<Double> covarianceMatrix = R064Store.FACTORY.makeFilled(dim, dim, uniformCorrelation);
         covarianceMatrix.fillDiagonal(1.0);
         covarianceMatrix.modifyAll(PrimitiveMath.DIVIDE.by(2.0));
         covarianceMatrix.modifyMatching(PrimitiveMath.ADD, covarianceMatrix.transpose());
@@ -163,7 +165,7 @@ public class TestEquilibrium extends FinancePortfolioTests {
         double[] rawWeights = MatrixR064.FACTORY.makeFilled(dim, 1, uniformWeight).toRawCopy1D();
         List<BigDecimal> normalisedWeights = new SimplePortfolio(rawWeights).normalise().getWeights();
 
-        MatrixR064 generatedWeights = MatrixR064.FACTORY.columns(normalisedWeights);
+        MatrixR064 generatedWeights = MatrixR064.FACTORY.column(normalisedWeights);
         MatrixR064 matchingReturns = equilibrium.calculateAssetReturns(generatedWeights);
         TestUtils.assertEquals(generatedWeights, equilibrium.calculateAssetWeights(matchingReturns), weightsContext);
 
