@@ -26,7 +26,7 @@ import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
 import org.ojalgo.matrix.decomposition.Cholesky;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.scalar.ComplexNumber;
 import org.ojalgo.type.context.NumberContext;
 
@@ -52,7 +52,7 @@ public class LargerCholeskyCase extends BasicMatrixTest {
 
         mtrxB = LargerCholeskyCase.getOriginal();
 
-        Cholesky<Double> tmpCholesky = Cholesky.PRIMITIVE.make();
+        Cholesky<Double> tmpCholesky = Cholesky.R064.make();
         tmpCholesky.decompose(mtrxB);
 
         mtrxA = MatrixR064.FACTORY.copy(tmpCholesky.getL());
@@ -68,7 +68,7 @@ public class LargerCholeskyCase extends BasicMatrixTest {
     public void testData() {
 
         MatrixR064 tmpMtrx = LargerCholeskyCase.getOriginal();
-        Cholesky<Double> tmpDecomp = Cholesky.PRIMITIVE.make();
+        Cholesky<Double> tmpDecomp = Cholesky.R064.make();
         tmpDecomp.decompose(tmpMtrx);
         TestUtils.assertEquals(true, tmpDecomp.isSolvable());
     }
@@ -77,10 +77,10 @@ public class LargerCholeskyCase extends BasicMatrixTest {
     public void testProblem() {
 
         MatrixR064 tmpMtrx = LargerCholeskyCase.getOriginal();
-        Cholesky<Double> tmpDecomp = Cholesky.PRIMITIVE.make();
+        Cholesky<Double> tmpDecomp = Cholesky.R064.make();
         tmpDecomp.decompose(tmpMtrx);
 
-        TestUtils.assertEquals(Primitive64Store.FACTORY.copy(tmpMtrx), tmpDecomp, ACCURACY);
+        TestUtils.assertEquals(R064Store.FACTORY.copy(tmpMtrx), tmpDecomp, ACCURACY);
     }
 
 }
