@@ -24,6 +24,7 @@ package org.ojalgo.matrix;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
+import org.ojalgo.matrix.store.RawStore;
 import org.ojalgo.type.context.NumberContext;
 
 /**
@@ -37,14 +38,15 @@ public class P20030422Case extends BasicMatrixTest {
     private static final NumberContext DEFINITION = NumberContext.of(7, 6);
 
     public static MatrixQ128 getProblematic() {
-        MatrixQ128 tmpMtrx = MatrixQ128.FACTORY.rows(new double[][] { { 0.973950, 0.132128, -0.009493, 0.052934, -0.069248, 0.015658, -0.008564, 0.004549 },
-                { -0.006969, -0.829742, -0.036236, 0.161777, -0.210089, 0.047385, -0.025882, 0.013746 },
-                { 0.000143, 0.006440, -0.998445, -0.016720, 0.021093, -0.004711, 0.002560, -0.001359 },
-                { -0.000036, -0.001408, 0.000752, -0.955688, -0.169493, 0.027513, -0.013046, 0.006811 },
-                { 0.000020, 0.000783, -0.000406, 0.058420, -0.910235, -0.074152, 0.023345, -0.011574 },
-                { -0.000003, -0.000101, 0.000052, -0.006126, 0.031007, -0.993209, -0.006144, 0.007871 },
-                { 0.000000, 0.000009, -0.000004, 0.000458, -0.001702, 0.002139, -0.946651, 0.219946 },
-                { 0.000000, 0.000002, -0.000001, 0.000085, -0.000388, -0.004230, -0.222064, 0.051624 } });
+        MatrixQ128 tmpMtrx = MatrixQ128.FACTORY
+                .copy(RawStore.wrap(new double[][] { { 0.973950, 0.132128, -0.009493, 0.052934, -0.069248, 0.015658, -0.008564, 0.004549 },
+                        { -0.006969, -0.829742, -0.036236, 0.161777, -0.210089, 0.047385, -0.025882, 0.013746 },
+                        { 0.000143, 0.006440, -0.998445, -0.016720, 0.021093, -0.004711, 0.002560, -0.001359 },
+                        { -0.000036, -0.001408, 0.000752, -0.955688, -0.169493, 0.027513, -0.013046, 0.006811 },
+                        { 0.000020, 0.000783, -0.000406, 0.058420, -0.910235, -0.074152, 0.023345, -0.011574 },
+                        { -0.000003, -0.000101, 0.000052, -0.006126, 0.031007, -0.993209, -0.006144, 0.007871 },
+                        { 0.000000, 0.000009, -0.000004, 0.000458, -0.001702, 0.002139, -0.946651, 0.219946 },
+                        { 0.000000, 0.000002, -0.000001, 0.000085, -0.000388, -0.004230, -0.222064, 0.051624 } }));
         return tmpMtrx.enforce(DEFINITION);
     }
 
