@@ -24,6 +24,7 @@ package org.ojalgo.matrix;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
+import org.ojalgo.matrix.store.RawStore;
 import org.ojalgo.type.context.NumberContext;
 
 /**
@@ -38,7 +39,7 @@ public class P20030512Case extends BasicMatrixTest {
 
     public static MatrixQ128 getProblematic() {
 
-        MatrixQ128 problematic = MatrixQ128.FACTORY.rows(new double[][] {
+        MatrixQ128 problematic = MatrixQ128.FACTORY.copy(RawStore.wrap(new double[][] {
                 { -0.9739496281920735, 0.13212842225762753, -0.009493226825028579, 0.05293424713580207, -0.06924760059060892, 0.015657944731764042,
                         -0.008564346745847575, 0.004549185362729688 },
                 { -0.006968800104298036, -0.8297418413337506, -0.0362355854907016, 0.16177736191417533, -0.2100891795366892, 0.047384677993178616,
@@ -54,7 +55,7 @@ public class P20030512Case extends BasicMatrixTest {
                 { 2.229928791772293E-7, 8.605627003794518E-6, -4.397793602224121E-6, 4.5796561576393096E-4, -0.0017021220200960682, 0.002139079626942216,
                         -0.9466510330795804, 0.21994580987160817 },
                 { 4.2787387020086915E-8, 1.6510244524754327E-6, -8.431008420700906E-7, 8.524039438893604E-5, -3.878467110438371E-4, -0.00423012863453722,
-                        -0.22206406664227266, 0.05162429369962791 } });
+                        -0.22206406664227266, 0.05162429369962791 } }));
 
         return problematic.enforce(DEFINITION);
     }
