@@ -26,7 +26,8 @@ import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
 import org.ojalgo.matrix.decomposition.SingularValue;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
+import org.ojalgo.matrix.store.RawStore;
 import org.ojalgo.type.context.NumberContext;
 
 /**
@@ -42,7 +43,7 @@ public class P20030528Case extends BasicMatrixTest {
 
     public static MatrixR064 getProblematic() {
         MatrixR064 tmpMtrx = MatrixR064.FACTORY
-                .rows(new double[][] { { 1, 0, 0, 0, 0, 0, 1 }, { 0, 1, 0, 0, 0, 1, 0 }, { 0, 0, 1, 0, 1, 0, 0 }, { 0, 0, 0, 1, 0, 0, 0 } });
+                .copy(RawStore.wrap(new double[][] { { 1, 0, 0, 0, 0, 0, 1 }, { 0, 1, 0, 0, 0, 1, 0 }, { 0, 0, 1, 0, 1, 0, 0 }, { 0, 0, 0, 1, 0, 0, 0 } }));
         return tmpMtrx.enforce(DEFINITION);
     }
 
@@ -72,9 +73,9 @@ public class P20030528Case extends BasicMatrixTest {
     @Test
     public void testProblem() {
 
-        PhysicalStore<Double> tmpA = Primitive64Store.FACTORY.copy(P20030528Case.getProblematic());
+        PhysicalStore<Double> tmpA = R064Store.FACTORY.copy(P20030528Case.getProblematic());
 
-        SingularValue<Double> tmpSVD = SingularValue.PRIMITIVE.make(tmpA);
+        SingularValue<Double> tmpSVD = SingularValue.R064.make(tmpA);
         tmpSVD.decompose(tmpA);
 
         // tmpSVD.equals(tmpA, EVALUATION);
