@@ -40,7 +40,7 @@ public class ReductionTest {
     @Test
     public void testReduction() {
 
-        MatrixR064.DenseReceiver builder = MatrixR064.FACTORY.makeDense(2, 3);
+        MatrixR064.DenseReceiver builder = MatrixR064.FACTORY.newDenseBuilder(2, 3);
         builder.set(0, 0, 1.0);
         builder.set(0, 1, 2.0);
         builder.set(0, 2, 3.0);
