@@ -24,6 +24,7 @@ package org.ojalgo.matrix;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
+import org.ojalgo.matrix.store.RawStore;
 import org.ojalgo.type.context.NumberContext;
 
 /**
@@ -37,28 +38,29 @@ public class SimpleLeastSquaresCase extends BasicMatrixTest {
     private static final NumberContext DEFINITION = NumberContext.of(7, 4);
 
     public static MatrixR064 getBody() {
-        MatrixR064 tmpMtrx = MatrixR064.FACTORY
-                .rows(new double[][] { { 1.0, 0.0, 0.0 }, { 0.0, 1.0, 0.0 }, { 0.0, 0.0, 1.0 }, { -1.0, 1.0, 0.0 }, { -1.0, 0.0, 1.0 }, { 0.0, -1.0, 1.0 } });
+        MatrixR064 tmpMtrx = MatrixR064.FACTORY.copy(RawStore
+                .wrap(new double[][] { { 1.0, 0.0, 0.0 }, { 0.0, 1.0, 0.0 }, { 0.0, 0.0, 1.0 }, { -1.0, 1.0, 0.0 }, { -1.0, 0.0, 1.0 }, { 0.0, -1.0, 1.0 } }));
         return tmpMtrx.enforce(DEFINITION);
     }
 
     public static MatrixR064 getRHS() {
-        MatrixR064 tmpMtrx = MatrixR064.FACTORY.rows(new double[][] { { 1237 }, { 1941 }, { 2417 }, { 711 }, { 1177 }, { 475 } });
+        MatrixR064 tmpMtrx = MatrixR064.FACTORY.copy(RawStore.wrap(new double[][] { { 1237 }, { 1941 }, { 2417 }, { 711 }, { 1177 }, { 475 } }));
         return tmpMtrx.enforce(DEFINITION);
     }
 
     public static MatrixR064 getSolution() {
-        MatrixR064 tmpMtrx = MatrixR064.FACTORY.rows(new double[][] { { 1236 }, { 1943 }, { 2416 } });
+        MatrixR064 tmpMtrx = MatrixR064.FACTORY.copy(RawStore.wrap(new double[][] { { 1236 }, { 1943 }, { 2416 } }));
         return tmpMtrx.enforce(DEFINITION);
     }
 
     private static MatrixR064 getFactorR() {
-        MatrixR064 tmpMtrx = MatrixR064.FACTORY.rows(new double[][] { { -1.7321, 0.5774, 0.5774 }, { 0.0, -1.6330, 0.8165 }, { 0.0, 0.0, -1.4142 } });
+        MatrixR064 tmpMtrx = MatrixR064.FACTORY
+                .copy(RawStore.wrap(new double[][] { { -1.7321, 0.5774, 0.5774 }, { 0.0, -1.6330, 0.8165 }, { 0.0, 0.0, -1.4142 } }));
         return tmpMtrx.enforce(DEFINITION);
     }
 
     private static MatrixR064 getTransformedRHS() {
-        MatrixR064 tmpMtrx = MatrixR064.FACTORY.rows(new double[][] { { 376 }, { -1200 }, { -3417 } });
+        MatrixR064 tmpMtrx = MatrixR064.FACTORY.copy(RawStore.wrap(new double[][] { { 376 }, { -1200 }, { -3417 } }));
         return tmpMtrx.enforce(DEFINITION);
     }
 
