@@ -49,7 +49,7 @@ import org.ojalgo.matrix.store.DiagonalStore;
 import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.matrix.store.RawStore;
 import org.ojalgo.matrix.task.SolverTask;
 import org.ojalgo.netio.BasicLogger;
@@ -78,13 +78,13 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
 
         int dim = eigenvalues.length;
 
-        Primitive64Store seed = Primitive64Store.FACTORY.makeFilled(dim, dim, Uniform.standard());
+        R064Store seed = R064Store.FACTORY.makeFilled(dim, dim, Uniform.standard());
         QR<Double> qr = QR.R064.make(seed);
         qr.decompose(seed);
 
         MatrixStore<Double> mtrxQ = qr.getQ();
 
-        DiagonalStore<Double, ArrayR064> mtrxD = Primitive64Store.FACTORY.makeDiagonal(ArrayR064.wrap(eigenvalues)).get();
+        DiagonalStore<Double, ArrayR064> mtrxD = R064Store.FACTORY.makeDiagonal(ArrayR064.wrap(eigenvalues)).get();
 
         return mtrxQ.multiply(mtrxD).multiply(mtrxQ.conjugate());
     }
@@ -127,7 +127,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
         CaseEigenvalue.doTestEigenvalues(generated, NumberContext.of(8), expected);
     }
 
-    private static void doVerifyGeneral(final Primitive64Store matrix) {
+    private static void doVerifyGeneral(final MatrixStore<Double> matrix) {
 
         for (Eigenvalue<Double> tmpEigenvalue : MatrixDecompositionTests.getPrimitiveEigenvalueGeneral()) {
 
@@ -163,7 +163,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
         matrix.set(0, 1, ComplexNumber.of(-2.0, 1.0));
         matrix.set(1, 1, ComplexNumber.of(5.0, 0.0));
 
-        Eigenvalue<ComplexNumber> evd = Eigenvalue.COMPLEX.make(matrix, true);
+        Eigenvalue<ComplexNumber> evd = Eigenvalue.C128.make(matrix, true);
         evd.decompose(matrix);
 
         MatrixStore<ComplexNumber> mtrxD = evd.getD();
@@ -218,7 +218,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
             BasicLogger.debugMatrix("B", mtrxB);
         }
 
-        Eigenvalue.Generalised<ComplexNumber> evd = Eigenvalue.COMPLEX.makeGeneralised(mtrxA, Generalisation.A_B);
+        Eigenvalue.Generalised<ComplexNumber> evd = Eigenvalue.C128.makeGeneralised(mtrxA, Generalisation.A_B);
         evd.decompose(mtrxA, mtrxB); // [A][V]=[B][V][D]
 
         MatrixStore<ComplexNumber> mtrxD = evd.getD();
@@ -286,7 +286,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
         String path = "src/test/resources/org/ojalgo/matrix/decomposition/GitHubIssue366_Mat.txt";
         List<String> lines = Files.lines(Paths.get(path)).collect(Collectors.toList());
 
-        Primitive64Store problematic = Primitive64Store.FACTORY.make(lines.size(), lines.size());
+        R064Store problematic = R064Store.FACTORY.make(lines.size(), lines.size());
 
         for (int r = 0; r < lines.size(); r++) {
             String[] line_vec = lines.get(r).split(" ");
@@ -305,8 +305,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
     @Test
     public void testJamaProblem() throws IOException {
 
-        Primitive64Store problematic = Primitive64Store.FACTORY
-                .rows(new double[][] { { 0, 0, 0, 0, 0 }, { 0, 0, 0, 0, 1 }, { 0, 0, 0, 1, 0 }, { 1, 1, 0, 0, 1 }, { 1, 0, 1, 0, 1 } });
+        RawStore problematic = RawStore.wrap(new double[][] { { 0, 0, 0, 0, 0 }, { 0, 0, 0, 0, 1 }, { 0, 0, 0, 1, 0 }, { 1, 1, 0, 0, 1 }, { 1, 0, 1, 0, 1 } });
 
         CaseEigenvalue.doVerifyGeneral(problematic);
     }
@@ -314,7 +313,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
     @Test
     public void testP20050125Case() {
 
-        PhysicalStore<Double> tmpOriginalMatrix = Primitive64Store.FACTORY.copy(P20050125Case.getProblematic());
+        PhysicalStore<Double> tmpOriginalMatrix = R064Store.FACTORY.copy(P20050125Case.getProblematic());
 
         TestUtils.assertTrue(tmpOriginalMatrix.isHermitian());
 
@@ -332,12 +331,12 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
 
             BasicLogger.debug("D");
             for (Eigenvalue<Double> tmpDecomp : tmpDecomps) {
-                BasicLogger.debug(tmpDecomp.getClass().getName() + ": " + Primitive64Store.FACTORY.copy(tmpDecomp.getD()));
+                BasicLogger.debug(tmpDecomp.getClass().getName() + ": " + R064Store.FACTORY.copy(tmpDecomp.getD()));
             }
 
             BasicLogger.debug("V");
             for (Eigenvalue<Double> tmpDecomp : tmpDecomps) {
-                BasicLogger.debug(tmpDecomp.getClass().getName() + ": " + Primitive64Store.FACTORY.copy(tmpDecomp.getV()));
+                BasicLogger.debug(tmpDecomp.getClass().getName() + ": " + R064Store.FACTORY.copy(tmpDecomp.getV()));
             }
         }
 
@@ -349,7 +348,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
     @Test
     public void testP20061119Case() {
 
-        PhysicalStore<Double> tmpOriginalMatrix = Primitive64Store.FACTORY.copy(P20061119Case.getProblematic());
+        PhysicalStore<Double> tmpOriginalMatrix = R064Store.FACTORY.copy(P20061119Case.getProblematic());
 
         ComplexNumber tmp00 = ComplexNumber.valueOf(26.14421883828456);
         ComplexNumber tmp11 = ComplexNumber.of(2.727890580857718, 3.6223578444417908);
@@ -362,7 +361,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
 
         MatrixStore<Double> tmpRecreatedMatrix;
 
-        Eigenvalue<Double> tmpDecomposition = Eigenvalue.PRIMITIVE.make(tmpOriginalMatrix);
+        Eigenvalue<Double> tmpDecomposition = Eigenvalue.R064.make(tmpOriginalMatrix);
         tmpDecomposition.decompose(tmpOriginalMatrix);
 
         Array1D<ComplexNumber> tmpEigenvalues = tmpDecomposition.getEigenvalues();
@@ -395,7 +394,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
     public void testPaulsMathNote() {
 
         double[][] tmpData = { { 3, -9 }, { 4, -3 } };
-        Primitive64Store tmpA = Primitive64Store.FACTORY.rows(tmpData);
+        RawStore tmpA = RawStore.wrap(tmpData);
         int tmpLength = tmpData.length;
 
         Array1D<ComplexNumber> tmpExpVals = Array1D.C128.make(2);
@@ -408,7 +407,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
         tmpExpVecs.set(0, 1, ComplexNumber.of(THREE, ZERO));
         tmpExpVecs.set(1, 1, ComplexNumber.of(ONE, PrimitiveMath.SQRT.invoke(THREE)));
 
-        Eigenvalue<Double> tmpEvD = Eigenvalue.PRIMITIVE.make(tmpA, false);
+        Eigenvalue<Double> tmpEvD = Eigenvalue.R064.make(tmpA, false);
         tmpEvD.decompose(tmpA);
 
         MatrixStore<Double> tmpD = tmpEvD.getD();
@@ -454,11 +453,11 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
     public void testPrimitiveAsComplex() {
 
         double[][] tmpData = { { 1, 0, 3 }, { 0, 4, 1 }, { -5, 1, 0 } };
-        Primitive64Store tmpA = Primitive64Store.FACTORY.rows(tmpData);
+        RawStore tmpA = RawStore.wrap(tmpData);
 
         int tmpLength = tmpData.length;
 
-        Eigenvalue<Double> tmpEvD = Eigenvalue.PRIMITIVE.make(tmpA, false);
+        Eigenvalue<Double> tmpEvD = Eigenvalue.R064.make(tmpA, false);
 
         tmpEvD.decompose(tmpA);
 
@@ -498,7 +497,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
     @Test
     public void testProblemFoundInTheWild() {
 
-        Primitive64Store matrix = Primitive64Store.FACTORY.rows(new double[][] { { 1, 0, 0 }, { 0.01, 0, -1 }, { 0.01, 1, 0 } });
+        RawStore matrix = RawStore.wrap(new double[][] { { 1, 0, 0 }, { 0.01, 0, -1 }, { 0.01, 1, 0 } });
 
         CaseEigenvalue.doVerifyGeneral(matrix);
     }
@@ -510,18 +509,18 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
 
         for (int dim = 2; dim < 10; dim++) {
 
-            Primitive64Store mtrxA = Primitive64Store.FACTORY.makeSPD(dim);
-            Primitive64Store mtrxB = Primitive64Store.FACTORY.makeSPD(dim);
+            R064Store mtrxA = R064Store.FACTORY.makeSPD(dim);
+            R064Store mtrxB = R064Store.FACTORY.makeSPD(dim);
 
-            Cholesky<Double> cholesky = Cholesky.PRIMITIVE.make(mtrxB);
+            Cholesky<Double> cholesky = Cholesky.R064.make(mtrxB);
             cholesky.decompose(mtrxB);
 
             MatrixStore<Double> compL = cholesky.getL();
             MatrixStore<Double> compU = cholesky.getR();
 
-            MatrixStore<Double> mtrxC = SolverTask.PRIMITIVE.solve(compL, SolverTask.PRIMITIVE.solve(compL, mtrxA).transpose());
+            MatrixStore<Double> mtrxC = SolverTask.R064.solve(compL, SolverTask.R064.solve(compL, mtrxA).transpose());
 
-            Eigenvalue<Double> eigenvalue = Eigenvalue.PRIMITIVE.make(mtrxC, true);
+            Eigenvalue<Double> eigenvalue = Eigenvalue.R064.make(mtrxC, true);
             eigenvalue.decompose(mtrxC);
             TestUtils.assertEquals(mtrxC, eigenvalue, accuracy);
 
@@ -531,17 +530,17 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
             MatrixStore<Double> vectorsY = eigenvalue.getV();
 
             MatrixStore<Double> leftY = mtrxC.multiply(vectorsY);
-            MatrixStore<Double> scales = leftY.onMatching(DIVIDE, vectorsY).collect(Primitive64Store.FACTORY);
-            MatrixStore<Double> averages = scales.reduceColumns(Aggregator.AVERAGE).collect(Primitive64Store.FACTORY);
+            MatrixStore<Double> scales = leftY.onMatching(DIVIDE, vectorsY).collect(R064Store.FACTORY);
+            MatrixStore<Double> averages = scales.reduceColumns(Aggregator.AVERAGE).collect(R064Store.FACTORY);
             TestUtils.assertEquals(values, averages, accuracy);
 
-            MatrixStore<Double> vectorsZ = SolverTask.PRIMITIVE.solve(compU, vectorsY);
+            MatrixStore<Double> vectorsZ = SolverTask.R064.solve(compU, vectorsY);
 
             MatrixStore<Double> leftZ = mtrxA.multiply(vectorsZ);
             MatrixStore<Double> rightZ = mtrxB.multiply(vectorsZ);
-            TestUtils.assertEquals(scales, leftZ.onMatching(DIVIDE, rightZ).collect(Primitive64Store.FACTORY), accuracy);
+            TestUtils.assertEquals(scales, leftZ.onMatching(DIVIDE, rightZ).collect(R064Store.FACTORY), accuracy);
 
-            Eigenvalue.Generalised<Double> generalised = Eigenvalue.PRIMITIVE.makeGeneralised(mtrxA);
+            Eigenvalue.Generalised<Double> generalised = Eigenvalue.R064.makeGeneralised(mtrxA);
             generalised.decompose(mtrxA, mtrxB);
 
             TestUtils.assertEquals(mtrxC, generalised.reconstruct(), accuracy);
@@ -557,10 +556,10 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
 
         for (int dim = 2; dim < 10; dim++) {
 
-            Primitive64Store mtrxA = Primitive64Store.FACTORY.makeSPD(dim);
-            Primitive64Store mtrxB = Primitive64Store.FACTORY.makeSPD(dim);
+            R064Store mtrxA = R064Store.FACTORY.makeSPD(dim);
+            R064Store mtrxB = R064Store.FACTORY.makeSPD(dim);
 
-            Cholesky<Double> cholesky = Cholesky.PRIMITIVE.make(mtrxB);
+            Cholesky<Double> cholesky = Cholesky.R064.make(mtrxB);
             cholesky.decompose(mtrxB);
 
             MatrixStore<Double> compL = cholesky.getL();
@@ -568,7 +567,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
 
             MatrixStore<Double> mtrxC = compL.transpose().multiply(mtrxA).multiply(compL);
 
-            Eigenvalue<Double> eigenvalue = Eigenvalue.PRIMITIVE.make(mtrxC, true);
+            Eigenvalue<Double> eigenvalue = Eigenvalue.R064.make(mtrxC, true);
             eigenvalue.decompose(mtrxC);
             TestUtils.assertEquals(mtrxC, eigenvalue, accuracy);
 
@@ -578,17 +577,17 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
             MatrixStore<Double> vectorsY = eigenvalue.getV();
 
             MatrixStore<Double> leftY = mtrxC.multiply(vectorsY);
-            MatrixStore<Double> scales = leftY.onMatching(DIVIDE, vectorsY).collect(Primitive64Store.FACTORY);
-            MatrixStore<Double> averages = scales.reduceColumns(Aggregator.AVERAGE).collect(Primitive64Store.FACTORY);
+            MatrixStore<Double> scales = leftY.onMatching(DIVIDE, vectorsY).collect(R064Store.FACTORY);
+            MatrixStore<Double> averages = scales.reduceColumns(Aggregator.AVERAGE).collect(R064Store.FACTORY);
             TestUtils.assertEquals(values, averages, accuracy);
 
-            MatrixStore<Double> vectorsZ = SolverTask.PRIMITIVE.solve(compU, vectorsY);
+            MatrixStore<Double> vectorsZ = SolverTask.R064.solve(compU, vectorsY);
 
             MatrixStore<Double> leftZ = mtrxA.multiply(mtrxB).multiply(vectorsZ);
             MatrixStore<Double> rightZ = vectorsZ;
-            TestUtils.assertEquals(scales, leftZ.onMatching(DIVIDE, rightZ).collect(Primitive64Store.FACTORY), accuracy);
+            TestUtils.assertEquals(scales, leftZ.onMatching(DIVIDE, rightZ).collect(R064Store.FACTORY), accuracy);
 
-            Eigenvalue.Generalised<Double> generalised = Eigenvalue.PRIMITIVE.makeGeneralised(mtrxA, Generalisation.AB);
+            Eigenvalue.Generalised<Double> generalised = Eigenvalue.R064.makeGeneralised(mtrxA, Generalisation.AB);
             generalised.decompose(mtrxA, mtrxB);
 
             if (DEBUG) {
@@ -608,10 +607,10 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
 
         for (int dim = 2; dim < 10; dim++) {
 
-            Primitive64Store mtrxA = Primitive64Store.FACTORY.makeSPD(dim);
-            Primitive64Store mtrxB = Primitive64Store.FACTORY.makeSPD(dim);
+            R064Store mtrxA = R064Store.FACTORY.makeSPD(dim);
+            R064Store mtrxB = R064Store.FACTORY.makeSPD(dim);
 
-            Cholesky<Double> cholesky = Cholesky.PRIMITIVE.make(mtrxB);
+            Cholesky<Double> cholesky = Cholesky.R064.make(mtrxB);
             cholesky.decompose(mtrxB);
 
             MatrixStore<Double> compL = cholesky.getL();
@@ -619,7 +618,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
 
             MatrixStore<Double> mtrxC = compL.transpose().multiply(mtrxA).multiply(compL);
 
-            Eigenvalue<Double> eigenvalue = Eigenvalue.PRIMITIVE.make(mtrxC, true);
+            Eigenvalue<Double> eigenvalue = Eigenvalue.R064.make(mtrxC, true);
             eigenvalue.decompose(mtrxC);
             TestUtils.assertEquals(mtrxC, eigenvalue, accuracy);
 
@@ -629,17 +628,17 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
             MatrixStore<Double> vectorsY = eigenvalue.getV();
 
             MatrixStore<Double> leftY = mtrxC.multiply(vectorsY);
-            MatrixStore<Double> scales = leftY.onMatching(DIVIDE, vectorsY).collect(Primitive64Store.FACTORY);
-            MatrixStore<Double> averages = scales.reduceColumns(Aggregator.AVERAGE).collect(Primitive64Store.FACTORY);
+            MatrixStore<Double> scales = leftY.onMatching(DIVIDE, vectorsY).collect(R064Store.FACTORY);
+            MatrixStore<Double> averages = scales.reduceColumns(Aggregator.AVERAGE).collect(R064Store.FACTORY);
             TestUtils.assertEquals(values, averages, accuracy);
 
             MatrixStore<Double> vectorsZ = compL.multiply(vectorsY);
 
             MatrixStore<Double> leftZ = mtrxB.multiply(mtrxA).multiply(vectorsZ);
             MatrixStore<Double> rightZ = vectorsZ;
-            TestUtils.assertEquals(scales, leftZ.onMatching(DIVIDE, rightZ).collect(Primitive64Store.FACTORY), accuracy);
+            TestUtils.assertEquals(scales, leftZ.onMatching(DIVIDE, rightZ).collect(R064Store.FACTORY), accuracy);
 
-            Eigenvalue.Generalised<Double> generalised = Eigenvalue.PRIMITIVE.makeGeneralised(mtrxA, Generalisation.BA);
+            Eigenvalue.Generalised<Double> generalised = Eigenvalue.R064.makeGeneralised(mtrxA, Generalisation.BA);
             generalised.decompose(mtrxA, mtrxB);
 
             TestUtils.assertEquals(mtrxC, generalised.reconstruct(), accuracy);
@@ -655,13 +654,13 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
 
         for (int dim = 2; dim < 10; dim++) {
 
-            Primitive64Store mtrxA = Primitive64Store.FACTORY.makeSPD(dim);
+            R064Store mtrxA = R064Store.FACTORY.makeSPD(dim);
 
-            Eigenvalue<Double> eigenvalue = Eigenvalue.PRIMITIVE.make(mtrxA, true);
+            Eigenvalue<Double> eigenvalue = Eigenvalue.R064.make(mtrxA, true);
             eigenvalue.decompose(mtrxA);
             TestUtils.assertEquals(mtrxA, eigenvalue, accuracy);
 
-            Eigenvalue.Generalised<Double> generalised = Eigenvalue.PRIMITIVE.makeGeneralised(mtrxA);
+            Eigenvalue.Generalised<Double> generalised = Eigenvalue.R064.makeGeneralised(mtrxA);
             generalised.decompose(mtrxA);
             TestUtils.assertEquals(mtrxA, generalised, accuracy);
 
@@ -679,7 +678,7 @@ public class CaseEigenvalue extends MatrixDecompositionTests {
         for (int dim = 1; dim < 10; dim++) {
 
             int dim1 = dim;
-            Primitive64Store matrix = Primitive64Store.FACTORY.makeSPD(dim1);
+            R064Store matrix = R064Store.FACTORY.makeSPD(dim1);
 
             for (Eigenvalue<Double> decomp : MatrixDecompositionTests.getPrimitiveEigenvalueSymmetric()) {
 
