@@ -40,7 +40,8 @@ import org.ojalgo.matrix.P20071019Case;
 import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
+import org.ojalgo.matrix.store.RawStore;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.random.Normal;
 import org.ojalgo.scalar.ComplexNumber;
@@ -50,8 +51,8 @@ import org.ojalgo.type.context.NumberContext;
 
 public class CaseSingularValue extends MatrixDecompositionTests {
 
-    private static final SingularValue<RationalNumber> IMPL_BIG = SingularValue.RATIONAL.make();
-    private static final SingularValue<ComplexNumber> IMPL_COMPLEX = SingularValue.COMPLEX.make();
+    private static final SingularValue<RationalNumber> IMPL_BIG = SingularValue.Q128.make();
+    private static final SingularValue<ComplexNumber> IMPL_COMPLEX = SingularValue.C128.make();
     private static final SingularValue<Double> IMPL_PRIMITIVE = new SingularValueDecomposition.R064();
     private static final SingularValue<Double> IMPL_RAW = new RawSingularValue();
 
@@ -64,290 +65,16 @@ public class CaseSingularValue extends MatrixDecompositionTests {
     static final NumberContext CNTXT_REAL_DECOMP = NumberContext.of(3, 2);
     static final NumberContext CNTXT_REAL_VALUES = NumberContext.of(7, 10);
 
-    @Override
-    @BeforeEach
-    public void minimiseAllBranchLimits() {
-        TestUtils.minimiseAllBranchLimits();
-    }
-
-    @Test
-    public void testBasicMatrixP20030422Case() {
-        CaseSingularValue.doTestTypes(P20030422Case.getProblematic());
-    }
-
-    @Test
-    public void testBasicMatrixP20030512Case() {
-        CaseSingularValue.doTestTypes(P20030512Case.getProblematic());
-    }
-
-    @Test
-    public void testBasicMatrixP20030528Case() {
-        CaseSingularValue.doTestTypes(P20030528Case.getProblematic());
-    }
-
-    @Test
-    public void testBasicMatrixP20050125Case() {
-        CaseSingularValue.doTestTypes(P20050125Case.getProblematic());
-    }
-
-    @Test
-    public void testBasicMatrixP20050827Case() {
-        CaseSingularValue.doTestTypes(MatrixQ128.FACTORY.copy(P20050827Case.getProblematic()));
-    }
-
-    @Test
-    public void testBasicMatrixP20061119Case() {
-        CaseSingularValue.doTestTypes(P20061119Case.getProblematic());
-    }
-
-    @Test
-    public void testBasicMatrixP20071019FatCase() {
-        CaseSingularValue.doTestTypes(P20071019Case.getFatProblematic());
-    }
-
-    @Test
-    public void testBasicMatrixP20071019TallCase() {
-        CaseSingularValue.doTestTypes(P20071019Case.getTallProblematic());
-    }
-
-    /**
-     * http://en.wikipedia.org/wiki/Singular_value_decomposition
-     */
-    @Test
-    public void testComplexNumberVersionOfWikipediaCase() {
-
-        PhysicalStore<Double> tmpBaseMtrx = Primitive64Store.FACTORY
-                .rows(new double[][] { { 1.0, 0.0, 0.0, 0.0, 2.0 }, { 0.0, 0.0, 3.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 4.0, 0.0, 0.0, 0.0 } });
-
-        double[] data = { 4.0, 3.0, PrimitiveMath.SQRT.invoke(5.0), 0.0 };
-        Array1D<Double> tmpExpectedSingularValues = Array1D.R064.copy(data);
-
-        ComplexNumber[] tmpScales = { ComplexNumber.makePolar(1.0, 0.0), ComplexNumber.makePolar(1.0, Math.PI / 2.0),
-                ComplexNumber.makePolar(1.0, -Math.PI / 2.0), ComplexNumber.makePolar(1.0, Math.PI / 4.0), ComplexNumber.makePolar(1.0, 4.0 * Math.PI / 3.0) };
-
-        Bidiagonal<ComplexNumber> tmpBidiagonal = Bidiagonal.COMPLEX.make();
-        SingularValue<ComplexNumber> tmpSVD = SingularValue.COMPLEX.make();
-
-        for (ComplexNumber tmpScale : tmpScales) {
-
-            PhysicalStore<ComplexNumber> tmpOriginalMtrx = GenericStore.C128.transpose(tmpBaseMtrx);
-            tmpOriginalMtrx.modifyAll(ComplexMath.MULTIPLY.first(tmpScale));
-
-            tmpBidiagonal.decompose(tmpOriginalMtrx);
-            MatrixStore<ComplexNumber> tmpReconstructed = tmpBidiagonal.reconstruct();
-            if (MatrixDecompositionTests.DEBUG) {
-                BasicLogger.debug();
-                BasicLogger.debugMatrix("Scale = {}", tmpScale);
-                BasicLogger.debugMatrix("A", tmpOriginalMtrx);
-                BasicLogger.debugMatrix("Q1", tmpBidiagonal.getLQ());
-                BasicLogger.debugMatrix("D", tmpBidiagonal.getD());
-                BasicLogger.debugMatrix("Q2", tmpBidiagonal.getRQ());
-                BasicLogger.debugMatrix("Reconstructed", tmpReconstructed);
-            }
-            TestUtils.assertEquals(tmpOriginalMtrx, tmpReconstructed, NumberContext.of(7, 6));
-        }
-
-        for (ComplexNumber tmpScale : tmpScales) {
-
-            if (MatrixDecompositionTests.DEBUG) {
-                BasicLogger.debug();
-                BasicLogger.debugMatrix("Scale = {}", tmpScale);
-            }
-
-            PhysicalStore<ComplexNumber> tmpOriginalMtrx = GenericStore.C128.copy(tmpBaseMtrx);
-            tmpOriginalMtrx.modifyAll(ComplexMath.MULTIPLY.first(tmpScale));
-
-            tmpBidiagonal.decompose(tmpOriginalMtrx.conjugate());
-            tmpSVD.decompose(tmpOriginalMtrx);
-
-            Array1D<Double> tmpActualSingularValues = tmpSVD.getSingularValues();
-            if (MatrixDecompositionTests.DEBUG) {
-                BasicLogger.debug("Expected = {}", tmpExpectedSingularValues);
-                BasicLogger.debug("Actual = {}", tmpActualSingularValues);
-            }
-            TestUtils.assertEquals(tmpExpectedSingularValues, tmpActualSingularValues, NumberContext.of(7, 6));
-
-            MatrixStore<ComplexNumber> tmpReconstructed = tmpSVD.reconstruct();
-            if (MatrixDecompositionTests.DEBUG) {
-                BasicLogger.debugMatrix("Original", tmpOriginalMtrx);
-                BasicLogger.debugMatrix("Reconstructed", tmpReconstructed);
-            }
-            TestUtils.assertEquals(tmpOriginalMtrx, tmpReconstructed, NumberContext.of(7, 6));
-        }
-
-    }
-
-    @Test
-    public void testGetCovariance() {
-
-        Primitive64Store original = Primitive64Store.FACTORY.makeFilled(9, 3, new Normal());
-
-        for (SingularValue<Double> decomp : MatrixDecompositionTests.getPrimitiveSingularValue()) {
-
-            decomp.decompose(original);
-
-            MatrixStore<Double> covariance = decomp.getCovariance();
-
-            decomp.decompose(original.premultiply(original.transpose()));
-
-            MatrixStore<Double> inverse = decomp.getInverse();
-
-            TestUtils.assertEquals(inverse, covariance);
-        }
-
-    }
-
-    /**
-     * https://stackoverflow.com/questions/56752647/huge-difference-between-svd-solution-output-of-commons-math3-and-ojalgo-librarie
-     */
-    @Test
-    public void testPseudoinverseSolve() {
-
-        double[][] olsColumns = { { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
-                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
-                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
-                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
-                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
-                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
-                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
-                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
-                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
-                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 } };
-        Primitive64Store body = Primitive64Store.FACTORY.rows(olsColumns);
-
-        double[] observationVector = { 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
-                0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
-                0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
-                0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 };
-        Primitive64Store rhs = Primitive64Store.FACTORY.column(observationVector);
-
-        double expected = 0.0161290322580645;
-        MatrixStore<Double> actual;
-        MatrixStore<Double> inverse;
-
-        for (SingularValue<Double> decomp : MatrixDecompositionTests.getPrimitiveSingularValue()) {
-
-            decomp.reset();
-            decomp.decompose(body);
-
-            actual = decomp.getSolution(rhs);
-            TestUtils.assertEquals(2, actual.count());
-            TestUtils.assertEquals(expected, actual.doubleValue(0));
-            TestUtils.assertEquals(expected, actual.doubleValue(1));
-
-            decomp.reset();
-            decomp.decompose(body);
-
-            actual = decomp.getSolution(rhs, decomp.preallocate(body, rhs));
-            TestUtils.assertEquals(2, actual.count());
-            TestUtils.assertEquals(expected, actual.doubleValue(0));
-            TestUtils.assertEquals(expected, actual.doubleValue(1));
-
-            decomp.reset();
-            decomp.decompose(body);
-
-            inverse = decomp.getInverse();
-            actual = inverse.multiply(rhs);
-            TestUtils.assertEquals(2, actual.count());
-            TestUtils.assertEquals(expected, actual.doubleValue(0));
-            TestUtils.assertEquals(expected, actual.doubleValue(1));
-
-            decomp.reset();
-            decomp.decompose(body);
-
-            inverse = decomp.getInverse(decomp.preallocate(body));
-            actual = inverse.multiply(rhs);
-            TestUtils.assertEquals(2, actual.count());
-            TestUtils.assertEquals(expected, actual.doubleValue(0));
-            TestUtils.assertEquals(expected, actual.doubleValue(1));
-        }
-    }
-
-    @Test
-    public void testRandomActuallyComplexCase() {
-
-        PhysicalStore<ComplexNumber> tmpOriginal = TestUtils.makeRandomComplexStore(4, 4);
-
-        SingularValue<ComplexNumber> tmpDecomposition = SingularValue.COMPLEX.make();
-
-        tmpDecomposition.decompose(tmpOriginal);
-
-        MatrixStore<ComplexNumber> tmpReconstructed = tmpDecomposition.reconstruct();
-
-        if (!Access2D.equals(tmpOriginal, tmpReconstructed, NumberContext.of(7, 6))) {
-            BasicLogger.error("Recreation failed for: {}", tmpDecomposition.getClass().getName());
-        }
-        if (!SingularValue.equals(tmpOriginal, tmpDecomposition, NumberContext.of(7, 6))) {
-            BasicLogger.error("Decomposition not correct for: {}", tmpDecomposition.getClass().getName());
-        }
-        if (MatrixDecompositionTests.DEBUG) {
-            BasicLogger.debug();
-            BasicLogger.debug(tmpDecomposition.toString());
-            BasicLogger.debugMatrix("Original", tmpOriginal);
-            BasicLogger.debugMatrix("Q1", tmpDecomposition.getU());
-            BasicLogger.debugMatrix("D", tmpDecomposition.getD());
-            BasicLogger.debugMatrix("Q2", tmpDecomposition.getV());
-            BasicLogger.debugMatrix("Reconstructed", tmpReconstructed);
-            PhysicalStore<ComplexNumber> tmpCopy = tmpOriginal.copy();
-            // tmpCopy.maxpy(ComplexNumber.NEG, tmpReconstructed);
-            tmpReconstructed.axpy(-1, tmpCopy);
-            BasicLogger.debugMatrix("Diff", tmpCopy);
-        }
-
-        TestUtils.assertEquals(tmpOriginal, tmpReconstructed, NumberContext.of(7, 6));
-        TestUtils.assertEquals(tmpOriginal, tmpDecomposition, NumberContext.of(7, 6));
-
-    }
-
-    @Test
-    public void testRandomFatCase() {
-        CaseSingularValue.doTestTypes(MTRX_FAT);
-    }
-
-    @Test
-    public void testRandomSquareCase() {
-        CaseSingularValue.doTestTypes(MTRX_SQUARE);
-    }
-
-    @Test
-    public void testRandomTallCase() {
-        CaseSingularValue.doTestTypes(MTRX_TALL);
-    }
-
-    @Test
-    public void testRecreationFat() {
-
-        PhysicalStore<Double> tmpOriginal = Primitive64Store.FACTORY.copy(MTRX_FAT);
-
-        this.testRecreation(tmpOriginal);
-    }
-
-    @Test
-    public void testRecreationSquare() {
-
-        PhysicalStore<Double> tmpOriginal = Primitive64Store.FACTORY.copy(MTRX_SQUARE);
-
-        this.testRecreation(tmpOriginal);
-    }
-
-    @Test
-    public void testRecreationTall() {
-
-        PhysicalStore<Double> tmpOriginal = Primitive64Store.FACTORY.copy(MTRX_TALL);
-
-        this.testRecreation(tmpOriginal);
-    }
-
     private static void doTestTypes(final Access2D<?> original) {
 
         PhysicalStore<RationalNumber> tmpBigStore = GenericStore.Q128.copy(original);
         PhysicalStore<ComplexNumber> tmpComplexStore = GenericStore.C128.copy(original);
-        PhysicalStore<Double> tmpPrimitiveStore = Primitive64Store.FACTORY.copy(original);
+        PhysicalStore<Double> tmpPrimitiveStore = R064Store.FACTORY.copy(original);
 
         IMPL_BIG.decompose(GenericStore.Q128.copy(original));
         IMPL_COMPLEX.decompose(GenericStore.C128.copy(original));
-        IMPL_RAW.decompose(Primitive64Store.FACTORY.copy(original));
-        IMPL_PRIMITIVE.decompose(Primitive64Store.FACTORY.copy(original));
+        IMPL_RAW.decompose(R064Store.FACTORY.copy(original));
+        IMPL_PRIMITIVE.decompose(R064Store.FACTORY.copy(original));
 
         Array1D<Double> tmpBigSingularValues = IMPL_BIG.getSingularValues();
         Array1D<Double> tmpComplexSingularValues = IMPL_COMPLEX.getSingularValues();
@@ -449,6 +176,280 @@ public class CaseSingularValue extends MatrixDecompositionTests {
         TestUtils.assertEquals(tmpPrimitiveStore, IMPL_PRIMITIVE, CNTXT_REAL_DECOMP);
     }
 
+    @Override
+    @BeforeEach
+    public void minimiseAllBranchLimits() {
+        TestUtils.minimiseAllBranchLimits();
+    }
+
+    @Test
+    public void testBasicMatrixP20030422Case() {
+        CaseSingularValue.doTestTypes(P20030422Case.getProblematic());
+    }
+
+    @Test
+    public void testBasicMatrixP20030512Case() {
+        CaseSingularValue.doTestTypes(P20030512Case.getProblematic());
+    }
+
+    @Test
+    public void testBasicMatrixP20030528Case() {
+        CaseSingularValue.doTestTypes(P20030528Case.getProblematic());
+    }
+
+    @Test
+    public void testBasicMatrixP20050125Case() {
+        CaseSingularValue.doTestTypes(P20050125Case.getProblematic());
+    }
+
+    @Test
+    public void testBasicMatrixP20050827Case() {
+        CaseSingularValue.doTestTypes(MatrixQ128.FACTORY.copy(P20050827Case.getProblematic()));
+    }
+
+    @Test
+    public void testBasicMatrixP20061119Case() {
+        CaseSingularValue.doTestTypes(P20061119Case.getProblematic());
+    }
+
+    @Test
+    public void testBasicMatrixP20071019FatCase() {
+        CaseSingularValue.doTestTypes(P20071019Case.getFatProblematic());
+    }
+
+    @Test
+    public void testBasicMatrixP20071019TallCase() {
+        CaseSingularValue.doTestTypes(P20071019Case.getTallProblematic());
+    }
+
+    /**
+     * http://en.wikipedia.org/wiki/Singular_value_decomposition
+     */
+    @Test
+    public void testComplexNumberVersionOfWikipediaCase() {
+
+        PhysicalStore<Double> tmpBaseMtrx = RawStore
+                .wrap(new double[][] { { 1.0, 0.0, 0.0, 0.0, 2.0 }, { 0.0, 0.0, 3.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 4.0, 0.0, 0.0, 0.0 } });
+
+        double[] data = { 4.0, 3.0, PrimitiveMath.SQRT.invoke(5.0), 0.0 };
+        Array1D<Double> tmpExpectedSingularValues = Array1D.R064.copy(data);
+
+        ComplexNumber[] tmpScales = { ComplexNumber.makePolar(1.0, 0.0), ComplexNumber.makePolar(1.0, Math.PI / 2.0),
+                ComplexNumber.makePolar(1.0, -Math.PI / 2.0), ComplexNumber.makePolar(1.0, Math.PI / 4.0), ComplexNumber.makePolar(1.0, 4.0 * Math.PI / 3.0) };
+
+        Bidiagonal<ComplexNumber> tmpBidiagonal = Bidiagonal.C128.make();
+        SingularValue<ComplexNumber> tmpSVD = SingularValue.C128.make();
+
+        for (ComplexNumber tmpScale : tmpScales) {
+
+            PhysicalStore<ComplexNumber> tmpOriginalMtrx = GenericStore.C128.transpose(tmpBaseMtrx);
+            tmpOriginalMtrx.modifyAll(ComplexMath.MULTIPLY.first(tmpScale));
+
+            tmpBidiagonal.decompose(tmpOriginalMtrx);
+            MatrixStore<ComplexNumber> tmpReconstructed = tmpBidiagonal.reconstruct();
+            if (MatrixDecompositionTests.DEBUG) {
+                BasicLogger.debug();
+                BasicLogger.debugMatrix("Scale = {}", tmpScale);
+                BasicLogger.debugMatrix("A", tmpOriginalMtrx);
+                BasicLogger.debugMatrix("Q1", tmpBidiagonal.getLQ());
+                BasicLogger.debugMatrix("D", tmpBidiagonal.getD());
+                BasicLogger.debugMatrix("Q2", tmpBidiagonal.getRQ());
+                BasicLogger.debugMatrix("Reconstructed", tmpReconstructed);
+            }
+            TestUtils.assertEquals(tmpOriginalMtrx, tmpReconstructed, NumberContext.of(7, 6));
+        }
+
+        for (ComplexNumber tmpScale : tmpScales) {
+
+            if (MatrixDecompositionTests.DEBUG) {
+                BasicLogger.debug();
+                BasicLogger.debugMatrix("Scale = {}", tmpScale);
+            }
+
+            PhysicalStore<ComplexNumber> tmpOriginalMtrx = GenericStore.C128.copy(tmpBaseMtrx);
+            tmpOriginalMtrx.modifyAll(ComplexMath.MULTIPLY.first(tmpScale));
+
+            tmpBidiagonal.decompose(tmpOriginalMtrx.conjugate());
+            tmpSVD.decompose(tmpOriginalMtrx);
+
+            Array1D<Double> tmpActualSingularValues = tmpSVD.getSingularValues();
+            if (MatrixDecompositionTests.DEBUG) {
+                BasicLogger.debug("Expected = {}", tmpExpectedSingularValues);
+                BasicLogger.debug("Actual = {}", tmpActualSingularValues);
+            }
+            TestUtils.assertEquals(tmpExpectedSingularValues, tmpActualSingularValues, NumberContext.of(7, 6));
+
+            MatrixStore<ComplexNumber> tmpReconstructed = tmpSVD.reconstruct();
+            if (MatrixDecompositionTests.DEBUG) {
+                BasicLogger.debugMatrix("Original", tmpOriginalMtrx);
+                BasicLogger.debugMatrix("Reconstructed", tmpReconstructed);
+            }
+            TestUtils.assertEquals(tmpOriginalMtrx, tmpReconstructed, NumberContext.of(7, 6));
+        }
+
+    }
+
+    @Test
+    public void testGetCovariance() {
+
+        R064Store original = R064Store.FACTORY.makeFilled(9, 3, new Normal());
+
+        for (SingularValue<Double> decomp : MatrixDecompositionTests.getPrimitiveSingularValue()) {
+
+            decomp.decompose(original);
+
+            MatrixStore<Double> covariance = decomp.getCovariance();
+
+            decomp.decompose(original.premultiply(original.transpose()));
+
+            MatrixStore<Double> inverse = decomp.getInverse();
+
+            TestUtils.assertEquals(inverse, covariance);
+        }
+
+    }
+
+    /**
+     * https://stackoverflow.com/questions/56752647/huge-difference-between-svd-solution-output-of-commons-math3-and-ojalgo-librarie
+     */
+    @Test
+    public void testPseudoinverseSolve() {
+
+        double[][] olsColumns = { { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
+                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
+                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
+                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
+                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
+                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
+                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
+                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
+                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 },
+                { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 }, { 1.0, 1.0 } };
+        RawStore body = RawStore.wrap(olsColumns);
+
+        double[] observationVector = { 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
+                0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
+                0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
+                0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 };
+        R064Store rhs = R064Store.FACTORY.column(observationVector);
+
+        double expected = 0.0161290322580645;
+        MatrixStore<Double> actual;
+        MatrixStore<Double> inverse;
+
+        for (SingularValue<Double> decomp : MatrixDecompositionTests.getPrimitiveSingularValue()) {
+
+            decomp.reset();
+            decomp.decompose(body);
+
+            actual = decomp.getSolution(rhs);
+            TestUtils.assertEquals(2, actual.count());
+            TestUtils.assertEquals(expected, actual.doubleValue(0));
+            TestUtils.assertEquals(expected, actual.doubleValue(1));
+
+            decomp.reset();
+            decomp.decompose(body);
+
+            actual = decomp.getSolution(rhs, decomp.preallocate(body, rhs));
+            TestUtils.assertEquals(2, actual.count());
+            TestUtils.assertEquals(expected, actual.doubleValue(0));
+            TestUtils.assertEquals(expected, actual.doubleValue(1));
+
+            decomp.reset();
+            decomp.decompose(body);
+
+            inverse = decomp.getInverse();
+            actual = inverse.multiply(rhs);
+            TestUtils.assertEquals(2, actual.count());
+            TestUtils.assertEquals(expected, actual.doubleValue(0));
+            TestUtils.assertEquals(expected, actual.doubleValue(1));
+
+            decomp.reset();
+            decomp.decompose(body);
+
+            inverse = decomp.getInverse(decomp.preallocate(body));
+            actual = inverse.multiply(rhs);
+            TestUtils.assertEquals(2, actual.count());
+            TestUtils.assertEquals(expected, actual.doubleValue(0));
+            TestUtils.assertEquals(expected, actual.doubleValue(1));
+        }
+    }
+
+    @Test
+    public void testRandomActuallyComplexCase() {
+
+        PhysicalStore<ComplexNumber> tmpOriginal = TestUtils.makeRandomComplexStore(4, 4);
+
+        SingularValue<ComplexNumber> tmpDecomposition = SingularValue.C128.make();
+
+        tmpDecomposition.decompose(tmpOriginal);
+
+        MatrixStore<ComplexNumber> tmpReconstructed = tmpDecomposition.reconstruct();
+
+        if (!Access2D.equals(tmpOriginal, tmpReconstructed, NumberContext.of(7, 6))) {
+            BasicLogger.error("Recreation failed for: {}", tmpDecomposition.getClass().getName());
+        }
+        if (!SingularValue.equals(tmpOriginal, tmpDecomposition, NumberContext.of(7, 6))) {
+            BasicLogger.error("Decomposition not correct for: {}", tmpDecomposition.getClass().getName());
+        }
+        if (MatrixDecompositionTests.DEBUG) {
+            BasicLogger.debug();
+            BasicLogger.debug(tmpDecomposition.toString());
+            BasicLogger.debugMatrix("Original", tmpOriginal);
+            BasicLogger.debugMatrix("Q1", tmpDecomposition.getU());
+            BasicLogger.debugMatrix("D", tmpDecomposition.getD());
+            BasicLogger.debugMatrix("Q2", tmpDecomposition.getV());
+            BasicLogger.debugMatrix("Reconstructed", tmpReconstructed);
+            PhysicalStore<ComplexNumber> tmpCopy = tmpOriginal.copy();
+            // tmpCopy.maxpy(ComplexNumber.NEG, tmpReconstructed);
+            tmpReconstructed.axpy(-1, tmpCopy);
+            BasicLogger.debugMatrix("Diff", tmpCopy);
+        }
+
+        TestUtils.assertEquals(tmpOriginal, tmpReconstructed, NumberContext.of(7, 6));
+        TestUtils.assertEquals(tmpOriginal, tmpDecomposition, NumberContext.of(7, 6));
+
+    }
+
+    @Test
+    public void testRandomFatCase() {
+        CaseSingularValue.doTestTypes(MTRX_FAT);
+    }
+
+    @Test
+    public void testRandomSquareCase() {
+        CaseSingularValue.doTestTypes(MTRX_SQUARE);
+    }
+
+    @Test
+    public void testRandomTallCase() {
+        CaseSingularValue.doTestTypes(MTRX_TALL);
+    }
+
+    @Test
+    public void testRecreationFat() {
+
+        PhysicalStore<Double> tmpOriginal = R064Store.FACTORY.copy(MTRX_FAT);
+
+        this.testRecreation(tmpOriginal);
+    }
+
+    @Test
+    public void testRecreationSquare() {
+
+        PhysicalStore<Double> tmpOriginal = R064Store.FACTORY.copy(MTRX_SQUARE);
+
+        this.testRecreation(tmpOriginal);
+    }
+
+    @Test
+    public void testRecreationTall() {
+
+        PhysicalStore<Double> tmpOriginal = R064Store.FACTORY.copy(MTRX_TALL);
+
+        this.testRecreation(tmpOriginal);
+    }
+
     private void testRecreation(final PhysicalStore<Double> aMtrx) {
 
         SingularValue<Double>[] tmpImpls = MatrixDecompositionTests.getPrimitiveSingularValue();
