@@ -30,7 +30,7 @@ import org.ojalgo.matrix.SimpleLUCase;
 import org.ojalgo.matrix.SimpleQRCase;
 import org.ojalgo.matrix.SimpleSingularValueCase;
 import org.ojalgo.matrix.store.MatrixStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.structure.Structure1D;
 import org.ojalgo.type.context.NumberContext;
 
@@ -42,12 +42,12 @@ public class CompareJamaAndPrimitive extends MatrixDecompositionTests {
     private static LU<Double> JAMA_LU = new RawLU();
     private static QR<Double> JAMA_QR = new RawQR();
     private static SingularValue<Double> JAMA_SVD = new RawSingularValue();
-    private static Cholesky<Double> PRIMITIVE_CHOLESKY = Cholesky.PRIMITIVE.make();
-    private static LU<Double> PRIMITIVE_DENSE_LU = LU.PRIMITIVE.make();
-    private static Eigenvalue<Double> PRIMITIVE_EvD = Eigenvalue.PRIMITIVE.make();
-    private static QR<Double> PRIMITIVE_QR = QR.PRIMITIVE.make();
-    private static LU<Double> PRIMITIVE_RAW_LU = LU.PRIMITIVE.make();
-    private static SingularValue<Double> PRIMITIVE_SVD = SingularValue.PRIMITIVE.make();
+    private static Cholesky<Double> PRIMITIVE_CHOLESKY = Cholesky.R064.make();
+    private static LU<Double> PRIMITIVE_DENSE_LU = LU.R064.make();
+    private static Eigenvalue<Double> PRIMITIVE_EvD = Eigenvalue.R064.make();
+    private static QR<Double> PRIMITIVE_QR = QR.R064.make();
+    private static LU<Double> PRIMITIVE_RAW_LU = LU.R064.make();
+    private static SingularValue<Double> PRIMITIVE_SVD = SingularValue.R064.make();
 
     @Override
     @BeforeEach
@@ -58,7 +58,7 @@ public class CompareJamaAndPrimitive extends MatrixDecompositionTests {
     @Test
     public void testSimpleCholeskyCase() {
 
-        final MatrixStore<Double> tmpMtrxA = Primitive64Store.FACTORY.copy(SimpleCholeskyCase.getOriginal());
+        final MatrixStore<Double> tmpMtrxA = R064Store.FACTORY.copy(SimpleCholeskyCase.getOriginal());
 
         TestUtils.assertEquals(JAMA_CHOLESKY.decompose(tmpMtrxA), PRIMITIVE_CHOLESKY.decompose(tmpMtrxA));
 
@@ -78,7 +78,7 @@ public class CompareJamaAndPrimitive extends MatrixDecompositionTests {
     @Test
     public void testSimpleEigenvalueCase() {
 
-        final MatrixStore<Double> tmpMtrxA = Primitive64Store.FACTORY.copy(SimpleEigenvalueCase.getOriginal());
+        final MatrixStore<Double> tmpMtrxA = R064Store.FACTORY.copy(SimpleEigenvalueCase.getOriginal());
 
         TestUtils.assertEquals(JAMA_EvD.decompose(tmpMtrxA), PRIMITIVE_EvD.decompose(tmpMtrxA));
 
@@ -99,7 +99,7 @@ public class CompareJamaAndPrimitive extends MatrixDecompositionTests {
 
         // Dense
 
-        final MatrixStore<Double> tmpMtrxA = Primitive64Store.FACTORY.copy(SimpleLUCase.getOrginal());
+        final MatrixStore<Double> tmpMtrxA = R064Store.FACTORY.copy(SimpleLUCase.getOrginal());
 
         TestUtils.assertEquals(JAMA_LU.decompose(tmpMtrxA), PRIMITIVE_DENSE_LU.decompose(tmpMtrxA));
 
@@ -137,7 +137,7 @@ public class CompareJamaAndPrimitive extends MatrixDecompositionTests {
     @Test
     public void testSimpleQRCase() {
 
-        MatrixStore<Double> mtrxA = Primitive64Store.FACTORY.copy(SimpleQRCase.getOriginal());
+        MatrixStore<Double> mtrxA = R064Store.FACTORY.copy(SimpleQRCase.getOriginal());
         int minDim = mtrxA.getMinDim();
 
         TestUtils.assertEquals(JAMA_QR.decompose(mtrxA), PRIMITIVE_QR.decompose(mtrxA));
@@ -159,7 +159,7 @@ public class CompareJamaAndPrimitive extends MatrixDecompositionTests {
     @Test
     public void testSimpleSingularValueCase() {
 
-        final MatrixStore<Double> tmpMtrxA = Primitive64Store.FACTORY.copy(SimpleSingularValueCase.getOriginal());
+        final MatrixStore<Double> tmpMtrxA = R064Store.FACTORY.copy(SimpleSingularValueCase.getOriginal());
 
         TestUtils.assertEquals(JAMA_SVD.decompose(tmpMtrxA), PRIMITIVE_SVD.decompose(tmpMtrxA));
 
