@@ -27,13 +27,12 @@ import org.junit.jupiter.api.Test;
 import org.ojalgo.RecoverableCondition;
 import org.ojalgo.TestUtils;
 import org.ojalgo.array.Array1D;
-import org.ojalgo.matrix.MatrixR064;
 import org.ojalgo.matrix.decomposition.MatrixDecomposition.Solver;
 import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.PhysicalStore.Factory;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
+import org.ojalgo.matrix.store.RawStore;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.random.Normal;
 import org.ojalgo.random.Uniform;
@@ -54,7 +53,7 @@ public class DecompositionProblems extends MatrixDecompositionTests {
     static void fullQR(final MatrixStore<Double> matrix) {
 
         // Initialize the QR decomposition object.
-        QR<Double> qr = QR.PRIMITIVE.make(matrix.transpose(), true);
+        QR<Double> qr = QR.R064.make(matrix.transpose(), true);
         // Set it to full size and confirm the setting.
         TestUtils.assertTrue("Full size flag is set to ", qr.isFullSize());
 
@@ -86,7 +85,7 @@ public class DecompositionProblems extends MatrixDecompositionTests {
         MatrixStore<Double> product = matrix.multiply(q);
         int kernelCount = 0;
         for (int i = 0; i < product.countColumns(); i++) {
-            double norm = Primitive64Store.FACTORY.columns(product.sliceColumn(i)).norm();
+            double norm = R064Store.FACTORY.column(product.sliceColumn(i)).norm();
             if (norm < ZERO) {
                 if (DEBUG) {
                     System.out.println(String.format("Column %d of Q belongs to the " + "kernel of A.", i));
@@ -104,7 +103,7 @@ public class DecompositionProblems extends MatrixDecompositionTests {
      */
     static void fullSVD(final MatrixStore<Double> matrix) {
         // Initialize the SVD object.
-        SingularValue<Double> svd = SingularValue.PRIMITIVE.make(matrix, true);
+        SingularValue<Double> svd = SingularValue.R064.make(matrix, true);
         // Set it to full size and confirm the setting.
         TestUtils.assertTrue("Full size flag is set to ", svd.isFullSize());
         // Perform the decomposition.
@@ -135,7 +134,7 @@ public class DecompositionProblems extends MatrixDecompositionTests {
         MatrixStore<Double> product = matrix.multiply(q2);
         int kernelCount = 0;
         for (int i = 0; i < product.countColumns(); i++) {
-            double norm = Primitive64Store.FACTORY.columns(product.sliceColumn(i)).norm();
+            double norm = R064Store.FACTORY.column(product.sliceColumn(i)).norm();
             if (norm < ZERO) {
                 if (DEBUG) {
                     System.out.println(String.format("Column %d of Q2 belongs to the " + "kernel of A.", i));
@@ -161,8 +160,7 @@ public class DecompositionProblems extends MatrixDecompositionTests {
 
         double[][] data = { { 1.0, 2.0, 3.0, 10.0 }, { 4.0, 5.0, 6.0, 11.0 }, { 7.0, 8.0, 9.0, 11.0 } };
 
-        PhysicalStore.Factory<Double, Primitive64Store> storeFactory = Primitive64Store.FACTORY;
-        Primitive64Store m = storeFactory.rows(data);
+        RawStore m = RawStore.wrap(data);
 
         if (DEBUG) {
             BasicLogger.debugMatrix("Original", m);
@@ -203,11 +201,10 @@ public class DecompositionProblems extends MatrixDecompositionTests {
                 { 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0 }, { 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0 }, { 1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0 } };
 
         double[] observationVector = { 26.0, 12.0, 9.0, 18.0, 16.0, 17.0, 24.0, 32.0, 30.0, 21.0, 16.0, 12.0, 21.0, 16.0 };
-
-        final Primitive64Store tmpOriginal = Primitive64Store.FACTORY.rows(olsColumns);
-        SingularValue<Double> tmpSVD = SingularValue.PRIMITIVE.make(tmpOriginal);
+        final RawStore tmpOriginal = RawStore.wrap(olsColumns);
+        SingularValue<Double> tmpSVD = SingularValue.R064.make(tmpOriginal);
         tmpSVD.decompose(tmpOriginal);
-        Primitive64Store rhs = Primitive64Store.FACTORY.column(observationVector);
+        R064Store rhs = R064Store.FACTORY.column(observationVector);
         tmpSVD.getSolution(rhs, tmpSVD.preallocate(tmpOriginal, rhs));
 
         // Simply test that we can run this program without getting an exception
@@ -219,10 +216,10 @@ public class DecompositionProblems extends MatrixDecompositionTests {
     @Test
     public void testP20090923() {
 
-        PhysicalStore<Double> tmpA = Primitive64Store.FACTORY
-                .rows(new double[][] { { 1.0, 0.0, 0.0, 0.0, 2.0 }, { 0.0, 0.0, 3.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 4.0, 0.0, 0.0, 0.0 } });
+        PhysicalStore<Double> tmpA = RawStore
+                .wrap(new double[][] { { 1.0, 0.0, 0.0, 0.0, 2.0 }, { 0.0, 0.0, 3.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 4.0, 0.0, 0.0, 0.0 } });
 
-        SingularValue<Double> tmpSVD = SingularValue.PRIMITIVE.make();
+        SingularValue<Double> tmpSVD = SingularValue.R064.make();
         tmpSVD.decompose(tmpA);
 
         if (MatrixDecompositionTests.DEBUG) {
@@ -240,9 +237,9 @@ public class DecompositionProblems extends MatrixDecompositionTests {
     @Test
     public void testP20091012() {
 
-        PhysicalStore<Double> tmpA = Primitive64Store.FACTORY.copy(TestUtils.makeRandomComplexStore(5, 9));
+        PhysicalStore<Double> tmpA = R064Store.FACTORY.copy(TestUtils.makeRandomComplexStore(5, 9));
 
-        QR<Double> tmpQR = QR.PRIMITIVE.make(tmpA);
+        QR<Double> tmpQR = QR.R064.make(tmpA);
         tmpQR.decompose(tmpA);
 
         TestUtils.assertEquals(tmpA, tmpQR, NumberContext.of(7, 6));
@@ -254,12 +251,12 @@ public class DecompositionProblems extends MatrixDecompositionTests {
     @Test
     public void testP20091012fixed() {
 
-        PhysicalStore<Double> tmpA = Primitive64Store.FACTORY
-                .rows(new double[][] { { 1.5686711899234411, 5.857030526629094, 2.1798778832593637, 1.4901137152515287, 5.640993583029061 },
+        PhysicalStore<Double> tmpA = RawStore
+                .wrap(new double[][] { { 1.5686711899234411, 5.857030526629094, 2.1798778832593637, 1.4901137152515287, 5.640993583029061 },
                         { 4.890945865607895, 4.2576454398997265, 1.0251822439318778, 0.8623492557631138, 5.7457253685285545 },
                         { 1.6397137349990025, 0.6795594856277076, 4.7101325736711095, 2.0823473021899517, 2.2159317240940233 } });
 
-        QR<Double> tmpQR = QR.PRIMITIVE.make(tmpA);
+        QR<Double> tmpQR = QR.R064.make(tmpA);
         tmpQR.decompose(tmpA);
 
         TestUtils.assertEquals(tmpA, tmpQR, NumberContext.of(7, 6));
@@ -268,10 +265,9 @@ public class DecompositionProblems extends MatrixDecompositionTests {
     @Test
     public void testP20100512() {
 
-        PhysicalStore<Double> tmpA = Primitive64Store.FACTORY
-                .rows(new double[][] { { 0.2845, 0.3597, 0.9544 }, { 0.3597, 0.6887, 0.0782 }, { 0.9544, 0.0782, 0.1140 } });
+        PhysicalStore<Double> tmpA = RawStore.wrap(new double[][] { { 0.2845, 0.3597, 0.9544 }, { 0.3597, 0.6887, 0.0782 }, { 0.9544, 0.0782, 0.1140 } });
 
-        Eigenvalue<Double> tmpPrimitive = Eigenvalue.PRIMITIVE.make();
+        Eigenvalue<Double> tmpPrimitive = Eigenvalue.R064.make();
         tmpPrimitive.decompose(tmpA);
 
         TestUtils.assertEquals(tmpA, tmpPrimitive, TOP_ACCURACY);
@@ -282,10 +278,10 @@ public class DecompositionProblems extends MatrixDecompositionTests {
 
         int tmpDim = 5;
 
-        PhysicalStore<Double> tmpA = Primitive64Store.FACTORY.copy(TestUtils.makeRandomComplexStore(tmpDim, tmpDim));
-        PhysicalStore<Double> tmpI = Primitive64Store.FACTORY.makeEye(tmpDim, tmpDim);
+        PhysicalStore<Double> tmpA = R064Store.FACTORY.copy(TestUtils.makeRandomComplexStore(tmpDim, tmpDim));
+        PhysicalStore<Double> tmpI = R064Store.FACTORY.makeEye(tmpDim, tmpDim);
 
-        LU<Double> tmpDecomp = LU.PRIMITIVE.make();
+        LU<Double> tmpDecomp = LU.R064.make();
 
         tmpDecomp.decompose(tmpA);
 
@@ -310,14 +306,14 @@ public class DecompositionProblems extends MatrixDecompositionTests {
         NumberContext tmpEqualsNumberContext = NumberContext.of(7, 11);
 
         int tmpDim = 99;
-        PhysicalStore<Double> tmpRandom = Primitive64Store.FACTORY.copy(TestUtils.makeRandomComplexStore(tmpDim, tmpDim));
-        PhysicalStore<Double> tmpIdentity = Primitive64Store.FACTORY.makeEye(tmpDim, tmpDim);
+        PhysicalStore<Double> tmpRandom = R064Store.FACTORY.copy(TestUtils.makeRandomComplexStore(tmpDim, tmpDim));
+        PhysicalStore<Double> tmpIdentity = R064Store.FACTORY.makeEye(tmpDim, tmpDim);
 
         LU<Double> tmpRefDecomps = new RawLU();
         tmpRefDecomps.decompose(tmpRandom);
         MatrixStore<Double> tmpExpected = tmpRefDecomps.getInverse();
 
-        LU<Double> tmpTestDecomp = LU.PRIMITIVE.make();
+        LU<Double> tmpTestDecomp = LU.R064.make();
         tmpTestDecomp.decompose(tmpRandom);
         MatrixStore<Double> tmpActual = tmpTestDecomp.getInverse();
 
@@ -350,15 +346,15 @@ public class DecompositionProblems extends MatrixDecompositionTests {
         MatrixStore<ComplexNumber> tmpActual;
 
         @SuppressWarnings("unchecked")
-        MatrixDecomposition<ComplexNumber>[] tmpCmplxDecomps = new MatrixDecomposition[] { Bidiagonal.COMPLEX.make(), Cholesky.COMPLEX.make(),
-                Eigenvalue.COMPLEX.make(MatrixDecomposition.TYPICAL,
+        MatrixDecomposition<ComplexNumber>[] tmpCmplxDecomps = new MatrixDecomposition[] { Bidiagonal.C128.make(), Cholesky.C128.make(),
+                Eigenvalue.C128.make(MatrixDecomposition.TYPICAL,
                         true)/*
                               * , HessenbergDecomposition. makeComplex()
                               */,
-                LU.COMPLEX.make(), QR.COMPLEX.make(),
-                SingularValue.COMPLEX.make() /*
-                                              * , TridiagonalDecomposition . makeComplex ( )
-                                              */ };
+                LU.C128.make(), QR.C128.make(),
+                SingularValue.C128.make() /*
+                                           * , TridiagonalDecomposition . makeComplex ( )
+                                           */ };
 
         for (MatrixDecomposition<ComplexNumber> tmpDecomposition : tmpCmplxDecomps) {
             tmpDecomposition.decompose(tmpHermitian);
@@ -391,8 +387,7 @@ public class DecompositionProblems extends MatrixDecompositionTests {
         MatrixStore<ComplexNumber> solution;
 
         @SuppressWarnings("unchecked")
-        MatrixDecomposition<ComplexNumber>[] tmpCmplxDecomps = new MatrixDecomposition[] { QR.COMPLEX.make(), SingularValue.COMPLEX.make(),
-                Bidiagonal.COMPLEX.make() };
+        MatrixDecomposition<ComplexNumber>[] tmpCmplxDecomps = new MatrixDecomposition[] { QR.C128.make(), SingularValue.C128.make(), Bidiagonal.C128.make() };
 
         for (MatrixDecomposition<ComplexNumber> decomp : tmpCmplxDecomps) {
 
@@ -423,7 +418,7 @@ public class DecompositionProblems extends MatrixDecompositionTests {
     @Tag("slow")
     public void testP20160419() {
 
-        Primitive64Store tmpOrg = Primitive64Store.FACTORY.makeFilled(2000, 2000, new Normal());
+        R064Store tmpOrg = R064Store.FACTORY.makeFilled(2000, 2000, new Normal());
 
         SingularValue<Double> tmpRaw = new RawSingularValue();
 
@@ -454,8 +449,7 @@ public class DecompositionProblems extends MatrixDecompositionTests {
             }
         }
         data[0][1] = 1.01;
-
-        MatrixR064 input = MatrixR064.FACTORY.rows(data);
+        RawStore input = RawStore.wrap(data);
         try {
             //   SingularValue<Double> svd = SingularValue.make(input);
             SingularValue<Double> svd = new SingularValueDecomposition.R064();
@@ -478,13 +472,12 @@ public class DecompositionProblems extends MatrixDecompositionTests {
     @Test
     public void testP20180614() {
 
-        Factory<Double, Primitive64Store> factory = Primitive64Store.FACTORY;
-
         // We start by creating a 5 x 7 matrix with rank 4.
         double[][] data = new double[][] { { 3, -6, 6, 9, 1, 3, 2 }, { -2, 4, 5, 3, 2, 7, 5 }, { -7, 14, 3, -4, 0, 0, 0 }, { 0, 0, -2, -2, 3, -5, -8 },
                 { -1, 2, 7, 6, 2, 0, -2 } };
+        final double[][] source = data;
 
-        MatrixStore<Double> matrixA = factory.rows(data);
+        MatrixStore<Double> matrixA = RawStore.wrap(source);
         // Print the matrix to verify it.
         if (DEBUG) {
             System.out.println("A matrix:\n" + matrixA);
@@ -498,8 +491,8 @@ public class DecompositionProblems extends MatrixDecompositionTests {
         // Repeat this with a square matrix (padding with rows of zeros).
         int rows = data.length;
         int cols = data[0].length;
-        MatrixStore<Double> zeros = factory.make(cols - rows, cols);
-        MatrixStore<Double> matrixB = matrixA.below(zeros).collect(factory);
+        MatrixStore<Double> zeros = R064Store.FACTORY.make(cols - rows, cols);
+        MatrixStore<Double> matrixB = matrixA.below(zeros).collect(R064Store.FACTORY);
         if (DEBUG) {
             // Print B to verify it.
             System.out.println("\nB matrix:\n" + matrixB);
@@ -534,7 +527,7 @@ public class DecompositionProblems extends MatrixDecompositionTests {
 
         NumberContext precision = NumberContext.of(12, 8);
 
-        Primitive64Store matrix = Primitive64Store.FACTORY.rows(new double[][] { { 0.730967787376657, 0.24053641567148587, 0.6374174253501083 },
+        RawStore matrix = RawStore.wrap(new double[][] { { 0.730967787376657, 0.24053641567148587, 0.6374174253501083 },
                 { 0.24053641567148587, 0.5975452777972018, 0.3332183994766498 }, { 0.6374174253501083, 0.3332183994766498, 0.8791825178724801 } });
 
         for (Eigenvalue<Double> evd : MatrixDecompositionTests.getPrimitiveEigenvalue()) {
