@@ -35,7 +35,8 @@ import org.ojalgo.matrix.decomposition.HermitianEvD.R064;
 import org.ojalgo.matrix.decomposition.MatrixDecomposition.RankRevealing;
 import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
+import org.ojalgo.matrix.store.RawStore;
 import org.ojalgo.matrix.task.InverterTask;
 import org.ojalgo.matrix.task.SolverTask;
 import org.ojalgo.netio.BasicLogger;
@@ -55,7 +56,7 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
      */
     static final NumberContext ACCURACY = NumberContext.of(12, 146);
 
-    private static void performInvertTest(final Primitive64Store original, final InverterTask<Double> task, final NumberContext context) {
+    private static void performInvertTest(final MatrixStore<Double> original, final InverterTask<Double> task, final NumberContext context) {
 
         String clazz = task.getClass().toString();
 
@@ -63,7 +64,7 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
 
             MatrixStore<Double> tmpInverse = task.invert(original);
 
-            MatrixStore<Double> tmpExpected = Primitive64Store.FACTORY.makeIdentity(original.countRows());
+            MatrixStore<Double> tmpExpected = R064Store.FACTORY.makeIdentity(original.countRows());
             MatrixStore<Double> tmpActual = original.multiply(tmpInverse);
 
             TestUtils.assertEquals(clazz, tmpExpected, tmpActual, context);
@@ -73,7 +74,8 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
         }
     }
 
-    private static void performSolveTest(final Primitive64Store body, final Primitive64Store rhs, final SolverTask<Double> task, final NumberContext accuracy) {
+    private static void performSolveTest(final MatrixStore<Double> body, final MatrixStore<Double> rhs, final SolverTask<Double> task,
+            final NumberContext accuracy) {
 
         String clazz = task.getClass().toString();
 
@@ -102,7 +104,7 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
                 for (int exp = 0; exp < 300; exp++) {
                     double scale = POWER.invoke(TEN, large ? exp : -exp);
 
-                    Primitive64Store original = Primitive64Store.FACTORY.makeSPD(dim);
+                    R064Store original = R064Store.FACTORY.makeSPD(dim);
                     if (DEBUG) {
                         BasicLogger.debug("Scale exp={} => factor={} and context={}", exp, scale, accuracy);
                         BasicLogger.debug("Original (unscaled) {}", original.toString());
@@ -110,7 +112,7 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
                     }
                     original.modifyAll(MULTIPLY.by(scale));
 
-                    ExtremeElementsCase.performInvertTest(original, InverterTask.PRIMITIVE.make(original), accuracy);
+                    ExtremeElementsCase.performInvertTest(original, InverterTask.R064.make(original), accuracy);
 
                     List<MatrixDecomposition<Double>> allDecomps = MatrixDecompositionTests.getPrimitiveAll();
                     for (MatrixDecomposition<Double> decomp : allDecomps) {
@@ -127,48 +129,6 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
         }
     }
 
-    static void doTestSVD(final boolean large) {
-
-        for (int precision = 1; precision < 16; precision++) {
-            NumberContext accuracy = ACCURACY.withPrecision(precision);
-
-            for (int dim = 2; dim <= 10; dim++) {
-
-                // exp = 308 could potentially create numbers that are 2E308 which is larger than Double.MAX_VALUE
-                for (int exp = 0; exp < 308; exp++) {
-                    double scale = POWER.invoke(TEN, large ? exp : -exp);
-
-                    Primitive64Store original = Primitive64Store.FACTORY.makeSPD(dim);
-                    if (DEBUG) {
-                        BasicLogger.debug();
-                        BasicLogger.debug("Scale exp={} => factor={} and context={}", exp, scale, accuracy);
-                        BasicLogger.debug("Original (unscaled) {}", original.toString());
-
-                    }
-                    original.modifyAll(MULTIPLY.by(scale));
-
-                    ExtremeElementsCase.performInvertTest(original, InverterTask.PRIMITIVE.make(original), accuracy);
-
-                    SingularValue<Double>[] allDecomps = MatrixDecompositionTests.getPrimitiveSingularValue();
-                    for (SingularValue<Double> decomp : allDecomps) {
-
-                        if (DEBUG) {
-                            BasicLogger.debug("{} at precision= {}, dim={}, exp={} and scale={}", decomp.getClass(), precision, dim, exp, scale);
-                        }
-                        decomp.decompose(original);
-
-                        if (precision == 2 && dim == 2 && exp == 0) {
-                            BasicLogger.debug();
-                        }
-                        decomp.decompose(original);
-
-                        TestUtils.assertEquals(original, decomp, accuracy);
-                    }
-                }
-            }
-        }
-    }
-
     static void doTestRank(final boolean large) {
 
         for (int dim = 1; dim <= 10; dim++) {
@@ -177,10 +137,10 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
             for (int exp = 0; exp < 308; exp++) {
                 double scale = POWER.invoke(TEN, large ? exp : -exp);
 
-                Primitive64Store matrix = Primitive64Store.FACTORY.makeSPD(dim);
+                R064Store matrix = R064Store.FACTORY.makeSPD(dim);
                 matrix.modifyAll(MULTIPLY.by(scale));
 
-                SingularValue<Double> reference = SingularValue.PRIMITIVE.make(matrix);
+                SingularValue<Double> reference = SingularValue.R064.make(matrix);
                 reference.decompose(matrix);
 
                 if (DEBUG) {
@@ -219,8 +179,8 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
                 for (int exp = 0; exp < 300; exp++) {
                     double scale = POWER.invoke(TEN, large ? exp : -exp);
 
-                    Primitive64Store tmpBody = Primitive64Store.FACTORY.makeSPD(dim);
-                    Primitive64Store tmpRHS = Primitive64Store.FACTORY.makeFilled(dim, 1, new Uniform());
+                    R064Store tmpBody = R064Store.FACTORY.makeSPD(dim);
+                    R064Store tmpRHS = R064Store.FACTORY.makeFilled(dim, 1, new Uniform());
                     if (DEBUG) {
                         BasicLogger.debug("Scale exp={} => factor={} and context={}", exp, scale, tmpContext);
                         BasicLogger.debug("Body (unscaled) {}", tmpBody.toString());
@@ -230,7 +190,7 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
                     tmpBody.modifyAll(tmpModifier);
                     tmpRHS.modifyAll(tmpModifier);
 
-                    ExtremeElementsCase.performSolveTest(tmpBody, tmpRHS, SolverTask.PRIMITIVE.make(tmpBody, tmpRHS), tmpContext);
+                    ExtremeElementsCase.performSolveTest(tmpBody, tmpRHS, SolverTask.R064.make(tmpBody, tmpRHS), tmpContext);
 
                     List<MatrixDecomposition<Double>> tmpAllDecomps = MatrixDecompositionTests.getPrimitiveAll();
                     for (MatrixDecomposition<Double> decomp : tmpAllDecomps) {
@@ -247,11 +207,53 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
         }
     }
 
+    static void doTestSVD(final boolean large) {
+
+        for (int precision = 1; precision < 16; precision++) {
+            NumberContext accuracy = ACCURACY.withPrecision(precision);
+
+            for (int dim = 2; dim <= 10; dim++) {
+
+                // exp = 308 could potentially create numbers that are 2E308 which is larger than Double.MAX_VALUE
+                for (int exp = 0; exp < 308; exp++) {
+                    double scale = POWER.invoke(TEN, large ? exp : -exp);
+
+                    R064Store original = R064Store.FACTORY.makeSPD(dim);
+                    if (DEBUG) {
+                        BasicLogger.debug();
+                        BasicLogger.debug("Scale exp={} => factor={} and context={}", exp, scale, accuracy);
+                        BasicLogger.debug("Original (unscaled) {}", original.toString());
+
+                    }
+                    original.modifyAll(MULTIPLY.by(scale));
+
+                    ExtremeElementsCase.performInvertTest(original, InverterTask.R064.make(original), accuracy);
+
+                    SingularValue<Double>[] allDecomps = MatrixDecompositionTests.getPrimitiveSingularValue();
+                    for (SingularValue<Double> decomp : allDecomps) {
+
+                        if (DEBUG) {
+                            BasicLogger.debug("{} at precision= {}, dim={}, exp={} and scale={}", decomp.getClass(), precision, dim, exp, scale);
+                        }
+                        decomp.decompose(original);
+
+                        if (precision == 2 && dim == 2 && exp == 0) {
+                            BasicLogger.debug();
+                        }
+                        decomp.decompose(original);
+
+                        TestUtils.assertEquals(original, decomp, accuracy);
+                    }
+                }
+            }
+        }
+    }
+
     static MatrixStore<Double> getVerySmall() {
 
         long dim = 5L;
 
-        Primitive64Store rndm = Primitive64Store.FACTORY.make(dim, dim);
+        R064Store rndm = R064Store.FACTORY.make(dim, dim);
 
         for (long j = 0L; j < dim; j++) {
             for (long i = 0L; i < dim; i++) {
@@ -273,9 +275,9 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
 
         MatrixStore<Double> tmpProblematic = ExtremeElementsCase.getVerySmall();
 
-        Eigenvalue<RationalNumber> tmpBig = Eigenvalue.RATIONAL.make(true);
-        Eigenvalue<ComplexNumber> tmpComplex = Eigenvalue.COMPLEX.make(true);
-        Eigenvalue<Double> tmpPrimitive = Eigenvalue.PRIMITIVE.make();
+        Eigenvalue<RationalNumber> tmpBig = Eigenvalue.Q128.make(true);
+        Eigenvalue<ComplexNumber> tmpComplex = Eigenvalue.C128.make(true);
+        Eigenvalue<Double> tmpPrimitive = Eigenvalue.R064.make();
         Eigenvalue<Double> tmpJama = new RawEigenvalue.Dynamic();
 
         TestUtils.assertTrue("Rational.compute()", tmpBig.decompose(GenericStore.Q128.makeWrapper(tmpProblematic)));
@@ -315,7 +317,7 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
     @Test
     public void testInvertEvD_10_307_1() {
 
-        Primitive64Store tmpOriginal = Primitive64Store.FACTORY.rows(new double[][] {
+        RawStore tmpOriginal = RawStore.wrap(new double[][] {
                 { 1.488828119167862, 0.42210916029401624, 0.3090339419657017, 0.31968488522727556, 0.32307269871880584, 0.46899580731023627,
                         0.12091920407255509, 0.03795763520492966, 0.17470282114825963, 0.3946701200769135 },
                 { 0.42210916029401624, 1.8635124366670595, 0.545906918558408, 0.5647217567560566, 0.570706312407284, 0.8284787565954789, 0.21360317145069477,
@@ -346,7 +348,7 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
     @Test
     public void testInvertEvD_3_155_1() {
 
-        Primitive64Store tmpOriginal = Primitive64Store.FACTORY.rows(new double[][] { { 1.509726074514643, 0.6439543946598099, 1.2096354379603502 },
+        RawStore tmpOriginal = RawStore.wrap(new double[][] { { 1.509726074514643, 0.6439543946598099, 1.2096354379603502 },
                 { 0.6439543946598099, 1.134228320145167, 0.8341376835908743 }, { 1.2096354379603502, 0.8341376835908743, 1.6999093634457072 } });
         tmpOriginal.modifyAll(MULTIPLY.second(POWER.invoke(TEN, 155)));
 
@@ -358,7 +360,7 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
     @Test
     public void testInvertSVD_6_307_2() {
 
-        Primitive64Store tmpOriginal = Primitive64Store.FACTORY.rows(
+        RawStore tmpOriginal = RawStore.wrap(
                 new double[][] { { 1.7951923814808213, 0.659451350679988, 0.7107146253894259, 0.5763579411022435, 0.7199441830503458, 0.6356947473097578 },
                         { 0.659451350679988, 1.829297873115869, 0.7411968989569697, 0.6010777087922337, 0.7508223087524556, 0.6629594475153139 },
                         { 0.7107146253894259, 0.7411968989569697, 1.8937643794649044, 0.6478032355134435, 0.8091884190528792, 0.7144954285155056 },
@@ -375,7 +377,7 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
     @Test
     public void testInvertSVD_7_307_1() {
 
-        Primitive64Store tmpOriginal = Primitive64Store.FACTORY.rows(new double[][] {
+        RawStore tmpOriginal = RawStore.wrap(new double[][] {
                 { 1.6630365629391541, 0.5725332799439422, 0.6293312306387542, 0.3255116741968718, 0.16197060952553563, 0.38338065513999414,
                         0.45947212690705896 },
                 { 0.5725332799439422, 1.8635018216883505, 0.8196058776803916, 0.42392824070490653, 0.2109414837777316, 0.4992935723573937, 0.5983908592318098 },
@@ -397,11 +399,10 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
     @Test
     public void testInvertTask_2_155_1() {
 
-        Primitive64Store tmpOriginal = Primitive64Store.FACTORY
-                .rows(new double[][] { { 1.7755876870972727, 0.5243083105843722 }, { 0.5243083105843722, 1.6760142267686806 } });
+        RawStore tmpOriginal = RawStore.wrap(new double[][] { { 1.7755876870972727, 0.5243083105843722 }, { 0.5243083105843722, 1.6760142267686806 } });
         tmpOriginal.modifyAll(MULTIPLY.second(POWER.invoke(TEN, 155)));
 
-        InverterTask<Double> tmpAlgorithm = InverterTask.PRIMITIVE.make(tmpOriginal);
+        InverterTask<Double> tmpAlgorithm = InverterTask.R064.make(tmpOriginal);
 
         ExtremeElementsCase.performInvertTest(tmpOriginal, tmpAlgorithm, ACCURACY.withoutScale().withPrecision(1));
     }
@@ -411,9 +412,9 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
 
         MatrixStore<Double> tmpProblematic = ExtremeElementsCase.getVerySmall();
 
-        LU<RationalNumber> tmpRational = LU.RATIONAL.make();
-        LU<ComplexNumber> tmpComplex = LU.COMPLEX.make();
-        LU<Double> tmpPrimitive = LU.PRIMITIVE.make();
+        LU<RationalNumber> tmpRational = LU.Q128.make();
+        LU<ComplexNumber> tmpComplex = LU.C128.make();
+        LU<Double> tmpPrimitive = LU.R064.make();
         LU<Double> tmpRaw = new RawLU();
 
         TestUtils.assertTrue("Rational.compute()", tmpRational.decompose(GenericStore.Q128.makeWrapper(tmpProblematic)));
@@ -465,14 +466,19 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
         ExtremeElementsCase.doTestSolve(true);
     }
 
+    @Test
+    public void testOverflowSVD() {
+        ExtremeElementsCase.doTestSVD(true);
+    }
+
     @Test
     public void testQR() {
 
         MatrixStore<Double> tmpProblematic = ExtremeElementsCase.getVerySmall();
 
-        QR<RationalNumber> tmpBig = QR.RATIONAL.make();
-        QR<ComplexNumber> tmpComplex = QR.COMPLEX.make();
-        QR<Double> tmpPrimitive = QR.PRIMITIVE.make();
+        QR<RationalNumber> tmpBig = QR.Q128.make();
+        QR<ComplexNumber> tmpComplex = QR.C128.make();
+        QR<Double> tmpPrimitive = QR.R064.make();
         QR<Double> tmpJama = new RawQR();
 
         TestUtils.assertTrue("Rational.compute()", tmpBig.decompose(GenericStore.Q128.makeWrapper(tmpProblematic)));
@@ -504,8 +510,8 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
     @Test
     public void testSolveLU_1_16_1() {
 
-        Primitive64Store tmpBody = Primitive64Store.FACTORY.rows(new double[][] { { 1.7259687987824925 } });
-        Primitive64Store tmpRHS = Primitive64Store.FACTORY.rows(new double[][] { { 0.6533251061005759 } });
+        RawStore tmpBody = RawStore.wrap(new double[][] { { 1.7259687987824925 } });
+        RawStore tmpRHS = RawStore.wrap(new double[][] { { 0.6533251061005759 } });
 
         UnaryFunction<Double> tmpSecond = MULTIPLY.second(POWER.invoke(TEN, -16));
         tmpBody.modifyAll(tmpSecond);
@@ -536,9 +542,4 @@ public class ExtremeElementsCase extends MatrixDecompositionTests {
         ExtremeElementsCase.doTestSVD(false);
     }
 
-    @Test
-    public void testOverflowSVD() {
-        ExtremeElementsCase.doTestSVD(true);
-    }
-
 }
