@@ -28,7 +28,7 @@ import org.ojalgo.array.Array1D;
 import org.ojalgo.function.constant.PrimitiveMath;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.RawStore;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.type.context.NumberContext;
 
@@ -51,7 +51,7 @@ public class SVDbyEvD extends MatrixDecompositionTests {
     @Test
     public void testHeath() {
 
-        final PhysicalStore<Double> tmpMtrx = Primitive64Store.FACTORY.rows(new double[][] { { 1, 2, 3 }, { 4, 5, 6 }, { 7, 8, 9 }, { 10, 11, 12 } });
+        final PhysicalStore<Double> tmpMtrx = RawStore.wrap(new double[][] { { 1, 2, 3 }, { 4, 5, 6 }, { 7, 8, 9 }, { 10, 11, 12 } });
 
         final Array1D<Double> tmpSingularValues = Array1D.R064.copy(new double[] { 25.4624074360364, 1.29066167576123, 0.0 });
 
@@ -65,7 +65,7 @@ public class SVDbyEvD extends MatrixDecompositionTests {
     @Test
     public void testSmall2x2() {
 
-        final PhysicalStore<Double> tmpMtrx = Primitive64Store.FACTORY.rows(new double[][] { { 4.0, 0.0 }, { 3.0, -5.0 } });
+        final PhysicalStore<Double> tmpMtrx = RawStore.wrap(new double[][] { { 4.0, 0.0 }, { 3.0, -5.0 } });
 
         final Array1D<Double> tmpSingularValues = Array1D.R064.copy(new double[] { 6.324555320336759, 3.1622776601683795 });
 
@@ -78,8 +78,8 @@ public class SVDbyEvD extends MatrixDecompositionTests {
     @Test
     public void testWikipedia() {
 
-        final PhysicalStore<Double> tmpMtrx = Primitive64Store.FACTORY
-                .rows(new double[][] { { 1.0, 0.0, 0.0, 0.0, 2.0 }, { 0.0, 0.0, 3.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 4.0, 0.0, 0.0, 0.0 } });
+        final PhysicalStore<Double> tmpMtrx = RawStore
+                .wrap(new double[][] { { 1.0, 0.0, 0.0, 0.0, 2.0 }, { 0.0, 0.0, 3.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 4.0, 0.0, 0.0, 0.0 } });
 
         final Array1D<Double> tmpSingularValues = Array1D.R064.copy(new double[] { 4.0, 3.0, PrimitiveMath.SQRT.invoke(5.0), 0.0 });
 
@@ -92,7 +92,7 @@ public class SVDbyEvD extends MatrixDecompositionTests {
         final MatrixStore<Double> leftA = matrixA.multiply(transpA);
         final MatrixStore<Double> rightA = transpA.multiply(matrixA);
 
-        final Eigenvalue<Double> decompEvD = Eigenvalue.PRIMITIVE.make(true);
+        final Eigenvalue<Double> decompEvD = Eigenvalue.R064.make(true);
 
         decompEvD.decompose(leftA);
         final MatrixStore<Double> leftD = decompEvD.getD();
@@ -125,7 +125,7 @@ public class SVDbyEvD extends MatrixDecompositionTests {
 
         // So far...
 
-        final SingularValue<Double> tmpExperimental = SingularValue.PRIMITIVE.make();
+        final SingularValue<Double> tmpExperimental = SingularValue.R064.make();
         tmpExperimental.decompose(matrixA);
 
         if (MatrixDecompositionTests.DEBUG) {
