@@ -23,7 +23,7 @@ package org.ojalgo.matrix.decomposition;
 
 import org.ojalgo.BenchmarkUtils;
 import org.ojalgo.array.operation.ApplyCholesky;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.openjdk.jmh.annotations.Benchmark;
 import org.openjdk.jmh.annotations.Param;
 import org.openjdk.jmh.annotations.Scope;
@@ -63,7 +63,7 @@ public class ThresholdApplyCholesky extends AbstractThresholdTuner {
 
     Cholesky<Double> decomposition = new CholeskyDecomposition.R064();
 
-    Primitive64Store matrix;
+    R064Store matrix;
 
     @Override
     @Setup
@@ -72,7 +72,7 @@ public class ThresholdApplyCholesky extends AbstractThresholdTuner {
         ApplyCholesky.THRESHOLD = dim / z;
         final int dim1 = dim;
 
-        matrix = Primitive64Store.FACTORY.makeSPD(dim1);
+        matrix = R064Store.FACTORY.makeSPD(dim1);
     }
 
     @Override
