@@ -22,7 +22,7 @@
 package org.ojalgo.matrix.operation;
 
 import org.ojalgo.BenchmarkUtils;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.random.Normal;
 import org.openjdk.jmh.annotations.Benchmark;
 import org.openjdk.jmh.annotations.Param;
@@ -84,33 +84,33 @@ public class MultTranspRightBoth {
     @Param({ "2", "3", "4", "5", "10", "20", "50" })
     public int complexity;
 
-    public Primitive64Store left;
-    public Primitive64Store product;
-    public Primitive64Store right;
+    public R064Store left;
+    public R064Store product;
+    public R064Store right;
 
     MultiplyBoth.Primitive MB;
     MultiplyRight.Primitive64 MR;
 
     @Benchmark
-    public Primitive64Store multiplyBoth() {
+    public R064Store multiplyBoth() {
         MB.invoke(product, left, complexity, right.transpose());
         return product;
     }
 
     @Benchmark
-    public Primitive64Store multiplyDynamic() {
+    public R064Store multiplyDynamic() {
         product.fillByMultiplying(left, right.transpose());
         return product;
     }
 
     @Benchmark
-    public Primitive64Store multiplyRight() {
+    public R064Store multiplyRight() {
         MR.invoke(product.data, left.data, complexity, right.transpose());
         return product;
     }
 
     @Benchmark
-    public Primitive64Store multiplyStatic() {
+    public R064Store multiplyStatic() {
         MultiplyRight.addMxC(product.data, 0, complexity, left.data, complexity, right.transpose());
         return product;
     }
@@ -118,9 +118,9 @@ public class MultTranspRightBoth {
     @Setup
     public void setup() {
 
-        left = Primitive64Store.FACTORY.makeFilled(complexity, complexity, new Normal());
-        right = Primitive64Store.FACTORY.makeFilled(complexity, complexity, new Normal());
-        product = Primitive64Store.FACTORY.make(complexity, complexity);
+        left = R064Store.FACTORY.makeFilled(complexity, complexity, new Normal());
+        right = R064Store.FACTORY.makeFilled(complexity, complexity, new Normal());
+        product = R064Store.FACTORY.make(complexity, complexity);
 
         MR = MultiplyRight.newPrimitive64(complexity, complexity);
         MB = MultiplyBoth.newPrimitive64(complexity, complexity);
