@@ -26,7 +26,7 @@ import java.util.List;
 import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
 import org.ojalgo.matrix.store.MatrixStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.random.Uniform;
 
 public final class DeterminantTest extends MatrixTaskTests {
@@ -103,11 +103,11 @@ public final class DeterminantTest extends MatrixTaskTests {
     }
 
     MatrixStore<Double> makeGeneral(final int dim) {
-        return Primitive64Store.FACTORY.makeFilled(dim, dim, new Uniform());
+        return R064Store.FACTORY.makeFilled(dim, dim, new Uniform());
     }
 
     MatrixStore<Double> makeSymmetric(final int dim) {
-        return Primitive64Store.FACTORY.makeSPD(dim);
+        return R064Store.FACTORY.makeSPD(dim);
     }
 
 }
