@@ -15,7 +15,8 @@ import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
 import org.ojalgo.matrix.store.PhysicalStore.Factory;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
+import org.ojalgo.matrix.store.RawStore;
 import org.ojalgo.matrix.task.SolverTask;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.optimisation.ExpressionsBasedModel;
@@ -31,6 +32,8 @@ public class IterativeRefinementTest extends OptimisationConvexTests {
     private static final NumberContext HIGH_ACCURACY = NumberContext.of(9);
     private static final Factory<RationalNumber, GenericStore<RationalNumber>> Q128 = GenericStore.Q128;
 
+    public static final PrimitiveFunction.Binary DIVIDE_SAFE = (arg1, arg2) -> Math.abs(arg2) < 1e-6 ? 0 : arg1 / arg2;
+
     private static void doReimplementExample4(final boolean step1AsInExample) {
 
         try {
@@ -71,7 +74,7 @@ public class IterativeRefinementTest extends OptimisationConvexTests {
 
             MatrixStore<RationalNumber> body = mtrxQ.right(mtrxAE.transpose()).below(mtrxAE);
             MatrixStore<RationalNumber> rhs = mtrxC.below(mtrxBE); // C-matrix already negated
-            SolverTask<RationalNumber> solver = SolverTask.RATIONAL.make(body, rhs);
+            SolverTask<RationalNumber> solver = SolverTask.Q128.make(body, rhs);
 
             MatrixStore<RationalNumber> expected = solver.solve(body, rhs);
 
@@ -106,8 +109,8 @@ public class IterativeRefinementTest extends OptimisationConvexTests {
 
             Result resultStep1 = ConvexSolver.newBuilder(mtrxQ).linear(mtrxC).equalities(mtrxAE, mtrxBE).inequalities(mtrxAI, mtrxBI).solve();
 
-            GenericStore<RationalNumber> step1X = Q128.columns(resultStep1);
-            GenericStore<RationalNumber> step1L = Q128.columns(resultStep1.getMultipliers().get());
+            GenericStore<RationalNumber> step1X = Q128.column(resultStep1);
+            GenericStore<RationalNumber> step1L = Q128.column(resultStep1.getMultipliers().get());
 
             if (DEBUG) {
                 BasicLogger.debugMatrix("Step 1 Solution", step1X);
@@ -138,8 +141,8 @@ public class IterativeRefinementTest extends OptimisationConvexTests {
 
             Result resultStep2 = ConvexSolver.newBuilder(mtrxQ).linear(mtrxC).equalities(mtrxAE, mtrxBE).inequalities(mtrxAI, mtrxBI).solve();
 
-            GenericStore<RationalNumber> step2X = Q128.columns(resultStep2);
-            GenericStore<RationalNumber> step2L = Q128.columns(resultStep2.getMultipliers().get());
+            GenericStore<RationalNumber> step2X = Q128.column(resultStep2);
+            GenericStore<RationalNumber> step2L = Q128.column(resultStep2.getMultipliers().get());
 
             if (DEBUG) {
                 BasicLogger.debugMatrix("Step 2 Solution", step2X);
@@ -186,8 +189,8 @@ public class IterativeRefinementTest extends OptimisationConvexTests {
         double C_Size = C_in.aggregateAll(Aggregator.LARGEST).doubleValue();
         double Q_Size = Q_in.aggregateAll(Aggregator.LARGEST).doubleValue();
 
-        MatrixStore<Quadruple> x = GenericStore.R128.columns(x_in);
-        MatrixStore<Quadruple> y = GenericStore.R128.columns(y_in);
+        MatrixStore<Quadruple> x = GenericStore.R128.column(x_in);
+        MatrixStore<Quadruple> y = GenericStore.R128.column(y_in);
 
         MatrixStore<Quadruple> Q = GenericStore.R128.makeWrapper(Q_in);
         MatrixStore<Quadruple> C = GenericStore.R128.makeWrapper(C_in);
@@ -322,24 +325,24 @@ public class IterativeRefinementTest extends OptimisationConvexTests {
         options.sparse = false;
         options.convex().solverSPD(Cholesky.R064::make).solverGeneral(LU.R064::make).iterative(NumberContext.of(16));
 
-        GenericStore<Quadruple> AE = GenericStore.R128.rows(new double[][] { { 1.0, 1.0, 1.0, 1.0, 1.0 } });
-        GenericStore<Quadruple> BE = GenericStore.R128.rows(new double[][] { { 8.5E-18 } });
+        GenericStore<Quadruple> AE = GenericStore.R128.copy(RawStore.wrap(new double[][] { { 1.0, 1.0, 1.0, 1.0, 1.0 } }));
+        GenericStore<Quadruple> BE = GenericStore.R128.copy(RawStore.wrap(new double[][] { { 8.5E-18 } }));
 
-        GenericStore<Quadruple> AI = GenericStore.R128.rows(new double[][] { { -1.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, -1.0, 0.0, 0.0, 0.0 },
-                { 0.0, 0.0, -1.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, -1.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, -1.0 } });
-        GenericStore<Quadruple> BI = GenericStore.R128.rows(new double[][] { { 0.7907669085467611 }, { 0.0019999999999900154 }, { 0.20323309144826854 },
-                { 0.0019999999999900154 }, { 0.0019999999999903207 } });
+        GenericStore<Quadruple> AI = GenericStore.R128.copy(RawStore.wrap(new double[][] { { -1.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, -1.0, 0.0, 0.0, 0.0 },
+                { 0.0, 0.0, -1.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, -1.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, -1.0 } }));
+        GenericStore<Quadruple> BI = GenericStore.R128.copy(RawStore.wrap(new double[][] { { 0.7907669085467611 }, { 0.0019999999999900154 },
+                { 0.20323309144826854 }, { 0.0019999999999900154 }, { 0.0019999999999903207 } }));
 
-        GenericStore<Quadruple> C = GenericStore.R128.rows(
-                new double[][] { { -550875.2032141489 }, { -562399.9568628508 }, { -564250.6957511578 }, { -691369.2681449897 }, { -1400521.5234620553 } });
+        GenericStore<Quadruple> C = GenericStore.R128.copy(RawStore.wrap(
+                new double[][] { { -550875.2032141489 }, { -562399.9568628508 }, { -564250.6957511578 }, { -691369.2681449897 }, { -1400521.5234620553 } }));
         GenericStore<Quadruple> Q = GenericStore.R128
-                .rows(new double[][] { { 10514.489048700269, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 4157254.9979421264, 0.0, 0.0, 0.0 },
-                        { 0.0, 0.0, 40911.20171773545, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 4157254.9979421264, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 4157254.9979414917 } });
+                .copy(RawStore.wrap(new double[][] { { 10514.489048700269, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 4157254.9979421264, 0.0, 0.0, 0.0 },
+                        { 0.0, 0.0, 40911.20171773545, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 4157254.9979421264, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 4157254.9979414917 } }));
 
         Optimisation.Result result = IterativeRefinementSolver.doSolve(Q, C, AE, BE, AI, BI, options);
 
-        MatrixStore<Double> x = Primitive64Store.FACTORY.columns(result);
-        MatrixStore<Double> y = Primitive64Store.FACTORY.columns(result.getMultipliers().get());
+        MatrixStore<Double> x = R064Store.FACTORY.column(result);
+        MatrixStore<Double> y = R064Store.FACTORY.column(result.getMultipliers().get());
 
         double precision = IterativeRefinementTest.getResidualQuadruplePrecision(x, y, Q, C, AE, BE, AI, BI);
         TestUtils.assertLessThan(1e-15, precision);
@@ -352,21 +355,21 @@ public class IterativeRefinementTest extends OptimisationConvexTests {
         options.sparse = false;
         options.convex().solverSPD(Cholesky.R064::make).solverGeneral(LU.R064::make).iterative(NumberContext.of(16));
 
-        GenericStore<Quadruple> AE = GenericStore.R128.rows(new double[][] { { 1.0, 1.0, 1.0, 1.0, 1.0 } });
-        GenericStore<Quadruple> BE = GenericStore.R128.rows(new double[][] { { 0 } });
-        GenericStore<Quadruple> AI = GenericStore.R128.rows(new double[][] { { -1.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, -1.0, 0.0, 0.0, 0.0 },
-                { 0.0, 0.0, -1.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, -1.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, -1.0 } });
+        GenericStore<Quadruple> AE = GenericStore.R128.copy(RawStore.wrap(new double[][] { { 1.0, 1.0, 1.0, 1.0, 1.0 } }));
+        GenericStore<Quadruple> BE = GenericStore.R128.copy(RawStore.wrap(new double[][] { { 0 } }));
+        GenericStore<Quadruple> AI = GenericStore.R128.copy(RawStore.wrap(new double[][] { { -1.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, -1.0, 0.0, 0.0, 0.0 },
+                { 0.0, 0.0, -1.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, -1.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, -1.0 } }));
         GenericStore<Quadruple> BI = GenericStore.R128
-                .rows(new double[][] { { 0.199999999999 }, { 0.199999999999 }, { 0.199999999999 }, { 0.199999999999 }, { 0.199999999999 } });
-        GenericStore<Quadruple> C = GenericStore.R128.rows(
-                new double[][] { { -539445.3637318831 }, { -600689.6904218349 }, { -564117.362709679 }, { -729659.0017039739 }, { -1438811.2570210383 } });
-        GenericStore<Quadruple> Q = GenericStore.R128.rows(new double[][] { { 41572.55, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 41572.55, 0.0, 0.0, 0.0 },
-                { 0.0, 0.0, 41572.55, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 41572.55, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 41572.55 } });
+                .copy(RawStore.wrap(new double[][] { { 0.199999999999 }, { 0.199999999999 }, { 0.199999999999 }, { 0.199999999999 }, { 0.199999999999 } }));
+        GenericStore<Quadruple> C = GenericStore.R128.copy(RawStore.wrap(
+                new double[][] { { -539445.3637318831 }, { -600689.6904218349 }, { -564117.362709679 }, { -729659.0017039739 }, { -1438811.2570210383 } }));
+        GenericStore<Quadruple> Q = GenericStore.R128.copy(RawStore.wrap(new double[][] { { 41572.55, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 41572.55, 0.0, 0.0, 0.0 },
+                { 0.0, 0.0, 41572.55, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 41572.55, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 41572.55 } }));
 
         Optimisation.Result result = IterativeRefinementSolver.doSolve(Q, C, AE, BE, AI, BI, options);
 
-        MatrixStore<Double> x = Primitive64Store.FACTORY.columns(result);
-        MatrixStore<Double> y = Primitive64Store.FACTORY.columns(result.getMultipliers().get());
+        MatrixStore<Double> x = R064Store.FACTORY.column(result);
+        MatrixStore<Double> y = R064Store.FACTORY.column(result.getMultipliers().get());
 
         double precision = IterativeRefinementTest.getResidualQuadruplePrecision(x, y, Q, C, AE, BE, AI, BI);
         TestUtils.assertLessThan(1e-15, precision);
@@ -380,17 +383,17 @@ public class IterativeRefinementTest extends OptimisationConvexTests {
         options.convex().solverSPD(Cholesky.R064::make).solverGeneral(LU.R064::make).iterative(NumberContext.of(16));
 
         GenericStore<Quadruple> AE = GenericStore.R128
-                .rows(new double[][] { { -0.5, -0.5, 0.0, 0.0, -5.763179164237471 }, { 0.0, 0.0, 0.0, 0.0, 1.0 }, { 0.0, 0.0, 0.0, 1.0, 0.0 },
-                        { -3.0067917411849886E-5, 3.0067917411849886E-5, 0.5, 0.0, 0.0 }, { 3.0067917411849886E-5, -3.0067917411849886E-5, 0.5, 0.0, 0.0 } });
-        GenericStore<Quadruple> BE = GenericStore.R128.rows(new double[][] { { 5763.179164237471 }, { -0.0 }, { -0.0 }, { -0.0 }, { 1.0 } });
-        GenericStore<Quadruple> AI = GenericStore.R128.rows(new double[][] { { -0.0, -0.0, -1.0, -0.0, -0.0 } });
-        GenericStore<Quadruple> BI = GenericStore.R128.rows(new double[][] { { 1.0 } });
-        GenericStore<Quadruple> C = GenericStore.R128.rows(new double[][] { { -0.0 }, { -0.0 }, { -1.0 }, { -100000.0 }, { -1000.0 } });
-        GenericStore<Quadruple> Q = GenericStore.R128.rows(new double[][] { { 1.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 1.0, 0.0, 0.0, 0.0 },
-                { 0.0, 0.0, 1.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 1.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 1.0 } });
+                .copy(RawStore.wrap(new double[][] { { -0.5, -0.5, 0.0, 0.0, -5.763179164237471 }, { 0.0, 0.0, 0.0, 0.0, 1.0 }, { 0.0, 0.0, 0.0, 1.0, 0.0 },
+                        { -3.0067917411849886E-5, 3.0067917411849886E-5, 0.5, 0.0, 0.0 }, { 3.0067917411849886E-5, -3.0067917411849886E-5, 0.5, 0.0, 0.0 } }));
+        GenericStore<Quadruple> BE = GenericStore.R128.copy(RawStore.wrap(new double[][] { { 5763.179164237471 }, { -0.0 }, { -0.0 }, { -0.0 }, { 1.0 } }));
+        GenericStore<Quadruple> AI = GenericStore.R128.copy(RawStore.wrap(new double[][] { { -0.0, -0.0, -1.0, -0.0, -0.0 } }));
+        GenericStore<Quadruple> BI = GenericStore.R128.copy(RawStore.wrap(new double[][] { { 1.0 } }));
+        GenericStore<Quadruple> C = GenericStore.R128.copy(RawStore.wrap(new double[][] { { -0.0 }, { -0.0 }, { -1.0 }, { -100000.0 }, { -1000.0 } }));
+        GenericStore<Quadruple> Q = GenericStore.R128.copy(RawStore.wrap(new double[][] { { 1.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 1.0, 0.0, 0.0, 0.0 },
+                { 0.0, 0.0, 1.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 1.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 1.0 } }));
         Optimisation.Result result = IterativeRefinementSolver.doSolve(Q, C, AE, BE, AI, BI, options);
-        MatrixStore<Double> x = Primitive64Store.FACTORY.columns(result);
-        MatrixStore<Double> y = Primitive64Store.FACTORY.columns(result.getMultipliers().get());
+        MatrixStore<Double> x = R064Store.FACTORY.column(result);
+        MatrixStore<Double> y = R064Store.FACTORY.column(result.getMultipliers().get());
 
         double precision = IterativeRefinementTest.getResidualQuadruplePrecision(x, y, Q, C, AE, BE, AI, BI);
         TestUtils.assertLessThan(1e-12, precision);
@@ -404,26 +407,26 @@ public class IterativeRefinementTest extends OptimisationConvexTests {
          */
 
         GenericStore<Quadruple> AE = GenericStore.R128
-                .rows(new double[][] { { 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 }, { 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 },
+                .copy(RawStore.wrap(new double[][] { { 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 }, { 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 },
                         { 0.0, 0.0, 8.352297391034406E-10, 0.8576273045259193, 1.4176006647997381, 0.0, 0.582399335200262, 0.0 },
                         { 0.0, 0.0, 0.9999999991647702, 0.1423726954740807, 0.0, 1.4176006647997381, 0.0, 0.582399335200262 },
-                        { 0.0, 0.0, 0.0, 0.0, -1.0, -1.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.0, -1.0 } });
+                        { 0.0, 0.0, 0.0, 0.0, -1.0, -1.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.0, -1.0 } }));
 
         GenericStore<Quadruple> BE = GenericStore.R128
-                .rows(new double[][] { { -0.0 }, { -0.0 }, { 5.184268104897471E-4 }, { -5.184268104898582E-4 }, { -0.0 }, { -0.0 } });
+                .copy(RawStore.wrap(new double[][] { { -0.0 }, { -0.0 }, { 5.184268104897471E-4 }, { -5.184268104898582E-4 }, { -0.0 }, { -0.0 } }));
 
         GenericStore<Quadruple> AI = GenericStore.R128
-                .rows(new double[][] { { -1.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0 }, { -0.0, -1.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0 },
+                .copy(RawStore.wrap(new double[][] { { -1.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0 }, { -0.0, -1.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0 },
                         { -0.0, -0.0, -1.0, -0.0, -0.0, -0.0, -0.0, -0.0 }, { -0.0, -0.0, -0.0, -1.0, -0.0, -0.0, -0.0, -0.0 },
                         { -0.0, -0.0, -0.0, -0.0, -1.0, -0.0, -0.0, -0.0 }, { -0.0, -0.0, -0.0, -0.0, -0.0, -1.0, -0.0, -0.0 },
-                        { -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.0, -0.0 }, { -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.0 } });
-        GenericStore<Quadruple> BI = GenericStore.R128.rows(new double[][] { { 99999.999 }, { 999.999 }, { 1.4176006647997381 }, { 0.582399335200262 },
-                { 8.342297391034407E-10 }, { 0.9999999991637702 }, { 0.8576273045249193 }, { 0.1423726954730807 } });
+                        { -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.0, -0.0 }, { -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.0 } }));
+        GenericStore<Quadruple> BI = GenericStore.R128.copy(RawStore.wrap(new double[][] { { 99999.999 }, { 999.999 }, { 1.4176006647997381 },
+                { 0.582399335200262 }, { 8.342297391034407E-10 }, { 0.9999999991637702 }, { 0.8576273045249193 }, { 0.1423726954730807 } }));
 
-        GenericStore<Quadruple> C = GenericStore.R128.rows(new double[][] { { -1.0507334266932648E-5 }, { 111.76733530105174 }, { 35972.35323772494 },
-                { 3402.691149823142 }, { 241369.47835246887 }, { 39207.7768435451 }, { -4098.6473014047 }, { 4596.891294076649 } });
+        GenericStore<Quadruple> C = GenericStore.R128.copy(RawStore.wrap(new double[][] { { -1.0507334266932648E-5 }, { 111.76733530105174 },
+                { 35972.35323772494 }, { 3402.691149823142 }, { 241369.47835246887 }, { 39207.7768435451 }, { -4098.6473014047 }, { 4596.891294076649 } }));
 
-        GenericStore<Quadruple> Q = GenericStore.R128.rows(new double[][] {
+        GenericStore<Quadruple> Q = GenericStore.R128.copy(RawStore.wrap(new double[][] {
                 { 0.001000000000015139, -1.3922723188263615E-7, -1.260916429481889E-5, 1.1365393461671568E-10, 3.833998314967881E-6, -4.89115589330624E-6,
                         -6.213978880671885E-11, 1.3194143917892373E-11 },
                 { -1.3922723188263615E-7, 1.2914061800397567, 111.98124430594436, 6.247515358606731, -290.69228055360566, 55.317474119999154,
@@ -439,7 +442,7 @@ public class IterativeRefinementTest extends OptimisationConvexTests {
                 { -6.213978880671885E-11, -1.8012674863750813, -0.0036948253353555976, 1962.2096944694779, -5.160496246346225E-7, -0.008194872881962646,
                         8749.126719131198, -1004.5850092088822 },
                 { 1.3194143917892375E-11, -2.686683179830683, 0.01055945876378435, -6249.852185851845, 8.324777613205291E-6, 0.010231508973073046,
-                        -1004.5850092088823, 34337.13657031502 } });
+                        -1004.5850092088823, 34337.13657031502 } }));
 
         Optimisation.Options options = new Optimisation.Options();
         options.sparse = false;
@@ -447,8 +450,8 @@ public class IterativeRefinementTest extends OptimisationConvexTests {
         options.convex().solverSPD(Cholesky.R064::make).solverGeneral(LU.R064::make).iterative(NumberContext.of(16));
         Optimisation.Result resultQuadruple = IterativeRefinementSolver.doSolve(Q, C, AE, BE, AI, BI, options);
 
-        MatrixStore<Double> xQ = Primitive64Store.FACTORY.columns(resultQuadruple);
-        MatrixStore<Double> yQ = Primitive64Store.FACTORY.columns(resultQuadruple.getMultipliers().get());
+        MatrixStore<Double> xQ = R064Store.FACTORY.column(resultQuadruple);
+        MatrixStore<Double> yQ = R064Store.FACTORY.column(resultQuadruple.getMultipliers().get());
 
         double precisionQuadruple = IterativeRefinementTest.getResidualQuadruplePrecision(xQ, yQ, Q, C, AE, BE, AI, BI);
         //        TestUtils.assertLessThan(1e-15, precision);
@@ -456,8 +459,8 @@ public class IterativeRefinementTest extends OptimisationConvexTests {
         options.convex().extendedPrecision(false);
         ConvexSolver model = ConvexSolver.newBuilder().objective(Q, C).equalities(AE, BE).inequalities(AI, BI).build(options);
         Result resultDouble = model.solve();
-        MatrixStore<Double> xD = Primitive64Store.FACTORY.columns(resultDouble);
-        MatrixStore<Double> yD = Primitive64Store.FACTORY.columns(resultDouble.getMultipliers().get());
+        MatrixStore<Double> xD = R064Store.FACTORY.column(resultDouble);
+        MatrixStore<Double> yD = R064Store.FACTORY.column(resultDouble.getMultipliers().get());
         double precisionDouble = IterativeRefinementTest.getResidualQuadruplePrecision(xD, yD, Q, C, AE, BE, AI, BI);
         double improvement = (resultDouble.getValue() - resultQuadruple.getValue()) / resultDouble.getValue();
 
@@ -475,6 +478,4 @@ public class IterativeRefinementTest extends OptimisationConvexTests {
         yAbsolute.onMatching(DIVIDE_SAFE, yQ).supplyTo(yRelative);
         double largestRelativeDualDiff = yRelative.aggregateAll(Aggregator.LARGEST).doubleValue();
     }
-
-    public static final PrimitiveFunction.Binary DIVIDE_SAFE = (arg1, arg2) -> Math.abs(arg2) < 1e-6 ? 0 : arg1 / arg2;
 }
