@@ -6,7 +6,7 @@ import java.io.InputStreamReader;
 import java.util.Arrays;
 
 import org.ojalgo.matrix.store.MatrixStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.RawStore;
 
 class MatrixReader {
 
@@ -16,8 +16,8 @@ class MatrixReader {
 
     static MatrixStore<Double> readMatrix(final String resourceName) throws IOException {
         try (BufferedReader r = new BufferedReader(new InputStreamReader(GitHubIssue300.class.getResourceAsStream(resourceName)))) {
-            final double[][] rows = r.lines().map(MatrixReader::parseLine).toArray(double[][]::new);
-            return Primitive64Store.FACTORY.rows(rows).get();
+            double[][] rows = r.lines().map(MatrixReader::parseLine).toArray(double[][]::new);
+            return RawStore.wrap(rows);
         }
     }
 
