@@ -22,7 +22,7 @@
 package org.ojalgo.optimisation.convex;
 
 import org.ojalgo.TestUtils;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.optimisation.ExpressionsBasedModel;
 import org.ojalgo.optimisation.Optimisation;
 import org.ojalgo.type.context.NumberContext;
@@ -34,7 +34,11 @@ public abstract class OptimisationConvexTests {
 
     static boolean DEBUG = false;
 
-    protected static void assertDirectAndIterativeEquals(final ConvexSolver.Builder builder, final NumberContext accuracy, Optimisation.Options options) {
+    public static ConvexData<Double> getOptimisationData(final ConvexSolver.Builder convexSolverBuilder) {
+        return convexSolverBuilder.getConvexData(R064Store.FACTORY);
+    }
+
+    protected static void assertDirectAndIterativeEquals(final ConvexData<Double> convexData, final NumberContext accuracy, Optimisation.Options options) {
 
         if (options == null) {
             options = new Optimisation.Options();
@@ -44,13 +48,13 @@ public abstract class OptimisationConvexTests {
             options.solution = accuracy;
         }
 
-        if (builder.countInequalityConstraints() > 0) {
+        if (convexData.countInequalityConstraints() > 0) {
             // ActiveSetSolver (ASS)
 
-            DirectASS directASS = new DirectASS(builder.getConvexData(Primitive64Store.FACTORY), options);
+            DirectASS directASS = new DirectASS(convexData, options);
             Optimisation.Result direct = directASS.solve();
 
-            IterativeASS iterativeASS = new IterativeASS(builder.getConvexData(Primitive64Store.FACTORY), options);
+            IterativeASS iterativeASS = new IterativeASS(convexData, options);
             Optimisation.Result iterative = iterativeASS.solve();
 
             if (!direct.getState().isFeasible()) {
@@ -63,17 +67,18 @@ public abstract class OptimisationConvexTests {
         }
     }
 
-    protected static void assertDirectAndIterativeEquals(final ExpressionsBasedModel model, final NumberContext accuracy) {
+    protected static void assertDirectAndIterativeEquals(final ConvexSolver.Builder builder, final NumberContext accuracy, final Optimisation.Options options) {
 
-        ConvexSolver.Builder builder = ConvexSolver.newBuilder();
+        ConvexData<Double> convexData = OptimisationConvexTests.getOptimisationData(builder);
 
-        ConvexSolver.copy(model, builder);
-
-        OptimisationConvexTests.assertDirectAndIterativeEquals(builder, accuracy, model.options);
+        OptimisationConvexTests.assertDirectAndIterativeEquals(convexData, accuracy, options);
     }
 
-    public static ConvexData<Double> getOptimisationData(final ConvexSolver.Builder convexSolverBuilder) {
-        return convexSolverBuilder.getConvexData(Primitive64Store.FACTORY);
+    protected static void assertDirectAndIterativeEquals(final ExpressionsBasedModel model, final NumberContext accuracy) {
+
+        ConvexData<Double> convexData = ConvexSolver.copy(model, R064Store.FACTORY);
+
+        OptimisationConvexTests.assertDirectAndIterativeEquals(convexData, accuracy, model.options);
     }
 
 }
