@@ -22,6 +22,7 @@
 package org.ojalgo.optimisation.convex;
 
 import org.ojalgo.matrix.MatrixQ128;
+import org.ojalgo.matrix.store.RawStore;
 
 /**
  * Qsd20030327P1Case
@@ -37,13 +38,13 @@ public class Qsd20030327P1Case extends GenericQPSolverTest {
 
         // Equations/Equalities
         retVal[0] = MatrixQ128.FACTORY
-                .rows(new double[][] { { 1, 1, 1, 1, 1, 1, 1 }, { 0, 0, 0, 0, 1, 0, 0 }, { 0, 0, 0, 0, 0, 1, 0 }, { 0, 0, 0, 0, 0, 0, 1 } });
+                .copy(RawStore.wrap(new double[][] { { 1, 1, 1, 1, 1, 1, 1 }, { 0, 0, 0, 0, 1, 0, 0 }, { 0, 0, 0, 0, 0, 1, 0 }, { 0, 0, 0, 0, 0, 0, 1 } }));
 
         // Levels/Values
-        retVal[1] = MatrixQ128.FACTORY.rows(new double[][] { { 1 }, { 0.0000 }, { 0.0000 }, { 0.0000 } });
+        retVal[1] = MatrixQ128.FACTORY.copy(RawStore.wrap(new double[][] { { 1 }, { 0.0000 }, { 0.0000 }, { 0.0000 } }));
 
         // Quadratic
-        retVal[2] = MatrixQ128.FACTORY.rows(new double[][] {
+        retVal[2] = MatrixQ128.FACTORY.copy(RawStore.wrap(new double[][] {
                 { 1.000000000000000000000000, 0.000000000000000000000000, 0.000000000000000000000000, 0.000000000000000000000000, 0.000000000000000000000000,
                         0.000000000000000000000000, 0.000000000000000000000000 },
                 { 0.000000000000000000000000, 1.000000000000000000000000, 0.000000000000000000000000, 0.000000000000000000000000, 0.000000000000000000000000,
@@ -57,26 +58,27 @@ public class Qsd20030327P1Case extends GenericQPSolverTest {
                 { 0.000000000000000000000000, 0.000000000000000000000000, 0.000000000000000000000000, 0.000000000000000000000000, 0.000000000000000000000000,
                         1.000000000000000000000000, 0.000000000000000000000000 },
                 { 0.000000000000000000000000, 0.000000000000000000000000, 0.000000000000000000000000, 0.000000000000000000000000, 0.000000000000000000000000,
-                        0.000000000000000000000000, 1.000000000000000000000000 } });
+                        0.000000000000000000000000, 1.000000000000000000000000 } }));
 
         // Linear
-        retVal[3] = MatrixQ128.FACTORY.rows(new double[][] { { -0.1100000000000000000000000000 }, { -0.1100000000000000000000000000 },
+        retVal[3] = MatrixQ128.FACTORY.copy(RawStore.wrap(new double[][] { { -0.1100000000000000000000000000 }, { -0.1100000000000000000000000000 },
                 { -0.5000000000000000000000000000 }, { -0.2800000000000000000000000000 }, { 0.0000000000000000000000000000 },
-                { 0.0000000000000000000000000000 }, { 0.0000000000000000000000000000 } });
+                { 0.0000000000000000000000000000 }, { 0.0000000000000000000000000000 } }));
 
         // Inequalities/Differences
-        retVal[4] = MatrixQ128.FACTORY.rows(new double[][] { { -1, 0, 0, 0, 0, 0, 0 }, { 0, -1, 0, 0, 0, 0, 0 }, { 0, 0, -1, 0, 0, 0, 0 },
-                { 0, 0, 0, -1, 0, 0, 0 }, { 1, 0, 0, 0, 0, 0, 0 }, { 0, 1, 0, 0, 0, 0, 0 }, { 0, 0, 1, 0, 0, 0, 0 }, { 0, 0, 0, 1, 0, 0, 0 } });
+        retVal[4] = MatrixQ128.FACTORY.copy(RawStore.wrap(new double[][] { { -1, 0, 0, 0, 0, 0, 0 }, { 0, -1, 0, 0, 0, 0, 0 }, { 0, 0, -1, 0, 0, 0, 0 },
+                { 0, 0, 0, -1, 0, 0, 0 }, { 1, 0, 0, 0, 0, 0, 0 }, { 0, 1, 0, 0, 0, 0, 0 }, { 0, 0, 1, 0, 0, 0, 0 }, { 0, 0, 0, 1, 0, 0, 0 } }));
 
         // Limits
         retVal[5] = MatrixQ128.FACTORY
-                .rows(new double[][] { { -0.0100 }, { -0.0100 }, { -0.4000 }, { -0.1600 }, { 0.2200 }, { 0.0668 }, { 0.6000 }, { 0.4000 } });
+                .copy(RawStore.wrap(new double[][] { { -0.0100 }, { -0.0100 }, { -0.4000 }, { -0.1600 }, { 0.2200 }, { 0.0668 }, { 0.6000 }, { 0.4000 } }));
 
         // LagrangeSolver
         retVal[6] = retVal[3].negate();
 
         // ActiveSetSolver
-        retVal[7] = MatrixQ128.FACTORY.rows(new double[][] { { 0.1244 }, { 0.0668 }, { 0.5144 }, { 0.2944 }, { 0.0000 }, { 0.0000 }, { 0.0000 } });
+        retVal[7] = MatrixQ128.FACTORY
+                .copy(RawStore.wrap(new double[][] { { 0.1244 }, { 0.0668 }, { 0.5144 }, { 0.2944 }, { 0.0000 }, { 0.0000 }, { 0.0000 } }));
 
         return retVal;
     }
