@@ -22,6 +22,7 @@
 package org.ojalgo.optimisation.convex;
 
 import org.ojalgo.matrix.MatrixQ128;
+import org.ojalgo.matrix.store.RawStore;
 
 /**
  * @author apete
@@ -35,34 +36,34 @@ public class QsdOldOptimalCase extends GenericQPSolverTest {
 
         // Equations/Equalities
         retVal[0] = MatrixQ128.FACTORY
-                .rows(new double[][] { { 1.0, 1.0, 1.0, 1.0, 1.0 }, { 0.0345, 0.0412, 0.0738, 0.1288, 0.069575 }, { 0.0, 0.0, 0.0, 0.0, 1.0 } });
+                .copy(RawStore.wrap(new double[][] { { 1.0, 1.0, 1.0, 1.0, 1.0 }, { 0.0345, 0.0412, 0.0738, 0.1288, 0.069575 }, { 0.0, 0.0, 0.0, 0.0, 1.0 } }));
 
         // Levels/Values
-        retVal[1] = MatrixQ128.FACTORY.rows(new double[][] { { 1.0 }, { 0.043807039117990006 }, { 0.0 } });
+        retVal[1] = MatrixQ128.FACTORY.copy(RawStore.wrap(new double[][] { { 1.0 }, { 0.043807039117990006 }, { 0.0 } }));
 
         // Quadratic
-        retVal[2] = MatrixQ128.FACTORY.rows(new double[][] { { 2.005994, -0.077922, -0.041957999999999995, -0.17982, 0.0 },
+        retVal[2] = MatrixQ128.FACTORY.copy(RawStore.wrap(new double[][] { { 2.005994, -0.077922, -0.041957999999999995, -0.17982, 0.0 },
                 { -0.077922, 2.95904, 0.50949, 2.17782, 0.0 }, { -0.041957999999999995, 0.50949, 35.454511999999994, 29.804166, 0.0 },
-                { -0.17982, 2.17782, 29.804166, 139.150712, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 16.747238000000003 } });
+                { -0.17982, 2.17782, 29.804166, 139.150712, 0.0 }, { 0.0, 0.0, 0.0, 0.0, 16.747238000000003 } }));
 
         // Linear
-        retVal[3] = MatrixQ128.FACTORY.rows(new double[][] { { -0.5 }, { -0.5 }, { -0.5 }, { -0.5 }, { -0.0 } });
+        retVal[3] = MatrixQ128.FACTORY.copy(RawStore.wrap(new double[][] { { -0.5 }, { -0.5 }, { -0.5 }, { -0.5 }, { -0.0 } }));
 
         // Inequalities/Differences
-        retVal[4] = MatrixQ128.FACTORY
-                .rows(new double[][] { { -1.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, -1.0, 0.0, 0.0, 0.0 }, { 0.0, 0.0, -1.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, -1.0, 0.0 },
-                        { 1.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 1.0, 0.0, 0.0, 0.0 }, { 0.0, 0.0, 1.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 1.0, 0.0 } });
+        retVal[4] = MatrixQ128.FACTORY.copy(RawStore
+                .wrap(new double[][] { { -1.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, -1.0, 0.0, 0.0, 0.0 }, { 0.0, 0.0, -1.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, -1.0, 0.0 },
+                        { 1.0, 0.0, 0.0, 0.0, 0.0 }, { 0.0, 1.0, 0.0, 0.0, 0.0 }, { 0.0, 0.0, 1.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0, 1.0, 0.0 } }));
 
         // Limits
-        retVal[5] = MatrixQ128.FACTORY.rows(new double[][] { { -0.0 }, { -0.0 }, { -0.0 }, { -0.0 }, { 1.0 }, { 1.0 }, { 1.0 }, { 1.0 } });
+        retVal[5] = MatrixQ128.FACTORY.copy(RawStore.wrap(new double[][] { { -0.0 }, { -0.0 }, { -0.0 }, { -0.0 }, { 1.0 }, { 1.0 }, { 1.0 }, { 1.0 } }));
 
         // LagrangeSolver
-        retVal[6] = MatrixQ128.FACTORY.rows(new double[][] { { 0.4506664080256741780 }, { 0.4388067927187100669 }, { 0.0737389738732712572 },
-                { 0.0367878253823444979 }, { 0.0000000000000000000 } });
+        retVal[6] = MatrixQ128.FACTORY.copy(RawStore.wrap(new double[][] { { 0.4506664080256741780 }, { 0.4388067927187100669 }, { 0.0737389738732712572 },
+                { 0.0367878253823444979 }, { 0.0000000000000000000 } }));
 
         // ActiveSetSolver
-        retVal[7] = MatrixQ128.FACTORY.rows(
-                new double[][] { { 0.4506664080256748 }, { 0.4388067927187099 }, { 0.0737389738732711 }, { 0.036787825382344326 }, { 2.651716120891472E-17 } });
+        retVal[7] = MatrixQ128.FACTORY.copy(RawStore.wrap(new double[][] { { 0.4506664080256748 }, { 0.4388067927187099 }, { 0.0737389738732711 },
+                { 0.036787825382344326 }, { 2.651716120891472E-17 } }));
 
         return retVal;
     }
