@@ -25,7 +25,6 @@ import java.math.BigDecimal;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.junit.jupiter.api.Tag;
 import org.junit.jupiter.api.Test;
 import org.ojalgo.optimisation.ExpressionsBasedModel;
 import org.ojalgo.optimisation.ModelFileTest;
@@ -39,14 +38,16 @@ public class RelaxedMIPCase extends OptimisationIntegerTests implements ModelFil
 
         ExpressionsBasedModel model = ModelFileTest.makeModel("miplib", name, true);
 
-        // model.options.debug(Optimisation.Solver.class);
-        // model.options.debug(IntegerSolver.class);
-        // model.options.debug(ConvexSolver.class);
-        // model.options.debug(LinearSolver.class);
-        // model.options.progress(IntegerSolver.class);
-        // model.options.validate = false;
-        // model.options.mip_defer = 0.25;
-        // model.options.mip_gap = 1.0E-5;
+        if (DEBUG) {
+            // model.options.debug(Optimisation.Solver.class);
+            // model.options.debug(IntegerSolver.class);
+            // model.options.debug(ConvexSolver.class);
+            // model.options.debug(LinearSolver.class);
+            // model.options.progress(IntegerSolver.class);
+            // model.options.validate = false;
+            // model.options.mip_defer = 0.25;
+            // model.options.mip_gap = 1.0E-5;
+        }
 
         ModelFileTest.assertValues(model, expMinValString, expMaxValString, ACCURACY);
     }
@@ -291,7 +292,6 @@ public class RelaxedMIPCase extends OptimisationIntegerTests implements ModelFil
      * </p>
      */
     @Test
-    @Tag("new_lp_problem")
     public void testNeos911880() {
         RelaxedMIPCase.doTest("neos-911880.mps", "23.26", null, null);
     }
