@@ -24,12 +24,15 @@ package org.ojalgo.optimisation.linear;
 import static org.ojalgo.function.constant.BigMath.*;
 
 import java.math.BigDecimal;
+import java.util.Map.Entry;
 
 import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
 import org.ojalgo.function.constant.BigMath;
+import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.optimisation.Expression;
 import org.ojalgo.optimisation.ExpressionsBasedModel;
+import org.ojalgo.optimisation.ExpressionsBasedModel.Integration;
 import org.ojalgo.optimisation.ModelFileTest;
 import org.ojalgo.optimisation.Optimisation.Result;
 import org.ojalgo.optimisation.Variable;
@@ -48,16 +51,40 @@ public class BurkardtDatasetsMps extends OptimisationLinearTests implements Mode
 
         ExpressionsBasedModel model = ModelFileTest.makeModel("burkardt", modelName, false);
 
-        // model.options.debug(Optimisation.Solver.class);
-        // model.options.debug(IntegerSolver.class);
-        // model.options.debug(ConvexSolver.class);
-        // model.options.debug(LinearSolver.class);
-        // model.options.progress(IntegerSolver.class);
-        // model.options.validate = false;
-        // model.options.mip_defer = 0.25;
-        // model.options.mip_gap = 1.0E-5;
+        for (Entry<String, Integration<LinearSolver>> entry : INTEGRATIONS.entrySet()) {
 
-        ModelFileTest.assertValues(model, expMinValString, expMaxValString, BurkardtDatasetsMps.ACCURACY);
+            String key = entry.getKey();
+            Integration<LinearSolver> integration = entry.getValue();
+
+            if (DEBUG) {
+                BasicLogger.debug();
+                BasicLogger.debug("########################################################################################");
+                BasicLogger.debug(key);
+                BasicLogger.debug("########################################################################################");
+            }
+
+            ExpressionsBasedModel.clearIntegrations();
+            ExpressionsBasedModel.addIntegration(integration);
+
+            if (DEBUG) {
+                // model.options.debug(Optimisation.Solver.class);
+                // model.options.debug(IntegerSolver.class);
+                // model.options.debug(ConvexSolver.class);
+                // model.options.debug(LinearSolver.class);
+                // model.options.progress(IntegerSolver.class);
+                // model.options.validate = false;
+                // model.options.mip_defer = 0.25;
+                // model.options.mip_gap = 1.0E-5;
+            }
+
+            ModelFileTest.assertValues(model, expMinValString, expMaxValString, BurkardtDatasetsMps.ACCURACY);
+            ExpressionsBasedModel.clearIntegrations();
+
+            if (DEBUG) {
+                BasicLogger.debug(model);
+                BasicLogger.debug();
+            }
+        }
 
         return model;
     }
@@ -169,14 +196,14 @@ public class BurkardtDatasetsMps extends OptimisationLinearTests implements Mode
 
         ExpressionsBasedModel parsedModel = BurkardtDatasetsMps.doTest("testprob.mps", "54", "80");
 
-        Variable tmpXONE = new Variable("XONE").weight(ONE).lower(ZERO).upper(FOUR);
-        Variable tmpYTWO = new Variable("YTWO").weight(FOUR).lower(NEG).upper(ONE);
-        Variable tmpZTHREE = new Variable("ZTHREE").weight(NINE).lower(ZERO).upper(null);
+        ExpressionsBasedModel reimplementedModel = new ExpressionsBasedModel();
+
+        Variable tmpXONE = reimplementedModel.newVariable("XONE").weight(ONE).lower(ZERO).upper(FOUR);
+        Variable tmpYTWO = reimplementedModel.newVariable("YTWO").weight(FOUR).lower(NEG).upper(ONE);
+        Variable tmpZTHREE = reimplementedModel.newVariable("ZTHREE").weight(NINE).lower(ZERO).upper(null);
 
         Variable[] tmpVariables = { tmpXONE, tmpYTWO, tmpZTHREE };
 
-        ExpressionsBasedModel reimplementedModel = new ExpressionsBasedModel(tmpVariables);
-
         Expression tmpLIM1 = reimplementedModel.newExpression("LIM1");
         for (int v = 0; v < tmpVariables.length; v++) {
             tmpLIM1.set(v, new BigDecimal[] { ONE, ONE, ZERO }[v]);
