@@ -28,7 +28,7 @@ import org.ojalgo.TestUtils;
 import org.ojalgo.function.constant.BigMath;
 import org.ojalgo.matrix.MatrixQ128;
 import org.ojalgo.matrix.store.MatrixStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.optimisation.Expression;
 import org.ojalgo.optimisation.ExpressionsBasedModel;
 import org.ojalgo.optimisation.Optimisation;
@@ -67,13 +67,14 @@ public class ComPictetPamBamTest extends OptimisationLinearTests {
         //
         // variables
         //
+        linearModel = new ExpressionsBasedModel();
+
         vars = new Variable[numberOfVars];
-        vars[0] = new Variable("x0").lower(BigMath.ZERO).upper(BigMath.HUNDRED);
-        vars[1] = new Variable("x1").lower(BigMath.ZERO).upper(BigMath.HUNDRED);
+        vars[0] = linearModel.newVariable("x0").lower(BigMath.ZERO).upper(BigMath.HUNDRED);
+        vars[1] = linearModel.newVariable("x1").lower(BigMath.ZERO).upper(BigMath.HUNDRED);
         //
         // model
         //
-        linearModel = new ExpressionsBasedModel(vars);
         {
             //
             // x0 = 2*x1, i.e. x0 - 2*x1 = 0
@@ -94,7 +95,7 @@ public class ComPictetPamBamTest extends OptimisationLinearTests {
             final String message = "State: " + tmpResult.getState() + ", validated: " + validated;
             TestUtils.assertTrue(message, validated);
             if (validated) {
-                return Primitive64Store.FACTORY.copy(MatrixQ128.FACTORY.columns(tmpResult));
+                return R064Store.FACTORY.copy(MatrixQ128.FACTORY.column(tmpResult));
             }
         } else {
             final String message = "State: " + tmpResult.getState() + ", validated: " + validated;
