@@ -218,13 +218,14 @@ public class CommonsMathSimplexSolverTest extends OptimisationLinearTests {
 
             super();
 
+            myModel = new ExpressionsBasedModel();
+
             Variable[] tmpVariables = new Variable[weights.length];
             for (int v = 0; v < tmpVariables.length; v++) {
-                tmpVariables[v] = new Variable("VAR" + v);
+                tmpVariables[v] = myModel.newVariable("VAR" + v);
                 tmpVariables[v].weight(new BigDecimal(weights[v]));
             }
 
-            myModel = new ExpressionsBasedModel(tmpVariables);
             myConstant = constant;
         }
 
@@ -240,10 +241,6 @@ public class CommonsMathSimplexSolverTest extends OptimisationLinearTests {
             return myModel.objective().toFunction();
         }
 
-        public Optimisation.Options options() {
-            return myModel.options;
-        }
-
         public List<Variable> getVariables() {
             return myModel.getVariables();
         }
@@ -256,6 +253,10 @@ public class CommonsMathSimplexSolverTest extends OptimisationLinearTests {
             return myModel.minimise();
         }
 
+        public Optimisation.Options options() {
+            return myModel.options;
+        }
+
     }
 
     static class PointValuePair {
@@ -837,6 +838,7 @@ public class CommonsMathSimplexSolverTest extends OptimisationLinearTests {
 
     @Test
     public void testAbortAfterIterationWithLargeModel() {
+
         LargeModelFactory lmf = new LargeModelFactory();
 
         LinearObjectiveFunction f = new LinearObjectiveFunction(lmf.objective, 0);
