@@ -30,21 +30,23 @@ import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
 import org.ojalgo.array.ArrayR256;
-import org.ojalgo.function.PrimitiveFunction;
 import org.ojalgo.function.constant.BigMath;
 import org.ojalgo.matrix.MatrixQ128;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
+import org.ojalgo.matrix.store.RawStore;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.optimisation.Expression;
 import org.ojalgo.optimisation.ExpressionsBasedModel;
 import org.ojalgo.optimisation.ExpressionsBasedModel.Integration;
+import org.ojalgo.optimisation.ModelFileTest;
 import org.ojalgo.optimisation.Optimisation;
 import org.ojalgo.optimisation.Optimisation.Result;
+import org.ojalgo.optimisation.Optimisation.Sense;
 import org.ojalgo.optimisation.Optimisation.State;
+import org.ojalgo.optimisation.OptimisationCase;
 import org.ojalgo.optimisation.Variable;
-import org.ojalgo.type.context.NumberContext;
 
 public class LinearDesignTestCases extends OptimisationLinearTests {
 
@@ -53,55 +55,56 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
         Variable tmpVar;
         Variable[] tmpVariables = new Variable[8];
 
-        tmpVar = new Variable("QRHEDGE");
+        ExpressionsBasedModel retVal = new ExpressionsBasedModel();
+
+        tmpVar = retVal.newVariable("QRHEDGE");
         tmpVar.weight(BigMath.ZERO);
         tmpVar.lower(BigMath.ZERO);
         tmpVar.upper(BigMath.ZERO);
         tmpVariables[0] = tmpVar;
 
-        tmpVar = new Variable("QKORT");
+        tmpVar = retVal.newVariable("QKORT");
         tmpVar.weight(new BigDecimal("0.0345"));
         tmpVar.lower(BigMath.ZERO);
         tmpVar.upper(BigMath.ONE);
         tmpVariables[1] = tmpVar;
 
-        tmpVar = new Variable("QHEDGE");
+        tmpVar = retVal.newVariable("QHEDGE");
         tmpVar.weight(new BigDecimal("0.04"));
         tmpVar.lower(new BigDecimal("0.1846"));
         tmpVar.upper(new BigDecimal("0.1846"));
         tmpVariables[2] = tmpVar;
 
-        tmpVar = new Variable("QLÅNG");
+        tmpVar = retVal.newVariable("QLÅNG");
         tmpVar.weight(new BigDecimal("0.0412"));
         tmpVar.lower(BigMath.ZERO);
         tmpVar.upper(BigMath.ONE);
         tmpVariables[3] = tmpVar;
 
-        tmpVar = new Variable("QFF");
+        tmpVar = retVal.newVariable("QFF");
         tmpVar.weight(new BigDecimal("0.069575"));
         tmpVar.lower(BigMath.ZERO);
         tmpVar.upper(BigMath.ZERO);
         tmpVariables[4] = tmpVar;
 
-        tmpVar = new Variable("QGLOBAL");
+        tmpVar = retVal.newVariable("QGLOBAL");
         tmpVar.weight(new BigDecimal("0.0738"));
         tmpVar.lower(BigMath.ZERO);
         tmpVar.upper(BigMath.ONE);
         tmpVariables[5] = tmpVar;
 
-        tmpVar = new Variable("QSVERIGE");
+        tmpVar = retVal.newVariable("QSVERIGE");
         tmpVar.weight(new BigDecimal("0.1288"));
         tmpVar.lower(BigMath.ZERO);
         tmpVar.upper(BigMath.ONE);
         tmpVariables[6] = tmpVar;
 
-        tmpVar = new Variable("QFF2");
+        tmpVar = retVal.newVariable("QFF2");
         tmpVar.weight(new BigDecimal("2.3"));
         tmpVar.lower(BigMath.ZERO);
         tmpVar.upper(BigMath.ZERO);
         tmpVariables[7] = tmpVar;
 
-        ExpressionsBasedModel retVal = new ExpressionsBasedModel(tmpVariables);
         int tmpLength = retVal.countVariables();
 
         Expression retVal2 = retVal.newExpression("100%");
@@ -117,6 +120,49 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
         return retVal;
     }
 
+    /**
+     * Small model with 3 variables and 3 constraints. The solution is:
+     * <P>
+     * OPTIMAL -1.29032258064516 @ { 1.74193548387097, 0.45161290322581, 1 }
+     */
+    static OptimisationCase makeModelPSmith338act14() {
+
+        ExpressionsBasedModel model = new ExpressionsBasedModel();
+
+        Variable x1 = model.newVariable("X1").lower(ZERO).weight(NEG);
+        Variable x2 = model.newVariable("X2").lower(ZERO).weight(ONE);
+        Variable x3 = model.newVariable("X3").lower(ZERO).weight(ZERO);
+
+        model.newExpression("C1").set(x1, SIX).set(x2, NEG).upper(TEN);
+        model.newExpression("C2").set(x1, ONE).set(x2, FIVE).lower(FOUR);
+        model.newExpression("C3").set(x1, ONE).set(x2, FIVE).set(x3, ONE).level(FIVE);
+
+        Optimisation.Result result = Optimisation.Result.of(-1.29032258064516, Optimisation.State.OPTIMAL, 1.74193548387097, 0.45161290322581, 1);
+
+        return OptimisationCase.of(model, Optimisation.Sense.MIN, result);
+    }
+
+    /**
+     * Gr4x6 is a multi-dimensional knapsack problem. This is an integer relaxed version of that MIP.
+     * <P>
+     * 24 (4x6) binary, and 24 continuous variables.
+     * <P>
+     * 10 (4+6) equality constraints, and 24 inequality constraints.
+     * <P>
+     * 10 artificial variables.
+     * <P>
+     * All variables have both lower and upper bounds, so using the dual solver is possible.
+     */
+    static OptimisationCase makeRelaxedGr4x6() {
+
+        ExpressionsBasedModel model = ModelFileTest.makeModel("miplib", "gr4x6.mps", true);
+
+        Result result = Optimisation.Result.parse(
+                "OPTIMAL 185.55 @ { 35, 10, 0, 0, 0, 0, 0, 10, 25, 0, 0, 0, 0, 10, 0, 5, 5, 0, 0, 0, 0, 10, 0, 5, 1, 0.3333333333333333, 0, 0, 0, 0, 0, 0.3333333333333333, 1, 0, 0, 0, 0, 0.5, 0, 0.3333333333333333, 1, 0, 0, 0, 0, 0.6666666666666667, 0, 1 }");
+
+        return OptimisationCase.of(model, Sense.MIN, result);
+    }
+
     @AfterEach
     public void reset() {
         ExpressionsBasedModel.clearIntegrations();
@@ -142,7 +188,7 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
 
             model.newVariable("X1").lower(ZERO).weight(ONE);
             model.newVariable("X2").lower(ZERO).weight(TWO);
-            model.newVariable("X3").lower(ZERO).weight(ONE.negate());
+            model.newVariable("X3").lower(ZERO).weight(NEG);
 
             model.newExpression("C1").set(0, TWO).set(1, ONE).set(2, ONE).upper(14);
             model.newExpression("C2").set(0, FOUR).set(1, TWO).set(2, THREE).upper(28);
@@ -169,10 +215,10 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
     @Test
     public void test2LinearModelCase() {
 
-        Variable[] tmpVariables = { new Variable("X1").lower(ZERO).weight(THREE), new Variable("X2").lower(ZERO).weight(ZERO),
-                new Variable("X3").lower(ZERO).weight(ONE) };
+        ExpressionsBasedModel tmpModel = new ExpressionsBasedModel();
 
-        ExpressionsBasedModel tmpModel = new ExpressionsBasedModel(tmpVariables);
+        Variable[] tmpVariables = { tmpModel.newVariable("X1").lower(ZERO).weight(THREE), tmpModel.newVariable("X2").lower(ZERO).weight(ZERO),
+                tmpModel.newVariable("X3").lower(ZERO).weight(ONE) };
 
         Expression tmpExprC1 = tmpModel.newExpression("C1");
         for (int i = 0; i < tmpModel.countVariables(); i++) {
@@ -187,10 +233,10 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
         tmpExprC2.level(SIX);
 
         Optimisation.Result tmpResult = tmpModel.maximise();
-        MatrixQ128 tmpSolution = MatrixQ128.FACTORY.columns(tmpResult);
+        MatrixQ128 tmpSolution = MatrixQ128.FACTORY.column(tmpResult);
 
-        PhysicalStore<Double> tmpExpX = Primitive64Store.FACTORY.rows(new double[][] { { 8.0 }, { 1.0 }, { 0.0 } });
-        PhysicalStore<Double> tmpActX = Primitive64Store.FACTORY.copy(tmpSolution.rows(0, 1, 2));
+        PhysicalStore<Double> tmpExpX = RawStore.wrap(new double[][] { { 8.0 }, { 1.0 }, { 0.0 } });
+        PhysicalStore<Double> tmpActX = R064Store.FACTORY.copy(tmpSolution.rows(0, 1, 2));
 
         TestUtils.assertEquals(tmpExpX, tmpActX);
     }
@@ -201,9 +247,9 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
     @Test
     public void test3LinearModelCase() {
 
-        Variable[] tmpVariables = { new Variable("X1").lower(ZERO).weight(TEN.add(FIVE)), new Variable("X2").lower(ZERO).weight(TEN) };
+        ExpressionsBasedModel tmpModel = new ExpressionsBasedModel();
 
-        ExpressionsBasedModel tmpModel = new ExpressionsBasedModel(tmpVariables);
+        Variable[] tmpVariables = { tmpModel.newVariable("X1").lower(ZERO).weight(TEN.add(FIVE)), tmpModel.newVariable("X2").lower(ZERO).weight(TEN) };
 
         Expression tmpExprC1 = tmpModel.newExpression("C1");
         for (int i = 0; i < tmpModel.countVariables(); i++) {
@@ -224,10 +270,10 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
         tmpExprC3.level(FOUR);
 
         Optimisation.Result tmpResult = tmpModel.maximise();
-        MatrixQ128 tmpSolution = MatrixQ128.FACTORY.columns(tmpResult);
+        MatrixQ128 tmpSolution = MatrixQ128.FACTORY.column(tmpResult);
 
-        PhysicalStore<Double> tmpExpX = Primitive64Store.FACTORY.rows(new double[][] { { 2.0 }, { 2.0 } });
-        PhysicalStore<Double> tmpActX = Primitive64Store.FACTORY.copy(tmpSolution.rows(0, 1));
+        PhysicalStore<Double> tmpExpX = RawStore.wrap(new double[][] { { 2.0 }, { 2.0 } });
+        PhysicalStore<Double> tmpActX = R064Store.FACTORY.copy(tmpSolution.rows(0, 1));
 
         TestUtils.assertEquals(tmpExpX, tmpActX);
     }
@@ -238,37 +284,9 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
     @Test
     public void test4LinearModelCase() {
 
-        Variable[] tmpVariables = { new Variable("X1").lower(ZERO).weight(ONE.negate()), new Variable("X2").lower(ZERO).weight(ONE),
-                new Variable("X3").lower(ZERO).weight(ZERO) };
+        OptimisationCase optimisationCase = LinearDesignTestCases.makeModelPSmith338act14();
 
-        ExpressionsBasedModel tmpModel = new ExpressionsBasedModel(tmpVariables);
-
-        Expression tmpExprC1 = tmpModel.newExpression("C1");
-        for (int i = 0; i < tmpModel.countVariables(); i++) {
-            tmpExprC1.set(i, new BigDecimal[] { SIX, ONE.negate(), ZERO }[i]);
-        }
-        tmpExprC1.upper(TEN);
-
-        Expression tmpExprC2 = tmpModel.newExpression("C2");
-        for (int i = 0; i < tmpModel.countVariables(); i++) {
-            tmpExprC2.set(i, new BigDecimal[] { ONE, FIVE, ZERO }[i]);
-        }
-        tmpExprC2.lower(FOUR);
-
-        Expression tmpExprC3 = tmpModel.newExpression("C3");
-        for (int i = 0; i < tmpModel.countVariables(); i++) {
-            tmpExprC3.set(i, new BigDecimal[] { ONE, FIVE, ONE }[i]);
-        }
-        tmpExprC3.level(FIVE);
-
-        Optimisation.Result tmpResult = tmpModel.minimise();
-        MatrixQ128 tmpSolution = MatrixQ128.FACTORY.columns(tmpResult);
-
-        PhysicalStore<Double> tmpExpX = Primitive64Store.FACTORY.rows(new double[][] { { 1.74 }, { 0.45 }, { 1.0 } });
-        PhysicalStore<Double> tmpActX = Primitive64Store.FACTORY.copy(tmpSolution.rows(0, 1, 2));
-        tmpActX.modifyAll(NumberContext.of(7, 2).getFunction(PrimitiveFunction.getSet()));
-
-        TestUtils.assertEquals(tmpExpX, tmpActX);
+        optimisationCase.assertResult();
     }
 
     /**
@@ -277,9 +295,9 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
     @Test
     public void test5LinearModelCase() {
 
-        Variable[] tmpVariables = { new Variable("X1").lower(ZERO).weight(TWO), new Variable("X2").lower(ZERO).weight(THREE) };
+        ExpressionsBasedModel tmpModel = new ExpressionsBasedModel();
 
-        ExpressionsBasedModel tmpModel = new ExpressionsBasedModel(tmpVariables);
+        Variable[] tmpVariables = { tmpModel.newVariable("X1").lower(ZERO).weight(TWO), tmpModel.newVariable("X2").lower(ZERO).weight(THREE) };
 
         Expression tmpExprC1 = tmpModel.newExpression("C1");
         for (int i = 0; i < tmpModel.countVariables(); i++) {
@@ -300,10 +318,10 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
         tmpExprC3.level(TEN);
 
         Optimisation.Result tmpResult = tmpModel.minimise();
-        MatrixQ128 tmpSolution = MatrixQ128.FACTORY.columns(tmpResult);
+        MatrixQ128 tmpSolution = MatrixQ128.FACTORY.column(tmpResult);
 
-        PhysicalStore<Double> tmpExpX = Primitive64Store.FACTORY.rows(new double[][] { { 5.0 }, { 5.0 } });
-        PhysicalStore<Double> tmpActX = Primitive64Store.FACTORY.copy(tmpSolution.rows(0, 1));
+        PhysicalStore<Double> tmpExpX = RawStore.wrap(new double[][] { { 5.0 }, { 5.0 } });
+        PhysicalStore<Double> tmpActX = R064Store.FACTORY.copy(tmpSolution.rows(0, 1));
 
         TestUtils.assertEquals(tmpExpX, tmpActX);
     }
@@ -314,10 +332,10 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
     @Test
     public void test6LinearModelCase() {
 
-        Variable[] tmpVariables = { new Variable("X1").lower(ZERO).weight(ONE), new Variable("X2").lower(ZERO).weight(TWO),
-                new Variable("X3").lower(ZERO).weight(THREE) };
+        ExpressionsBasedModel tmpModel = new ExpressionsBasedModel();
 
-        ExpressionsBasedModel tmpModel = new ExpressionsBasedModel(tmpVariables);
+        Variable[] tmpVariables = { tmpModel.newVariable("X1").lower(ZERO).weight(ONE), tmpModel.newVariable("X2").lower(ZERO).weight(TWO),
+                tmpModel.newVariable("X3").lower(ZERO).weight(THREE) };
 
         Optimisation.Result tmpResult = tmpModel.maximise();
 
@@ -330,9 +348,9 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
     @Test
     public void test7LinearModelCase() {
 
-        Variable[] variables = { new Variable("X1").lower(ZERO).weight(TWO), new Variable("X2").lower(ZERO).weight(THREE) };
+        ExpressionsBasedModel model = new ExpressionsBasedModel();
 
-        ExpressionsBasedModel model = new ExpressionsBasedModel(variables);
+        Variable[] variables = { model.newVariable("X1").lower(ZERO).weight(TWO), model.newVariable("X2").lower(ZERO).weight(THREE) };
 
         BigDecimal[] paramC1 = { ONE, ONE };
         Expression exprC1 = model.newExpression("C1");
@@ -398,10 +416,10 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
     @Test
     public void testInfeasibleCase() {
 
-        Variable[] tmpVariables = { new Variable("X1").lower(ONE).weight(ONE), new Variable("X2").lower(ONE).weight(TWO),
-                new Variable("X3").lower(ONE).weight(THREE) };
+        ExpressionsBasedModel tmpModel = new ExpressionsBasedModel();
 
-        ExpressionsBasedModel tmpModel = new ExpressionsBasedModel(tmpVariables);
+        Variable[] tmpVariables = { tmpModel.newVariable("X1").lower(ONE).weight(ONE), tmpModel.newVariable("X2").lower(ONE).weight(TWO),
+                tmpModel.newVariable("X3").lower(ONE).weight(THREE) };
 
         Expression tmpExprC1 = tmpModel.newExpression("C1");
         for (int i = 0; i < tmpModel.countVariables(); i++) {
@@ -421,11 +439,10 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
         ExpressionsBasedModel tmpModel = LinearDesignTestCases.buildOldKnapsackTestModel();
 
         Optimisation.Result tmpResult = tmpModel.maximise();
-        MatrixQ128 tmpSolution = MatrixQ128.FACTORY.columns(tmpResult);
+        MatrixQ128 tmpSolution = MatrixQ128.FACTORY.column(tmpResult);
 
-        MatrixStore<Double> tmpExpX = Primitive64Store.FACTORY
-                .rows(new double[][] { { 0.0 }, { 0.0 }, { 0.1846 }, { 0.0 }, { 0.0 }, { 0.0 }, { 0.8154 }, { 0.0 } });
-        MatrixStore<Double> tmpActX = Primitive64Store.FACTORY.copy(tmpSolution.rows(0, 1, 2, 3, 4, 5, 6, 7));
+        MatrixStore<Double> tmpExpX = RawStore.wrap(new double[][] { { 0.0 }, { 0.0 }, { 0.1846 }, { 0.0 }, { 0.0 }, { 0.0 }, { 0.8154 }, { 0.0 } });
+        MatrixStore<Double> tmpActX = R064Store.FACTORY.copy(tmpSolution.rows(0, 1, 2, 3, 4, 5, 6, 7));
 
         TestUtils.assertEquals(tmpExpX, tmpActX);
     }
@@ -436,11 +453,10 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
         ExpressionsBasedModel tmpModel = LinearDesignTestCases.buildOldKnapsackTestModel();
 
         Optimisation.Result tmpResult = tmpModel.minimise();
-        MatrixQ128 tmpSolution = MatrixQ128.FACTORY.columns(tmpResult);
+        MatrixQ128 tmpSolution = MatrixQ128.FACTORY.column(tmpResult);
 
-        MatrixStore<Double> tmpExpX = Primitive64Store.FACTORY
-                .rows(new double[][] { { 0.0 }, { 0.8154 }, { 0.1846 }, { 0.0 }, { 0.0 }, { 0.0 }, { 0.0 }, { 0.0 } });
-        MatrixStore<Double> tmpActX = Primitive64Store.FACTORY.copy(tmpSolution.rows(0, 1, 2, 3, 4, 5, 6, 7));
+        MatrixStore<Double> tmpExpX = RawStore.wrap(new double[][] { { 0.0 }, { 0.8154 }, { 0.1846 }, { 0.0 }, { 0.0 }, { 0.0 }, { 0.0 }, { 0.0 } });
+        MatrixStore<Double> tmpActX = R064Store.FACTORY.copy(tmpSolution.rows(0, 1, 2, 3, 4, 5, 6, 7));
 
         TestUtils.assertEquals(tmpExpX, tmpActX);
     }
@@ -455,22 +471,18 @@ public class LinearDesignTestCases extends OptimisationLinearTests {
     @Test
     public void testP20130409b() {
 
-        Variable x1 = Variable.make("x1");
-        Variable x2013 = Variable.make("x2013");
-        Variable x2014 = Variable.make("x2014");
-        Variable x2015 = Variable.make("x2015");
+        ExpressionsBasedModel model = new ExpressionsBasedModel();
+
+        Variable x1 = model.newVariable("x1");
+        Variable x2013 = model.newVariable("x2013");
+        Variable x2014 = model.newVariable("x2014");
+        Variable x2015 = model.newVariable("x2015");
         //      x2013.setInteger(true);
         //      x2014.setInteger(true);
         //      x2015.setInteger(true);
         x2013.lower(BigDecimal.valueOf(1245L));
         x2014.lower(BigDecimal.valueOf(1269L));
 
-        ExpressionsBasedModel model = new ExpressionsBasedModel();
-        model.addVariable(x1);
-        model.addVariable(x2013);
-        model.addVariable(x2014);
-        model.addVariable(x2015);
-
         Expression obj = model.newExpression("obj");
         obj.set(x1, 1);
         obj.weight(BigDecimal.valueOf(1));
