@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2022 Optimatika
+ * Copyright 1997-2024 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -27,17 +27,22 @@ import java.math.BigDecimal;
 
 import org.junit.jupiter.api.Test;
 import org.ojalgo.TestUtils;
-import org.ojalgo.array.ArrayR128;
+import org.ojalgo.array.ArrayR256;
 import org.ojalgo.function.constant.BigMath;
-import org.ojalgo.matrix.Primitive64Matrix;
-import org.ojalgo.matrix.RationalMatrix;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.MatrixQ128;
+import org.ojalgo.matrix.MatrixR064;
+import org.ojalgo.matrix.store.R064Store;
+import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.optimisation.Expression;
 import org.ojalgo.optimisation.ExpressionsBasedModel;
+import org.ojalgo.optimisation.ModelFileTest;
 import org.ojalgo.optimisation.Optimisation;
 import org.ojalgo.optimisation.Optimisation.Result;
+import org.ojalgo.optimisation.Optimisation.Sense;
 import org.ojalgo.optimisation.Optimisation.State;
+import org.ojalgo.optimisation.OptimisationCase;
 import org.ojalgo.optimisation.Variable;
+import org.ojalgo.optimisation.integer.IntegerProblems;
 import org.ojalgo.optimisation.integer.OptimisationIntegerData;
 import org.ojalgo.optimisation.integer.P20150127b;
 import org.ojalgo.type.TypeUtils;
@@ -47,6 +52,21 @@ public class LinearProblems extends OptimisationLinearTests {
 
     private static final NumberContext ACCURACY = NumberContext.of(7, 6);
 
+    /**
+     * https://github.com/optimatika/ojAlgo/issues/546
+     */
+    static OptimisationCase makeGitHub546() {
+
+        // INFEASIBLE 8.5755E8 @ { 7.84804E+8, 0, 0, 7.2746E+7 }
+        // OPTIMAL    8.5755E8 @ { 7.84804E+8, 0, 0, 7.2746E+7 }
+
+        Optimisation.Result result = Result.of(8.5755E8, State.OPTIMAL, 7.84804E+8, 0, 0, 7.2746E+7);
+
+        ExpressionsBasedModel model = ModelFileTest.makeModel("usersupplied", "GitHub546.ebm", false);
+
+        return OptimisationCase.of(model, Sense.MIN, result);
+    }
+
     /**
      * https://github.com/optimatika/ojAlgo/issues/117 <br>
      * Problem was getting different state after second solve.
@@ -55,21 +75,21 @@ public class LinearProblems extends OptimisationLinearTests {
     public void precisionTestDoubleRunInfeasible() {
 
         ExpressionsBasedModel model = new ExpressionsBasedModel();
-        Variable d35 = model.addVariable("d35");
-        Variable d56 = model.addVariable("d56");
-        Variable d57 = model.addVariable("d57");
+        Variable d35 = model.newVariable("d35");
+        Variable d56 = model.newVariable("d56");
+        Variable d57 = model.newVariable("d57");
 
         // d35 = 0.0;
         d35.level(0.0);
 
         // d56 - d35 = -2000.0400000000002;
-        Expression expression1 = model.addExpression("d56 - d35");
+        Expression expression1 = model.newExpression("d56 - d35");
         expression1.set(d56, 1.0);
         expression1.set(d35, -1.0);
         expression1.level(-2000.0400000000002);
 
         // d57 - d56 = 0.0;
-        Expression expression2 = model.addExpression("d57 - d56");
+        Expression expression2 = model.newExpression("d57 - d56");
         expression2.set(d57, 1.0);
         expression2.set(d56, -1.0);
         expression2.level(0.0);
@@ -86,23 +106,69 @@ public class LinearProblems extends OptimisationLinearTests {
         TestUtils.assertStateAndSolution(result1, result2);
     }
 
+    /**
+     * https://github.com/optimatika/ojAlgo/discussions/513
+     * <p>
+     * The key problem was that the LP solver failed to solve a (the root) sub-problem. It failed in the worst
+     * possible way – returned a constraint breaking solution but still reported it to be optimal. This test
+     * case reproduces that node model.
+     */
+    @Test
+    public void testGitHub513() {
+
+        ExpressionsBasedModel model = IntegerProblems.makeModelGitHub513();
+
+        Result solutionMIP = Result.of(-97.59, State.OPTIMAL, 0, 1, 0, 1, 0, 1, 1, 0);
+
+        // nudge 9.758999999999999E-5 -> lower constraint = -97.58990241
+
+        // Convert to LP node model
+        model.relax();
+        model.limitObjective(BigDecimal.valueOf(-97.58990241), null);
+
+        if (DEBUG) {
+            model.options.debug(LinearSolver.class);
+        }
+
+        Result actual = model.maximise();
+
+        if (DEBUG) {
+            BasicLogger.debug(actual);
+            BasicLogger.debug(model);
+            model.validate(actual, BasicLogger.DEBUG);
+        }
+
+        TestUtils.assertStateLessThanFeasible(actual);
+    }
+
+    /**
+     * https://github.com/optimatika/ojAlgo/issues/546
+     */
+    @Test
+    public void testGitHub546() {
+        LinearProblems.makeGitHub546().assertResult();
+    }
+
     @Test
     public void testMath286() {
 
-        Variable tmpX1 = new Variable("X1").weight(TENTH.multiply(EIGHT)).lower(TEN);
-        Variable tmpX2 = new Variable("X2").weight(TENTH.multiply(TWO)).lower(ZERO);
-        Variable tmpX3 = new Variable("X3").weight(TENTH.multiply(SEVEN)).lower(EIGHT);
-        Variable tmpX4 = new Variable("X4").weight(TENTH.multiply(THREE)).lower(ZERO);
-        Variable tmpX5 = new Variable("X5").weight(TENTH.multiply(SIX)).lower(FIVE);
-        Variable tmpX6 = new Variable("X6").weight(TENTH.multiply(FOUR)).lower(ZERO);
+        ExpressionsBasedModel modFull = new ExpressionsBasedModel();
+        ExpressionsBasedModel modOdd = new ExpressionsBasedModel();
+        ExpressionsBasedModel modEven = new ExpressionsBasedModel();
 
-        Variable[] varsFull = new Variable[] { tmpX1.copy(), tmpX2.copy(), tmpX3.copy(), tmpX4.copy(), tmpX5.copy(), tmpX6.copy() };
-        Variable[] varsOdd = new Variable[] { tmpX1.copy(), tmpX3.copy(), tmpX5.copy() };
-        Variable[] varsEven = new Variable[] { tmpX2.copy(), tmpX4.copy(), tmpX6.copy() };
+        modFull.newVariable("X1").weight(TENTH.multiply(EIGHT)).lower(TEN);
+        modFull.newVariable("X2").weight(TENTH.multiply(TWO)).lower(ZERO);
+        modFull.newVariable("X3").weight(TENTH.multiply(SEVEN)).lower(EIGHT);
+        modFull.newVariable("X4").weight(TENTH.multiply(THREE)).lower(ZERO);
+        modFull.newVariable("X5").weight(TENTH.multiply(SIX)).lower(FIVE);
+        modFull.newVariable("X6").weight(TENTH.multiply(FOUR)).lower(ZERO);
 
-        ExpressionsBasedModel modFull = new ExpressionsBasedModel(varsFull);
-        ExpressionsBasedModel modOdd = new ExpressionsBasedModel(varsOdd);
-        ExpressionsBasedModel modEven = new ExpressionsBasedModel(varsEven);
+        modOdd.newVariable("X1").weight(TENTH.multiply(EIGHT)).lower(TEN);
+        modEven.newVariable("X2").weight(TENTH.multiply(TWO)).lower(ZERO);
+        modOdd.newVariable("X3").weight(TENTH.multiply(SEVEN)).lower(EIGHT);
+        modEven.newVariable("X4").weight(TENTH.multiply(THREE)).lower(ZERO);
+        modOdd.newVariable("X5").weight(TENTH.multiply(SIX)).lower(FIVE);
+        modEven.newVariable("X6").weight(TENTH.multiply(FOUR)).lower(ZERO);
 
         //        modFull.options.debug(LinearSolver.class);
         //        modOdd.options.debug(LinearSolver.class);
@@ -110,25 +176,25 @@ public class LinearProblems extends OptimisationLinearTests {
 
         BigDecimal tmpRHS = new BigDecimal("23.0");
 
-        Expression constr1Full = modFull.addExpression("C1");
+        Expression constr1Full = modFull.newExpression("C1");
         for (int i = 0; i < modFull.countVariables(); i++) {
             constr1Full.set(i, new BigDecimal[] { ONE, ZERO, ONE, ZERO, ONE, ZERO }[i]);
         }
         constr1Full.level(tmpRHS);
 
-        Expression constr1Odd = modOdd.addExpression("C1");
+        Expression constr1Odd = modOdd.newExpression("C1");
         for (int i = 0; i < modOdd.countVariables(); i++) {
             constr1Odd.set(i, new BigDecimal[] { ONE, ONE, ONE }[i]);
         }
         constr1Odd.level(tmpRHS);
 
-        Expression constr2Full = modFull.addExpression("C2");
+        Expression constr2Full = modFull.newExpression("C2");
         for (int i = 0; i < modFull.countVariables(); i++) {
             constr2Full.set(i, new BigDecimal[] { ZERO, ONE, ZERO, ONE, ZERO, ONE }[i]);
         }
         constr2Full.level(tmpRHS);
 
-        Expression constr2Even = modEven.addExpression("C2");
+        Expression constr2Even = modEven.newExpression("C2");
         for (int i = 0; i < modEven.countVariables(); i++) {
             constr2Even.set(i, new BigDecimal[] { ONE, ONE, ONE }[i]);
         }
@@ -138,18 +204,19 @@ public class LinearProblems extends OptimisationLinearTests {
         // X1=10, X2=0, X3=8, X4=0, X5=5, X6=23
         BigDecimal claimedValue = new BigDecimal("25.8");
 
-        Primitive64Matrix.DenseReceiver solutionBuilder = Primitive64Matrix.FACTORY.makeDense(6, 1);
+        MatrixR064.DenseReceiver solutionBuilder = MatrixR064.FACTORY.newDenseBuilder(6, 1);
         solutionBuilder.set(0, 0, 10);
         solutionBuilder.set(2, 0, 8);
         solutionBuilder.set(4, 0, 5);
         solutionBuilder.set(5, 0, 23);
-        Primitive64Matrix claimedSolutionFull = solutionBuilder.get();
-        Primitive64Matrix claimedSolutionOdd = claimedSolutionFull.rows(new int[] { 0, 2, 4 });
-        Primitive64Matrix claimedSolutionEven = claimedSolutionFull.rows(new int[] { 1, 3, 5 });
 
-        TestUtils.assertEquals("Claimed solution not valid!", true, modFull.validate(ArrayR128.FACTORY.copy(claimedSolutionFull), ACCURACY));
+        MatrixR064 claimedSolutionFull = solutionBuilder.get();
+        MatrixR064 claimedSolutionOdd = claimedSolutionFull.rows(0, 2, 4);
+        MatrixR064 claimedSolutionEven = claimedSolutionFull.rows(1, 3, 5);
 
-        Double tmpActualValue = modFull.objective().toFunction().invoke(Primitive64Store.FACTORY.copy(claimedSolutionFull));
+        TestUtils.assertEquals("Claimed solution not valid!", true, modFull.validate(ArrayR256.FACTORY.copy(claimedSolutionFull), ACCURACY));
+
+        Double tmpActualValue = modFull.objective().toFunction().invoke(R064Store.FACTORY.copy(claimedSolutionFull));
         //  BigDecimal tmpActualValue = TypeUtils.toBigDecimal(tmpObjectiveValue);
         //JUnitUtils.assertEquals("Claimed objective value wrong!", 0, tmpClaimedValue.compareTo(tmpActualValue));
         TestUtils.assertEquals(claimedValue, tmpActualValue, ACCURACY);
@@ -165,21 +232,21 @@ public class LinearProblems extends OptimisationLinearTests {
         TestUtils.assertEquals(true, modFull.validate(tmpFullResult, ACCURACY));
         int[] someRows2 = { 0, 1, 2 };
 
-        TestUtils.assertEquals(claimedSolutionEven, RationalMatrix.FACTORY.columns(tmpEvenResult).rows(someRows2), ACCURACY);
+        TestUtils.assertEquals(claimedSolutionEven, MatrixQ128.FACTORY.column(tmpEvenResult).rows(someRows2), ACCURACY);
         int[] someRows3 = { 0, 1, 2 };
-        TestUtils.assertEquals(claimedSolutionOdd, RationalMatrix.FACTORY.columns(tmpOddResult).rows(someRows3), ACCURACY);
+        TestUtils.assertEquals(claimedSolutionOdd, MatrixQ128.FACTORY.column(tmpOddResult).rows(someRows3), ACCURACY);
         int[] someRows4 = { 0, 1, 2, 3, 4, 5 };
-        TestUtils.assertEquals(claimedSolutionFull, RationalMatrix.FACTORY.columns(tmpFullResult).rows(someRows4), ACCURACY);
+        TestUtils.assertEquals(claimedSolutionFull, MatrixQ128.FACTORY.column(tmpFullResult).rows(someRows4), ACCURACY);
         int[] someRows5 = { 0, 1, 2 };
 
-        BigDecimal tmpEvenValue = ACCURACY.enforce(TypeUtils.toBigDecimal(
-                modEven.objective().toFunction().invoke(Primitive64Store.FACTORY.copy(Primitive64Matrix.FACTORY.columns(tmpEvenResult).rows(someRows5)))));
+        BigDecimal tmpEvenValue = ACCURACY.enforce(TypeUtils
+                .toBigDecimal(modEven.objective().toFunction().invoke(R064Store.FACTORY.copy(MatrixR064.FACTORY.column(tmpEvenResult).rows(someRows5)))));
         int[] someRows6 = { 0, 1, 2 };
-        BigDecimal tmpOddValue = ACCURACY.enforce(TypeUtils.toBigDecimal(
-                modOdd.objective().toFunction().invoke(Primitive64Store.FACTORY.copy(Primitive64Matrix.FACTORY.columns(tmpOddResult).rows(someRows6)))));
+        BigDecimal tmpOddValue = ACCURACY.enforce(TypeUtils
+                .toBigDecimal(modOdd.objective().toFunction().invoke(R064Store.FACTORY.copy(MatrixR064.FACTORY.column(tmpOddResult).rows(someRows6)))));
         int[] someRows7 = { 0, 1, 2, 3, 4, 5 };
-        BigDecimal tmpFullValue = ACCURACY.enforce(TypeUtils.toBigDecimal(
-                modFull.objective().toFunction().invoke(Primitive64Store.FACTORY.copy(Primitive64Matrix.FACTORY.columns(tmpFullResult).rows(someRows7)))));
+        BigDecimal tmpFullValue = ACCURACY.enforce(TypeUtils
+                .toBigDecimal(modFull.objective().toFunction().invoke(R064Store.FACTORY.copy(MatrixR064.FACTORY.column(tmpFullResult).rows(someRows7)))));
 
         TestUtils.assertEquals(0, tmpFullValue.compareTo(tmpEvenValue.add(tmpOddValue)));
         TestUtils.assertEquals(0, claimedValue.compareTo(tmpFullValue));
@@ -207,30 +274,31 @@ public class LinearProblems extends OptimisationLinearTests {
     @Test
     public void testP20111010() {
 
-        Variable[] tmpVariables = new Variable[] { new Variable("X").lower(ZERO).weight(ONE), new Variable("Y").lower(ZERO).weight(ZERO),
-                new Variable("Z").lower(ZERO).weight(ZERO) };
-        ExpressionsBasedModel tmpModel = new ExpressionsBasedModel(tmpVariables);
+        ExpressionsBasedModel tmpModel = new ExpressionsBasedModel();
 
-        Expression tmpExprC1 = tmpModel.addExpression("C1");
+        Variable[] tmpVariables = { tmpModel.newVariable("X").lower(ZERO).weight(ONE), tmpModel.newVariable("Y").lower(ZERO).weight(ZERO),
+                tmpModel.newVariable("Z").lower(ZERO).weight(ZERO) };
+
+        Expression tmpExprC1 = tmpModel.newExpression("C1");
         tmpExprC1.level(ZERO);
         tmpExprC1.set(0, ONE);
 
-        Expression tmpExprC2 = tmpModel.addExpression("C2");
+        Expression tmpExprC2 = tmpModel.newExpression("C2");
         tmpExprC2.level(ZERO);
         tmpExprC2.set(0, ONE);
         tmpExprC2.set(1, NEG);
 
-        Expression tmpExprC3 = tmpModel.addExpression("C3");
+        Expression tmpExprC3 = tmpModel.newExpression("C3");
         tmpExprC3.level(ZERO);
         tmpExprC3.set(0, ONE);
         tmpExprC3.set(2, NEG);
 
-        Primitive64Matrix tmpExpectedSolution = Primitive64Matrix.FACTORY.make(3, 1);
+        MatrixR064 tmpExpectedSolution = MatrixR064.FACTORY.make(3, 1);
 
         Optimisation.Result tmpResult11 = tmpModel.minimise();
         //TestUtils.assertEquals(tmpExpectedState, tmpResult11.getState());
         TestUtils.assertStateNotLessThanOptimal(tmpResult11);
-        TestUtils.assertEquals(tmpExpectedSolution, RationalMatrix.FACTORY.columns(tmpResult11));
+        TestUtils.assertEquals(tmpExpectedSolution, MatrixQ128.FACTORY.column(tmpResult11));
 
         tmpExprC2.set(0, NEG);
         tmpExprC2.set(1, ONE);
@@ -241,7 +309,7 @@ public class LinearProblems extends OptimisationLinearTests {
         Optimisation.Result tmpResultN1 = tmpModel.minimise();
         //TestUtils.assertEquals(tmpExpectedState, tmpResultN1.getState());
         TestUtils.assertStateNotLessThanOptimal(tmpResultN1);
-        TestUtils.assertEquals(tmpExpectedSolution, RationalMatrix.FACTORY.columns(tmpResultN1));
+        TestUtils.assertEquals(tmpExpectedSolution, MatrixQ128.FACTORY.column(tmpResultN1));
 
         tmpExprC2.set(0, ONE);
         tmpExprC2.set(1, NEG);
@@ -252,7 +320,7 @@ public class LinearProblems extends OptimisationLinearTests {
         Optimisation.Result tmpResult1N = tmpModel.minimise();
         //TestUtils.assertEquals(tmpExpectedState, tmpResult1N.getState());
         TestUtils.assertStateNotLessThanOptimal(tmpResult1N);
-        TestUtils.assertEquals(tmpExpectedSolution, RationalMatrix.FACTORY.columns(tmpResult1N));
+        TestUtils.assertEquals(tmpExpectedSolution, MatrixQ128.FACTORY.column(tmpResult1N));
 
         tmpExprC2.set(0, NEG);
         tmpExprC2.set(1, ONE);
@@ -263,7 +331,7 @@ public class LinearProblems extends OptimisationLinearTests {
         Optimisation.Result tmpResultNN = tmpModel.minimise();
         //TestUtils.assertEquals(tmpExpectedState, tmpResultNN.getState());
         TestUtils.assertStateNotLessThanOptimal(tmpResultNN);
-        TestUtils.assertEquals(tmpExpectedSolution, RationalMatrix.FACTORY.columns(tmpResultNN));
+        TestUtils.assertEquals(tmpExpectedSolution, MatrixQ128.FACTORY.column(tmpResultNN));
     }
 
     /**
@@ -292,17 +360,15 @@ public class LinearProblems extends OptimisationLinearTests {
     @Test
     public void testP20180310_61() {
 
-        Variable x = Variable.make("x").lower(0);
-        Variable y = Variable.make("y").lower(0);
-
         ExpressionsBasedModel model = new ExpressionsBasedModel();
-        model.addVariable(x);
-        model.addVariable(y);
 
-        model.addExpression("first").set(x, 2).set(y, 3).upper(1);
-        model.addExpression("second").set(x, -2).set(y, 3).lower(1);
+        Variable x = model.newVariable("x").lower(0);
+        Variable y = model.newVariable("y").lower(0);
 
-        ArrayR128 expected = ArrayR128.wrap(BigMath.ZERO, BigMath.THIRD);
+        model.newExpression("first").set(x, 2).set(y, 3).upper(1);
+        model.newExpression("second").set(x, -2).set(y, 3).lower(1);
+
+        ArrayR256 expected = ArrayR256.wrap(BigMath.ZERO, BigMath.THIRD);
 
         Optimisation.Result result = model.maximise();
         TestUtils.assertEquals(expected, result);
@@ -316,15 +382,13 @@ public class LinearProblems extends OptimisationLinearTests {
     @Test
     public void testP20180310_62() {
 
-        Variable x = Variable.make("x").lower(0).weight(1);
-        Variable y = Variable.make("y").lower(0).weight(0);
-
         ExpressionsBasedModel model = new ExpressionsBasedModel();
-        model.addVariable(x);
-        model.addVariable(y);
 
-        model.addExpression("first").set(x, 0).set(y, 1).lower(1);
-        model.addExpression("second").set(x, 0).set(y, 1).upper(-1);
+        Variable x = model.newVariable("x").lower(0).weight(1);
+        Variable y = model.newVariable("y").lower(0).weight(0);
+
+        model.newExpression("first").set(x, 0).set(y, 1).lower(1);
+        model.newExpression("second").set(x, 0).set(y, 1).upper(-1);
 
         TestUtils.assertEquals(Optimisation.State.INFEASIBLE, model.maximise().getState());
 
@@ -336,17 +400,15 @@ public class LinearProblems extends OptimisationLinearTests {
     @Test
     public void testP20180311_64() {
 
-        Variable x = Variable.make("x").lower(0).weight(3);
-        Variable y = Variable.make("y").lower(0).weight(-2);
-
         ExpressionsBasedModel model = new ExpressionsBasedModel();
-        model.addVariable(x);
-        model.addVariable(y);
+
+        Variable x = model.newVariable("x").lower(0).weight(3);
+        Variable y = model.newVariable("y").lower(0).weight(-2);
 
         model.addExpression().set(x, -1).set(y, 0).lower(0);
         model.addExpression().set(x, -1).set(y, 3).level(2);
 
-        ArrayR128 expected = ArrayR128.wrap(BigMath.ZERO, BigMath.TWO.multiply(BigMath.THIRD));
+        ArrayR256 expected = ArrayR256.wrap(BigMath.ZERO, BigMath.TWO.multiply(BigMath.THIRD));
 
         Optimisation.Result result = model.maximise();
         TestUtils.assertEquals(expected, result);
@@ -360,14 +422,11 @@ public class LinearProblems extends OptimisationLinearTests {
     @Test
     public void testP20180311_66() {
 
-        Variable x = Variable.make("x").lower(0).weight(2);
-        Variable y = Variable.make("y").lower(0).weight(-1);
-        Variable z = Variable.make("z").lower(0).weight(4);
-
         ExpressionsBasedModel model = new ExpressionsBasedModel();
-        model.addVariable(x);
-        model.addVariable(y);
-        model.addVariable(z);
+
+        Variable x = model.newVariable("x").lower(0).weight(2);
+        Variable y = model.newVariable("y").lower(0).weight(-1);
+        Variable z = model.newVariable("z").lower(0).weight(4);
 
         model.addExpression().set(x, 3).set(y, 2).set(z, 2).upper(0);
         model.addExpression().set(x, 0).set(y, 3).set(z, -2).lower(2);
@@ -384,14 +443,11 @@ public class LinearProblems extends OptimisationLinearTests {
     @Test
     public void testP20180312_69() {
 
-        Variable x = Variable.make("x").lower(0).weight(3);
-        Variable y = Variable.make("y").lower(0).weight(2);
-        Variable z = Variable.make("z").lower(0).weight(-2);
-
         ExpressionsBasedModel model = new ExpressionsBasedModel();
-        model.addVariable(x);
-        model.addVariable(y);
-        model.addVariable(z);
+
+        Variable x = model.newVariable("x").lower(0).weight(3);
+        Variable y = model.newVariable("y").lower(0).weight(2);
+        Variable z = model.newVariable("z").lower(0).weight(-2);
 
         model.addExpression().set(x, 0).set(y, 1).set(z, -2).level(4);
         model.addExpression().set(x, 0).set(y, 4).set(z, -2).upper(1);
@@ -411,18 +467,16 @@ public class LinearProblems extends OptimisationLinearTests {
     @Test
     public void testP20180314_70() {
 
-        Variable x = Variable.make("x").lower(0).weight(-2);
-        Variable y = Variable.make("y").lower(0).weight(-2);
-
         ExpressionsBasedModel model = new ExpressionsBasedModel();
-        model.addVariable(x);
-        model.addVariable(y);
+
+        Variable x = model.newVariable("x").lower(0).weight(-2);
+        Variable y = model.newVariable("y").lower(0).weight(-2);
 
         model.addExpression().set(x, 3).set(y, 0).lower(2);
         model.addExpression().set(x, 1).set(y, 2).lower(-5);
         model.addExpression().set(x, 3).set(y, 1).upper(2);
 
-        ArrayR128 expected = ArrayR128.wrap(DIVIDE.invoke(TWO, THREE), ZERO);
+        ArrayR256 expected = ArrayR256.wrap(DIVIDE.invoke(TWO, THREE), ZERO);
         TestUtils.assertTrue(model.validate(expected));
 
         Optimisation.Result solution = model.maximise();
